# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params import (
        apps as apps,
        billing as billing,
        billing_portal as billing_portal,
        capital as capital,
        checkout as checkout,
        climate as climate,
        delegated_checkout as delegated_checkout,
        entitlements as entitlements,
        financial_connections as financial_connections,
        forwarding as forwarding,
        identity as identity,
        issuing as issuing,
        privacy as privacy,
        radar as radar,
        reporting as reporting,
        sigma as sigma,
        tax as tax,
        terminal as terminal,
        test_helpers as test_helpers,
        treasury as treasury,
    )
    from stripe.params._account_capability_list_params import (
        AccountCapabilityListParams as AccountCapabilityListParams,
    )
    from stripe.params._account_capability_retrieve_params import (
        AccountCapabilityRetrieveParams as AccountCapabilityRetrieveParams,
    )
    from stripe.params._account_capability_update_params import (
        AccountCapabilityUpdateParams as AccountCapabilityUpdateParams,
    )
    from stripe.params._account_create_external_account_params import (
        AccountCreateExternalAccountParams as AccountCreateExternalAccountParams,
        AccountCreateExternalAccountParamsBankAccount as AccountCreateExternalAccountParamsBankAccount,
        AccountCreateExternalAccountParamsCard as AccountCreateExternalAccountParamsCard,
        AccountCreateExternalAccountParamsCardToken as AccountCreateExternalAccountParamsCardToken,
    )
    from stripe.params._account_create_login_link_params import (
        AccountCreateLoginLinkParams as AccountCreateLoginLinkParams,
    )
    from stripe.params._account_create_params import (
        AccountCreateParams as AccountCreateParams,
        AccountCreateParamsBankAccount as AccountCreateParamsBankAccount,
        AccountCreateParamsBusinessProfile as AccountCreateParamsBusinessProfile,
        AccountCreateParamsBusinessProfileAnnualRevenue as AccountCreateParamsBusinessProfileAnnualRevenue,
        AccountCreateParamsBusinessProfileMonthlyEstimatedRevenue as AccountCreateParamsBusinessProfileMonthlyEstimatedRevenue,
        AccountCreateParamsBusinessProfileSupportAddress as AccountCreateParamsBusinessProfileSupportAddress,
        AccountCreateParamsCapabilities as AccountCreateParamsCapabilities,
        AccountCreateParamsCapabilitiesAcssDebitPayments as AccountCreateParamsCapabilitiesAcssDebitPayments,
        AccountCreateParamsCapabilitiesAffirmPayments as AccountCreateParamsCapabilitiesAffirmPayments,
        AccountCreateParamsCapabilitiesAfterpayClearpayPayments as AccountCreateParamsCapabilitiesAfterpayClearpayPayments,
        AccountCreateParamsCapabilitiesAlmaPayments as AccountCreateParamsCapabilitiesAlmaPayments,
        AccountCreateParamsCapabilitiesAmazonPayPayments as AccountCreateParamsCapabilitiesAmazonPayPayments,
        AccountCreateParamsCapabilitiesAuBecsDebitPayments as AccountCreateParamsCapabilitiesAuBecsDebitPayments,
        AccountCreateParamsCapabilitiesAutomaticIndirectTax as AccountCreateParamsCapabilitiesAutomaticIndirectTax,
        AccountCreateParamsCapabilitiesBacsDebitPayments as AccountCreateParamsCapabilitiesBacsDebitPayments,
        AccountCreateParamsCapabilitiesBancontactPayments as AccountCreateParamsCapabilitiesBancontactPayments,
        AccountCreateParamsCapabilitiesBankTransferPayments as AccountCreateParamsCapabilitiesBankTransferPayments,
        AccountCreateParamsCapabilitiesBilliePayments as AccountCreateParamsCapabilitiesBilliePayments,
        AccountCreateParamsCapabilitiesBlikPayments as AccountCreateParamsCapabilitiesBlikPayments,
        AccountCreateParamsCapabilitiesBoletoPayments as AccountCreateParamsCapabilitiesBoletoPayments,
        AccountCreateParamsCapabilitiesCardIssuing as AccountCreateParamsCapabilitiesCardIssuing,
        AccountCreateParamsCapabilitiesCardPayments as AccountCreateParamsCapabilitiesCardPayments,
        AccountCreateParamsCapabilitiesCartesBancairesPayments as AccountCreateParamsCapabilitiesCartesBancairesPayments,
        AccountCreateParamsCapabilitiesCashappPayments as AccountCreateParamsCapabilitiesCashappPayments,
        AccountCreateParamsCapabilitiesCryptoPayments as AccountCreateParamsCapabilitiesCryptoPayments,
        AccountCreateParamsCapabilitiesEpsPayments as AccountCreateParamsCapabilitiesEpsPayments,
        AccountCreateParamsCapabilitiesFpxPayments as AccountCreateParamsCapabilitiesFpxPayments,
        AccountCreateParamsCapabilitiesGbBankTransferPayments as AccountCreateParamsCapabilitiesGbBankTransferPayments,
        AccountCreateParamsCapabilitiesGiropayPayments as AccountCreateParamsCapabilitiesGiropayPayments,
        AccountCreateParamsCapabilitiesGopayPayments as AccountCreateParamsCapabilitiesGopayPayments,
        AccountCreateParamsCapabilitiesGrabpayPayments as AccountCreateParamsCapabilitiesGrabpayPayments,
        AccountCreateParamsCapabilitiesIdBankTransferPayments as AccountCreateParamsCapabilitiesIdBankTransferPayments,
        AccountCreateParamsCapabilitiesIdBankTransferPaymentsBca as AccountCreateParamsCapabilitiesIdBankTransferPaymentsBca,
        AccountCreateParamsCapabilitiesIdealPayments as AccountCreateParamsCapabilitiesIdealPayments,
        AccountCreateParamsCapabilitiesIndiaInternationalPayments as AccountCreateParamsCapabilitiesIndiaInternationalPayments,
        AccountCreateParamsCapabilitiesJcbPayments as AccountCreateParamsCapabilitiesJcbPayments,
        AccountCreateParamsCapabilitiesJpBankTransferPayments as AccountCreateParamsCapabilitiesJpBankTransferPayments,
        AccountCreateParamsCapabilitiesKakaoPayPayments as AccountCreateParamsCapabilitiesKakaoPayPayments,
        AccountCreateParamsCapabilitiesKlarnaPayments as AccountCreateParamsCapabilitiesKlarnaPayments,
        AccountCreateParamsCapabilitiesKonbiniPayments as AccountCreateParamsCapabilitiesKonbiniPayments,
        AccountCreateParamsCapabilitiesKrCardPayments as AccountCreateParamsCapabilitiesKrCardPayments,
        AccountCreateParamsCapabilitiesLegacyPayments as AccountCreateParamsCapabilitiesLegacyPayments,
        AccountCreateParamsCapabilitiesLinkPayments as AccountCreateParamsCapabilitiesLinkPayments,
        AccountCreateParamsCapabilitiesMbWayPayments as AccountCreateParamsCapabilitiesMbWayPayments,
        AccountCreateParamsCapabilitiesMobilepayPayments as AccountCreateParamsCapabilitiesMobilepayPayments,
        AccountCreateParamsCapabilitiesMultibancoPayments as AccountCreateParamsCapabilitiesMultibancoPayments,
        AccountCreateParamsCapabilitiesMxBankTransferPayments as AccountCreateParamsCapabilitiesMxBankTransferPayments,
        AccountCreateParamsCapabilitiesNaverPayPayments as AccountCreateParamsCapabilitiesNaverPayPayments,
        AccountCreateParamsCapabilitiesNzBankAccountBecsDebitPayments as AccountCreateParamsCapabilitiesNzBankAccountBecsDebitPayments,
        AccountCreateParamsCapabilitiesOxxoPayments as AccountCreateParamsCapabilitiesOxxoPayments,
        AccountCreateParamsCapabilitiesP24Payments as AccountCreateParamsCapabilitiesP24Payments,
        AccountCreateParamsCapabilitiesPayByBankPayments as AccountCreateParamsCapabilitiesPayByBankPayments,
        AccountCreateParamsCapabilitiesPaycoPayments as AccountCreateParamsCapabilitiesPaycoPayments,
        AccountCreateParamsCapabilitiesPaynowPayments as AccountCreateParamsCapabilitiesPaynowPayments,
        AccountCreateParamsCapabilitiesPaypalPayments as AccountCreateParamsCapabilitiesPaypalPayments,
        AccountCreateParamsCapabilitiesPaypayPayments as AccountCreateParamsCapabilitiesPaypayPayments,
        AccountCreateParamsCapabilitiesPaytoPayments as AccountCreateParamsCapabilitiesPaytoPayments,
        AccountCreateParamsCapabilitiesPixPayments as AccountCreateParamsCapabilitiesPixPayments,
        AccountCreateParamsCapabilitiesPromptpayPayments as AccountCreateParamsCapabilitiesPromptpayPayments,
        AccountCreateParamsCapabilitiesQrisPayments as AccountCreateParamsCapabilitiesQrisPayments,
        AccountCreateParamsCapabilitiesRechnungPayments as AccountCreateParamsCapabilitiesRechnungPayments,
        AccountCreateParamsCapabilitiesRevolutPayPayments as AccountCreateParamsCapabilitiesRevolutPayPayments,
        AccountCreateParamsCapabilitiesSamsungPayPayments as AccountCreateParamsCapabilitiesSamsungPayPayments,
        AccountCreateParamsCapabilitiesSatispayPayments as AccountCreateParamsCapabilitiesSatispayPayments,
        AccountCreateParamsCapabilitiesSepaBankTransferPayments as AccountCreateParamsCapabilitiesSepaBankTransferPayments,
        AccountCreateParamsCapabilitiesSepaDebitPayments as AccountCreateParamsCapabilitiesSepaDebitPayments,
        AccountCreateParamsCapabilitiesShopeepayPayments as AccountCreateParamsCapabilitiesShopeepayPayments,
        AccountCreateParamsCapabilitiesSofortPayments as AccountCreateParamsCapabilitiesSofortPayments,
        AccountCreateParamsCapabilitiesStripeBalancePayments as AccountCreateParamsCapabilitiesStripeBalancePayments,
        AccountCreateParamsCapabilitiesSwishPayments as AccountCreateParamsCapabilitiesSwishPayments,
        AccountCreateParamsCapabilitiesTaxReportingUs1099K as AccountCreateParamsCapabilitiesTaxReportingUs1099K,
        AccountCreateParamsCapabilitiesTaxReportingUs1099Misc as AccountCreateParamsCapabilitiesTaxReportingUs1099Misc,
        AccountCreateParamsCapabilitiesTransfers as AccountCreateParamsCapabilitiesTransfers,
        AccountCreateParamsCapabilitiesTreasury as AccountCreateParamsCapabilitiesTreasury,
        AccountCreateParamsCapabilitiesTreasuryEvolve as AccountCreateParamsCapabilitiesTreasuryEvolve,
        AccountCreateParamsCapabilitiesTreasuryFifthThird as AccountCreateParamsCapabilitiesTreasuryFifthThird,
        AccountCreateParamsCapabilitiesTreasuryGoldmanSachs as AccountCreateParamsCapabilitiesTreasuryGoldmanSachs,
        AccountCreateParamsCapabilitiesTwintPayments as AccountCreateParamsCapabilitiesTwintPayments,
        AccountCreateParamsCapabilitiesUsBankAccountAchPayments as AccountCreateParamsCapabilitiesUsBankAccountAchPayments,
        AccountCreateParamsCapabilitiesUsBankTransferPayments as AccountCreateParamsCapabilitiesUsBankTransferPayments,
        AccountCreateParamsCapabilitiesZipPayments as AccountCreateParamsCapabilitiesZipPayments,
        AccountCreateParamsCard as AccountCreateParamsCard,
        AccountCreateParamsCardToken as AccountCreateParamsCardToken,
        AccountCreateParamsCompany as AccountCreateParamsCompany,
        AccountCreateParamsCompanyAddress as AccountCreateParamsCompanyAddress,
        AccountCreateParamsCompanyAddressKana as AccountCreateParamsCompanyAddressKana,
        AccountCreateParamsCompanyAddressKanji as AccountCreateParamsCompanyAddressKanji,
        AccountCreateParamsCompanyDirectorshipDeclaration as AccountCreateParamsCompanyDirectorshipDeclaration,
        AccountCreateParamsCompanyOwnershipDeclaration as AccountCreateParamsCompanyOwnershipDeclaration,
        AccountCreateParamsCompanyRegistrationDate as AccountCreateParamsCompanyRegistrationDate,
        AccountCreateParamsCompanyRepresentativeDeclaration as AccountCreateParamsCompanyRepresentativeDeclaration,
        AccountCreateParamsCompanyVerification as AccountCreateParamsCompanyVerification,
        AccountCreateParamsCompanyVerificationDocument as AccountCreateParamsCompanyVerificationDocument,
        AccountCreateParamsController as AccountCreateParamsController,
        AccountCreateParamsControllerApplication as AccountCreateParamsControllerApplication,
        AccountCreateParamsControllerDashboard as AccountCreateParamsControllerDashboard,
        AccountCreateParamsControllerFees as AccountCreateParamsControllerFees,
        AccountCreateParamsControllerLosses as AccountCreateParamsControllerLosses,
        AccountCreateParamsControllerStripeDashboard as AccountCreateParamsControllerStripeDashboard,
        AccountCreateParamsDocuments as AccountCreateParamsDocuments,
        AccountCreateParamsDocumentsBankAccountOwnershipVerification as AccountCreateParamsDocumentsBankAccountOwnershipVerification,
        AccountCreateParamsDocumentsCompanyLicense as AccountCreateParamsDocumentsCompanyLicense,
        AccountCreateParamsDocumentsCompanyMemorandumOfAssociation as AccountCreateParamsDocumentsCompanyMemorandumOfAssociation,
        AccountCreateParamsDocumentsCompanyMinisterialDecree as AccountCreateParamsDocumentsCompanyMinisterialDecree,
        AccountCreateParamsDocumentsCompanyRegistrationVerification as AccountCreateParamsDocumentsCompanyRegistrationVerification,
        AccountCreateParamsDocumentsCompanyTaxIdVerification as AccountCreateParamsDocumentsCompanyTaxIdVerification,
        AccountCreateParamsDocumentsProofOfAddress as AccountCreateParamsDocumentsProofOfAddress,
        AccountCreateParamsDocumentsProofOfRegistration as AccountCreateParamsDocumentsProofOfRegistration,
        AccountCreateParamsDocumentsProofOfUltimateBeneficialOwnership as AccountCreateParamsDocumentsProofOfUltimateBeneficialOwnership,
        AccountCreateParamsGroups as AccountCreateParamsGroups,
        AccountCreateParamsIndividual as AccountCreateParamsIndividual,
        AccountCreateParamsIndividualAddress as AccountCreateParamsIndividualAddress,
        AccountCreateParamsIndividualAddressKana as AccountCreateParamsIndividualAddressKana,
        AccountCreateParamsIndividualAddressKanji as AccountCreateParamsIndividualAddressKanji,
        AccountCreateParamsIndividualDob as AccountCreateParamsIndividualDob,
        AccountCreateParamsIndividualRegisteredAddress as AccountCreateParamsIndividualRegisteredAddress,
        AccountCreateParamsIndividualRelationship as AccountCreateParamsIndividualRelationship,
        AccountCreateParamsIndividualSelfReportedIncome as AccountCreateParamsIndividualSelfReportedIncome,
        AccountCreateParamsIndividualSelfReportedMonthlyHousingPayment as AccountCreateParamsIndividualSelfReportedMonthlyHousingPayment,
        AccountCreateParamsIndividualVerification as AccountCreateParamsIndividualVerification,
        AccountCreateParamsIndividualVerificationAdditionalDocument as AccountCreateParamsIndividualVerificationAdditionalDocument,
        AccountCreateParamsIndividualVerificationDocument as AccountCreateParamsIndividualVerificationDocument,
        AccountCreateParamsRiskControls as AccountCreateParamsRiskControls,
        AccountCreateParamsRiskControlsCharges as AccountCreateParamsRiskControlsCharges,
        AccountCreateParamsRiskControlsPayouts as AccountCreateParamsRiskControlsPayouts,
        AccountCreateParamsSettings as AccountCreateParamsSettings,
        AccountCreateParamsSettingsBacsDebitPayments as AccountCreateParamsSettingsBacsDebitPayments,
        AccountCreateParamsSettingsBankBcaOnboarding as AccountCreateParamsSettingsBankBcaOnboarding,
        AccountCreateParamsSettingsBranding as AccountCreateParamsSettingsBranding,
        AccountCreateParamsSettingsCapital as AccountCreateParamsSettingsCapital,
        AccountCreateParamsSettingsCardIssuing as AccountCreateParamsSettingsCardIssuing,
        AccountCreateParamsSettingsCardIssuingTosAcceptance as AccountCreateParamsSettingsCardIssuingTosAcceptance,
        AccountCreateParamsSettingsCardPayments as AccountCreateParamsSettingsCardPayments,
        AccountCreateParamsSettingsCardPaymentsDeclineOn as AccountCreateParamsSettingsCardPaymentsDeclineOn,
        AccountCreateParamsSettingsInvoices as AccountCreateParamsSettingsInvoices,
        AccountCreateParamsSettingsPayments as AccountCreateParamsSettingsPayments,
        AccountCreateParamsSettingsPayouts as AccountCreateParamsSettingsPayouts,
        AccountCreateParamsSettingsPayoutsSchedule as AccountCreateParamsSettingsPayoutsSchedule,
        AccountCreateParamsSettingsPaypayPayments as AccountCreateParamsSettingsPaypayPayments,
        AccountCreateParamsSettingsTaxForms as AccountCreateParamsSettingsTaxForms,
        AccountCreateParamsSettingsTreasury as AccountCreateParamsSettingsTreasury,
        AccountCreateParamsSettingsTreasuryTosAcceptance as AccountCreateParamsSettingsTreasuryTosAcceptance,
        AccountCreateParamsTosAcceptance as AccountCreateParamsTosAcceptance,
    )
    from stripe.params._account_create_person_params import (
        AccountCreatePersonParams as AccountCreatePersonParams,
        AccountCreatePersonParamsAdditionalTosAcceptances as AccountCreatePersonParamsAdditionalTosAcceptances,
        AccountCreatePersonParamsAdditionalTosAcceptancesAccount as AccountCreatePersonParamsAdditionalTosAcceptancesAccount,
        AccountCreatePersonParamsAddress as AccountCreatePersonParamsAddress,
        AccountCreatePersonParamsAddressKana as AccountCreatePersonParamsAddressKana,
        AccountCreatePersonParamsAddressKanji as AccountCreatePersonParamsAddressKanji,
        AccountCreatePersonParamsDob as AccountCreatePersonParamsDob,
        AccountCreatePersonParamsDocuments as AccountCreatePersonParamsDocuments,
        AccountCreatePersonParamsDocumentsCompanyAuthorization as AccountCreatePersonParamsDocumentsCompanyAuthorization,
        AccountCreatePersonParamsDocumentsPassport as AccountCreatePersonParamsDocumentsPassport,
        AccountCreatePersonParamsDocumentsVisa as AccountCreatePersonParamsDocumentsVisa,
        AccountCreatePersonParamsRegisteredAddress as AccountCreatePersonParamsRegisteredAddress,
        AccountCreatePersonParamsRelationship as AccountCreatePersonParamsRelationship,
        AccountCreatePersonParamsSelfReportedIncome as AccountCreatePersonParamsSelfReportedIncome,
        AccountCreatePersonParamsSelfReportedMonthlyHousingPayment as AccountCreatePersonParamsSelfReportedMonthlyHousingPayment,
        AccountCreatePersonParamsUsCfpbData as AccountCreatePersonParamsUsCfpbData,
        AccountCreatePersonParamsUsCfpbDataEthnicityDetails as AccountCreatePersonParamsUsCfpbDataEthnicityDetails,
        AccountCreatePersonParamsUsCfpbDataRaceDetails as AccountCreatePersonParamsUsCfpbDataRaceDetails,
        AccountCreatePersonParamsVerification as AccountCreatePersonParamsVerification,
        AccountCreatePersonParamsVerificationAdditionalDocument as AccountCreatePersonParamsVerificationAdditionalDocument,
        AccountCreatePersonParamsVerificationDocument as AccountCreatePersonParamsVerificationDocument,
    )
    from stripe.params._account_delete_external_account_params import (
        AccountDeleteExternalAccountParams as AccountDeleteExternalAccountParams,
    )
    from stripe.params._account_delete_params import (
        AccountDeleteParams as AccountDeleteParams,
    )
    from stripe.params._account_delete_person_params import (
        AccountDeletePersonParams as AccountDeletePersonParams,
    )
    from stripe.params._account_external_account_create_params import (
        AccountExternalAccountCreateParams as AccountExternalAccountCreateParams,
        AccountExternalAccountCreateParamsBankAccount as AccountExternalAccountCreateParamsBankAccount,
        AccountExternalAccountCreateParamsCard as AccountExternalAccountCreateParamsCard,
        AccountExternalAccountCreateParamsCardToken as AccountExternalAccountCreateParamsCardToken,
    )
    from stripe.params._account_external_account_delete_params import (
        AccountExternalAccountDeleteParams as AccountExternalAccountDeleteParams,
    )
    from stripe.params._account_external_account_list_params import (
        AccountExternalAccountListParams as AccountExternalAccountListParams,
    )
    from stripe.params._account_external_account_retrieve_params import (
        AccountExternalAccountRetrieveParams as AccountExternalAccountRetrieveParams,
    )
    from stripe.params._account_external_account_update_params import (
        AccountExternalAccountUpdateParams as AccountExternalAccountUpdateParams,
        AccountExternalAccountUpdateParamsDocuments as AccountExternalAccountUpdateParamsDocuments,
        AccountExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification as AccountExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification,
    )
    from stripe.params._account_link_create_params import (
        AccountLinkCreateParams as AccountLinkCreateParams,
        AccountLinkCreateParamsCollectionOptions as AccountLinkCreateParamsCollectionOptions,
    )
    from stripe.params._account_list_capabilities_params import (
        AccountListCapabilitiesParams as AccountListCapabilitiesParams,
    )
    from stripe.params._account_list_external_accounts_params import (
        AccountListExternalAccountsParams as AccountListExternalAccountsParams,
    )
    from stripe.params._account_list_params import (
        AccountListParams as AccountListParams,
        AccountListParamsCreated as AccountListParamsCreated,
    )
    from stripe.params._account_list_persons_params import (
        AccountListPersonsParams as AccountListPersonsParams,
        AccountListPersonsParamsRelationship as AccountListPersonsParamsRelationship,
    )
    from stripe.params._account_login_link_create_params import (
        AccountLoginLinkCreateParams as AccountLoginLinkCreateParams,
    )
    from stripe.params._account_modify_capability_params import (
        AccountModifyCapabilityParams as AccountModifyCapabilityParams,
    )
    from stripe.params._account_modify_external_account_params import (
        AccountModifyExternalAccountParams as AccountModifyExternalAccountParams,
        AccountModifyExternalAccountParamsDocuments as AccountModifyExternalAccountParamsDocuments,
        AccountModifyExternalAccountParamsDocumentsBankAccountOwnershipVerification as AccountModifyExternalAccountParamsDocumentsBankAccountOwnershipVerification,
    )
    from stripe.params._account_modify_person_params import (
        AccountModifyPersonParams as AccountModifyPersonParams,
        AccountModifyPersonParamsAdditionalTosAcceptances as AccountModifyPersonParamsAdditionalTosAcceptances,
        AccountModifyPersonParamsAdditionalTosAcceptancesAccount as AccountModifyPersonParamsAdditionalTosAcceptancesAccount,
        AccountModifyPersonParamsAddress as AccountModifyPersonParamsAddress,
        AccountModifyPersonParamsAddressKana as AccountModifyPersonParamsAddressKana,
        AccountModifyPersonParamsAddressKanji as AccountModifyPersonParamsAddressKanji,
        AccountModifyPersonParamsDob as AccountModifyPersonParamsDob,
        AccountModifyPersonParamsDocuments as AccountModifyPersonParamsDocuments,
        AccountModifyPersonParamsDocumentsCompanyAuthorization as AccountModifyPersonParamsDocumentsCompanyAuthorization,
        AccountModifyPersonParamsDocumentsPassport as AccountModifyPersonParamsDocumentsPassport,
        AccountModifyPersonParamsDocumentsVisa as AccountModifyPersonParamsDocumentsVisa,
        AccountModifyPersonParamsRegisteredAddress as AccountModifyPersonParamsRegisteredAddress,
        AccountModifyPersonParamsRelationship as AccountModifyPersonParamsRelationship,
        AccountModifyPersonParamsSelfReportedIncome as AccountModifyPersonParamsSelfReportedIncome,
        AccountModifyPersonParamsSelfReportedMonthlyHousingPayment as AccountModifyPersonParamsSelfReportedMonthlyHousingPayment,
        AccountModifyPersonParamsUsCfpbData as AccountModifyPersonParamsUsCfpbData,
        AccountModifyPersonParamsUsCfpbDataEthnicityDetails as AccountModifyPersonParamsUsCfpbDataEthnicityDetails,
        AccountModifyPersonParamsUsCfpbDataRaceDetails as AccountModifyPersonParamsUsCfpbDataRaceDetails,
        AccountModifyPersonParamsVerification as AccountModifyPersonParamsVerification,
        AccountModifyPersonParamsVerificationAdditionalDocument as AccountModifyPersonParamsVerificationAdditionalDocument,
        AccountModifyPersonParamsVerificationDocument as AccountModifyPersonParamsVerificationDocument,
    )
    from stripe.params._account_notice_list_params import (
        AccountNoticeListParams as AccountNoticeListParams,
    )
    from stripe.params._account_notice_modify_params import (
        AccountNoticeModifyParams as AccountNoticeModifyParams,
        AccountNoticeModifyParamsEmail as AccountNoticeModifyParamsEmail,
    )
    from stripe.params._account_notice_retrieve_params import (
        AccountNoticeRetrieveParams as AccountNoticeRetrieveParams,
    )
    from stripe.params._account_notice_update_params import (
        AccountNoticeUpdateParams as AccountNoticeUpdateParams,
        AccountNoticeUpdateParamsEmail as AccountNoticeUpdateParamsEmail,
    )
    from stripe.params._account_person_create_params import (
        AccountPersonCreateParams as AccountPersonCreateParams,
        AccountPersonCreateParamsAdditionalTosAcceptances as AccountPersonCreateParamsAdditionalTosAcceptances,
        AccountPersonCreateParamsAdditionalTosAcceptancesAccount as AccountPersonCreateParamsAdditionalTosAcceptancesAccount,
        AccountPersonCreateParamsAddress as AccountPersonCreateParamsAddress,
        AccountPersonCreateParamsAddressKana as AccountPersonCreateParamsAddressKana,
        AccountPersonCreateParamsAddressKanji as AccountPersonCreateParamsAddressKanji,
        AccountPersonCreateParamsDob as AccountPersonCreateParamsDob,
        AccountPersonCreateParamsDocuments as AccountPersonCreateParamsDocuments,
        AccountPersonCreateParamsDocumentsCompanyAuthorization as AccountPersonCreateParamsDocumentsCompanyAuthorization,
        AccountPersonCreateParamsDocumentsPassport as AccountPersonCreateParamsDocumentsPassport,
        AccountPersonCreateParamsDocumentsVisa as AccountPersonCreateParamsDocumentsVisa,
        AccountPersonCreateParamsRegisteredAddress as AccountPersonCreateParamsRegisteredAddress,
        AccountPersonCreateParamsRelationship as AccountPersonCreateParamsRelationship,
        AccountPersonCreateParamsSelfReportedIncome as AccountPersonCreateParamsSelfReportedIncome,
        AccountPersonCreateParamsSelfReportedMonthlyHousingPayment as AccountPersonCreateParamsSelfReportedMonthlyHousingPayment,
        AccountPersonCreateParamsUsCfpbData as AccountPersonCreateParamsUsCfpbData,
        AccountPersonCreateParamsUsCfpbDataEthnicityDetails as AccountPersonCreateParamsUsCfpbDataEthnicityDetails,
        AccountPersonCreateParamsUsCfpbDataRaceDetails as AccountPersonCreateParamsUsCfpbDataRaceDetails,
        AccountPersonCreateParamsVerification as AccountPersonCreateParamsVerification,
        AccountPersonCreateParamsVerificationAdditionalDocument as AccountPersonCreateParamsVerificationAdditionalDocument,
        AccountPersonCreateParamsVerificationDocument as AccountPersonCreateParamsVerificationDocument,
    )
    from stripe.params._account_person_delete_params import (
        AccountPersonDeleteParams as AccountPersonDeleteParams,
    )
    from stripe.params._account_person_list_params import (
        AccountPersonListParams as AccountPersonListParams,
        AccountPersonListParamsRelationship as AccountPersonListParamsRelationship,
    )
    from stripe.params._account_person_retrieve_params import (
        AccountPersonRetrieveParams as AccountPersonRetrieveParams,
    )
    from stripe.params._account_person_update_params import (
        AccountPersonUpdateParams as AccountPersonUpdateParams,
        AccountPersonUpdateParamsAdditionalTosAcceptances as AccountPersonUpdateParamsAdditionalTosAcceptances,
        AccountPersonUpdateParamsAdditionalTosAcceptancesAccount as AccountPersonUpdateParamsAdditionalTosAcceptancesAccount,
        AccountPersonUpdateParamsAddress as AccountPersonUpdateParamsAddress,
        AccountPersonUpdateParamsAddressKana as AccountPersonUpdateParamsAddressKana,
        AccountPersonUpdateParamsAddressKanji as AccountPersonUpdateParamsAddressKanji,
        AccountPersonUpdateParamsDob as AccountPersonUpdateParamsDob,
        AccountPersonUpdateParamsDocuments as AccountPersonUpdateParamsDocuments,
        AccountPersonUpdateParamsDocumentsCompanyAuthorization as AccountPersonUpdateParamsDocumentsCompanyAuthorization,
        AccountPersonUpdateParamsDocumentsPassport as AccountPersonUpdateParamsDocumentsPassport,
        AccountPersonUpdateParamsDocumentsVisa as AccountPersonUpdateParamsDocumentsVisa,
        AccountPersonUpdateParamsRegisteredAddress as AccountPersonUpdateParamsRegisteredAddress,
        AccountPersonUpdateParamsRelationship as AccountPersonUpdateParamsRelationship,
        AccountPersonUpdateParamsSelfReportedIncome as AccountPersonUpdateParamsSelfReportedIncome,
        AccountPersonUpdateParamsSelfReportedMonthlyHousingPayment as AccountPersonUpdateParamsSelfReportedMonthlyHousingPayment,
        AccountPersonUpdateParamsUsCfpbData as AccountPersonUpdateParamsUsCfpbData,
        AccountPersonUpdateParamsUsCfpbDataEthnicityDetails as AccountPersonUpdateParamsUsCfpbDataEthnicityDetails,
        AccountPersonUpdateParamsUsCfpbDataRaceDetails as AccountPersonUpdateParamsUsCfpbDataRaceDetails,
        AccountPersonUpdateParamsVerification as AccountPersonUpdateParamsVerification,
        AccountPersonUpdateParamsVerificationAdditionalDocument as AccountPersonUpdateParamsVerificationAdditionalDocument,
        AccountPersonUpdateParamsVerificationDocument as AccountPersonUpdateParamsVerificationDocument,
    )
    from stripe.params._account_persons_params import (
        AccountPersonsParams as AccountPersonsParams,
        AccountPersonsParamsRelationship as AccountPersonsParamsRelationship,
    )
    from stripe.params._account_reject_params import (
        AccountRejectParams as AccountRejectParams,
    )
    from stripe.params._account_retrieve_capability_params import (
        AccountRetrieveCapabilityParams as AccountRetrieveCapabilityParams,
    )
    from stripe.params._account_retrieve_current_params import (
        AccountRetrieveCurrentParams as AccountRetrieveCurrentParams,
    )
    from stripe.params._account_retrieve_external_account_params import (
        AccountRetrieveExternalAccountParams as AccountRetrieveExternalAccountParams,
    )
    from stripe.params._account_retrieve_params import (
        AccountRetrieveParams as AccountRetrieveParams,
    )
    from stripe.params._account_retrieve_person_params import (
        AccountRetrievePersonParams as AccountRetrievePersonParams,
    )
    from stripe.params._account_session_create_params import (
        AccountSessionCreateParams as AccountSessionCreateParams,
        AccountSessionCreateParamsComponents as AccountSessionCreateParamsComponents,
        AccountSessionCreateParamsComponentsAccountManagement as AccountSessionCreateParamsComponentsAccountManagement,
        AccountSessionCreateParamsComponentsAccountManagementFeatures as AccountSessionCreateParamsComponentsAccountManagementFeatures,
        AccountSessionCreateParamsComponentsAccountOnboarding as AccountSessionCreateParamsComponentsAccountOnboarding,
        AccountSessionCreateParamsComponentsAccountOnboardingFeatures as AccountSessionCreateParamsComponentsAccountOnboardingFeatures,
        AccountSessionCreateParamsComponentsAppInstall as AccountSessionCreateParamsComponentsAppInstall,
        AccountSessionCreateParamsComponentsAppInstallFeatures as AccountSessionCreateParamsComponentsAppInstallFeatures,
        AccountSessionCreateParamsComponentsAppViewport as AccountSessionCreateParamsComponentsAppViewport,
        AccountSessionCreateParamsComponentsAppViewportFeatures as AccountSessionCreateParamsComponentsAppViewportFeatures,
        AccountSessionCreateParamsComponentsBalances as AccountSessionCreateParamsComponentsBalances,
        AccountSessionCreateParamsComponentsBalancesFeatures as AccountSessionCreateParamsComponentsBalancesFeatures,
        AccountSessionCreateParamsComponentsCapitalFinancing as AccountSessionCreateParamsComponentsCapitalFinancing,
        AccountSessionCreateParamsComponentsCapitalFinancingApplication as AccountSessionCreateParamsComponentsCapitalFinancingApplication,
        AccountSessionCreateParamsComponentsCapitalFinancingApplicationFeatures as AccountSessionCreateParamsComponentsCapitalFinancingApplicationFeatures,
        AccountSessionCreateParamsComponentsCapitalFinancingFeatures as AccountSessionCreateParamsComponentsCapitalFinancingFeatures,
        AccountSessionCreateParamsComponentsCapitalFinancingPromotion as AccountSessionCreateParamsComponentsCapitalFinancingPromotion,
        AccountSessionCreateParamsComponentsCapitalFinancingPromotionFeatures as AccountSessionCreateParamsComponentsCapitalFinancingPromotionFeatures,
        AccountSessionCreateParamsComponentsCapitalOverview as AccountSessionCreateParamsComponentsCapitalOverview,
        AccountSessionCreateParamsComponentsCapitalOverviewFeatures as AccountSessionCreateParamsComponentsCapitalOverviewFeatures,
        AccountSessionCreateParamsComponentsDisputesList as AccountSessionCreateParamsComponentsDisputesList,
        AccountSessionCreateParamsComponentsDisputesListFeatures as AccountSessionCreateParamsComponentsDisputesListFeatures,
        AccountSessionCreateParamsComponentsDocuments as AccountSessionCreateParamsComponentsDocuments,
        AccountSessionCreateParamsComponentsDocumentsFeatures as AccountSessionCreateParamsComponentsDocumentsFeatures,
        AccountSessionCreateParamsComponentsExportTaxTransactions as AccountSessionCreateParamsComponentsExportTaxTransactions,
        AccountSessionCreateParamsComponentsExportTaxTransactionsFeatures as AccountSessionCreateParamsComponentsExportTaxTransactionsFeatures,
        AccountSessionCreateParamsComponentsFinancialAccount as AccountSessionCreateParamsComponentsFinancialAccount,
        AccountSessionCreateParamsComponentsFinancialAccountFeatures as AccountSessionCreateParamsComponentsFinancialAccountFeatures,
        AccountSessionCreateParamsComponentsFinancialAccountTransactions as AccountSessionCreateParamsComponentsFinancialAccountTransactions,
        AccountSessionCreateParamsComponentsFinancialAccountTransactionsFeatures as AccountSessionCreateParamsComponentsFinancialAccountTransactionsFeatures,
        AccountSessionCreateParamsComponentsInstantPayoutsPromotion as AccountSessionCreateParamsComponentsInstantPayoutsPromotion,
        AccountSessionCreateParamsComponentsInstantPayoutsPromotionFeatures as AccountSessionCreateParamsComponentsInstantPayoutsPromotionFeatures,
        AccountSessionCreateParamsComponentsIssuingCard as AccountSessionCreateParamsComponentsIssuingCard,
        AccountSessionCreateParamsComponentsIssuingCardFeatures as AccountSessionCreateParamsComponentsIssuingCardFeatures,
        AccountSessionCreateParamsComponentsIssuingCardsList as AccountSessionCreateParamsComponentsIssuingCardsList,
        AccountSessionCreateParamsComponentsIssuingCardsListFeatures as AccountSessionCreateParamsComponentsIssuingCardsListFeatures,
        AccountSessionCreateParamsComponentsNotificationBanner as AccountSessionCreateParamsComponentsNotificationBanner,
        AccountSessionCreateParamsComponentsNotificationBannerFeatures as AccountSessionCreateParamsComponentsNotificationBannerFeatures,
        AccountSessionCreateParamsComponentsPaymentDetails as AccountSessionCreateParamsComponentsPaymentDetails,
        AccountSessionCreateParamsComponentsPaymentDetailsFeatures as AccountSessionCreateParamsComponentsPaymentDetailsFeatures,
        AccountSessionCreateParamsComponentsPaymentDisputes as AccountSessionCreateParamsComponentsPaymentDisputes,
        AccountSessionCreateParamsComponentsPaymentDisputesFeatures as AccountSessionCreateParamsComponentsPaymentDisputesFeatures,
        AccountSessionCreateParamsComponentsPaymentMethodSettings as AccountSessionCreateParamsComponentsPaymentMethodSettings,
        AccountSessionCreateParamsComponentsPaymentMethodSettingsFeatures as AccountSessionCreateParamsComponentsPaymentMethodSettingsFeatures,
        AccountSessionCreateParamsComponentsPayments as AccountSessionCreateParamsComponentsPayments,
        AccountSessionCreateParamsComponentsPaymentsFeatures as AccountSessionCreateParamsComponentsPaymentsFeatures,
        AccountSessionCreateParamsComponentsPayoutDetails as AccountSessionCreateParamsComponentsPayoutDetails,
        AccountSessionCreateParamsComponentsPayoutDetailsFeatures as AccountSessionCreateParamsComponentsPayoutDetailsFeatures,
        AccountSessionCreateParamsComponentsPayouts as AccountSessionCreateParamsComponentsPayouts,
        AccountSessionCreateParamsComponentsPayoutsFeatures as AccountSessionCreateParamsComponentsPayoutsFeatures,
        AccountSessionCreateParamsComponentsPayoutsList as AccountSessionCreateParamsComponentsPayoutsList,
        AccountSessionCreateParamsComponentsPayoutsListFeatures as AccountSessionCreateParamsComponentsPayoutsListFeatures,
        AccountSessionCreateParamsComponentsProductTaxCodeSelector as AccountSessionCreateParamsComponentsProductTaxCodeSelector,
        AccountSessionCreateParamsComponentsProductTaxCodeSelectorFeatures as AccountSessionCreateParamsComponentsProductTaxCodeSelectorFeatures,
        AccountSessionCreateParamsComponentsRecipients as AccountSessionCreateParamsComponentsRecipients,
        AccountSessionCreateParamsComponentsRecipientsFeatures as AccountSessionCreateParamsComponentsRecipientsFeatures,
        AccountSessionCreateParamsComponentsReportingChart as AccountSessionCreateParamsComponentsReportingChart,
        AccountSessionCreateParamsComponentsReportingChartFeatures as AccountSessionCreateParamsComponentsReportingChartFeatures,
        AccountSessionCreateParamsComponentsTaxRegistrations as AccountSessionCreateParamsComponentsTaxRegistrations,
        AccountSessionCreateParamsComponentsTaxRegistrationsFeatures as AccountSessionCreateParamsComponentsTaxRegistrationsFeatures,
        AccountSessionCreateParamsComponentsTaxSettings as AccountSessionCreateParamsComponentsTaxSettings,
        AccountSessionCreateParamsComponentsTaxSettingsFeatures as AccountSessionCreateParamsComponentsTaxSettingsFeatures,
        AccountSessionCreateParamsComponentsTaxThresholdMonitoring as AccountSessionCreateParamsComponentsTaxThresholdMonitoring,
        AccountSessionCreateParamsComponentsTaxThresholdMonitoringFeatures as AccountSessionCreateParamsComponentsTaxThresholdMonitoringFeatures,
    )
    from stripe.params._account_update_params import (
        AccountUpdateParams as AccountUpdateParams,
        AccountUpdateParamsBankAccount as AccountUpdateParamsBankAccount,
        AccountUpdateParamsBusinessProfile as AccountUpdateParamsBusinessProfile,
        AccountUpdateParamsBusinessProfileAnnualRevenue as AccountUpdateParamsBusinessProfileAnnualRevenue,
        AccountUpdateParamsBusinessProfileMonthlyEstimatedRevenue as AccountUpdateParamsBusinessProfileMonthlyEstimatedRevenue,
        AccountUpdateParamsBusinessProfileSupportAddress as AccountUpdateParamsBusinessProfileSupportAddress,
        AccountUpdateParamsCapabilities as AccountUpdateParamsCapabilities,
        AccountUpdateParamsCapabilitiesAcssDebitPayments as AccountUpdateParamsCapabilitiesAcssDebitPayments,
        AccountUpdateParamsCapabilitiesAffirmPayments as AccountUpdateParamsCapabilitiesAffirmPayments,
        AccountUpdateParamsCapabilitiesAfterpayClearpayPayments as AccountUpdateParamsCapabilitiesAfterpayClearpayPayments,
        AccountUpdateParamsCapabilitiesAlmaPayments as AccountUpdateParamsCapabilitiesAlmaPayments,
        AccountUpdateParamsCapabilitiesAmazonPayPayments as AccountUpdateParamsCapabilitiesAmazonPayPayments,
        AccountUpdateParamsCapabilitiesAuBecsDebitPayments as AccountUpdateParamsCapabilitiesAuBecsDebitPayments,
        AccountUpdateParamsCapabilitiesAutomaticIndirectTax as AccountUpdateParamsCapabilitiesAutomaticIndirectTax,
        AccountUpdateParamsCapabilitiesBacsDebitPayments as AccountUpdateParamsCapabilitiesBacsDebitPayments,
        AccountUpdateParamsCapabilitiesBancontactPayments as AccountUpdateParamsCapabilitiesBancontactPayments,
        AccountUpdateParamsCapabilitiesBankTransferPayments as AccountUpdateParamsCapabilitiesBankTransferPayments,
        AccountUpdateParamsCapabilitiesBilliePayments as AccountUpdateParamsCapabilitiesBilliePayments,
        AccountUpdateParamsCapabilitiesBlikPayments as AccountUpdateParamsCapabilitiesBlikPayments,
        AccountUpdateParamsCapabilitiesBoletoPayments as AccountUpdateParamsCapabilitiesBoletoPayments,
        AccountUpdateParamsCapabilitiesCardIssuing as AccountUpdateParamsCapabilitiesCardIssuing,
        AccountUpdateParamsCapabilitiesCardPayments as AccountUpdateParamsCapabilitiesCardPayments,
        AccountUpdateParamsCapabilitiesCartesBancairesPayments as AccountUpdateParamsCapabilitiesCartesBancairesPayments,
        AccountUpdateParamsCapabilitiesCashappPayments as AccountUpdateParamsCapabilitiesCashappPayments,
        AccountUpdateParamsCapabilitiesCryptoPayments as AccountUpdateParamsCapabilitiesCryptoPayments,
        AccountUpdateParamsCapabilitiesEpsPayments as AccountUpdateParamsCapabilitiesEpsPayments,
        AccountUpdateParamsCapabilitiesFpxPayments as AccountUpdateParamsCapabilitiesFpxPayments,
        AccountUpdateParamsCapabilitiesGbBankTransferPayments as AccountUpdateParamsCapabilitiesGbBankTransferPayments,
        AccountUpdateParamsCapabilitiesGiropayPayments as AccountUpdateParamsCapabilitiesGiropayPayments,
        AccountUpdateParamsCapabilitiesGopayPayments as AccountUpdateParamsCapabilitiesGopayPayments,
        AccountUpdateParamsCapabilitiesGrabpayPayments as AccountUpdateParamsCapabilitiesGrabpayPayments,
        AccountUpdateParamsCapabilitiesIdBankTransferPayments as AccountUpdateParamsCapabilitiesIdBankTransferPayments,
        AccountUpdateParamsCapabilitiesIdBankTransferPaymentsBca as AccountUpdateParamsCapabilitiesIdBankTransferPaymentsBca,
        AccountUpdateParamsCapabilitiesIdealPayments as AccountUpdateParamsCapabilitiesIdealPayments,
        AccountUpdateParamsCapabilitiesIndiaInternationalPayments as AccountUpdateParamsCapabilitiesIndiaInternationalPayments,
        AccountUpdateParamsCapabilitiesJcbPayments as AccountUpdateParamsCapabilitiesJcbPayments,
        AccountUpdateParamsCapabilitiesJpBankTransferPayments as AccountUpdateParamsCapabilitiesJpBankTransferPayments,
        AccountUpdateParamsCapabilitiesKakaoPayPayments as AccountUpdateParamsCapabilitiesKakaoPayPayments,
        AccountUpdateParamsCapabilitiesKlarnaPayments as AccountUpdateParamsCapabilitiesKlarnaPayments,
        AccountUpdateParamsCapabilitiesKonbiniPayments as AccountUpdateParamsCapabilitiesKonbiniPayments,
        AccountUpdateParamsCapabilitiesKrCardPayments as AccountUpdateParamsCapabilitiesKrCardPayments,
        AccountUpdateParamsCapabilitiesLegacyPayments as AccountUpdateParamsCapabilitiesLegacyPayments,
        AccountUpdateParamsCapabilitiesLinkPayments as AccountUpdateParamsCapabilitiesLinkPayments,
        AccountUpdateParamsCapabilitiesMbWayPayments as AccountUpdateParamsCapabilitiesMbWayPayments,
        AccountUpdateParamsCapabilitiesMobilepayPayments as AccountUpdateParamsCapabilitiesMobilepayPayments,
        AccountUpdateParamsCapabilitiesMultibancoPayments as AccountUpdateParamsCapabilitiesMultibancoPayments,
        AccountUpdateParamsCapabilitiesMxBankTransferPayments as AccountUpdateParamsCapabilitiesMxBankTransferPayments,
        AccountUpdateParamsCapabilitiesNaverPayPayments as AccountUpdateParamsCapabilitiesNaverPayPayments,
        AccountUpdateParamsCapabilitiesNzBankAccountBecsDebitPayments as AccountUpdateParamsCapabilitiesNzBankAccountBecsDebitPayments,
        AccountUpdateParamsCapabilitiesOxxoPayments as AccountUpdateParamsCapabilitiesOxxoPayments,
        AccountUpdateParamsCapabilitiesP24Payments as AccountUpdateParamsCapabilitiesP24Payments,
        AccountUpdateParamsCapabilitiesPayByBankPayments as AccountUpdateParamsCapabilitiesPayByBankPayments,
        AccountUpdateParamsCapabilitiesPaycoPayments as AccountUpdateParamsCapabilitiesPaycoPayments,
        AccountUpdateParamsCapabilitiesPaynowPayments as AccountUpdateParamsCapabilitiesPaynowPayments,
        AccountUpdateParamsCapabilitiesPaypalPayments as AccountUpdateParamsCapabilitiesPaypalPayments,
        AccountUpdateParamsCapabilitiesPaypayPayments as AccountUpdateParamsCapabilitiesPaypayPayments,
        AccountUpdateParamsCapabilitiesPaytoPayments as AccountUpdateParamsCapabilitiesPaytoPayments,
        AccountUpdateParamsCapabilitiesPixPayments as AccountUpdateParamsCapabilitiesPixPayments,
        AccountUpdateParamsCapabilitiesPromptpayPayments as AccountUpdateParamsCapabilitiesPromptpayPayments,
        AccountUpdateParamsCapabilitiesQrisPayments as AccountUpdateParamsCapabilitiesQrisPayments,
        AccountUpdateParamsCapabilitiesRechnungPayments as AccountUpdateParamsCapabilitiesRechnungPayments,
        AccountUpdateParamsCapabilitiesRevolutPayPayments as AccountUpdateParamsCapabilitiesRevolutPayPayments,
        AccountUpdateParamsCapabilitiesSamsungPayPayments as AccountUpdateParamsCapabilitiesSamsungPayPayments,
        AccountUpdateParamsCapabilitiesSatispayPayments as AccountUpdateParamsCapabilitiesSatispayPayments,
        AccountUpdateParamsCapabilitiesSepaBankTransferPayments as AccountUpdateParamsCapabilitiesSepaBankTransferPayments,
        AccountUpdateParamsCapabilitiesSepaDebitPayments as AccountUpdateParamsCapabilitiesSepaDebitPayments,
        AccountUpdateParamsCapabilitiesShopeepayPayments as AccountUpdateParamsCapabilitiesShopeepayPayments,
        AccountUpdateParamsCapabilitiesSofortPayments as AccountUpdateParamsCapabilitiesSofortPayments,
        AccountUpdateParamsCapabilitiesStripeBalancePayments as AccountUpdateParamsCapabilitiesStripeBalancePayments,
        AccountUpdateParamsCapabilitiesSwishPayments as AccountUpdateParamsCapabilitiesSwishPayments,
        AccountUpdateParamsCapabilitiesTaxReportingUs1099K as AccountUpdateParamsCapabilitiesTaxReportingUs1099K,
        AccountUpdateParamsCapabilitiesTaxReportingUs1099Misc as AccountUpdateParamsCapabilitiesTaxReportingUs1099Misc,
        AccountUpdateParamsCapabilitiesTransfers as AccountUpdateParamsCapabilitiesTransfers,
        AccountUpdateParamsCapabilitiesTreasury as AccountUpdateParamsCapabilitiesTreasury,
        AccountUpdateParamsCapabilitiesTreasuryEvolve as AccountUpdateParamsCapabilitiesTreasuryEvolve,
        AccountUpdateParamsCapabilitiesTreasuryFifthThird as AccountUpdateParamsCapabilitiesTreasuryFifthThird,
        AccountUpdateParamsCapabilitiesTreasuryGoldmanSachs as AccountUpdateParamsCapabilitiesTreasuryGoldmanSachs,
        AccountUpdateParamsCapabilitiesTwintPayments as AccountUpdateParamsCapabilitiesTwintPayments,
        AccountUpdateParamsCapabilitiesUsBankAccountAchPayments as AccountUpdateParamsCapabilitiesUsBankAccountAchPayments,
        AccountUpdateParamsCapabilitiesUsBankTransferPayments as AccountUpdateParamsCapabilitiesUsBankTransferPayments,
        AccountUpdateParamsCapabilitiesZipPayments as AccountUpdateParamsCapabilitiesZipPayments,
        AccountUpdateParamsCard as AccountUpdateParamsCard,
        AccountUpdateParamsCardToken as AccountUpdateParamsCardToken,
        AccountUpdateParamsCompany as AccountUpdateParamsCompany,
        AccountUpdateParamsCompanyAddress as AccountUpdateParamsCompanyAddress,
        AccountUpdateParamsCompanyAddressKana as AccountUpdateParamsCompanyAddressKana,
        AccountUpdateParamsCompanyAddressKanji as AccountUpdateParamsCompanyAddressKanji,
        AccountUpdateParamsCompanyDirectorshipDeclaration as AccountUpdateParamsCompanyDirectorshipDeclaration,
        AccountUpdateParamsCompanyOwnershipDeclaration as AccountUpdateParamsCompanyOwnershipDeclaration,
        AccountUpdateParamsCompanyRegistrationDate as AccountUpdateParamsCompanyRegistrationDate,
        AccountUpdateParamsCompanyRepresentativeDeclaration as AccountUpdateParamsCompanyRepresentativeDeclaration,
        AccountUpdateParamsCompanyVerification as AccountUpdateParamsCompanyVerification,
        AccountUpdateParamsCompanyVerificationDocument as AccountUpdateParamsCompanyVerificationDocument,
        AccountUpdateParamsDocuments as AccountUpdateParamsDocuments,
        AccountUpdateParamsDocumentsBankAccountOwnershipVerification as AccountUpdateParamsDocumentsBankAccountOwnershipVerification,
        AccountUpdateParamsDocumentsCompanyLicense as AccountUpdateParamsDocumentsCompanyLicense,
        AccountUpdateParamsDocumentsCompanyMemorandumOfAssociation as AccountUpdateParamsDocumentsCompanyMemorandumOfAssociation,
        AccountUpdateParamsDocumentsCompanyMinisterialDecree as AccountUpdateParamsDocumentsCompanyMinisterialDecree,
        AccountUpdateParamsDocumentsCompanyRegistrationVerification as AccountUpdateParamsDocumentsCompanyRegistrationVerification,
        AccountUpdateParamsDocumentsCompanyTaxIdVerification as AccountUpdateParamsDocumentsCompanyTaxIdVerification,
        AccountUpdateParamsDocumentsProofOfAddress as AccountUpdateParamsDocumentsProofOfAddress,
        AccountUpdateParamsDocumentsProofOfRegistration as AccountUpdateParamsDocumentsProofOfRegistration,
        AccountUpdateParamsDocumentsProofOfUltimateBeneficialOwnership as AccountUpdateParamsDocumentsProofOfUltimateBeneficialOwnership,
        AccountUpdateParamsGroups as AccountUpdateParamsGroups,
        AccountUpdateParamsIndividual as AccountUpdateParamsIndividual,
        AccountUpdateParamsIndividualAddress as AccountUpdateParamsIndividualAddress,
        AccountUpdateParamsIndividualAddressKana as AccountUpdateParamsIndividualAddressKana,
        AccountUpdateParamsIndividualAddressKanji as AccountUpdateParamsIndividualAddressKanji,
        AccountUpdateParamsIndividualDob as AccountUpdateParamsIndividualDob,
        AccountUpdateParamsIndividualRegisteredAddress as AccountUpdateParamsIndividualRegisteredAddress,
        AccountUpdateParamsIndividualRelationship as AccountUpdateParamsIndividualRelationship,
        AccountUpdateParamsIndividualSelfReportedIncome as AccountUpdateParamsIndividualSelfReportedIncome,
        AccountUpdateParamsIndividualSelfReportedMonthlyHousingPayment as AccountUpdateParamsIndividualSelfReportedMonthlyHousingPayment,
        AccountUpdateParamsIndividualVerification as AccountUpdateParamsIndividualVerification,
        AccountUpdateParamsIndividualVerificationAdditionalDocument as AccountUpdateParamsIndividualVerificationAdditionalDocument,
        AccountUpdateParamsIndividualVerificationDocument as AccountUpdateParamsIndividualVerificationDocument,
        AccountUpdateParamsRiskControls as AccountUpdateParamsRiskControls,
        AccountUpdateParamsRiskControlsCharges as AccountUpdateParamsRiskControlsCharges,
        AccountUpdateParamsRiskControlsPayouts as AccountUpdateParamsRiskControlsPayouts,
        AccountUpdateParamsSettings as AccountUpdateParamsSettings,
        AccountUpdateParamsSettingsBacsDebitPayments as AccountUpdateParamsSettingsBacsDebitPayments,
        AccountUpdateParamsSettingsBankBcaOnboarding as AccountUpdateParamsSettingsBankBcaOnboarding,
        AccountUpdateParamsSettingsBranding as AccountUpdateParamsSettingsBranding,
        AccountUpdateParamsSettingsCapital as AccountUpdateParamsSettingsCapital,
        AccountUpdateParamsSettingsCardIssuing as AccountUpdateParamsSettingsCardIssuing,
        AccountUpdateParamsSettingsCardIssuingTosAcceptance as AccountUpdateParamsSettingsCardIssuingTosAcceptance,
        AccountUpdateParamsSettingsCardPayments as AccountUpdateParamsSettingsCardPayments,
        AccountUpdateParamsSettingsCardPaymentsDeclineOn as AccountUpdateParamsSettingsCardPaymentsDeclineOn,
        AccountUpdateParamsSettingsInvoices as AccountUpdateParamsSettingsInvoices,
        AccountUpdateParamsSettingsPayments as AccountUpdateParamsSettingsPayments,
        AccountUpdateParamsSettingsPayouts as AccountUpdateParamsSettingsPayouts,
        AccountUpdateParamsSettingsPayoutsSchedule as AccountUpdateParamsSettingsPayoutsSchedule,
        AccountUpdateParamsSettingsPaypayPayments as AccountUpdateParamsSettingsPaypayPayments,
        AccountUpdateParamsSettingsTaxForms as AccountUpdateParamsSettingsTaxForms,
        AccountUpdateParamsSettingsTreasury as AccountUpdateParamsSettingsTreasury,
        AccountUpdateParamsSettingsTreasuryTosAcceptance as AccountUpdateParamsSettingsTreasuryTosAcceptance,
        AccountUpdateParamsTosAcceptance as AccountUpdateParamsTosAcceptance,
    )
    from stripe.params._apple_pay_domain_create_params import (
        ApplePayDomainCreateParams as ApplePayDomainCreateParams,
    )
    from stripe.params._apple_pay_domain_delete_params import (
        ApplePayDomainDeleteParams as ApplePayDomainDeleteParams,
    )
    from stripe.params._apple_pay_domain_list_params import (
        ApplePayDomainListParams as ApplePayDomainListParams,
    )
    from stripe.params._apple_pay_domain_retrieve_params import (
        ApplePayDomainRetrieveParams as ApplePayDomainRetrieveParams,
    )
    from stripe.params._application_fee_create_refund_params import (
        ApplicationFeeCreateRefundParams as ApplicationFeeCreateRefundParams,
    )
    from stripe.params._application_fee_list_params import (
        ApplicationFeeListParams as ApplicationFeeListParams,
        ApplicationFeeListParamsCreated as ApplicationFeeListParamsCreated,
    )
    from stripe.params._application_fee_list_refunds_params import (
        ApplicationFeeListRefundsParams as ApplicationFeeListRefundsParams,
    )
    from stripe.params._application_fee_modify_refund_params import (
        ApplicationFeeModifyRefundParams as ApplicationFeeModifyRefundParams,
    )
    from stripe.params._application_fee_refund_create_params import (
        ApplicationFeeRefundCreateParams as ApplicationFeeRefundCreateParams,
    )
    from stripe.params._application_fee_refund_list_params import (
        ApplicationFeeRefundListParams as ApplicationFeeRefundListParams,
    )
    from stripe.params._application_fee_refund_params import (
        ApplicationFeeRefundParams as ApplicationFeeRefundParams,
    )
    from stripe.params._application_fee_refund_retrieve_params import (
        ApplicationFeeRefundRetrieveParams as ApplicationFeeRefundRetrieveParams,
    )
    from stripe.params._application_fee_refund_update_params import (
        ApplicationFeeRefundUpdateParams as ApplicationFeeRefundUpdateParams,
    )
    from stripe.params._application_fee_retrieve_params import (
        ApplicationFeeRetrieveParams as ApplicationFeeRetrieveParams,
    )
    from stripe.params._application_fee_retrieve_refund_params import (
        ApplicationFeeRetrieveRefundParams as ApplicationFeeRetrieveRefundParams,
    )
    from stripe.params._balance_retrieve_params import (
        BalanceRetrieveParams as BalanceRetrieveParams,
    )
    from stripe.params._balance_settings_modify_params import (
        BalanceSettingsModifyParams as BalanceSettingsModifyParams,
        BalanceSettingsModifyParamsPayments as BalanceSettingsModifyParamsPayments,
        BalanceSettingsModifyParamsPaymentsPayouts as BalanceSettingsModifyParamsPaymentsPayouts,
        BalanceSettingsModifyParamsPaymentsPayoutsSchedule as BalanceSettingsModifyParamsPaymentsPayoutsSchedule,
        BalanceSettingsModifyParamsPaymentsSettlementTiming as BalanceSettingsModifyParamsPaymentsSettlementTiming,
    )
    from stripe.params._balance_settings_retrieve_params import (
        BalanceSettingsRetrieveParams as BalanceSettingsRetrieveParams,
    )
    from stripe.params._balance_settings_update_params import (
        BalanceSettingsUpdateParams as BalanceSettingsUpdateParams,
        BalanceSettingsUpdateParamsPayments as BalanceSettingsUpdateParamsPayments,
        BalanceSettingsUpdateParamsPaymentsPayouts as BalanceSettingsUpdateParamsPaymentsPayouts,
        BalanceSettingsUpdateParamsPaymentsPayoutsSchedule as BalanceSettingsUpdateParamsPaymentsPayoutsSchedule,
        BalanceSettingsUpdateParamsPaymentsSettlementTiming as BalanceSettingsUpdateParamsPaymentsSettlementTiming,
    )
    from stripe.params._balance_transaction_list_params import (
        BalanceTransactionListParams as BalanceTransactionListParams,
        BalanceTransactionListParamsCreated as BalanceTransactionListParamsCreated,
    )
    from stripe.params._balance_transaction_retrieve_params import (
        BalanceTransactionRetrieveParams as BalanceTransactionRetrieveParams,
    )
    from stripe.params._balance_transfer_create_params import (
        BalanceTransferCreateParams as BalanceTransferCreateParams,
        BalanceTransferCreateParamsDestinationBalance as BalanceTransferCreateParamsDestinationBalance,
        BalanceTransferCreateParamsSourceBalance as BalanceTransferCreateParamsSourceBalance,
        BalanceTransferCreateParamsSourceBalanceAllocatedFunds as BalanceTransferCreateParamsSourceBalanceAllocatedFunds,
    )
    from stripe.params._bank_account_delete_params import (
        BankAccountDeleteParams as BankAccountDeleteParams,
    )
    from stripe.params._card_delete_params import (
        CardDeleteParams as CardDeleteParams,
    )
    from stripe.params._charge_capture_params import (
        ChargeCaptureParams as ChargeCaptureParams,
        ChargeCaptureParamsPaymentDetails as ChargeCaptureParamsPaymentDetails,
        ChargeCaptureParamsPaymentDetailsCarRental as ChargeCaptureParamsPaymentDetailsCarRental,
        ChargeCaptureParamsPaymentDetailsCarRentalAffiliate as ChargeCaptureParamsPaymentDetailsCarRentalAffiliate,
        ChargeCaptureParamsPaymentDetailsCarRentalDatum as ChargeCaptureParamsPaymentDetailsCarRentalDatum,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumAffiliate as ChargeCaptureParamsPaymentDetailsCarRentalDatumAffiliate,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumDistance as ChargeCaptureParamsPaymentDetailsCarRentalDatumDistance,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumDriver as ChargeCaptureParamsPaymentDetailsCarRentalDatumDriver,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as ChargeCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOff as ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOff,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress as ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumInsurance as ChargeCaptureParamsPaymentDetailsCarRentalDatumInsurance,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumPickup as ChargeCaptureParamsPaymentDetailsCarRentalDatumPickup,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumPickupAddress as ChargeCaptureParamsPaymentDetailsCarRentalDatumPickupAddress,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumTotal as ChargeCaptureParamsPaymentDetailsCarRentalDatumTotal,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts as ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge as ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTax as ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTax,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax as ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        ChargeCaptureParamsPaymentDetailsCarRentalDatumVehicle as ChargeCaptureParamsPaymentDetailsCarRentalDatumVehicle,
        ChargeCaptureParamsPaymentDetailsCarRentalDelivery as ChargeCaptureParamsPaymentDetailsCarRentalDelivery,
        ChargeCaptureParamsPaymentDetailsCarRentalDeliveryRecipient as ChargeCaptureParamsPaymentDetailsCarRentalDeliveryRecipient,
        ChargeCaptureParamsPaymentDetailsCarRentalDistance as ChargeCaptureParamsPaymentDetailsCarRentalDistance,
        ChargeCaptureParamsPaymentDetailsCarRentalDriver as ChargeCaptureParamsPaymentDetailsCarRentalDriver,
        ChargeCaptureParamsPaymentDetailsCarRentalPickupAddress as ChargeCaptureParamsPaymentDetailsCarRentalPickupAddress,
        ChargeCaptureParamsPaymentDetailsCarRentalReturnAddress as ChargeCaptureParamsPaymentDetailsCarRentalReturnAddress,
        ChargeCaptureParamsPaymentDetailsEventDetails as ChargeCaptureParamsPaymentDetailsEventDetails,
        ChargeCaptureParamsPaymentDetailsEventDetailsAddress as ChargeCaptureParamsPaymentDetailsEventDetailsAddress,
        ChargeCaptureParamsPaymentDetailsEventDetailsAffiliate as ChargeCaptureParamsPaymentDetailsEventDetailsAffiliate,
        ChargeCaptureParamsPaymentDetailsEventDetailsDelivery as ChargeCaptureParamsPaymentDetailsEventDetailsDelivery,
        ChargeCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient as ChargeCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient,
        ChargeCaptureParamsPaymentDetailsFlight as ChargeCaptureParamsPaymentDetailsFlight,
        ChargeCaptureParamsPaymentDetailsFlightAffiliate as ChargeCaptureParamsPaymentDetailsFlightAffiliate,
        ChargeCaptureParamsPaymentDetailsFlightDatum as ChargeCaptureParamsPaymentDetailsFlightDatum,
        ChargeCaptureParamsPaymentDetailsFlightDatumAffiliate as ChargeCaptureParamsPaymentDetailsFlightDatumAffiliate,
        ChargeCaptureParamsPaymentDetailsFlightDatumInsurance as ChargeCaptureParamsPaymentDetailsFlightDatumInsurance,
        ChargeCaptureParamsPaymentDetailsFlightDatumPassenger as ChargeCaptureParamsPaymentDetailsFlightDatumPassenger,
        ChargeCaptureParamsPaymentDetailsFlightDatumSegment as ChargeCaptureParamsPaymentDetailsFlightDatumSegment,
        ChargeCaptureParamsPaymentDetailsFlightDatumSegmentArrival as ChargeCaptureParamsPaymentDetailsFlightDatumSegmentArrival,
        ChargeCaptureParamsPaymentDetailsFlightDatumSegmentDeparture as ChargeCaptureParamsPaymentDetailsFlightDatumSegmentDeparture,
        ChargeCaptureParamsPaymentDetailsFlightDatumTotal as ChargeCaptureParamsPaymentDetailsFlightDatumTotal,
        ChargeCaptureParamsPaymentDetailsFlightDatumTotalDiscounts as ChargeCaptureParamsPaymentDetailsFlightDatumTotalDiscounts,
        ChargeCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge as ChargeCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge,
        ChargeCaptureParamsPaymentDetailsFlightDatumTotalTax as ChargeCaptureParamsPaymentDetailsFlightDatumTotalTax,
        ChargeCaptureParamsPaymentDetailsFlightDatumTotalTaxTax as ChargeCaptureParamsPaymentDetailsFlightDatumTotalTaxTax,
        ChargeCaptureParamsPaymentDetailsFlightDelivery as ChargeCaptureParamsPaymentDetailsFlightDelivery,
        ChargeCaptureParamsPaymentDetailsFlightDeliveryRecipient as ChargeCaptureParamsPaymentDetailsFlightDeliveryRecipient,
        ChargeCaptureParamsPaymentDetailsFlightPassenger as ChargeCaptureParamsPaymentDetailsFlightPassenger,
        ChargeCaptureParamsPaymentDetailsFlightSegment as ChargeCaptureParamsPaymentDetailsFlightSegment,
        ChargeCaptureParamsPaymentDetailsLodging as ChargeCaptureParamsPaymentDetailsLodging,
        ChargeCaptureParamsPaymentDetailsLodgingAddress as ChargeCaptureParamsPaymentDetailsLodgingAddress,
        ChargeCaptureParamsPaymentDetailsLodgingAffiliate as ChargeCaptureParamsPaymentDetailsLodgingAffiliate,
        ChargeCaptureParamsPaymentDetailsLodgingDatum as ChargeCaptureParamsPaymentDetailsLodgingDatum,
        ChargeCaptureParamsPaymentDetailsLodgingDatumAccommodation as ChargeCaptureParamsPaymentDetailsLodgingDatumAccommodation,
        ChargeCaptureParamsPaymentDetailsLodgingDatumAffiliate as ChargeCaptureParamsPaymentDetailsLodgingDatumAffiliate,
        ChargeCaptureParamsPaymentDetailsLodgingDatumGuest as ChargeCaptureParamsPaymentDetailsLodgingDatumGuest,
        ChargeCaptureParamsPaymentDetailsLodgingDatumHost as ChargeCaptureParamsPaymentDetailsLodgingDatumHost,
        ChargeCaptureParamsPaymentDetailsLodgingDatumHostAddress as ChargeCaptureParamsPaymentDetailsLodgingDatumHostAddress,
        ChargeCaptureParamsPaymentDetailsLodgingDatumInsurance as ChargeCaptureParamsPaymentDetailsLodgingDatumInsurance,
        ChargeCaptureParamsPaymentDetailsLodgingDatumTotal as ChargeCaptureParamsPaymentDetailsLodgingDatumTotal,
        ChargeCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts as ChargeCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts,
        ChargeCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge as ChargeCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTax as ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTax,
        ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax as ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax,
        ChargeCaptureParamsPaymentDetailsLodgingDelivery as ChargeCaptureParamsPaymentDetailsLodgingDelivery,
        ChargeCaptureParamsPaymentDetailsLodgingDeliveryRecipient as ChargeCaptureParamsPaymentDetailsLodgingDeliveryRecipient,
        ChargeCaptureParamsPaymentDetailsLodgingPassenger as ChargeCaptureParamsPaymentDetailsLodgingPassenger,
        ChargeCaptureParamsPaymentDetailsSubscription as ChargeCaptureParamsPaymentDetailsSubscription,
        ChargeCaptureParamsPaymentDetailsSubscriptionAffiliate as ChargeCaptureParamsPaymentDetailsSubscriptionAffiliate,
        ChargeCaptureParamsPaymentDetailsSubscriptionBillingInterval as ChargeCaptureParamsPaymentDetailsSubscriptionBillingInterval,
        ChargeCaptureParamsTransferData as ChargeCaptureParamsTransferData,
    )
    from stripe.params._charge_create_params import (
        ChargeCreateParams as ChargeCreateParams,
        ChargeCreateParamsDestination as ChargeCreateParamsDestination,
        ChargeCreateParamsRadarOptions as ChargeCreateParamsRadarOptions,
        ChargeCreateParamsShipping as ChargeCreateParamsShipping,
        ChargeCreateParamsShippingAddress as ChargeCreateParamsShippingAddress,
        ChargeCreateParamsTransferData as ChargeCreateParamsTransferData,
    )
    from stripe.params._charge_list_params import (
        ChargeListParams as ChargeListParams,
        ChargeListParamsCreated as ChargeListParamsCreated,
    )
    from stripe.params._charge_list_refunds_params import (
        ChargeListRefundsParams as ChargeListRefundsParams,
    )
    from stripe.params._charge_modify_params import (
        ChargeModifyParams as ChargeModifyParams,
        ChargeModifyParamsFraudDetails as ChargeModifyParamsFraudDetails,
        ChargeModifyParamsPaymentDetails as ChargeModifyParamsPaymentDetails,
        ChargeModifyParamsPaymentDetailsCarRental as ChargeModifyParamsPaymentDetailsCarRental,
        ChargeModifyParamsPaymentDetailsCarRentalAffiliate as ChargeModifyParamsPaymentDetailsCarRentalAffiliate,
        ChargeModifyParamsPaymentDetailsCarRentalDatum as ChargeModifyParamsPaymentDetailsCarRentalDatum,
        ChargeModifyParamsPaymentDetailsCarRentalDatumAffiliate as ChargeModifyParamsPaymentDetailsCarRentalDatumAffiliate,
        ChargeModifyParamsPaymentDetailsCarRentalDatumDistance as ChargeModifyParamsPaymentDetailsCarRentalDatumDistance,
        ChargeModifyParamsPaymentDetailsCarRentalDatumDriver as ChargeModifyParamsPaymentDetailsCarRentalDatumDriver,
        ChargeModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as ChargeModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        ChargeModifyParamsPaymentDetailsCarRentalDatumDropOff as ChargeModifyParamsPaymentDetailsCarRentalDatumDropOff,
        ChargeModifyParamsPaymentDetailsCarRentalDatumDropOffAddress as ChargeModifyParamsPaymentDetailsCarRentalDatumDropOffAddress,
        ChargeModifyParamsPaymentDetailsCarRentalDatumInsurance as ChargeModifyParamsPaymentDetailsCarRentalDatumInsurance,
        ChargeModifyParamsPaymentDetailsCarRentalDatumPickup as ChargeModifyParamsPaymentDetailsCarRentalDatumPickup,
        ChargeModifyParamsPaymentDetailsCarRentalDatumPickupAddress as ChargeModifyParamsPaymentDetailsCarRentalDatumPickupAddress,
        ChargeModifyParamsPaymentDetailsCarRentalDatumTotal as ChargeModifyParamsPaymentDetailsCarRentalDatumTotal,
        ChargeModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts as ChargeModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        ChargeModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge as ChargeModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTax as ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTax,
        ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax as ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        ChargeModifyParamsPaymentDetailsCarRentalDatumVehicle as ChargeModifyParamsPaymentDetailsCarRentalDatumVehicle,
        ChargeModifyParamsPaymentDetailsCarRentalDelivery as ChargeModifyParamsPaymentDetailsCarRentalDelivery,
        ChargeModifyParamsPaymentDetailsCarRentalDeliveryRecipient as ChargeModifyParamsPaymentDetailsCarRentalDeliveryRecipient,
        ChargeModifyParamsPaymentDetailsCarRentalDistance as ChargeModifyParamsPaymentDetailsCarRentalDistance,
        ChargeModifyParamsPaymentDetailsCarRentalDriver as ChargeModifyParamsPaymentDetailsCarRentalDriver,
        ChargeModifyParamsPaymentDetailsCarRentalPickupAddress as ChargeModifyParamsPaymentDetailsCarRentalPickupAddress,
        ChargeModifyParamsPaymentDetailsCarRentalReturnAddress as ChargeModifyParamsPaymentDetailsCarRentalReturnAddress,
        ChargeModifyParamsPaymentDetailsEventDetails as ChargeModifyParamsPaymentDetailsEventDetails,
        ChargeModifyParamsPaymentDetailsEventDetailsAddress as ChargeModifyParamsPaymentDetailsEventDetailsAddress,
        ChargeModifyParamsPaymentDetailsEventDetailsAffiliate as ChargeModifyParamsPaymentDetailsEventDetailsAffiliate,
        ChargeModifyParamsPaymentDetailsEventDetailsDelivery as ChargeModifyParamsPaymentDetailsEventDetailsDelivery,
        ChargeModifyParamsPaymentDetailsEventDetailsDeliveryRecipient as ChargeModifyParamsPaymentDetailsEventDetailsDeliveryRecipient,
        ChargeModifyParamsPaymentDetailsFlight as ChargeModifyParamsPaymentDetailsFlight,
        ChargeModifyParamsPaymentDetailsFlightAffiliate as ChargeModifyParamsPaymentDetailsFlightAffiliate,
        ChargeModifyParamsPaymentDetailsFlightDatum as ChargeModifyParamsPaymentDetailsFlightDatum,
        ChargeModifyParamsPaymentDetailsFlightDatumAffiliate as ChargeModifyParamsPaymentDetailsFlightDatumAffiliate,
        ChargeModifyParamsPaymentDetailsFlightDatumInsurance as ChargeModifyParamsPaymentDetailsFlightDatumInsurance,
        ChargeModifyParamsPaymentDetailsFlightDatumPassenger as ChargeModifyParamsPaymentDetailsFlightDatumPassenger,
        ChargeModifyParamsPaymentDetailsFlightDatumSegment as ChargeModifyParamsPaymentDetailsFlightDatumSegment,
        ChargeModifyParamsPaymentDetailsFlightDatumSegmentArrival as ChargeModifyParamsPaymentDetailsFlightDatumSegmentArrival,
        ChargeModifyParamsPaymentDetailsFlightDatumSegmentDeparture as ChargeModifyParamsPaymentDetailsFlightDatumSegmentDeparture,
        ChargeModifyParamsPaymentDetailsFlightDatumTotal as ChargeModifyParamsPaymentDetailsFlightDatumTotal,
        ChargeModifyParamsPaymentDetailsFlightDatumTotalDiscounts as ChargeModifyParamsPaymentDetailsFlightDatumTotalDiscounts,
        ChargeModifyParamsPaymentDetailsFlightDatumTotalExtraCharge as ChargeModifyParamsPaymentDetailsFlightDatumTotalExtraCharge,
        ChargeModifyParamsPaymentDetailsFlightDatumTotalTax as ChargeModifyParamsPaymentDetailsFlightDatumTotalTax,
        ChargeModifyParamsPaymentDetailsFlightDatumTotalTaxTax as ChargeModifyParamsPaymentDetailsFlightDatumTotalTaxTax,
        ChargeModifyParamsPaymentDetailsFlightDelivery as ChargeModifyParamsPaymentDetailsFlightDelivery,
        ChargeModifyParamsPaymentDetailsFlightDeliveryRecipient as ChargeModifyParamsPaymentDetailsFlightDeliveryRecipient,
        ChargeModifyParamsPaymentDetailsFlightPassenger as ChargeModifyParamsPaymentDetailsFlightPassenger,
        ChargeModifyParamsPaymentDetailsFlightSegment as ChargeModifyParamsPaymentDetailsFlightSegment,
        ChargeModifyParamsPaymentDetailsLodging as ChargeModifyParamsPaymentDetailsLodging,
        ChargeModifyParamsPaymentDetailsLodgingAddress as ChargeModifyParamsPaymentDetailsLodgingAddress,
        ChargeModifyParamsPaymentDetailsLodgingAffiliate as ChargeModifyParamsPaymentDetailsLodgingAffiliate,
        ChargeModifyParamsPaymentDetailsLodgingDatum as ChargeModifyParamsPaymentDetailsLodgingDatum,
        ChargeModifyParamsPaymentDetailsLodgingDatumAccommodation as ChargeModifyParamsPaymentDetailsLodgingDatumAccommodation,
        ChargeModifyParamsPaymentDetailsLodgingDatumAffiliate as ChargeModifyParamsPaymentDetailsLodgingDatumAffiliate,
        ChargeModifyParamsPaymentDetailsLodgingDatumGuest as ChargeModifyParamsPaymentDetailsLodgingDatumGuest,
        ChargeModifyParamsPaymentDetailsLodgingDatumHost as ChargeModifyParamsPaymentDetailsLodgingDatumHost,
        ChargeModifyParamsPaymentDetailsLodgingDatumHostAddress as ChargeModifyParamsPaymentDetailsLodgingDatumHostAddress,
        ChargeModifyParamsPaymentDetailsLodgingDatumInsurance as ChargeModifyParamsPaymentDetailsLodgingDatumInsurance,
        ChargeModifyParamsPaymentDetailsLodgingDatumTotal as ChargeModifyParamsPaymentDetailsLodgingDatumTotal,
        ChargeModifyParamsPaymentDetailsLodgingDatumTotalDiscounts as ChargeModifyParamsPaymentDetailsLodgingDatumTotalDiscounts,
        ChargeModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge as ChargeModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        ChargeModifyParamsPaymentDetailsLodgingDatumTotalTax as ChargeModifyParamsPaymentDetailsLodgingDatumTotalTax,
        ChargeModifyParamsPaymentDetailsLodgingDatumTotalTaxTax as ChargeModifyParamsPaymentDetailsLodgingDatumTotalTaxTax,
        ChargeModifyParamsPaymentDetailsLodgingDelivery as ChargeModifyParamsPaymentDetailsLodgingDelivery,
        ChargeModifyParamsPaymentDetailsLodgingDeliveryRecipient as ChargeModifyParamsPaymentDetailsLodgingDeliveryRecipient,
        ChargeModifyParamsPaymentDetailsLodgingPassenger as ChargeModifyParamsPaymentDetailsLodgingPassenger,
        ChargeModifyParamsPaymentDetailsSubscription as ChargeModifyParamsPaymentDetailsSubscription,
        ChargeModifyParamsPaymentDetailsSubscriptionAffiliate as ChargeModifyParamsPaymentDetailsSubscriptionAffiliate,
        ChargeModifyParamsPaymentDetailsSubscriptionBillingInterval as ChargeModifyParamsPaymentDetailsSubscriptionBillingInterval,
        ChargeModifyParamsShipping as ChargeModifyParamsShipping,
        ChargeModifyParamsShippingAddress as ChargeModifyParamsShippingAddress,
    )
    from stripe.params._charge_retrieve_params import (
        ChargeRetrieveParams as ChargeRetrieveParams,
    )
    from stripe.params._charge_retrieve_refund_params import (
        ChargeRetrieveRefundParams as ChargeRetrieveRefundParams,
    )
    from stripe.params._charge_search_params import (
        ChargeSearchParams as ChargeSearchParams,
    )
    from stripe.params._charge_update_params import (
        ChargeUpdateParams as ChargeUpdateParams,
        ChargeUpdateParamsFraudDetails as ChargeUpdateParamsFraudDetails,
        ChargeUpdateParamsPaymentDetails as ChargeUpdateParamsPaymentDetails,
        ChargeUpdateParamsPaymentDetailsCarRental as ChargeUpdateParamsPaymentDetailsCarRental,
        ChargeUpdateParamsPaymentDetailsCarRentalAffiliate as ChargeUpdateParamsPaymentDetailsCarRentalAffiliate,
        ChargeUpdateParamsPaymentDetailsCarRentalDatum as ChargeUpdateParamsPaymentDetailsCarRentalDatum,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumAffiliate as ChargeUpdateParamsPaymentDetailsCarRentalDatumAffiliate,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumDistance as ChargeUpdateParamsPaymentDetailsCarRentalDatumDistance,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumDriver as ChargeUpdateParamsPaymentDetailsCarRentalDatumDriver,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as ChargeUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOff as ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOff,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress as ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumInsurance as ChargeUpdateParamsPaymentDetailsCarRentalDatumInsurance,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumPickup as ChargeUpdateParamsPaymentDetailsCarRentalDatumPickup,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumPickupAddress as ChargeUpdateParamsPaymentDetailsCarRentalDatumPickupAddress,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumTotal as ChargeUpdateParamsPaymentDetailsCarRentalDatumTotal,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts as ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge as ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTax as ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTax,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax as ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        ChargeUpdateParamsPaymentDetailsCarRentalDatumVehicle as ChargeUpdateParamsPaymentDetailsCarRentalDatumVehicle,
        ChargeUpdateParamsPaymentDetailsCarRentalDelivery as ChargeUpdateParamsPaymentDetailsCarRentalDelivery,
        ChargeUpdateParamsPaymentDetailsCarRentalDeliveryRecipient as ChargeUpdateParamsPaymentDetailsCarRentalDeliveryRecipient,
        ChargeUpdateParamsPaymentDetailsCarRentalDistance as ChargeUpdateParamsPaymentDetailsCarRentalDistance,
        ChargeUpdateParamsPaymentDetailsCarRentalDriver as ChargeUpdateParamsPaymentDetailsCarRentalDriver,
        ChargeUpdateParamsPaymentDetailsCarRentalPickupAddress as ChargeUpdateParamsPaymentDetailsCarRentalPickupAddress,
        ChargeUpdateParamsPaymentDetailsCarRentalReturnAddress as ChargeUpdateParamsPaymentDetailsCarRentalReturnAddress,
        ChargeUpdateParamsPaymentDetailsEventDetails as ChargeUpdateParamsPaymentDetailsEventDetails,
        ChargeUpdateParamsPaymentDetailsEventDetailsAddress as ChargeUpdateParamsPaymentDetailsEventDetailsAddress,
        ChargeUpdateParamsPaymentDetailsEventDetailsAffiliate as ChargeUpdateParamsPaymentDetailsEventDetailsAffiliate,
        ChargeUpdateParamsPaymentDetailsEventDetailsDelivery as ChargeUpdateParamsPaymentDetailsEventDetailsDelivery,
        ChargeUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient as ChargeUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient,
        ChargeUpdateParamsPaymentDetailsFlight as ChargeUpdateParamsPaymentDetailsFlight,
        ChargeUpdateParamsPaymentDetailsFlightAffiliate as ChargeUpdateParamsPaymentDetailsFlightAffiliate,
        ChargeUpdateParamsPaymentDetailsFlightDatum as ChargeUpdateParamsPaymentDetailsFlightDatum,
        ChargeUpdateParamsPaymentDetailsFlightDatumAffiliate as ChargeUpdateParamsPaymentDetailsFlightDatumAffiliate,
        ChargeUpdateParamsPaymentDetailsFlightDatumInsurance as ChargeUpdateParamsPaymentDetailsFlightDatumInsurance,
        ChargeUpdateParamsPaymentDetailsFlightDatumPassenger as ChargeUpdateParamsPaymentDetailsFlightDatumPassenger,
        ChargeUpdateParamsPaymentDetailsFlightDatumSegment as ChargeUpdateParamsPaymentDetailsFlightDatumSegment,
        ChargeUpdateParamsPaymentDetailsFlightDatumSegmentArrival as ChargeUpdateParamsPaymentDetailsFlightDatumSegmentArrival,
        ChargeUpdateParamsPaymentDetailsFlightDatumSegmentDeparture as ChargeUpdateParamsPaymentDetailsFlightDatumSegmentDeparture,
        ChargeUpdateParamsPaymentDetailsFlightDatumTotal as ChargeUpdateParamsPaymentDetailsFlightDatumTotal,
        ChargeUpdateParamsPaymentDetailsFlightDatumTotalDiscounts as ChargeUpdateParamsPaymentDetailsFlightDatumTotalDiscounts,
        ChargeUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge as ChargeUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge,
        ChargeUpdateParamsPaymentDetailsFlightDatumTotalTax as ChargeUpdateParamsPaymentDetailsFlightDatumTotalTax,
        ChargeUpdateParamsPaymentDetailsFlightDatumTotalTaxTax as ChargeUpdateParamsPaymentDetailsFlightDatumTotalTaxTax,
        ChargeUpdateParamsPaymentDetailsFlightDelivery as ChargeUpdateParamsPaymentDetailsFlightDelivery,
        ChargeUpdateParamsPaymentDetailsFlightDeliveryRecipient as ChargeUpdateParamsPaymentDetailsFlightDeliveryRecipient,
        ChargeUpdateParamsPaymentDetailsFlightPassenger as ChargeUpdateParamsPaymentDetailsFlightPassenger,
        ChargeUpdateParamsPaymentDetailsFlightSegment as ChargeUpdateParamsPaymentDetailsFlightSegment,
        ChargeUpdateParamsPaymentDetailsLodging as ChargeUpdateParamsPaymentDetailsLodging,
        ChargeUpdateParamsPaymentDetailsLodgingAddress as ChargeUpdateParamsPaymentDetailsLodgingAddress,
        ChargeUpdateParamsPaymentDetailsLodgingAffiliate as ChargeUpdateParamsPaymentDetailsLodgingAffiliate,
        ChargeUpdateParamsPaymentDetailsLodgingDatum as ChargeUpdateParamsPaymentDetailsLodgingDatum,
        ChargeUpdateParamsPaymentDetailsLodgingDatumAccommodation as ChargeUpdateParamsPaymentDetailsLodgingDatumAccommodation,
        ChargeUpdateParamsPaymentDetailsLodgingDatumAffiliate as ChargeUpdateParamsPaymentDetailsLodgingDatumAffiliate,
        ChargeUpdateParamsPaymentDetailsLodgingDatumGuest as ChargeUpdateParamsPaymentDetailsLodgingDatumGuest,
        ChargeUpdateParamsPaymentDetailsLodgingDatumHost as ChargeUpdateParamsPaymentDetailsLodgingDatumHost,
        ChargeUpdateParamsPaymentDetailsLodgingDatumHostAddress as ChargeUpdateParamsPaymentDetailsLodgingDatumHostAddress,
        ChargeUpdateParamsPaymentDetailsLodgingDatumInsurance as ChargeUpdateParamsPaymentDetailsLodgingDatumInsurance,
        ChargeUpdateParamsPaymentDetailsLodgingDatumTotal as ChargeUpdateParamsPaymentDetailsLodgingDatumTotal,
        ChargeUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts as ChargeUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts,
        ChargeUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge as ChargeUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTax as ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTax,
        ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax as ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax,
        ChargeUpdateParamsPaymentDetailsLodgingDelivery as ChargeUpdateParamsPaymentDetailsLodgingDelivery,
        ChargeUpdateParamsPaymentDetailsLodgingDeliveryRecipient as ChargeUpdateParamsPaymentDetailsLodgingDeliveryRecipient,
        ChargeUpdateParamsPaymentDetailsLodgingPassenger as ChargeUpdateParamsPaymentDetailsLodgingPassenger,
        ChargeUpdateParamsPaymentDetailsSubscription as ChargeUpdateParamsPaymentDetailsSubscription,
        ChargeUpdateParamsPaymentDetailsSubscriptionAffiliate as ChargeUpdateParamsPaymentDetailsSubscriptionAffiliate,
        ChargeUpdateParamsPaymentDetailsSubscriptionBillingInterval as ChargeUpdateParamsPaymentDetailsSubscriptionBillingInterval,
        ChargeUpdateParamsShipping as ChargeUpdateParamsShipping,
        ChargeUpdateParamsShippingAddress as ChargeUpdateParamsShippingAddress,
    )
    from stripe.params._confirmation_token_create_params import (
        ConfirmationTokenCreateParams as ConfirmationTokenCreateParams,
        ConfirmationTokenCreateParamsPaymentMethodData as ConfirmationTokenCreateParamsPaymentMethodData,
        ConfirmationTokenCreateParamsPaymentMethodDataAcssDebit as ConfirmationTokenCreateParamsPaymentMethodDataAcssDebit,
        ConfirmationTokenCreateParamsPaymentMethodDataAffirm as ConfirmationTokenCreateParamsPaymentMethodDataAffirm,
        ConfirmationTokenCreateParamsPaymentMethodDataAfterpayClearpay as ConfirmationTokenCreateParamsPaymentMethodDataAfterpayClearpay,
        ConfirmationTokenCreateParamsPaymentMethodDataAlipay as ConfirmationTokenCreateParamsPaymentMethodDataAlipay,
        ConfirmationTokenCreateParamsPaymentMethodDataAlma as ConfirmationTokenCreateParamsPaymentMethodDataAlma,
        ConfirmationTokenCreateParamsPaymentMethodDataAmazonPay as ConfirmationTokenCreateParamsPaymentMethodDataAmazonPay,
        ConfirmationTokenCreateParamsPaymentMethodDataAuBecsDebit as ConfirmationTokenCreateParamsPaymentMethodDataAuBecsDebit,
        ConfirmationTokenCreateParamsPaymentMethodDataBacsDebit as ConfirmationTokenCreateParamsPaymentMethodDataBacsDebit,
        ConfirmationTokenCreateParamsPaymentMethodDataBancontact as ConfirmationTokenCreateParamsPaymentMethodDataBancontact,
        ConfirmationTokenCreateParamsPaymentMethodDataBillie as ConfirmationTokenCreateParamsPaymentMethodDataBillie,
        ConfirmationTokenCreateParamsPaymentMethodDataBillingDetails as ConfirmationTokenCreateParamsPaymentMethodDataBillingDetails,
        ConfirmationTokenCreateParamsPaymentMethodDataBillingDetailsAddress as ConfirmationTokenCreateParamsPaymentMethodDataBillingDetailsAddress,
        ConfirmationTokenCreateParamsPaymentMethodDataBlik as ConfirmationTokenCreateParamsPaymentMethodDataBlik,
        ConfirmationTokenCreateParamsPaymentMethodDataBoleto as ConfirmationTokenCreateParamsPaymentMethodDataBoleto,
        ConfirmationTokenCreateParamsPaymentMethodDataCashapp as ConfirmationTokenCreateParamsPaymentMethodDataCashapp,
        ConfirmationTokenCreateParamsPaymentMethodDataCrypto as ConfirmationTokenCreateParamsPaymentMethodDataCrypto,
        ConfirmationTokenCreateParamsPaymentMethodDataCustomerBalance as ConfirmationTokenCreateParamsPaymentMethodDataCustomerBalance,
        ConfirmationTokenCreateParamsPaymentMethodDataEps as ConfirmationTokenCreateParamsPaymentMethodDataEps,
        ConfirmationTokenCreateParamsPaymentMethodDataFpx as ConfirmationTokenCreateParamsPaymentMethodDataFpx,
        ConfirmationTokenCreateParamsPaymentMethodDataGiropay as ConfirmationTokenCreateParamsPaymentMethodDataGiropay,
        ConfirmationTokenCreateParamsPaymentMethodDataGopay as ConfirmationTokenCreateParamsPaymentMethodDataGopay,
        ConfirmationTokenCreateParamsPaymentMethodDataGrabpay as ConfirmationTokenCreateParamsPaymentMethodDataGrabpay,
        ConfirmationTokenCreateParamsPaymentMethodDataIdBankTransfer as ConfirmationTokenCreateParamsPaymentMethodDataIdBankTransfer,
        ConfirmationTokenCreateParamsPaymentMethodDataIdeal as ConfirmationTokenCreateParamsPaymentMethodDataIdeal,
        ConfirmationTokenCreateParamsPaymentMethodDataInteracPresent as ConfirmationTokenCreateParamsPaymentMethodDataInteracPresent,
        ConfirmationTokenCreateParamsPaymentMethodDataKakaoPay as ConfirmationTokenCreateParamsPaymentMethodDataKakaoPay,
        ConfirmationTokenCreateParamsPaymentMethodDataKlarna as ConfirmationTokenCreateParamsPaymentMethodDataKlarna,
        ConfirmationTokenCreateParamsPaymentMethodDataKlarnaDob as ConfirmationTokenCreateParamsPaymentMethodDataKlarnaDob,
        ConfirmationTokenCreateParamsPaymentMethodDataKonbini as ConfirmationTokenCreateParamsPaymentMethodDataKonbini,
        ConfirmationTokenCreateParamsPaymentMethodDataKrCard as ConfirmationTokenCreateParamsPaymentMethodDataKrCard,
        ConfirmationTokenCreateParamsPaymentMethodDataLink as ConfirmationTokenCreateParamsPaymentMethodDataLink,
        ConfirmationTokenCreateParamsPaymentMethodDataMbWay as ConfirmationTokenCreateParamsPaymentMethodDataMbWay,
        ConfirmationTokenCreateParamsPaymentMethodDataMobilepay as ConfirmationTokenCreateParamsPaymentMethodDataMobilepay,
        ConfirmationTokenCreateParamsPaymentMethodDataMultibanco as ConfirmationTokenCreateParamsPaymentMethodDataMultibanco,
        ConfirmationTokenCreateParamsPaymentMethodDataNaverPay as ConfirmationTokenCreateParamsPaymentMethodDataNaverPay,
        ConfirmationTokenCreateParamsPaymentMethodDataNzBankAccount as ConfirmationTokenCreateParamsPaymentMethodDataNzBankAccount,
        ConfirmationTokenCreateParamsPaymentMethodDataOxxo as ConfirmationTokenCreateParamsPaymentMethodDataOxxo,
        ConfirmationTokenCreateParamsPaymentMethodDataP24 as ConfirmationTokenCreateParamsPaymentMethodDataP24,
        ConfirmationTokenCreateParamsPaymentMethodDataPayByBank as ConfirmationTokenCreateParamsPaymentMethodDataPayByBank,
        ConfirmationTokenCreateParamsPaymentMethodDataPayco as ConfirmationTokenCreateParamsPaymentMethodDataPayco,
        ConfirmationTokenCreateParamsPaymentMethodDataPaynow as ConfirmationTokenCreateParamsPaymentMethodDataPaynow,
        ConfirmationTokenCreateParamsPaymentMethodDataPaypal as ConfirmationTokenCreateParamsPaymentMethodDataPaypal,
        ConfirmationTokenCreateParamsPaymentMethodDataPaypay as ConfirmationTokenCreateParamsPaymentMethodDataPaypay,
        ConfirmationTokenCreateParamsPaymentMethodDataPayto as ConfirmationTokenCreateParamsPaymentMethodDataPayto,
        ConfirmationTokenCreateParamsPaymentMethodDataPix as ConfirmationTokenCreateParamsPaymentMethodDataPix,
        ConfirmationTokenCreateParamsPaymentMethodDataPromptpay as ConfirmationTokenCreateParamsPaymentMethodDataPromptpay,
        ConfirmationTokenCreateParamsPaymentMethodDataQris as ConfirmationTokenCreateParamsPaymentMethodDataQris,
        ConfirmationTokenCreateParamsPaymentMethodDataRadarOptions as ConfirmationTokenCreateParamsPaymentMethodDataRadarOptions,
        ConfirmationTokenCreateParamsPaymentMethodDataRechnung as ConfirmationTokenCreateParamsPaymentMethodDataRechnung,
        ConfirmationTokenCreateParamsPaymentMethodDataRechnungDob as ConfirmationTokenCreateParamsPaymentMethodDataRechnungDob,
        ConfirmationTokenCreateParamsPaymentMethodDataRevolutPay as ConfirmationTokenCreateParamsPaymentMethodDataRevolutPay,
        ConfirmationTokenCreateParamsPaymentMethodDataSamsungPay as ConfirmationTokenCreateParamsPaymentMethodDataSamsungPay,
        ConfirmationTokenCreateParamsPaymentMethodDataSatispay as ConfirmationTokenCreateParamsPaymentMethodDataSatispay,
        ConfirmationTokenCreateParamsPaymentMethodDataSepaDebit as ConfirmationTokenCreateParamsPaymentMethodDataSepaDebit,
        ConfirmationTokenCreateParamsPaymentMethodDataShopeepay as ConfirmationTokenCreateParamsPaymentMethodDataShopeepay,
        ConfirmationTokenCreateParamsPaymentMethodDataSofort as ConfirmationTokenCreateParamsPaymentMethodDataSofort,
        ConfirmationTokenCreateParamsPaymentMethodDataStripeBalance as ConfirmationTokenCreateParamsPaymentMethodDataStripeBalance,
        ConfirmationTokenCreateParamsPaymentMethodDataSwish as ConfirmationTokenCreateParamsPaymentMethodDataSwish,
        ConfirmationTokenCreateParamsPaymentMethodDataTwint as ConfirmationTokenCreateParamsPaymentMethodDataTwint,
        ConfirmationTokenCreateParamsPaymentMethodDataUsBankAccount as ConfirmationTokenCreateParamsPaymentMethodDataUsBankAccount,
        ConfirmationTokenCreateParamsPaymentMethodDataWechatPay as ConfirmationTokenCreateParamsPaymentMethodDataWechatPay,
        ConfirmationTokenCreateParamsPaymentMethodDataZip as ConfirmationTokenCreateParamsPaymentMethodDataZip,
        ConfirmationTokenCreateParamsPaymentMethodOptions as ConfirmationTokenCreateParamsPaymentMethodOptions,
        ConfirmationTokenCreateParamsPaymentMethodOptionsCard as ConfirmationTokenCreateParamsPaymentMethodOptionsCard,
        ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallments as ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallments,
        ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallmentsPlan as ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallmentsPlan,
        ConfirmationTokenCreateParamsShipping as ConfirmationTokenCreateParamsShipping,
        ConfirmationTokenCreateParamsShippingAddress as ConfirmationTokenCreateParamsShippingAddress,
    )
    from stripe.params._confirmation_token_retrieve_params import (
        ConfirmationTokenRetrieveParams as ConfirmationTokenRetrieveParams,
    )
    from stripe.params._country_spec_list_params import (
        CountrySpecListParams as CountrySpecListParams,
    )
    from stripe.params._country_spec_retrieve_params import (
        CountrySpecRetrieveParams as CountrySpecRetrieveParams,
    )
    from stripe.params._coupon_create_params import (
        CouponCreateParams as CouponCreateParams,
        CouponCreateParamsAppliesTo as CouponCreateParamsAppliesTo,
        CouponCreateParamsCurrencyOptions as CouponCreateParamsCurrencyOptions,
        CouponCreateParamsScript as CouponCreateParamsScript,
    )
    from stripe.params._coupon_delete_params import (
        CouponDeleteParams as CouponDeleteParams,
    )
    from stripe.params._coupon_list_params import (
        CouponListParams as CouponListParams,
        CouponListParamsCreated as CouponListParamsCreated,
    )
    from stripe.params._coupon_modify_params import (
        CouponModifyParams as CouponModifyParams,
        CouponModifyParamsCurrencyOptions as CouponModifyParamsCurrencyOptions,
    )
    from stripe.params._coupon_retrieve_params import (
        CouponRetrieveParams as CouponRetrieveParams,
    )
    from stripe.params._coupon_update_params import (
        CouponUpdateParams as CouponUpdateParams,
        CouponUpdateParamsCurrencyOptions as CouponUpdateParamsCurrencyOptions,
    )
    from stripe.params._credit_note_create_params import (
        CreditNoteCreateParams as CreditNoteCreateParams,
        CreditNoteCreateParamsLine as CreditNoteCreateParamsLine,
        CreditNoteCreateParamsLineTaxAmount as CreditNoteCreateParamsLineTaxAmount,
        CreditNoteCreateParamsRefund as CreditNoteCreateParamsRefund,
        CreditNoteCreateParamsRefundPaymentRecordRefund as CreditNoteCreateParamsRefundPaymentRecordRefund,
        CreditNoteCreateParamsShippingCost as CreditNoteCreateParamsShippingCost,
    )
    from stripe.params._credit_note_line_item_list_params import (
        CreditNoteLineItemListParams as CreditNoteLineItemListParams,
    )
    from stripe.params._credit_note_list_lines_params import (
        CreditNoteListLinesParams as CreditNoteListLinesParams,
    )
    from stripe.params._credit_note_list_params import (
        CreditNoteListParams as CreditNoteListParams,
        CreditNoteListParamsCreated as CreditNoteListParamsCreated,
    )
    from stripe.params._credit_note_modify_params import (
        CreditNoteModifyParams as CreditNoteModifyParams,
    )
    from stripe.params._credit_note_preview_lines_list_params import (
        CreditNotePreviewLinesListParams as CreditNotePreviewLinesListParams,
        CreditNotePreviewLinesListParamsLine as CreditNotePreviewLinesListParamsLine,
        CreditNotePreviewLinesListParamsLineTaxAmount as CreditNotePreviewLinesListParamsLineTaxAmount,
        CreditNotePreviewLinesListParamsRefund as CreditNotePreviewLinesListParamsRefund,
        CreditNotePreviewLinesListParamsRefundPaymentRecordRefund as CreditNotePreviewLinesListParamsRefundPaymentRecordRefund,
        CreditNotePreviewLinesListParamsShippingCost as CreditNotePreviewLinesListParamsShippingCost,
    )
    from stripe.params._credit_note_preview_lines_params import (
        CreditNotePreviewLinesParams as CreditNotePreviewLinesParams,
        CreditNotePreviewLinesParamsLine as CreditNotePreviewLinesParamsLine,
        CreditNotePreviewLinesParamsLineTaxAmount as CreditNotePreviewLinesParamsLineTaxAmount,
        CreditNotePreviewLinesParamsRefund as CreditNotePreviewLinesParamsRefund,
        CreditNotePreviewLinesParamsRefundPaymentRecordRefund as CreditNotePreviewLinesParamsRefundPaymentRecordRefund,
        CreditNotePreviewLinesParamsShippingCost as CreditNotePreviewLinesParamsShippingCost,
    )
    from stripe.params._credit_note_preview_params import (
        CreditNotePreviewParams as CreditNotePreviewParams,
        CreditNotePreviewParamsLine as CreditNotePreviewParamsLine,
        CreditNotePreviewParamsLineTaxAmount as CreditNotePreviewParamsLineTaxAmount,
        CreditNotePreviewParamsRefund as CreditNotePreviewParamsRefund,
        CreditNotePreviewParamsRefundPaymentRecordRefund as CreditNotePreviewParamsRefundPaymentRecordRefund,
        CreditNotePreviewParamsShippingCost as CreditNotePreviewParamsShippingCost,
    )
    from stripe.params._credit_note_retrieve_params import (
        CreditNoteRetrieveParams as CreditNoteRetrieveParams,
    )
    from stripe.params._credit_note_update_params import (
        CreditNoteUpdateParams as CreditNoteUpdateParams,
    )
    from stripe.params._credit_note_void_credit_note_params import (
        CreditNoteVoidCreditNoteParams as CreditNoteVoidCreditNoteParams,
    )
    from stripe.params._customer_balance_transaction_create_params import (
        CustomerBalanceTransactionCreateParams as CustomerBalanceTransactionCreateParams,
    )
    from stripe.params._customer_balance_transaction_list_params import (
        CustomerBalanceTransactionListParams as CustomerBalanceTransactionListParams,
        CustomerBalanceTransactionListParamsCreated as CustomerBalanceTransactionListParamsCreated,
    )
    from stripe.params._customer_balance_transaction_retrieve_params import (
        CustomerBalanceTransactionRetrieveParams as CustomerBalanceTransactionRetrieveParams,
    )
    from stripe.params._customer_balance_transaction_update_params import (
        CustomerBalanceTransactionUpdateParams as CustomerBalanceTransactionUpdateParams,
    )
    from stripe.params._customer_cash_balance_retrieve_params import (
        CustomerCashBalanceRetrieveParams as CustomerCashBalanceRetrieveParams,
    )
    from stripe.params._customer_cash_balance_transaction_list_params import (
        CustomerCashBalanceTransactionListParams as CustomerCashBalanceTransactionListParams,
    )
    from stripe.params._customer_cash_balance_transaction_retrieve_params import (
        CustomerCashBalanceTransactionRetrieveParams as CustomerCashBalanceTransactionRetrieveParams,
    )
    from stripe.params._customer_cash_balance_update_params import (
        CustomerCashBalanceUpdateParams as CustomerCashBalanceUpdateParams,
        CustomerCashBalanceUpdateParamsSettings as CustomerCashBalanceUpdateParamsSettings,
    )
    from stripe.params._customer_create_balance_transaction_params import (
        CustomerCreateBalanceTransactionParams as CustomerCreateBalanceTransactionParams,
    )
    from stripe.params._customer_create_funding_instructions_params import (
        CustomerCreateFundingInstructionsParams as CustomerCreateFundingInstructionsParams,
        CustomerCreateFundingInstructionsParamsBankTransfer as CustomerCreateFundingInstructionsParamsBankTransfer,
        CustomerCreateFundingInstructionsParamsBankTransferEuBankTransfer as CustomerCreateFundingInstructionsParamsBankTransferEuBankTransfer,
    )
    from stripe.params._customer_create_params import (
        CustomerCreateParams as CustomerCreateParams,
        CustomerCreateParamsAddress as CustomerCreateParamsAddress,
        CustomerCreateParamsCashBalance as CustomerCreateParamsCashBalance,
        CustomerCreateParamsCashBalanceSettings as CustomerCreateParamsCashBalanceSettings,
        CustomerCreateParamsInvoiceSettings as CustomerCreateParamsInvoiceSettings,
        CustomerCreateParamsInvoiceSettingsCustomField as CustomerCreateParamsInvoiceSettingsCustomField,
        CustomerCreateParamsInvoiceSettingsRenderingOptions as CustomerCreateParamsInvoiceSettingsRenderingOptions,
        CustomerCreateParamsShipping as CustomerCreateParamsShipping,
        CustomerCreateParamsShippingAddress as CustomerCreateParamsShippingAddress,
        CustomerCreateParamsTax as CustomerCreateParamsTax,
        CustomerCreateParamsTaxIdDatum as CustomerCreateParamsTaxIdDatum,
    )
    from stripe.params._customer_create_source_params import (
        CustomerCreateSourceParams as CustomerCreateSourceParams,
    )
    from stripe.params._customer_create_tax_id_params import (
        CustomerCreateTaxIdParams as CustomerCreateTaxIdParams,
    )
    from stripe.params._customer_delete_discount_params import (
        CustomerDeleteDiscountParams as CustomerDeleteDiscountParams,
    )
    from stripe.params._customer_delete_params import (
        CustomerDeleteParams as CustomerDeleteParams,
    )
    from stripe.params._customer_delete_source_params import (
        CustomerDeleteSourceParams as CustomerDeleteSourceParams,
    )
    from stripe.params._customer_delete_tax_id_params import (
        CustomerDeleteTaxIdParams as CustomerDeleteTaxIdParams,
    )
    from stripe.params._customer_fund_cash_balance_params import (
        CustomerFundCashBalanceParams as CustomerFundCashBalanceParams,
    )
    from stripe.params._customer_funding_instructions_create_params import (
        CustomerFundingInstructionsCreateParams as CustomerFundingInstructionsCreateParams,
        CustomerFundingInstructionsCreateParamsBankTransfer as CustomerFundingInstructionsCreateParamsBankTransfer,
        CustomerFundingInstructionsCreateParamsBankTransferEuBankTransfer as CustomerFundingInstructionsCreateParamsBankTransferEuBankTransfer,
    )
    from stripe.params._customer_list_balance_transactions_params import (
        CustomerListBalanceTransactionsParams as CustomerListBalanceTransactionsParams,
        CustomerListBalanceTransactionsParamsCreated as CustomerListBalanceTransactionsParamsCreated,
    )
    from stripe.params._customer_list_cash_balance_transactions_params import (
        CustomerListCashBalanceTransactionsParams as CustomerListCashBalanceTransactionsParams,
    )
    from stripe.params._customer_list_params import (
        CustomerListParams as CustomerListParams,
        CustomerListParamsCreated as CustomerListParamsCreated,
    )
    from stripe.params._customer_list_payment_methods_params import (
        CustomerListPaymentMethodsParams as CustomerListPaymentMethodsParams,
    )
    from stripe.params._customer_list_sources_params import (
        CustomerListSourcesParams as CustomerListSourcesParams,
    )
    from stripe.params._customer_list_tax_ids_params import (
        CustomerListTaxIdsParams as CustomerListTaxIdsParams,
    )
    from stripe.params._customer_modify_balance_transaction_params import (
        CustomerModifyBalanceTransactionParams as CustomerModifyBalanceTransactionParams,
    )
    from stripe.params._customer_modify_cash_balance_params import (
        CustomerModifyCashBalanceParams as CustomerModifyCashBalanceParams,
        CustomerModifyCashBalanceParamsSettings as CustomerModifyCashBalanceParamsSettings,
    )
    from stripe.params._customer_modify_params import (
        CustomerModifyParams as CustomerModifyParams,
        CustomerModifyParamsAddress as CustomerModifyParamsAddress,
        CustomerModifyParamsCashBalance as CustomerModifyParamsCashBalance,
        CustomerModifyParamsCashBalanceSettings as CustomerModifyParamsCashBalanceSettings,
        CustomerModifyParamsInvoiceSettings as CustomerModifyParamsInvoiceSettings,
        CustomerModifyParamsInvoiceSettingsCustomField as CustomerModifyParamsInvoiceSettingsCustomField,
        CustomerModifyParamsInvoiceSettingsRenderingOptions as CustomerModifyParamsInvoiceSettingsRenderingOptions,
        CustomerModifyParamsShipping as CustomerModifyParamsShipping,
        CustomerModifyParamsShippingAddress as CustomerModifyParamsShippingAddress,
        CustomerModifyParamsTax as CustomerModifyParamsTax,
    )
    from stripe.params._customer_modify_source_params import (
        CustomerModifySourceParams as CustomerModifySourceParams,
        CustomerModifySourceParamsOwner as CustomerModifySourceParamsOwner,
        CustomerModifySourceParamsOwnerAddress as CustomerModifySourceParamsOwnerAddress,
    )
    from stripe.params._customer_payment_method_list_params import (
        CustomerPaymentMethodListParams as CustomerPaymentMethodListParams,
    )
    from stripe.params._customer_payment_method_retrieve_params import (
        CustomerPaymentMethodRetrieveParams as CustomerPaymentMethodRetrieveParams,
    )
    from stripe.params._customer_payment_source_create_params import (
        CustomerPaymentSourceCreateParams as CustomerPaymentSourceCreateParams,
    )
    from stripe.params._customer_payment_source_delete_params import (
        CustomerPaymentSourceDeleteParams as CustomerPaymentSourceDeleteParams,
    )
    from stripe.params._customer_payment_source_list_params import (
        CustomerPaymentSourceListParams as CustomerPaymentSourceListParams,
    )
    from stripe.params._customer_payment_source_retrieve_params import (
        CustomerPaymentSourceRetrieveParams as CustomerPaymentSourceRetrieveParams,
    )
    from stripe.params._customer_payment_source_update_params import (
        CustomerPaymentSourceUpdateParams as CustomerPaymentSourceUpdateParams,
        CustomerPaymentSourceUpdateParamsOwner as CustomerPaymentSourceUpdateParamsOwner,
        CustomerPaymentSourceUpdateParamsOwnerAddress as CustomerPaymentSourceUpdateParamsOwnerAddress,
    )
    from stripe.params._customer_payment_source_verify_params import (
        CustomerPaymentSourceVerifyParams as CustomerPaymentSourceVerifyParams,
    )
    from stripe.params._customer_retrieve_balance_transaction_params import (
        CustomerRetrieveBalanceTransactionParams as CustomerRetrieveBalanceTransactionParams,
    )
    from stripe.params._customer_retrieve_cash_balance_params import (
        CustomerRetrieveCashBalanceParams as CustomerRetrieveCashBalanceParams,
    )
    from stripe.params._customer_retrieve_cash_balance_transaction_params import (
        CustomerRetrieveCashBalanceTransactionParams as CustomerRetrieveCashBalanceTransactionParams,
    )
    from stripe.params._customer_retrieve_params import (
        CustomerRetrieveParams as CustomerRetrieveParams,
    )
    from stripe.params._customer_retrieve_payment_method_params import (
        CustomerRetrievePaymentMethodParams as CustomerRetrievePaymentMethodParams,
    )
    from stripe.params._customer_retrieve_source_params import (
        CustomerRetrieveSourceParams as CustomerRetrieveSourceParams,
    )
    from stripe.params._customer_retrieve_tax_id_params import (
        CustomerRetrieveTaxIdParams as CustomerRetrieveTaxIdParams,
    )
    from stripe.params._customer_search_params import (
        CustomerSearchParams as CustomerSearchParams,
    )
    from stripe.params._customer_session_create_params import (
        CustomerSessionCreateParams as CustomerSessionCreateParams,
        CustomerSessionCreateParamsComponents as CustomerSessionCreateParamsComponents,
        CustomerSessionCreateParamsComponentsBuyButton as CustomerSessionCreateParamsComponentsBuyButton,
        CustomerSessionCreateParamsComponentsCustomerSheet as CustomerSessionCreateParamsComponentsCustomerSheet,
        CustomerSessionCreateParamsComponentsCustomerSheetFeatures as CustomerSessionCreateParamsComponentsCustomerSheetFeatures,
        CustomerSessionCreateParamsComponentsMobilePaymentElement as CustomerSessionCreateParamsComponentsMobilePaymentElement,
        CustomerSessionCreateParamsComponentsMobilePaymentElementFeatures as CustomerSessionCreateParamsComponentsMobilePaymentElementFeatures,
        CustomerSessionCreateParamsComponentsPaymentElement as CustomerSessionCreateParamsComponentsPaymentElement,
        CustomerSessionCreateParamsComponentsPaymentElementFeatures as CustomerSessionCreateParamsComponentsPaymentElementFeatures,
        CustomerSessionCreateParamsComponentsPricingTable as CustomerSessionCreateParamsComponentsPricingTable,
        CustomerSessionCreateParamsComponentsTaxIdElement as CustomerSessionCreateParamsComponentsTaxIdElement,
        CustomerSessionCreateParamsComponentsTaxIdElementFeatures as CustomerSessionCreateParamsComponentsTaxIdElementFeatures,
    )
    from stripe.params._customer_tax_id_create_params import (
        CustomerTaxIdCreateParams as CustomerTaxIdCreateParams,
    )
    from stripe.params._customer_tax_id_delete_params import (
        CustomerTaxIdDeleteParams as CustomerTaxIdDeleteParams,
    )
    from stripe.params._customer_tax_id_list_params import (
        CustomerTaxIdListParams as CustomerTaxIdListParams,
    )
    from stripe.params._customer_tax_id_retrieve_params import (
        CustomerTaxIdRetrieveParams as CustomerTaxIdRetrieveParams,
    )
    from stripe.params._customer_update_params import (
        CustomerUpdateParams as CustomerUpdateParams,
        CustomerUpdateParamsAddress as CustomerUpdateParamsAddress,
        CustomerUpdateParamsCashBalance as CustomerUpdateParamsCashBalance,
        CustomerUpdateParamsCashBalanceSettings as CustomerUpdateParamsCashBalanceSettings,
        CustomerUpdateParamsInvoiceSettings as CustomerUpdateParamsInvoiceSettings,
        CustomerUpdateParamsInvoiceSettingsCustomField as CustomerUpdateParamsInvoiceSettingsCustomField,
        CustomerUpdateParamsInvoiceSettingsRenderingOptions as CustomerUpdateParamsInvoiceSettingsRenderingOptions,
        CustomerUpdateParamsShipping as CustomerUpdateParamsShipping,
        CustomerUpdateParamsShippingAddress as CustomerUpdateParamsShippingAddress,
        CustomerUpdateParamsTax as CustomerUpdateParamsTax,
    )
    from stripe.params._dispute_close_params import (
        DisputeCloseParams as DisputeCloseParams,
    )
    from stripe.params._dispute_list_params import (
        DisputeListParams as DisputeListParams,
        DisputeListParamsCreated as DisputeListParamsCreated,
    )
    from stripe.params._dispute_modify_params import (
        DisputeModifyParams as DisputeModifyParams,
        DisputeModifyParamsEvidence as DisputeModifyParamsEvidence,
        DisputeModifyParamsEvidenceEnhancedEvidence as DisputeModifyParamsEvidenceEnhancedEvidence,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3 as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress,
        DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompliance as DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompliance,
    )
    from stripe.params._dispute_retrieve_params import (
        DisputeRetrieveParams as DisputeRetrieveParams,
    )
    from stripe.params._dispute_update_params import (
        DisputeUpdateParams as DisputeUpdateParams,
        DisputeUpdateParamsEvidence as DisputeUpdateParamsEvidence,
        DisputeUpdateParamsEvidenceEnhancedEvidence as DisputeUpdateParamsEvidenceEnhancedEvidence,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3 as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress,
        DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompliance as DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompliance,
    )
    from stripe.params._ephemeral_key_create_params import (
        EphemeralKeyCreateParams as EphemeralKeyCreateParams,
    )
    from stripe.params._ephemeral_key_delete_params import (
        EphemeralKeyDeleteParams as EphemeralKeyDeleteParams,
    )
    from stripe.params._event_list_params import (
        EventListParams as EventListParams,
        EventListParamsCreated as EventListParamsCreated,
    )
    from stripe.params._event_retrieve_params import (
        EventRetrieveParams as EventRetrieveParams,
    )
    from stripe.params._exchange_rate_list_params import (
        ExchangeRateListParams as ExchangeRateListParams,
    )
    from stripe.params._exchange_rate_retrieve_params import (
        ExchangeRateRetrieveParams as ExchangeRateRetrieveParams,
    )
    from stripe.params._external_account_create_params import (
        ExternalAccountCreateParams as ExternalAccountCreateParams,
        ExternalAccountCreateParamsBankAccount as ExternalAccountCreateParamsBankAccount,
        ExternalAccountCreateParamsCard as ExternalAccountCreateParamsCard,
        ExternalAccountCreateParamsCardToken as ExternalAccountCreateParamsCardToken,
    )
    from stripe.params._external_account_delete_params import (
        ExternalAccountDeleteParams as ExternalAccountDeleteParams,
    )
    from stripe.params._external_account_list_params import (
        ExternalAccountListParams as ExternalAccountListParams,
    )
    from stripe.params._external_account_retrieve_params import (
        ExternalAccountRetrieveParams as ExternalAccountRetrieveParams,
    )
    from stripe.params._external_account_update_params import (
        ExternalAccountUpdateParams as ExternalAccountUpdateParams,
        ExternalAccountUpdateParamsDocuments as ExternalAccountUpdateParamsDocuments,
        ExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification as ExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification,
    )
    from stripe.params._file_create_params import (
        FileCreateParams as FileCreateParams,
        FileCreateParamsFileLinkData as FileCreateParamsFileLinkData,
    )
    from stripe.params._file_link_create_params import (
        FileLinkCreateParams as FileLinkCreateParams,
    )
    from stripe.params._file_link_list_params import (
        FileLinkListParams as FileLinkListParams,
        FileLinkListParamsCreated as FileLinkListParamsCreated,
    )
    from stripe.params._file_link_modify_params import (
        FileLinkModifyParams as FileLinkModifyParams,
    )
    from stripe.params._file_link_retrieve_params import (
        FileLinkRetrieveParams as FileLinkRetrieveParams,
    )
    from stripe.params._file_link_update_params import (
        FileLinkUpdateParams as FileLinkUpdateParams,
    )
    from stripe.params._file_list_params import (
        FileListParams as FileListParams,
        FileListParamsCreated as FileListParamsCreated,
    )
    from stripe.params._file_retrieve_params import (
        FileRetrieveParams as FileRetrieveParams,
    )
    from stripe.params._fx_quote_create_params import (
        FxQuoteCreateParams as FxQuoteCreateParams,
        FxQuoteCreateParamsUsage as FxQuoteCreateParamsUsage,
        FxQuoteCreateParamsUsagePayment as FxQuoteCreateParamsUsagePayment,
        FxQuoteCreateParamsUsageTransfer as FxQuoteCreateParamsUsageTransfer,
    )
    from stripe.params._fx_quote_list_params import (
        FxQuoteListParams as FxQuoteListParams,
    )
    from stripe.params._fx_quote_retrieve_params import (
        FxQuoteRetrieveParams as FxQuoteRetrieveParams,
    )
    from stripe.params._invoice_add_lines_params import (
        InvoiceAddLinesParams as InvoiceAddLinesParams,
        InvoiceAddLinesParamsLine as InvoiceAddLinesParamsLine,
        InvoiceAddLinesParamsLineDiscount as InvoiceAddLinesParamsLineDiscount,
        InvoiceAddLinesParamsLineDiscountDiscountEnd as InvoiceAddLinesParamsLineDiscountDiscountEnd,
        InvoiceAddLinesParamsLineDiscountDiscountEndDuration as InvoiceAddLinesParamsLineDiscountDiscountEndDuration,
        InvoiceAddLinesParamsLinePeriod as InvoiceAddLinesParamsLinePeriod,
        InvoiceAddLinesParamsLinePriceData as InvoiceAddLinesParamsLinePriceData,
        InvoiceAddLinesParamsLinePriceDataProductData as InvoiceAddLinesParamsLinePriceDataProductData,
        InvoiceAddLinesParamsLinePricing as InvoiceAddLinesParamsLinePricing,
        InvoiceAddLinesParamsLineTaxAmount as InvoiceAddLinesParamsLineTaxAmount,
        InvoiceAddLinesParamsLineTaxAmountTaxRateData as InvoiceAddLinesParamsLineTaxAmountTaxRateData,
    )
    from stripe.params._invoice_attach_payment_params import (
        InvoiceAttachPaymentParams as InvoiceAttachPaymentParams,
        InvoiceAttachPaymentParamsPaymentRecordData as InvoiceAttachPaymentParamsPaymentRecordData,
    )
    from stripe.params._invoice_create_params import (
        InvoiceCreateParams as InvoiceCreateParams,
        InvoiceCreateParamsAmountsDue as InvoiceCreateParamsAmountsDue,
        InvoiceCreateParamsAutomaticTax as InvoiceCreateParamsAutomaticTax,
        InvoiceCreateParamsAutomaticTaxLiability as InvoiceCreateParamsAutomaticTaxLiability,
        InvoiceCreateParamsCustomField as InvoiceCreateParamsCustomField,
        InvoiceCreateParamsDiscount as InvoiceCreateParamsDiscount,
        InvoiceCreateParamsDiscountDiscountEnd as InvoiceCreateParamsDiscountDiscountEnd,
        InvoiceCreateParamsDiscountDiscountEndDuration as InvoiceCreateParamsDiscountDiscountEndDuration,
        InvoiceCreateParamsFromInvoice as InvoiceCreateParamsFromInvoice,
        InvoiceCreateParamsIssuer as InvoiceCreateParamsIssuer,
        InvoiceCreateParamsPaymentSettings as InvoiceCreateParamsPaymentSettings,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptions as InvoiceCreateParamsPaymentSettingsPaymentMethodOptions,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsBancontact as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCard as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCard,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallments as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallments,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsKonbini as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsKonbini,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsPix as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsPix,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpi as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpi,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        InvoiceCreateParamsRendering as InvoiceCreateParamsRendering,
        InvoiceCreateParamsRenderingPdf as InvoiceCreateParamsRenderingPdf,
        InvoiceCreateParamsShippingCost as InvoiceCreateParamsShippingCost,
        InvoiceCreateParamsShippingCostShippingRateData as InvoiceCreateParamsShippingCostShippingRateData,
        InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimate as InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimate,
        InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum as InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum as InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        InvoiceCreateParamsShippingCostShippingRateDataFixedAmount as InvoiceCreateParamsShippingCostShippingRateDataFixedAmount,
        InvoiceCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as InvoiceCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        InvoiceCreateParamsShippingDetails as InvoiceCreateParamsShippingDetails,
        InvoiceCreateParamsShippingDetailsAddress as InvoiceCreateParamsShippingDetailsAddress,
        InvoiceCreateParamsTransferData as InvoiceCreateParamsTransferData,
    )
    from stripe.params._invoice_create_preview_params import (
        InvoiceCreatePreviewParams as InvoiceCreatePreviewParams,
        InvoiceCreatePreviewParamsAutomaticTax as InvoiceCreatePreviewParamsAutomaticTax,
        InvoiceCreatePreviewParamsAutomaticTaxLiability as InvoiceCreatePreviewParamsAutomaticTaxLiability,
        InvoiceCreatePreviewParamsCustomerDetails as InvoiceCreatePreviewParamsCustomerDetails,
        InvoiceCreatePreviewParamsCustomerDetailsAddress as InvoiceCreatePreviewParamsCustomerDetailsAddress,
        InvoiceCreatePreviewParamsCustomerDetailsShipping as InvoiceCreatePreviewParamsCustomerDetailsShipping,
        InvoiceCreatePreviewParamsCustomerDetailsShippingAddress as InvoiceCreatePreviewParamsCustomerDetailsShippingAddress,
        InvoiceCreatePreviewParamsCustomerDetailsTax as InvoiceCreatePreviewParamsCustomerDetailsTax,
        InvoiceCreatePreviewParamsCustomerDetailsTaxId as InvoiceCreatePreviewParamsCustomerDetailsTaxId,
        InvoiceCreatePreviewParamsDiscount as InvoiceCreatePreviewParamsDiscount,
        InvoiceCreatePreviewParamsDiscountDiscountEnd as InvoiceCreatePreviewParamsDiscountDiscountEnd,
        InvoiceCreatePreviewParamsDiscountDiscountEndDuration as InvoiceCreatePreviewParamsDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsInvoiceItem as InvoiceCreatePreviewParamsInvoiceItem,
        InvoiceCreatePreviewParamsInvoiceItemDiscount as InvoiceCreatePreviewParamsInvoiceItemDiscount,
        InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEnd as InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEnd,
        InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEndDuration as InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsInvoiceItemPeriod as InvoiceCreatePreviewParamsInvoiceItemPeriod,
        InvoiceCreatePreviewParamsInvoiceItemPriceData as InvoiceCreatePreviewParamsInvoiceItemPriceData,
        InvoiceCreatePreviewParamsIssuer as InvoiceCreatePreviewParamsIssuer,
        InvoiceCreatePreviewParamsScheduleDetails as InvoiceCreatePreviewParamsScheduleDetails,
        InvoiceCreatePreviewParamsScheduleDetailsAmendment as InvoiceCreatePreviewParamsScheduleDetailsAmendment,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDuration as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStart as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStart,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartAmendmentEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartAmendmentEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesAction as InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesAction,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesActionAppliesTo as InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesActionAppliesTo,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountAction as InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountAction,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAdd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAdd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAddDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAddDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionRemove as InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionRemove,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionSet as InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionSet,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemAction as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemAction,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAdd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAdd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscount as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscount,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEndDuration as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddTrial as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddTrial,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionRemove as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionRemove,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSet as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSet,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscount as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscount,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEndDuration as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetTrial as InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetTrial,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentMetadataAction as InvoiceCreatePreviewParamsScheduleDetailsAmendmentMetadataAction,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollection as InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollection,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollectionSet as InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollectionSet,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettings as InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettings,
        InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettingsEndBehavior as InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettingsEndBehavior,
        InvoiceCreatePreviewParamsScheduleDetailsBillingMode as InvoiceCreatePreviewParamsScheduleDetailsBillingMode,
        InvoiceCreatePreviewParamsScheduleDetailsBillingModeFlexible as InvoiceCreatePreviewParamsScheduleDetailsBillingModeFlexible,
        InvoiceCreatePreviewParamsScheduleDetailsBillingSchedule as InvoiceCreatePreviewParamsScheduleDetailsBillingSchedule,
        InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleAppliesTo as InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleAppliesTo,
        InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntil as InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntil,
        InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntilDuration as InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntilDuration,
        InvoiceCreatePreviewParamsScheduleDetailsPhase as InvoiceCreatePreviewParamsScheduleDetailsPhase,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItem as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItem,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscount as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscount,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEndDuration as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriod as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriod,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodEnd as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodEnd,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodStart as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodStart,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPriceData as InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPriceData,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTax as InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTax,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTaxLiability as InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTaxLiability,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseBillingThresholds as InvoiceCreatePreviewParamsScheduleDetailsPhaseBillingThresholds,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscount as InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscount,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEndDuration as InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseDuration as InvoiceCreatePreviewParamsScheduleDetailsPhaseDuration,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettings as InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettings,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettingsIssuer as InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettingsIssuer,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItem as InvoiceCreatePreviewParamsScheduleDetailsPhaseItem,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemBillingThresholds as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemBillingThresholds,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscount as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscount,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEnd as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEnd,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEndDuration as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceData as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceData,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceDataRecurring as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceDataRecurring,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseItemTrial as InvoiceCreatePreviewParamsScheduleDetailsPhaseItemTrial,
        InvoiceCreatePreviewParamsScheduleDetailsPhasePauseCollection as InvoiceCreatePreviewParamsScheduleDetailsPhasePauseCollection,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseTransferData as InvoiceCreatePreviewParamsScheduleDetailsPhaseTransferData,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettings as InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettings,
        InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettingsEndBehavior as InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettingsEndBehavior,
        InvoiceCreatePreviewParamsScheduleDetailsPrebilling as InvoiceCreatePreviewParamsScheduleDetailsPrebilling,
        InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntil as InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntil,
        InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilAmendmentEnd as InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilAmendmentEnd,
        InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilDuration as InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilDuration,
        InvoiceCreatePreviewParamsSubscriptionDetails as InvoiceCreatePreviewParamsSubscriptionDetails,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingMode as InvoiceCreatePreviewParamsSubscriptionDetailsBillingMode,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingModeFlexible as InvoiceCreatePreviewParamsSubscriptionDetailsBillingModeFlexible,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingSchedule as InvoiceCreatePreviewParamsSubscriptionDetailsBillingSchedule,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleAppliesTo as InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleAppliesTo,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntil as InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntil,
        InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntilDuration as InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntilDuration,
        InvoiceCreatePreviewParamsSubscriptionDetailsItem as InvoiceCreatePreviewParamsSubscriptionDetailsItem,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemBillingThresholds as InvoiceCreatePreviewParamsSubscriptionDetailsItemBillingThresholds,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscount as InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscount,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEnd as InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEnd,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEndDuration as InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEndDuration,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceData as InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceData,
        InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceDataRecurring as InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceDataRecurring,
        InvoiceCreatePreviewParamsSubscriptionDetailsPrebilling as InvoiceCreatePreviewParamsSubscriptionDetailsPrebilling,
    )
    from stripe.params._invoice_delete_params import (
        InvoiceDeleteParams as InvoiceDeleteParams,
    )
    from stripe.params._invoice_finalize_invoice_params import (
        InvoiceFinalizeInvoiceParams as InvoiceFinalizeInvoiceParams,
    )
    from stripe.params._invoice_item_create_params import (
        InvoiceItemCreateParams as InvoiceItemCreateParams,
        InvoiceItemCreateParamsDiscount as InvoiceItemCreateParamsDiscount,
        InvoiceItemCreateParamsDiscountDiscountEnd as InvoiceItemCreateParamsDiscountDiscountEnd,
        InvoiceItemCreateParamsDiscountDiscountEndDuration as InvoiceItemCreateParamsDiscountDiscountEndDuration,
        InvoiceItemCreateParamsPeriod as InvoiceItemCreateParamsPeriod,
        InvoiceItemCreateParamsPriceData as InvoiceItemCreateParamsPriceData,
        InvoiceItemCreateParamsPricing as InvoiceItemCreateParamsPricing,
    )
    from stripe.params._invoice_item_delete_params import (
        InvoiceItemDeleteParams as InvoiceItemDeleteParams,
    )
    from stripe.params._invoice_item_list_params import (
        InvoiceItemListParams as InvoiceItemListParams,
        InvoiceItemListParamsCreated as InvoiceItemListParamsCreated,
    )
    from stripe.params._invoice_item_modify_params import (
        InvoiceItemModifyParams as InvoiceItemModifyParams,
        InvoiceItemModifyParamsDiscount as InvoiceItemModifyParamsDiscount,
        InvoiceItemModifyParamsDiscountDiscountEnd as InvoiceItemModifyParamsDiscountDiscountEnd,
        InvoiceItemModifyParamsDiscountDiscountEndDuration as InvoiceItemModifyParamsDiscountDiscountEndDuration,
        InvoiceItemModifyParamsPeriod as InvoiceItemModifyParamsPeriod,
        InvoiceItemModifyParamsPriceData as InvoiceItemModifyParamsPriceData,
        InvoiceItemModifyParamsPricing as InvoiceItemModifyParamsPricing,
    )
    from stripe.params._invoice_item_retrieve_params import (
        InvoiceItemRetrieveParams as InvoiceItemRetrieveParams,
    )
    from stripe.params._invoice_item_update_params import (
        InvoiceItemUpdateParams as InvoiceItemUpdateParams,
        InvoiceItemUpdateParamsDiscount as InvoiceItemUpdateParamsDiscount,
        InvoiceItemUpdateParamsDiscountDiscountEnd as InvoiceItemUpdateParamsDiscountDiscountEnd,
        InvoiceItemUpdateParamsDiscountDiscountEndDuration as InvoiceItemUpdateParamsDiscountDiscountEndDuration,
        InvoiceItemUpdateParamsPeriod as InvoiceItemUpdateParamsPeriod,
        InvoiceItemUpdateParamsPriceData as InvoiceItemUpdateParamsPriceData,
        InvoiceItemUpdateParamsPricing as InvoiceItemUpdateParamsPricing,
    )
    from stripe.params._invoice_line_item_list_params import (
        InvoiceLineItemListParams as InvoiceLineItemListParams,
    )
    from stripe.params._invoice_line_item_update_params import (
        InvoiceLineItemUpdateParams as InvoiceLineItemUpdateParams,
        InvoiceLineItemUpdateParamsDiscount as InvoiceLineItemUpdateParamsDiscount,
        InvoiceLineItemUpdateParamsDiscountDiscountEnd as InvoiceLineItemUpdateParamsDiscountDiscountEnd,
        InvoiceLineItemUpdateParamsDiscountDiscountEndDuration as InvoiceLineItemUpdateParamsDiscountDiscountEndDuration,
        InvoiceLineItemUpdateParamsPeriod as InvoiceLineItemUpdateParamsPeriod,
        InvoiceLineItemUpdateParamsPriceData as InvoiceLineItemUpdateParamsPriceData,
        InvoiceLineItemUpdateParamsPriceDataProductData as InvoiceLineItemUpdateParamsPriceDataProductData,
        InvoiceLineItemUpdateParamsPricing as InvoiceLineItemUpdateParamsPricing,
        InvoiceLineItemUpdateParamsTaxAmount as InvoiceLineItemUpdateParamsTaxAmount,
        InvoiceLineItemUpdateParamsTaxAmountTaxRateData as InvoiceLineItemUpdateParamsTaxAmountTaxRateData,
    )
    from stripe.params._invoice_list_lines_params import (
        InvoiceListLinesParams as InvoiceListLinesParams,
    )
    from stripe.params._invoice_list_params import (
        InvoiceListParams as InvoiceListParams,
        InvoiceListParamsCreated as InvoiceListParamsCreated,
        InvoiceListParamsDueDate as InvoiceListParamsDueDate,
    )
    from stripe.params._invoice_mark_uncollectible_params import (
        InvoiceMarkUncollectibleParams as InvoiceMarkUncollectibleParams,
    )
    from stripe.params._invoice_modify_params import (
        InvoiceModifyParams as InvoiceModifyParams,
        InvoiceModifyParamsAmountsDue as InvoiceModifyParamsAmountsDue,
        InvoiceModifyParamsAutomaticTax as InvoiceModifyParamsAutomaticTax,
        InvoiceModifyParamsAutomaticTaxLiability as InvoiceModifyParamsAutomaticTaxLiability,
        InvoiceModifyParamsCustomField as InvoiceModifyParamsCustomField,
        InvoiceModifyParamsDiscount as InvoiceModifyParamsDiscount,
        InvoiceModifyParamsDiscountDiscountEnd as InvoiceModifyParamsDiscountDiscountEnd,
        InvoiceModifyParamsDiscountDiscountEndDuration as InvoiceModifyParamsDiscountDiscountEndDuration,
        InvoiceModifyParamsIssuer as InvoiceModifyParamsIssuer,
        InvoiceModifyParamsPaymentSettings as InvoiceModifyParamsPaymentSettings,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptions as InvoiceModifyParamsPaymentSettingsPaymentMethodOptions,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsBancontact as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsBancontact,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCard as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCard,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallments as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallments,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsKonbini as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsKonbini,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsPix as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsPix,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpi as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpi,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        InvoiceModifyParamsRendering as InvoiceModifyParamsRendering,
        InvoiceModifyParamsRenderingPdf as InvoiceModifyParamsRenderingPdf,
        InvoiceModifyParamsShippingCost as InvoiceModifyParamsShippingCost,
        InvoiceModifyParamsShippingCostShippingRateData as InvoiceModifyParamsShippingCostShippingRateData,
        InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimate as InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimate,
        InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum as InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum as InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        InvoiceModifyParamsShippingCostShippingRateDataFixedAmount as InvoiceModifyParamsShippingCostShippingRateDataFixedAmount,
        InvoiceModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as InvoiceModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        InvoiceModifyParamsShippingDetails as InvoiceModifyParamsShippingDetails,
        InvoiceModifyParamsShippingDetailsAddress as InvoiceModifyParamsShippingDetailsAddress,
        InvoiceModifyParamsTransferData as InvoiceModifyParamsTransferData,
    )
    from stripe.params._invoice_pay_params import (
        InvoicePayParams as InvoicePayParams,
    )
    from stripe.params._invoice_payment_list_params import (
        InvoicePaymentListParams as InvoicePaymentListParams,
        InvoicePaymentListParamsCreated as InvoicePaymentListParamsCreated,
        InvoicePaymentListParamsPayment as InvoicePaymentListParamsPayment,
    )
    from stripe.params._invoice_payment_retrieve_params import (
        InvoicePaymentRetrieveParams as InvoicePaymentRetrieveParams,
    )
    from stripe.params._invoice_remove_lines_params import (
        InvoiceRemoveLinesParams as InvoiceRemoveLinesParams,
        InvoiceRemoveLinesParamsLine as InvoiceRemoveLinesParamsLine,
    )
    from stripe.params._invoice_rendering_template_archive_params import (
        InvoiceRenderingTemplateArchiveParams as InvoiceRenderingTemplateArchiveParams,
    )
    from stripe.params._invoice_rendering_template_list_params import (
        InvoiceRenderingTemplateListParams as InvoiceRenderingTemplateListParams,
    )
    from stripe.params._invoice_rendering_template_retrieve_params import (
        InvoiceRenderingTemplateRetrieveParams as InvoiceRenderingTemplateRetrieveParams,
    )
    from stripe.params._invoice_rendering_template_unarchive_params import (
        InvoiceRenderingTemplateUnarchiveParams as InvoiceRenderingTemplateUnarchiveParams,
    )
    from stripe.params._invoice_retrieve_params import (
        InvoiceRetrieveParams as InvoiceRetrieveParams,
    )
    from stripe.params._invoice_search_params import (
        InvoiceSearchParams as InvoiceSearchParams,
    )
    from stripe.params._invoice_send_invoice_params import (
        InvoiceSendInvoiceParams as InvoiceSendInvoiceParams,
    )
    from stripe.params._invoice_update_lines_params import (
        InvoiceUpdateLinesParams as InvoiceUpdateLinesParams,
        InvoiceUpdateLinesParamsLine as InvoiceUpdateLinesParamsLine,
        InvoiceUpdateLinesParamsLineDiscount as InvoiceUpdateLinesParamsLineDiscount,
        InvoiceUpdateLinesParamsLineDiscountDiscountEnd as InvoiceUpdateLinesParamsLineDiscountDiscountEnd,
        InvoiceUpdateLinesParamsLineDiscountDiscountEndDuration as InvoiceUpdateLinesParamsLineDiscountDiscountEndDuration,
        InvoiceUpdateLinesParamsLinePeriod as InvoiceUpdateLinesParamsLinePeriod,
        InvoiceUpdateLinesParamsLinePriceData as InvoiceUpdateLinesParamsLinePriceData,
        InvoiceUpdateLinesParamsLinePriceDataProductData as InvoiceUpdateLinesParamsLinePriceDataProductData,
        InvoiceUpdateLinesParamsLinePricing as InvoiceUpdateLinesParamsLinePricing,
        InvoiceUpdateLinesParamsLineTaxAmount as InvoiceUpdateLinesParamsLineTaxAmount,
        InvoiceUpdateLinesParamsLineTaxAmountTaxRateData as InvoiceUpdateLinesParamsLineTaxAmountTaxRateData,
    )
    from stripe.params._invoice_update_params import (
        InvoiceUpdateParams as InvoiceUpdateParams,
        InvoiceUpdateParamsAmountsDue as InvoiceUpdateParamsAmountsDue,
        InvoiceUpdateParamsAutomaticTax as InvoiceUpdateParamsAutomaticTax,
        InvoiceUpdateParamsAutomaticTaxLiability as InvoiceUpdateParamsAutomaticTaxLiability,
        InvoiceUpdateParamsCustomField as InvoiceUpdateParamsCustomField,
        InvoiceUpdateParamsDiscount as InvoiceUpdateParamsDiscount,
        InvoiceUpdateParamsDiscountDiscountEnd as InvoiceUpdateParamsDiscountDiscountEnd,
        InvoiceUpdateParamsDiscountDiscountEndDuration as InvoiceUpdateParamsDiscountDiscountEndDuration,
        InvoiceUpdateParamsIssuer as InvoiceUpdateParamsIssuer,
        InvoiceUpdateParamsPaymentSettings as InvoiceUpdateParamsPaymentSettings,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptions as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptions,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCard as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCard,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallments as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallments,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsPix as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsPix,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpi as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpi,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        InvoiceUpdateParamsRendering as InvoiceUpdateParamsRendering,
        InvoiceUpdateParamsRenderingPdf as InvoiceUpdateParamsRenderingPdf,
        InvoiceUpdateParamsShippingCost as InvoiceUpdateParamsShippingCost,
        InvoiceUpdateParamsShippingCostShippingRateData as InvoiceUpdateParamsShippingCostShippingRateData,
        InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimate as InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimate,
        InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum as InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum as InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        InvoiceUpdateParamsShippingCostShippingRateDataFixedAmount as InvoiceUpdateParamsShippingCostShippingRateDataFixedAmount,
        InvoiceUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as InvoiceUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        InvoiceUpdateParamsShippingDetails as InvoiceUpdateParamsShippingDetails,
        InvoiceUpdateParamsShippingDetailsAddress as InvoiceUpdateParamsShippingDetailsAddress,
        InvoiceUpdateParamsTransferData as InvoiceUpdateParamsTransferData,
    )
    from stripe.params._invoice_void_invoice_params import (
        InvoiceVoidInvoiceParams as InvoiceVoidInvoiceParams,
    )
    from stripe.params._mandate_list_params import (
        MandateListParams as MandateListParams,
    )
    from stripe.params._mandate_retrieve_params import (
        MandateRetrieveParams as MandateRetrieveParams,
    )
    from stripe.params._margin_create_params import (
        MarginCreateParams as MarginCreateParams,
    )
    from stripe.params._margin_list_params import (
        MarginListParams as MarginListParams,
    )
    from stripe.params._margin_modify_params import (
        MarginModifyParams as MarginModifyParams,
    )
    from stripe.params._margin_retrieve_params import (
        MarginRetrieveParams as MarginRetrieveParams,
    )
    from stripe.params._margin_update_params import (
        MarginUpdateParams as MarginUpdateParams,
    )
    from stripe.params._order_cancel_params import (
        OrderCancelParams as OrderCancelParams,
    )
    from stripe.params._order_create_params import (
        OrderCreateParams as OrderCreateParams,
        OrderCreateParamsAutomaticTax as OrderCreateParamsAutomaticTax,
        OrderCreateParamsBillingDetails as OrderCreateParamsBillingDetails,
        OrderCreateParamsBillingDetailsAddress as OrderCreateParamsBillingDetailsAddress,
        OrderCreateParamsDiscount as OrderCreateParamsDiscount,
        OrderCreateParamsLineItem as OrderCreateParamsLineItem,
        OrderCreateParamsLineItemDiscount as OrderCreateParamsLineItemDiscount,
        OrderCreateParamsLineItemPriceData as OrderCreateParamsLineItemPriceData,
        OrderCreateParamsLineItemProductData as OrderCreateParamsLineItemProductData,
        OrderCreateParamsLineItemProductDataPackageDimensions as OrderCreateParamsLineItemProductDataPackageDimensions,
        OrderCreateParamsPayment as OrderCreateParamsPayment,
        OrderCreateParamsPaymentSettings as OrderCreateParamsPaymentSettings,
        OrderCreateParamsPaymentSettingsPaymentMethodOptions as OrderCreateParamsPaymentSettingsPaymentMethodOptions,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay as OrderCreateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsAlipay as OrderCreateParamsPaymentSettingsPaymentMethodOptionsAlipay,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsBancontact as OrderCreateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsCard as OrderCreateParamsPaymentSettingsPaymentMethodOptionsCard,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsIdeal as OrderCreateParamsPaymentSettingsPaymentMethodOptionsIdeal,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarna as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarna,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsLink as OrderCreateParamsPaymentSettingsPaymentMethodOptionsLink,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsOxxo as OrderCreateParamsPaymentSettingsPaymentMethodOptionsOxxo,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsP24 as OrderCreateParamsPaymentSettingsPaymentMethodOptionsP24,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypal as OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypal,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem as OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax as OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions as OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsSofort as OrderCreateParamsPaymentSettingsPaymentMethodOptionsSofort,
        OrderCreateParamsPaymentSettingsPaymentMethodOptionsWechatPay as OrderCreateParamsPaymentSettingsPaymentMethodOptionsWechatPay,
        OrderCreateParamsPaymentSettingsTransferData as OrderCreateParamsPaymentSettingsTransferData,
        OrderCreateParamsShippingCost as OrderCreateParamsShippingCost,
        OrderCreateParamsShippingCostShippingRateData as OrderCreateParamsShippingCostShippingRateData,
        OrderCreateParamsShippingCostShippingRateDataDeliveryEstimate as OrderCreateParamsShippingCostShippingRateDataDeliveryEstimate,
        OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum as OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum as OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        OrderCreateParamsShippingCostShippingRateDataFixedAmount as OrderCreateParamsShippingCostShippingRateDataFixedAmount,
        OrderCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as OrderCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        OrderCreateParamsShippingDetails as OrderCreateParamsShippingDetails,
        OrderCreateParamsShippingDetailsAddress as OrderCreateParamsShippingDetailsAddress,
        OrderCreateParamsTaxDetails as OrderCreateParamsTaxDetails,
        OrderCreateParamsTaxDetailsTaxId as OrderCreateParamsTaxDetailsTaxId,
    )
    from stripe.params._order_line_item_list_params import (
        OrderLineItemListParams as OrderLineItemListParams,
    )
    from stripe.params._order_list_line_items_params import (
        OrderListLineItemsParams as OrderListLineItemsParams,
    )
    from stripe.params._order_list_params import (
        OrderListParams as OrderListParams,
    )
    from stripe.params._order_modify_params import (
        OrderModifyParams as OrderModifyParams,
        OrderModifyParamsAutomaticTax as OrderModifyParamsAutomaticTax,
        OrderModifyParamsBillingDetails as OrderModifyParamsBillingDetails,
        OrderModifyParamsBillingDetailsAddress as OrderModifyParamsBillingDetailsAddress,
        OrderModifyParamsDiscount as OrderModifyParamsDiscount,
        OrderModifyParamsLineItem as OrderModifyParamsLineItem,
        OrderModifyParamsLineItemDiscount as OrderModifyParamsLineItemDiscount,
        OrderModifyParamsLineItemPriceData as OrderModifyParamsLineItemPriceData,
        OrderModifyParamsLineItemProductData as OrderModifyParamsLineItemProductData,
        OrderModifyParamsLineItemProductDataPackageDimensions as OrderModifyParamsLineItemProductDataPackageDimensions,
        OrderModifyParamsPayment as OrderModifyParamsPayment,
        OrderModifyParamsPaymentSettings as OrderModifyParamsPaymentSettings,
        OrderModifyParamsPaymentSettingsPaymentMethodOptions as OrderModifyParamsPaymentSettingsPaymentMethodOptions,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit as OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay as OrderModifyParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsAlipay as OrderModifyParamsPaymentSettingsPaymentMethodOptionsAlipay,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsBancontact as OrderModifyParamsPaymentSettingsPaymentMethodOptionsBancontact,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsCard as OrderModifyParamsPaymentSettingsPaymentMethodOptionsCard,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsIdeal as OrderModifyParamsPaymentSettingsPaymentMethodOptionsIdeal,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarna as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarna,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsLink as OrderModifyParamsPaymentSettingsPaymentMethodOptionsLink,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsOxxo as OrderModifyParamsPaymentSettingsPaymentMethodOptionsOxxo,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsP24 as OrderModifyParamsPaymentSettingsPaymentMethodOptionsP24,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypal as OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypal,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem as OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax as OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit as OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions as OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsSofort as OrderModifyParamsPaymentSettingsPaymentMethodOptionsSofort,
        OrderModifyParamsPaymentSettingsPaymentMethodOptionsWechatPay as OrderModifyParamsPaymentSettingsPaymentMethodOptionsWechatPay,
        OrderModifyParamsPaymentSettingsTransferData as OrderModifyParamsPaymentSettingsTransferData,
        OrderModifyParamsShippingCost as OrderModifyParamsShippingCost,
        OrderModifyParamsShippingCostShippingRateData as OrderModifyParamsShippingCostShippingRateData,
        OrderModifyParamsShippingCostShippingRateDataDeliveryEstimate as OrderModifyParamsShippingCostShippingRateDataDeliveryEstimate,
        OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum as OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum as OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        OrderModifyParamsShippingCostShippingRateDataFixedAmount as OrderModifyParamsShippingCostShippingRateDataFixedAmount,
        OrderModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as OrderModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        OrderModifyParamsShippingDetails as OrderModifyParamsShippingDetails,
        OrderModifyParamsShippingDetailsAddress as OrderModifyParamsShippingDetailsAddress,
        OrderModifyParamsTaxDetails as OrderModifyParamsTaxDetails,
        OrderModifyParamsTaxDetailsTaxId as OrderModifyParamsTaxDetailsTaxId,
    )
    from stripe.params._order_reopen_params import (
        OrderReopenParams as OrderReopenParams,
    )
    from stripe.params._order_retrieve_params import (
        OrderRetrieveParams as OrderRetrieveParams,
    )
    from stripe.params._order_submit_params import (
        OrderSubmitParams as OrderSubmitParams,
    )
    from stripe.params._order_update_params import (
        OrderUpdateParams as OrderUpdateParams,
        OrderUpdateParamsAutomaticTax as OrderUpdateParamsAutomaticTax,
        OrderUpdateParamsBillingDetails as OrderUpdateParamsBillingDetails,
        OrderUpdateParamsBillingDetailsAddress as OrderUpdateParamsBillingDetailsAddress,
        OrderUpdateParamsDiscount as OrderUpdateParamsDiscount,
        OrderUpdateParamsLineItem as OrderUpdateParamsLineItem,
        OrderUpdateParamsLineItemDiscount as OrderUpdateParamsLineItemDiscount,
        OrderUpdateParamsLineItemPriceData as OrderUpdateParamsLineItemPriceData,
        OrderUpdateParamsLineItemProductData as OrderUpdateParamsLineItemProductData,
        OrderUpdateParamsLineItemProductDataPackageDimensions as OrderUpdateParamsLineItemProductDataPackageDimensions,
        OrderUpdateParamsPayment as OrderUpdateParamsPayment,
        OrderUpdateParamsPaymentSettings as OrderUpdateParamsPaymentSettings,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptions as OrderUpdateParamsPaymentSettingsPaymentMethodOptions,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAlipay as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAlipay,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCard as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCard,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsIdeal as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsIdeal,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarna as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarna,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsLink as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsLink,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsOxxo as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsOxxo,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsP24 as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsP24,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypal as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypal,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSofort as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSofort,
        OrderUpdateParamsPaymentSettingsPaymentMethodOptionsWechatPay as OrderUpdateParamsPaymentSettingsPaymentMethodOptionsWechatPay,
        OrderUpdateParamsPaymentSettingsTransferData as OrderUpdateParamsPaymentSettingsTransferData,
        OrderUpdateParamsShippingCost as OrderUpdateParamsShippingCost,
        OrderUpdateParamsShippingCostShippingRateData as OrderUpdateParamsShippingCostShippingRateData,
        OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimate as OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimate,
        OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum as OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum,
        OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum as OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum,
        OrderUpdateParamsShippingCostShippingRateDataFixedAmount as OrderUpdateParamsShippingCostShippingRateDataFixedAmount,
        OrderUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions as OrderUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions,
        OrderUpdateParamsShippingDetails as OrderUpdateParamsShippingDetails,
        OrderUpdateParamsShippingDetailsAddress as OrderUpdateParamsShippingDetailsAddress,
        OrderUpdateParamsTaxDetails as OrderUpdateParamsTaxDetails,
        OrderUpdateParamsTaxDetailsTaxId as OrderUpdateParamsTaxDetailsTaxId,
    )
    from stripe.params._payment_attempt_record_list_params import (
        PaymentAttemptRecordListParams as PaymentAttemptRecordListParams,
    )
    from stripe.params._payment_attempt_record_retrieve_params import (
        PaymentAttemptRecordRetrieveParams as PaymentAttemptRecordRetrieveParams,
    )
    from stripe.params._payment_intent_amount_details_line_item_list_params import (
        PaymentIntentAmountDetailsLineItemListParams as PaymentIntentAmountDetailsLineItemListParams,
    )
    from stripe.params._payment_intent_apply_customer_balance_params import (
        PaymentIntentApplyCustomerBalanceParams as PaymentIntentApplyCustomerBalanceParams,
    )
    from stripe.params._payment_intent_cancel_params import (
        PaymentIntentCancelParams as PaymentIntentCancelParams,
    )
    from stripe.params._payment_intent_capture_params import (
        PaymentIntentCaptureParams as PaymentIntentCaptureParams,
        PaymentIntentCaptureParamsAmountDetails as PaymentIntentCaptureParamsAmountDetails,
        PaymentIntentCaptureParamsAmountDetailsLineItem as PaymentIntentCaptureParamsAmountDetailsLineItem,
        PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentCaptureParamsAmountDetailsLineItemTax as PaymentIntentCaptureParamsAmountDetailsLineItemTax,
        PaymentIntentCaptureParamsAmountDetailsShipping as PaymentIntentCaptureParamsAmountDetailsShipping,
        PaymentIntentCaptureParamsAmountDetailsTax as PaymentIntentCaptureParamsAmountDetailsTax,
        PaymentIntentCaptureParamsHooks as PaymentIntentCaptureParamsHooks,
        PaymentIntentCaptureParamsHooksInputs as PaymentIntentCaptureParamsHooksInputs,
        PaymentIntentCaptureParamsHooksInputsTax as PaymentIntentCaptureParamsHooksInputsTax,
        PaymentIntentCaptureParamsPaymentDetails as PaymentIntentCaptureParamsPaymentDetails,
        PaymentIntentCaptureParamsPaymentDetailsCarRental as PaymentIntentCaptureParamsPaymentDetailsCarRental,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalAffiliate as PaymentIntentCaptureParamsPaymentDetailsCarRentalAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatum as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatum,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumAffiliate as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDistance as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDistance,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriver as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriver,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOff as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOff,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumInsurance as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumInsurance,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickup as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickup,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickupAddress as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickupAddress,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotal as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotal,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTax as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTax,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumVehicle as PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumVehicle,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDelivery as PaymentIntentCaptureParamsPaymentDetailsCarRentalDelivery,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDeliveryRecipient as PaymentIntentCaptureParamsPaymentDetailsCarRentalDeliveryRecipient,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDistance as PaymentIntentCaptureParamsPaymentDetailsCarRentalDistance,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalDriver as PaymentIntentCaptureParamsPaymentDetailsCarRentalDriver,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalPickupAddress as PaymentIntentCaptureParamsPaymentDetailsCarRentalPickupAddress,
        PaymentIntentCaptureParamsPaymentDetailsCarRentalReturnAddress as PaymentIntentCaptureParamsPaymentDetailsCarRentalReturnAddress,
        PaymentIntentCaptureParamsPaymentDetailsEventDetails as PaymentIntentCaptureParamsPaymentDetailsEventDetails,
        PaymentIntentCaptureParamsPaymentDetailsEventDetailsAddress as PaymentIntentCaptureParamsPaymentDetailsEventDetailsAddress,
        PaymentIntentCaptureParamsPaymentDetailsEventDetailsAffiliate as PaymentIntentCaptureParamsPaymentDetailsEventDetailsAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsEventDetailsDelivery as PaymentIntentCaptureParamsPaymentDetailsEventDetailsDelivery,
        PaymentIntentCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient as PaymentIntentCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient,
        PaymentIntentCaptureParamsPaymentDetailsFlight as PaymentIntentCaptureParamsPaymentDetailsFlight,
        PaymentIntentCaptureParamsPaymentDetailsFlightAffiliate as PaymentIntentCaptureParamsPaymentDetailsFlightAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatum as PaymentIntentCaptureParamsPaymentDetailsFlightDatum,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumAffiliate as PaymentIntentCaptureParamsPaymentDetailsFlightDatumAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumInsurance as PaymentIntentCaptureParamsPaymentDetailsFlightDatumInsurance,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumPassenger as PaymentIntentCaptureParamsPaymentDetailsFlightDatumPassenger,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegment as PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegment,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentArrival as PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentArrival,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentDeparture as PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentDeparture,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotal as PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotal,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalDiscounts as PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalDiscounts,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge as PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTax as PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTax,
        PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTaxTax as PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTaxTax,
        PaymentIntentCaptureParamsPaymentDetailsFlightDelivery as PaymentIntentCaptureParamsPaymentDetailsFlightDelivery,
        PaymentIntentCaptureParamsPaymentDetailsFlightDeliveryRecipient as PaymentIntentCaptureParamsPaymentDetailsFlightDeliveryRecipient,
        PaymentIntentCaptureParamsPaymentDetailsFlightPassenger as PaymentIntentCaptureParamsPaymentDetailsFlightPassenger,
        PaymentIntentCaptureParamsPaymentDetailsFlightSegment as PaymentIntentCaptureParamsPaymentDetailsFlightSegment,
        PaymentIntentCaptureParamsPaymentDetailsLodging as PaymentIntentCaptureParamsPaymentDetailsLodging,
        PaymentIntentCaptureParamsPaymentDetailsLodgingAddress as PaymentIntentCaptureParamsPaymentDetailsLodgingAddress,
        PaymentIntentCaptureParamsPaymentDetailsLodgingAffiliate as PaymentIntentCaptureParamsPaymentDetailsLodgingAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatum as PaymentIntentCaptureParamsPaymentDetailsLodgingDatum,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAccommodation as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAccommodation,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAffiliate as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumGuest as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumGuest,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHost as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHost,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHostAddress as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHostAddress,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumInsurance as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumInsurance,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotal as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotal,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTax as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTax,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax as PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDelivery as PaymentIntentCaptureParamsPaymentDetailsLodgingDelivery,
        PaymentIntentCaptureParamsPaymentDetailsLodgingDeliveryRecipient as PaymentIntentCaptureParamsPaymentDetailsLodgingDeliveryRecipient,
        PaymentIntentCaptureParamsPaymentDetailsLodgingPassenger as PaymentIntentCaptureParamsPaymentDetailsLodgingPassenger,
        PaymentIntentCaptureParamsPaymentDetailsSubscription as PaymentIntentCaptureParamsPaymentDetailsSubscription,
        PaymentIntentCaptureParamsPaymentDetailsSubscriptionAffiliate as PaymentIntentCaptureParamsPaymentDetailsSubscriptionAffiliate,
        PaymentIntentCaptureParamsPaymentDetailsSubscriptionBillingInterval as PaymentIntentCaptureParamsPaymentDetailsSubscriptionBillingInterval,
        PaymentIntentCaptureParamsTransferData as PaymentIntentCaptureParamsTransferData,
    )
    from stripe.params._payment_intent_confirm_params import (
        PaymentIntentConfirmParams as PaymentIntentConfirmParams,
        PaymentIntentConfirmParamsAllocatedFunds as PaymentIntentConfirmParamsAllocatedFunds,
        PaymentIntentConfirmParamsAmountDetails as PaymentIntentConfirmParamsAmountDetails,
        PaymentIntentConfirmParamsAmountDetailsLineItem as PaymentIntentConfirmParamsAmountDetailsLineItem,
        PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentConfirmParamsAmountDetailsLineItemTax as PaymentIntentConfirmParamsAmountDetailsLineItemTax,
        PaymentIntentConfirmParamsAmountDetailsShipping as PaymentIntentConfirmParamsAmountDetailsShipping,
        PaymentIntentConfirmParamsAmountDetailsTax as PaymentIntentConfirmParamsAmountDetailsTax,
        PaymentIntentConfirmParamsHooks as PaymentIntentConfirmParamsHooks,
        PaymentIntentConfirmParamsHooksInputs as PaymentIntentConfirmParamsHooksInputs,
        PaymentIntentConfirmParamsHooksInputsTax as PaymentIntentConfirmParamsHooksInputsTax,
        PaymentIntentConfirmParamsMandateData as PaymentIntentConfirmParamsMandateData,
        PaymentIntentConfirmParamsMandateDataCustomerAcceptance as PaymentIntentConfirmParamsMandateDataCustomerAcceptance,
        PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOffline as PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOffline,
        PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOnline as PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOnline,
        PaymentIntentConfirmParamsPaymentDetails as PaymentIntentConfirmParamsPaymentDetails,
        PaymentIntentConfirmParamsPaymentDetailsBenefit as PaymentIntentConfirmParamsPaymentDetailsBenefit,
        PaymentIntentConfirmParamsPaymentDetailsBenefitFrMealVoucher as PaymentIntentConfirmParamsPaymentDetailsBenefitFrMealVoucher,
        PaymentIntentConfirmParamsPaymentDetailsCarRental as PaymentIntentConfirmParamsPaymentDetailsCarRental,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalAffiliate as PaymentIntentConfirmParamsPaymentDetailsCarRentalAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatum as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatum,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumAffiliate as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDistance as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDistance,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriver as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriver,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOff as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOff,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOffAddress as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOffAddress,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumInsurance as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumInsurance,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickup as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickup,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickupAddress as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickupAddress,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotal as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotal,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalDiscounts as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalExtraCharge as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTax as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTax,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTaxTax as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumVehicle as PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumVehicle,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDelivery as PaymentIntentConfirmParamsPaymentDetailsCarRentalDelivery,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDeliveryRecipient as PaymentIntentConfirmParamsPaymentDetailsCarRentalDeliveryRecipient,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDistance as PaymentIntentConfirmParamsPaymentDetailsCarRentalDistance,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalDriver as PaymentIntentConfirmParamsPaymentDetailsCarRentalDriver,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalPickupAddress as PaymentIntentConfirmParamsPaymentDetailsCarRentalPickupAddress,
        PaymentIntentConfirmParamsPaymentDetailsCarRentalReturnAddress as PaymentIntentConfirmParamsPaymentDetailsCarRentalReturnAddress,
        PaymentIntentConfirmParamsPaymentDetailsEventDetails as PaymentIntentConfirmParamsPaymentDetailsEventDetails,
        PaymentIntentConfirmParamsPaymentDetailsEventDetailsAddress as PaymentIntentConfirmParamsPaymentDetailsEventDetailsAddress,
        PaymentIntentConfirmParamsPaymentDetailsEventDetailsAffiliate as PaymentIntentConfirmParamsPaymentDetailsEventDetailsAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsEventDetailsDelivery as PaymentIntentConfirmParamsPaymentDetailsEventDetailsDelivery,
        PaymentIntentConfirmParamsPaymentDetailsEventDetailsDeliveryRecipient as PaymentIntentConfirmParamsPaymentDetailsEventDetailsDeliveryRecipient,
        PaymentIntentConfirmParamsPaymentDetailsFlight as PaymentIntentConfirmParamsPaymentDetailsFlight,
        PaymentIntentConfirmParamsPaymentDetailsFlightAffiliate as PaymentIntentConfirmParamsPaymentDetailsFlightAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatum as PaymentIntentConfirmParamsPaymentDetailsFlightDatum,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumAffiliate as PaymentIntentConfirmParamsPaymentDetailsFlightDatumAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumInsurance as PaymentIntentConfirmParamsPaymentDetailsFlightDatumInsurance,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumPassenger as PaymentIntentConfirmParamsPaymentDetailsFlightDatumPassenger,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegment as PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegment,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentArrival as PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentArrival,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentDeparture as PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentDeparture,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotal as PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotal,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalDiscounts as PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalDiscounts,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalExtraCharge as PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalExtraCharge,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTax as PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTax,
        PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTaxTax as PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTaxTax,
        PaymentIntentConfirmParamsPaymentDetailsFlightDelivery as PaymentIntentConfirmParamsPaymentDetailsFlightDelivery,
        PaymentIntentConfirmParamsPaymentDetailsFlightDeliveryRecipient as PaymentIntentConfirmParamsPaymentDetailsFlightDeliveryRecipient,
        PaymentIntentConfirmParamsPaymentDetailsFlightPassenger as PaymentIntentConfirmParamsPaymentDetailsFlightPassenger,
        PaymentIntentConfirmParamsPaymentDetailsFlightSegment as PaymentIntentConfirmParamsPaymentDetailsFlightSegment,
        PaymentIntentConfirmParamsPaymentDetailsLodging as PaymentIntentConfirmParamsPaymentDetailsLodging,
        PaymentIntentConfirmParamsPaymentDetailsLodgingAddress as PaymentIntentConfirmParamsPaymentDetailsLodgingAddress,
        PaymentIntentConfirmParamsPaymentDetailsLodgingAffiliate as PaymentIntentConfirmParamsPaymentDetailsLodgingAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatum as PaymentIntentConfirmParamsPaymentDetailsLodgingDatum,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAccommodation as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAccommodation,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAffiliate as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumGuest as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumGuest,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHost as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHost,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHostAddress as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHostAddress,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumInsurance as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumInsurance,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotal as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotal,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalDiscounts as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalDiscounts,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalExtraCharge as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTax as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTax,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTaxTax as PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTaxTax,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDelivery as PaymentIntentConfirmParamsPaymentDetailsLodgingDelivery,
        PaymentIntentConfirmParamsPaymentDetailsLodgingDeliveryRecipient as PaymentIntentConfirmParamsPaymentDetailsLodgingDeliveryRecipient,
        PaymentIntentConfirmParamsPaymentDetailsLodgingPassenger as PaymentIntentConfirmParamsPaymentDetailsLodgingPassenger,
        PaymentIntentConfirmParamsPaymentDetailsSubscription as PaymentIntentConfirmParamsPaymentDetailsSubscription,
        PaymentIntentConfirmParamsPaymentDetailsSubscriptionAffiliate as PaymentIntentConfirmParamsPaymentDetailsSubscriptionAffiliate,
        PaymentIntentConfirmParamsPaymentDetailsSubscriptionBillingInterval as PaymentIntentConfirmParamsPaymentDetailsSubscriptionBillingInterval,
        PaymentIntentConfirmParamsPaymentMethodData as PaymentIntentConfirmParamsPaymentMethodData,
        PaymentIntentConfirmParamsPaymentMethodDataAcssDebit as PaymentIntentConfirmParamsPaymentMethodDataAcssDebit,
        PaymentIntentConfirmParamsPaymentMethodDataAffirm as PaymentIntentConfirmParamsPaymentMethodDataAffirm,
        PaymentIntentConfirmParamsPaymentMethodDataAfterpayClearpay as PaymentIntentConfirmParamsPaymentMethodDataAfterpayClearpay,
        PaymentIntentConfirmParamsPaymentMethodDataAlipay as PaymentIntentConfirmParamsPaymentMethodDataAlipay,
        PaymentIntentConfirmParamsPaymentMethodDataAlma as PaymentIntentConfirmParamsPaymentMethodDataAlma,
        PaymentIntentConfirmParamsPaymentMethodDataAmazonPay as PaymentIntentConfirmParamsPaymentMethodDataAmazonPay,
        PaymentIntentConfirmParamsPaymentMethodDataAuBecsDebit as PaymentIntentConfirmParamsPaymentMethodDataAuBecsDebit,
        PaymentIntentConfirmParamsPaymentMethodDataBacsDebit as PaymentIntentConfirmParamsPaymentMethodDataBacsDebit,
        PaymentIntentConfirmParamsPaymentMethodDataBancontact as PaymentIntentConfirmParamsPaymentMethodDataBancontact,
        PaymentIntentConfirmParamsPaymentMethodDataBillie as PaymentIntentConfirmParamsPaymentMethodDataBillie,
        PaymentIntentConfirmParamsPaymentMethodDataBillingDetails as PaymentIntentConfirmParamsPaymentMethodDataBillingDetails,
        PaymentIntentConfirmParamsPaymentMethodDataBillingDetailsAddress as PaymentIntentConfirmParamsPaymentMethodDataBillingDetailsAddress,
        PaymentIntentConfirmParamsPaymentMethodDataBlik as PaymentIntentConfirmParamsPaymentMethodDataBlik,
        PaymentIntentConfirmParamsPaymentMethodDataBoleto as PaymentIntentConfirmParamsPaymentMethodDataBoleto,
        PaymentIntentConfirmParamsPaymentMethodDataCashapp as PaymentIntentConfirmParamsPaymentMethodDataCashapp,
        PaymentIntentConfirmParamsPaymentMethodDataCrypto as PaymentIntentConfirmParamsPaymentMethodDataCrypto,
        PaymentIntentConfirmParamsPaymentMethodDataCustomerBalance as PaymentIntentConfirmParamsPaymentMethodDataCustomerBalance,
        PaymentIntentConfirmParamsPaymentMethodDataEps as PaymentIntentConfirmParamsPaymentMethodDataEps,
        PaymentIntentConfirmParamsPaymentMethodDataFpx as PaymentIntentConfirmParamsPaymentMethodDataFpx,
        PaymentIntentConfirmParamsPaymentMethodDataGiropay as PaymentIntentConfirmParamsPaymentMethodDataGiropay,
        PaymentIntentConfirmParamsPaymentMethodDataGopay as PaymentIntentConfirmParamsPaymentMethodDataGopay,
        PaymentIntentConfirmParamsPaymentMethodDataGrabpay as PaymentIntentConfirmParamsPaymentMethodDataGrabpay,
        PaymentIntentConfirmParamsPaymentMethodDataIdBankTransfer as PaymentIntentConfirmParamsPaymentMethodDataIdBankTransfer,
        PaymentIntentConfirmParamsPaymentMethodDataIdeal as PaymentIntentConfirmParamsPaymentMethodDataIdeal,
        PaymentIntentConfirmParamsPaymentMethodDataInteracPresent as PaymentIntentConfirmParamsPaymentMethodDataInteracPresent,
        PaymentIntentConfirmParamsPaymentMethodDataKakaoPay as PaymentIntentConfirmParamsPaymentMethodDataKakaoPay,
        PaymentIntentConfirmParamsPaymentMethodDataKlarna as PaymentIntentConfirmParamsPaymentMethodDataKlarna,
        PaymentIntentConfirmParamsPaymentMethodDataKlarnaDob as PaymentIntentConfirmParamsPaymentMethodDataKlarnaDob,
        PaymentIntentConfirmParamsPaymentMethodDataKonbini as PaymentIntentConfirmParamsPaymentMethodDataKonbini,
        PaymentIntentConfirmParamsPaymentMethodDataKrCard as PaymentIntentConfirmParamsPaymentMethodDataKrCard,
        PaymentIntentConfirmParamsPaymentMethodDataLink as PaymentIntentConfirmParamsPaymentMethodDataLink,
        PaymentIntentConfirmParamsPaymentMethodDataMbWay as PaymentIntentConfirmParamsPaymentMethodDataMbWay,
        PaymentIntentConfirmParamsPaymentMethodDataMobilepay as PaymentIntentConfirmParamsPaymentMethodDataMobilepay,
        PaymentIntentConfirmParamsPaymentMethodDataMultibanco as PaymentIntentConfirmParamsPaymentMethodDataMultibanco,
        PaymentIntentConfirmParamsPaymentMethodDataNaverPay as PaymentIntentConfirmParamsPaymentMethodDataNaverPay,
        PaymentIntentConfirmParamsPaymentMethodDataNzBankAccount as PaymentIntentConfirmParamsPaymentMethodDataNzBankAccount,
        PaymentIntentConfirmParamsPaymentMethodDataOxxo as PaymentIntentConfirmParamsPaymentMethodDataOxxo,
        PaymentIntentConfirmParamsPaymentMethodDataP24 as PaymentIntentConfirmParamsPaymentMethodDataP24,
        PaymentIntentConfirmParamsPaymentMethodDataPayByBank as PaymentIntentConfirmParamsPaymentMethodDataPayByBank,
        PaymentIntentConfirmParamsPaymentMethodDataPayco as PaymentIntentConfirmParamsPaymentMethodDataPayco,
        PaymentIntentConfirmParamsPaymentMethodDataPaynow as PaymentIntentConfirmParamsPaymentMethodDataPaynow,
        PaymentIntentConfirmParamsPaymentMethodDataPaypal as PaymentIntentConfirmParamsPaymentMethodDataPaypal,
        PaymentIntentConfirmParamsPaymentMethodDataPaypay as PaymentIntentConfirmParamsPaymentMethodDataPaypay,
        PaymentIntentConfirmParamsPaymentMethodDataPayto as PaymentIntentConfirmParamsPaymentMethodDataPayto,
        PaymentIntentConfirmParamsPaymentMethodDataPix as PaymentIntentConfirmParamsPaymentMethodDataPix,
        PaymentIntentConfirmParamsPaymentMethodDataPromptpay as PaymentIntentConfirmParamsPaymentMethodDataPromptpay,
        PaymentIntentConfirmParamsPaymentMethodDataQris as PaymentIntentConfirmParamsPaymentMethodDataQris,
        PaymentIntentConfirmParamsPaymentMethodDataRadarOptions as PaymentIntentConfirmParamsPaymentMethodDataRadarOptions,
        PaymentIntentConfirmParamsPaymentMethodDataRechnung as PaymentIntentConfirmParamsPaymentMethodDataRechnung,
        PaymentIntentConfirmParamsPaymentMethodDataRechnungDob as PaymentIntentConfirmParamsPaymentMethodDataRechnungDob,
        PaymentIntentConfirmParamsPaymentMethodDataRevolutPay as PaymentIntentConfirmParamsPaymentMethodDataRevolutPay,
        PaymentIntentConfirmParamsPaymentMethodDataSamsungPay as PaymentIntentConfirmParamsPaymentMethodDataSamsungPay,
        PaymentIntentConfirmParamsPaymentMethodDataSatispay as PaymentIntentConfirmParamsPaymentMethodDataSatispay,
        PaymentIntentConfirmParamsPaymentMethodDataSepaDebit as PaymentIntentConfirmParamsPaymentMethodDataSepaDebit,
        PaymentIntentConfirmParamsPaymentMethodDataShopeepay as PaymentIntentConfirmParamsPaymentMethodDataShopeepay,
        PaymentIntentConfirmParamsPaymentMethodDataSofort as PaymentIntentConfirmParamsPaymentMethodDataSofort,
        PaymentIntentConfirmParamsPaymentMethodDataStripeBalance as PaymentIntentConfirmParamsPaymentMethodDataStripeBalance,
        PaymentIntentConfirmParamsPaymentMethodDataSwish as PaymentIntentConfirmParamsPaymentMethodDataSwish,
        PaymentIntentConfirmParamsPaymentMethodDataTwint as PaymentIntentConfirmParamsPaymentMethodDataTwint,
        PaymentIntentConfirmParamsPaymentMethodDataUsBankAccount as PaymentIntentConfirmParamsPaymentMethodDataUsBankAccount,
        PaymentIntentConfirmParamsPaymentMethodDataWechatPay as PaymentIntentConfirmParamsPaymentMethodDataWechatPay,
        PaymentIntentConfirmParamsPaymentMethodDataZip as PaymentIntentConfirmParamsPaymentMethodDataZip,
        PaymentIntentConfirmParamsPaymentMethodOptions as PaymentIntentConfirmParamsPaymentMethodOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebit as PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebit,
        PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsAffirm as PaymentIntentConfirmParamsPaymentMethodOptionsAffirm,
        PaymentIntentConfirmParamsPaymentMethodOptionsAfterpayClearpay as PaymentIntentConfirmParamsPaymentMethodOptionsAfterpayClearpay,
        PaymentIntentConfirmParamsPaymentMethodOptionsAlipay as PaymentIntentConfirmParamsPaymentMethodOptionsAlipay,
        PaymentIntentConfirmParamsPaymentMethodOptionsAlma as PaymentIntentConfirmParamsPaymentMethodOptionsAlma,
        PaymentIntentConfirmParamsPaymentMethodOptionsAmazonPay as PaymentIntentConfirmParamsPaymentMethodOptionsAmazonPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsAuBecsDebit as PaymentIntentConfirmParamsPaymentMethodOptionsAuBecsDebit,
        PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebit as PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebit,
        PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsBancontact as PaymentIntentConfirmParamsPaymentMethodOptionsBancontact,
        PaymentIntentConfirmParamsPaymentMethodOptionsBillie as PaymentIntentConfirmParamsPaymentMethodOptionsBillie,
        PaymentIntentConfirmParamsPaymentMethodOptionsBlik as PaymentIntentConfirmParamsPaymentMethodOptionsBlik,
        PaymentIntentConfirmParamsPaymentMethodOptionsBoleto as PaymentIntentConfirmParamsPaymentMethodOptionsBoleto,
        PaymentIntentConfirmParamsPaymentMethodOptionsCard as PaymentIntentConfirmParamsPaymentMethodOptionsCard,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallments as PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallments,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallmentsPlan as PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallmentsPlan,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsCardMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardPresent as PaymentIntentConfirmParamsPaymentMethodOptionsCardPresent,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardPresentRouting as PaymentIntentConfirmParamsPaymentMethodOptionsCardPresentRouting,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetails as PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetails,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetailsAddress as PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetailsAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure as PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        PaymentIntentConfirmParamsPaymentMethodOptionsCashapp as PaymentIntentConfirmParamsPaymentMethodOptionsCashapp,
        PaymentIntentConfirmParamsPaymentMethodOptionsCrypto as PaymentIntentConfirmParamsPaymentMethodOptionsCrypto,
        PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalance as PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalance,
        PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransfer as PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        PaymentIntentConfirmParamsPaymentMethodOptionsEps as PaymentIntentConfirmParamsPaymentMethodOptionsEps,
        PaymentIntentConfirmParamsPaymentMethodOptionsFpx as PaymentIntentConfirmParamsPaymentMethodOptionsFpx,
        PaymentIntentConfirmParamsPaymentMethodOptionsGiropay as PaymentIntentConfirmParamsPaymentMethodOptionsGiropay,
        PaymentIntentConfirmParamsPaymentMethodOptionsGopay as PaymentIntentConfirmParamsPaymentMethodOptionsGopay,
        PaymentIntentConfirmParamsPaymentMethodOptionsGrabpay as PaymentIntentConfirmParamsPaymentMethodOptionsGrabpay,
        PaymentIntentConfirmParamsPaymentMethodOptionsIdBankTransfer as PaymentIntentConfirmParamsPaymentMethodOptionsIdBankTransfer,
        PaymentIntentConfirmParamsPaymentMethodOptionsIdeal as PaymentIntentConfirmParamsPaymentMethodOptionsIdeal,
        PaymentIntentConfirmParamsPaymentMethodOptionsInteracPresent as PaymentIntentConfirmParamsPaymentMethodOptionsInteracPresent,
        PaymentIntentConfirmParamsPaymentMethodOptionsKakaoPay as PaymentIntentConfirmParamsPaymentMethodOptionsKakaoPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarna as PaymentIntentConfirmParamsPaymentMethodOptionsKlarna,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        PaymentIntentConfirmParamsPaymentMethodOptionsKonbini as PaymentIntentConfirmParamsPaymentMethodOptionsKonbini,
        PaymentIntentConfirmParamsPaymentMethodOptionsKrCard as PaymentIntentConfirmParamsPaymentMethodOptionsKrCard,
        PaymentIntentConfirmParamsPaymentMethodOptionsLink as PaymentIntentConfirmParamsPaymentMethodOptionsLink,
        PaymentIntentConfirmParamsPaymentMethodOptionsMbWay as PaymentIntentConfirmParamsPaymentMethodOptionsMbWay,
        PaymentIntentConfirmParamsPaymentMethodOptionsMobilepay as PaymentIntentConfirmParamsPaymentMethodOptionsMobilepay,
        PaymentIntentConfirmParamsPaymentMethodOptionsMultibanco as PaymentIntentConfirmParamsPaymentMethodOptionsMultibanco,
        PaymentIntentConfirmParamsPaymentMethodOptionsNaverPay as PaymentIntentConfirmParamsPaymentMethodOptionsNaverPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsNzBankAccount as PaymentIntentConfirmParamsPaymentMethodOptionsNzBankAccount,
        PaymentIntentConfirmParamsPaymentMethodOptionsOxxo as PaymentIntentConfirmParamsPaymentMethodOptionsOxxo,
        PaymentIntentConfirmParamsPaymentMethodOptionsP24 as PaymentIntentConfirmParamsPaymentMethodOptionsP24,
        PaymentIntentConfirmParamsPaymentMethodOptionsPayByBank as PaymentIntentConfirmParamsPaymentMethodOptionsPayByBank,
        PaymentIntentConfirmParamsPaymentMethodOptionsPayco as PaymentIntentConfirmParamsPaymentMethodOptionsPayco,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaynow as PaymentIntentConfirmParamsPaymentMethodOptionsPaynow,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaypal as PaymentIntentConfirmParamsPaymentMethodOptionsPaypal,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItem as PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItem,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItemTax as PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItemTax,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaypay as PaymentIntentConfirmParamsPaymentMethodOptionsPaypay,
        PaymentIntentConfirmParamsPaymentMethodOptionsPayto as PaymentIntentConfirmParamsPaymentMethodOptionsPayto,
        PaymentIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsPix as PaymentIntentConfirmParamsPaymentMethodOptionsPix,
        PaymentIntentConfirmParamsPaymentMethodOptionsPixMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsPixMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsPromptpay as PaymentIntentConfirmParamsPaymentMethodOptionsPromptpay,
        PaymentIntentConfirmParamsPaymentMethodOptionsQris as PaymentIntentConfirmParamsPaymentMethodOptionsQris,
        PaymentIntentConfirmParamsPaymentMethodOptionsRechnung as PaymentIntentConfirmParamsPaymentMethodOptionsRechnung,
        PaymentIntentConfirmParamsPaymentMethodOptionsRevolutPay as PaymentIntentConfirmParamsPaymentMethodOptionsRevolutPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsSamsungPay as PaymentIntentConfirmParamsPaymentMethodOptionsSamsungPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsSatispay as PaymentIntentConfirmParamsPaymentMethodOptionsSatispay,
        PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebit as PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebit,
        PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsShopeepay as PaymentIntentConfirmParamsPaymentMethodOptionsShopeepay,
        PaymentIntentConfirmParamsPaymentMethodOptionsSofort as PaymentIntentConfirmParamsPaymentMethodOptionsSofort,
        PaymentIntentConfirmParamsPaymentMethodOptionsStripeBalance as PaymentIntentConfirmParamsPaymentMethodOptionsStripeBalance,
        PaymentIntentConfirmParamsPaymentMethodOptionsSwish as PaymentIntentConfirmParamsPaymentMethodOptionsSwish,
        PaymentIntentConfirmParamsPaymentMethodOptionsTwint as PaymentIntentConfirmParamsPaymentMethodOptionsTwint,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccount as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccount,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks as PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks,
        PaymentIntentConfirmParamsPaymentMethodOptionsWechatPay as PaymentIntentConfirmParamsPaymentMethodOptionsWechatPay,
        PaymentIntentConfirmParamsPaymentMethodOptionsZip as PaymentIntentConfirmParamsPaymentMethodOptionsZip,
        PaymentIntentConfirmParamsRadarOptions as PaymentIntentConfirmParamsRadarOptions,
        PaymentIntentConfirmParamsShipping as PaymentIntentConfirmParamsShipping,
        PaymentIntentConfirmParamsShippingAddress as PaymentIntentConfirmParamsShippingAddress,
    )
    from stripe.params._payment_intent_create_params import (
        PaymentIntentCreateParams as PaymentIntentCreateParams,
        PaymentIntentCreateParamsAllocatedFunds as PaymentIntentCreateParamsAllocatedFunds,
        PaymentIntentCreateParamsAmountDetails as PaymentIntentCreateParamsAmountDetails,
        PaymentIntentCreateParamsAmountDetailsLineItem as PaymentIntentCreateParamsAmountDetailsLineItem,
        PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentCreateParamsAmountDetailsLineItemTax as PaymentIntentCreateParamsAmountDetailsLineItemTax,
        PaymentIntentCreateParamsAmountDetailsShipping as PaymentIntentCreateParamsAmountDetailsShipping,
        PaymentIntentCreateParamsAmountDetailsTax as PaymentIntentCreateParamsAmountDetailsTax,
        PaymentIntentCreateParamsAutomaticPaymentMethods as PaymentIntentCreateParamsAutomaticPaymentMethods,
        PaymentIntentCreateParamsHooks as PaymentIntentCreateParamsHooks,
        PaymentIntentCreateParamsHooksInputs as PaymentIntentCreateParamsHooksInputs,
        PaymentIntentCreateParamsHooksInputsTax as PaymentIntentCreateParamsHooksInputsTax,
        PaymentIntentCreateParamsMandateData as PaymentIntentCreateParamsMandateData,
        PaymentIntentCreateParamsMandateDataCustomerAcceptance as PaymentIntentCreateParamsMandateDataCustomerAcceptance,
        PaymentIntentCreateParamsMandateDataCustomerAcceptanceOffline as PaymentIntentCreateParamsMandateDataCustomerAcceptanceOffline,
        PaymentIntentCreateParamsMandateDataCustomerAcceptanceOnline as PaymentIntentCreateParamsMandateDataCustomerAcceptanceOnline,
        PaymentIntentCreateParamsPaymentDetails as PaymentIntentCreateParamsPaymentDetails,
        PaymentIntentCreateParamsPaymentDetailsBenefit as PaymentIntentCreateParamsPaymentDetailsBenefit,
        PaymentIntentCreateParamsPaymentDetailsBenefitFrMealVoucher as PaymentIntentCreateParamsPaymentDetailsBenefitFrMealVoucher,
        PaymentIntentCreateParamsPaymentDetailsCarRental as PaymentIntentCreateParamsPaymentDetailsCarRental,
        PaymentIntentCreateParamsPaymentDetailsCarRentalAffiliate as PaymentIntentCreateParamsPaymentDetailsCarRentalAffiliate,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatum as PaymentIntentCreateParamsPaymentDetailsCarRentalDatum,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumAffiliate as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumAffiliate,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDistance as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDistance,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriver as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriver,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOff as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOff,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOffAddress as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOffAddress,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumInsurance as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumInsurance,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickup as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickup,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickupAddress as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickupAddress,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotal as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotal,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalDiscounts as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalExtraCharge as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTax as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTax,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTaxTax as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDatumVehicle as PaymentIntentCreateParamsPaymentDetailsCarRentalDatumVehicle,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDelivery as PaymentIntentCreateParamsPaymentDetailsCarRentalDelivery,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDeliveryRecipient as PaymentIntentCreateParamsPaymentDetailsCarRentalDeliveryRecipient,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDistance as PaymentIntentCreateParamsPaymentDetailsCarRentalDistance,
        PaymentIntentCreateParamsPaymentDetailsCarRentalDriver as PaymentIntentCreateParamsPaymentDetailsCarRentalDriver,
        PaymentIntentCreateParamsPaymentDetailsCarRentalPickupAddress as PaymentIntentCreateParamsPaymentDetailsCarRentalPickupAddress,
        PaymentIntentCreateParamsPaymentDetailsCarRentalReturnAddress as PaymentIntentCreateParamsPaymentDetailsCarRentalReturnAddress,
        PaymentIntentCreateParamsPaymentDetailsEventDetails as PaymentIntentCreateParamsPaymentDetailsEventDetails,
        PaymentIntentCreateParamsPaymentDetailsEventDetailsAddress as PaymentIntentCreateParamsPaymentDetailsEventDetailsAddress,
        PaymentIntentCreateParamsPaymentDetailsEventDetailsAffiliate as PaymentIntentCreateParamsPaymentDetailsEventDetailsAffiliate,
        PaymentIntentCreateParamsPaymentDetailsEventDetailsDelivery as PaymentIntentCreateParamsPaymentDetailsEventDetailsDelivery,
        PaymentIntentCreateParamsPaymentDetailsEventDetailsDeliveryRecipient as PaymentIntentCreateParamsPaymentDetailsEventDetailsDeliveryRecipient,
        PaymentIntentCreateParamsPaymentDetailsFlight as PaymentIntentCreateParamsPaymentDetailsFlight,
        PaymentIntentCreateParamsPaymentDetailsFlightAffiliate as PaymentIntentCreateParamsPaymentDetailsFlightAffiliate,
        PaymentIntentCreateParamsPaymentDetailsFlightDatum as PaymentIntentCreateParamsPaymentDetailsFlightDatum,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumAffiliate as PaymentIntentCreateParamsPaymentDetailsFlightDatumAffiliate,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumInsurance as PaymentIntentCreateParamsPaymentDetailsFlightDatumInsurance,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumPassenger as PaymentIntentCreateParamsPaymentDetailsFlightDatumPassenger,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumSegment as PaymentIntentCreateParamsPaymentDetailsFlightDatumSegment,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentArrival as PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentArrival,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentDeparture as PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentDeparture,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumTotal as PaymentIntentCreateParamsPaymentDetailsFlightDatumTotal,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalDiscounts as PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalDiscounts,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalExtraCharge as PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalExtraCharge,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTax as PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTax,
        PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTaxTax as PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTaxTax,
        PaymentIntentCreateParamsPaymentDetailsFlightDelivery as PaymentIntentCreateParamsPaymentDetailsFlightDelivery,
        PaymentIntentCreateParamsPaymentDetailsFlightDeliveryRecipient as PaymentIntentCreateParamsPaymentDetailsFlightDeliveryRecipient,
        PaymentIntentCreateParamsPaymentDetailsFlightPassenger as PaymentIntentCreateParamsPaymentDetailsFlightPassenger,
        PaymentIntentCreateParamsPaymentDetailsFlightSegment as PaymentIntentCreateParamsPaymentDetailsFlightSegment,
        PaymentIntentCreateParamsPaymentDetailsLodging as PaymentIntentCreateParamsPaymentDetailsLodging,
        PaymentIntentCreateParamsPaymentDetailsLodgingAddress as PaymentIntentCreateParamsPaymentDetailsLodgingAddress,
        PaymentIntentCreateParamsPaymentDetailsLodgingAffiliate as PaymentIntentCreateParamsPaymentDetailsLodgingAffiliate,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatum as PaymentIntentCreateParamsPaymentDetailsLodgingDatum,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumAccommodation as PaymentIntentCreateParamsPaymentDetailsLodgingDatumAccommodation,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumAffiliate as PaymentIntentCreateParamsPaymentDetailsLodgingDatumAffiliate,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumGuest as PaymentIntentCreateParamsPaymentDetailsLodgingDatumGuest,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumHost as PaymentIntentCreateParamsPaymentDetailsLodgingDatumHost,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumHostAddress as PaymentIntentCreateParamsPaymentDetailsLodgingDatumHostAddress,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumInsurance as PaymentIntentCreateParamsPaymentDetailsLodgingDatumInsurance,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotal as PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotal,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalDiscounts as PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalDiscounts,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalExtraCharge as PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTax as PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTax,
        PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTaxTax as PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTaxTax,
        PaymentIntentCreateParamsPaymentDetailsLodgingDelivery as PaymentIntentCreateParamsPaymentDetailsLodgingDelivery,
        PaymentIntentCreateParamsPaymentDetailsLodgingDeliveryRecipient as PaymentIntentCreateParamsPaymentDetailsLodgingDeliveryRecipient,
        PaymentIntentCreateParamsPaymentDetailsLodgingPassenger as PaymentIntentCreateParamsPaymentDetailsLodgingPassenger,
        PaymentIntentCreateParamsPaymentDetailsSubscription as PaymentIntentCreateParamsPaymentDetailsSubscription,
        PaymentIntentCreateParamsPaymentDetailsSubscriptionAffiliate as PaymentIntentCreateParamsPaymentDetailsSubscriptionAffiliate,
        PaymentIntentCreateParamsPaymentDetailsSubscriptionBillingInterval as PaymentIntentCreateParamsPaymentDetailsSubscriptionBillingInterval,
        PaymentIntentCreateParamsPaymentMethodData as PaymentIntentCreateParamsPaymentMethodData,
        PaymentIntentCreateParamsPaymentMethodDataAcssDebit as PaymentIntentCreateParamsPaymentMethodDataAcssDebit,
        PaymentIntentCreateParamsPaymentMethodDataAffirm as PaymentIntentCreateParamsPaymentMethodDataAffirm,
        PaymentIntentCreateParamsPaymentMethodDataAfterpayClearpay as PaymentIntentCreateParamsPaymentMethodDataAfterpayClearpay,
        PaymentIntentCreateParamsPaymentMethodDataAlipay as PaymentIntentCreateParamsPaymentMethodDataAlipay,
        PaymentIntentCreateParamsPaymentMethodDataAlma as PaymentIntentCreateParamsPaymentMethodDataAlma,
        PaymentIntentCreateParamsPaymentMethodDataAmazonPay as PaymentIntentCreateParamsPaymentMethodDataAmazonPay,
        PaymentIntentCreateParamsPaymentMethodDataAuBecsDebit as PaymentIntentCreateParamsPaymentMethodDataAuBecsDebit,
        PaymentIntentCreateParamsPaymentMethodDataBacsDebit as PaymentIntentCreateParamsPaymentMethodDataBacsDebit,
        PaymentIntentCreateParamsPaymentMethodDataBancontact as PaymentIntentCreateParamsPaymentMethodDataBancontact,
        PaymentIntentCreateParamsPaymentMethodDataBillie as PaymentIntentCreateParamsPaymentMethodDataBillie,
        PaymentIntentCreateParamsPaymentMethodDataBillingDetails as PaymentIntentCreateParamsPaymentMethodDataBillingDetails,
        PaymentIntentCreateParamsPaymentMethodDataBillingDetailsAddress as PaymentIntentCreateParamsPaymentMethodDataBillingDetailsAddress,
        PaymentIntentCreateParamsPaymentMethodDataBlik as PaymentIntentCreateParamsPaymentMethodDataBlik,
        PaymentIntentCreateParamsPaymentMethodDataBoleto as PaymentIntentCreateParamsPaymentMethodDataBoleto,
        PaymentIntentCreateParamsPaymentMethodDataCashapp as PaymentIntentCreateParamsPaymentMethodDataCashapp,
        PaymentIntentCreateParamsPaymentMethodDataCrypto as PaymentIntentCreateParamsPaymentMethodDataCrypto,
        PaymentIntentCreateParamsPaymentMethodDataCustomerBalance as PaymentIntentCreateParamsPaymentMethodDataCustomerBalance,
        PaymentIntentCreateParamsPaymentMethodDataEps as PaymentIntentCreateParamsPaymentMethodDataEps,
        PaymentIntentCreateParamsPaymentMethodDataFpx as PaymentIntentCreateParamsPaymentMethodDataFpx,
        PaymentIntentCreateParamsPaymentMethodDataGiropay as PaymentIntentCreateParamsPaymentMethodDataGiropay,
        PaymentIntentCreateParamsPaymentMethodDataGopay as PaymentIntentCreateParamsPaymentMethodDataGopay,
        PaymentIntentCreateParamsPaymentMethodDataGrabpay as PaymentIntentCreateParamsPaymentMethodDataGrabpay,
        PaymentIntentCreateParamsPaymentMethodDataIdBankTransfer as PaymentIntentCreateParamsPaymentMethodDataIdBankTransfer,
        PaymentIntentCreateParamsPaymentMethodDataIdeal as PaymentIntentCreateParamsPaymentMethodDataIdeal,
        PaymentIntentCreateParamsPaymentMethodDataInteracPresent as PaymentIntentCreateParamsPaymentMethodDataInteracPresent,
        PaymentIntentCreateParamsPaymentMethodDataKakaoPay as PaymentIntentCreateParamsPaymentMethodDataKakaoPay,
        PaymentIntentCreateParamsPaymentMethodDataKlarna as PaymentIntentCreateParamsPaymentMethodDataKlarna,
        PaymentIntentCreateParamsPaymentMethodDataKlarnaDob as PaymentIntentCreateParamsPaymentMethodDataKlarnaDob,
        PaymentIntentCreateParamsPaymentMethodDataKonbini as PaymentIntentCreateParamsPaymentMethodDataKonbini,
        PaymentIntentCreateParamsPaymentMethodDataKrCard as PaymentIntentCreateParamsPaymentMethodDataKrCard,
        PaymentIntentCreateParamsPaymentMethodDataLink as PaymentIntentCreateParamsPaymentMethodDataLink,
        PaymentIntentCreateParamsPaymentMethodDataMbWay as PaymentIntentCreateParamsPaymentMethodDataMbWay,
        PaymentIntentCreateParamsPaymentMethodDataMobilepay as PaymentIntentCreateParamsPaymentMethodDataMobilepay,
        PaymentIntentCreateParamsPaymentMethodDataMultibanco as PaymentIntentCreateParamsPaymentMethodDataMultibanco,
        PaymentIntentCreateParamsPaymentMethodDataNaverPay as PaymentIntentCreateParamsPaymentMethodDataNaverPay,
        PaymentIntentCreateParamsPaymentMethodDataNzBankAccount as PaymentIntentCreateParamsPaymentMethodDataNzBankAccount,
        PaymentIntentCreateParamsPaymentMethodDataOxxo as PaymentIntentCreateParamsPaymentMethodDataOxxo,
        PaymentIntentCreateParamsPaymentMethodDataP24 as PaymentIntentCreateParamsPaymentMethodDataP24,
        PaymentIntentCreateParamsPaymentMethodDataPayByBank as PaymentIntentCreateParamsPaymentMethodDataPayByBank,
        PaymentIntentCreateParamsPaymentMethodDataPayco as PaymentIntentCreateParamsPaymentMethodDataPayco,
        PaymentIntentCreateParamsPaymentMethodDataPaynow as PaymentIntentCreateParamsPaymentMethodDataPaynow,
        PaymentIntentCreateParamsPaymentMethodDataPaypal as PaymentIntentCreateParamsPaymentMethodDataPaypal,
        PaymentIntentCreateParamsPaymentMethodDataPaypay as PaymentIntentCreateParamsPaymentMethodDataPaypay,
        PaymentIntentCreateParamsPaymentMethodDataPayto as PaymentIntentCreateParamsPaymentMethodDataPayto,
        PaymentIntentCreateParamsPaymentMethodDataPix as PaymentIntentCreateParamsPaymentMethodDataPix,
        PaymentIntentCreateParamsPaymentMethodDataPromptpay as PaymentIntentCreateParamsPaymentMethodDataPromptpay,
        PaymentIntentCreateParamsPaymentMethodDataQris as PaymentIntentCreateParamsPaymentMethodDataQris,
        PaymentIntentCreateParamsPaymentMethodDataRadarOptions as PaymentIntentCreateParamsPaymentMethodDataRadarOptions,
        PaymentIntentCreateParamsPaymentMethodDataRechnung as PaymentIntentCreateParamsPaymentMethodDataRechnung,
        PaymentIntentCreateParamsPaymentMethodDataRechnungDob as PaymentIntentCreateParamsPaymentMethodDataRechnungDob,
        PaymentIntentCreateParamsPaymentMethodDataRevolutPay as PaymentIntentCreateParamsPaymentMethodDataRevolutPay,
        PaymentIntentCreateParamsPaymentMethodDataSamsungPay as PaymentIntentCreateParamsPaymentMethodDataSamsungPay,
        PaymentIntentCreateParamsPaymentMethodDataSatispay as PaymentIntentCreateParamsPaymentMethodDataSatispay,
        PaymentIntentCreateParamsPaymentMethodDataSepaDebit as PaymentIntentCreateParamsPaymentMethodDataSepaDebit,
        PaymentIntentCreateParamsPaymentMethodDataShopeepay as PaymentIntentCreateParamsPaymentMethodDataShopeepay,
        PaymentIntentCreateParamsPaymentMethodDataSofort as PaymentIntentCreateParamsPaymentMethodDataSofort,
        PaymentIntentCreateParamsPaymentMethodDataStripeBalance as PaymentIntentCreateParamsPaymentMethodDataStripeBalance,
        PaymentIntentCreateParamsPaymentMethodDataSwish as PaymentIntentCreateParamsPaymentMethodDataSwish,
        PaymentIntentCreateParamsPaymentMethodDataTwint as PaymentIntentCreateParamsPaymentMethodDataTwint,
        PaymentIntentCreateParamsPaymentMethodDataUsBankAccount as PaymentIntentCreateParamsPaymentMethodDataUsBankAccount,
        PaymentIntentCreateParamsPaymentMethodDataWechatPay as PaymentIntentCreateParamsPaymentMethodDataWechatPay,
        PaymentIntentCreateParamsPaymentMethodDataZip as PaymentIntentCreateParamsPaymentMethodDataZip,
        PaymentIntentCreateParamsPaymentMethodOptions as PaymentIntentCreateParamsPaymentMethodOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsAcssDebit as PaymentIntentCreateParamsPaymentMethodOptionsAcssDebit,
        PaymentIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsAffirm as PaymentIntentCreateParamsPaymentMethodOptionsAffirm,
        PaymentIntentCreateParamsPaymentMethodOptionsAfterpayClearpay as PaymentIntentCreateParamsPaymentMethodOptionsAfterpayClearpay,
        PaymentIntentCreateParamsPaymentMethodOptionsAlipay as PaymentIntentCreateParamsPaymentMethodOptionsAlipay,
        PaymentIntentCreateParamsPaymentMethodOptionsAlma as PaymentIntentCreateParamsPaymentMethodOptionsAlma,
        PaymentIntentCreateParamsPaymentMethodOptionsAmazonPay as PaymentIntentCreateParamsPaymentMethodOptionsAmazonPay,
        PaymentIntentCreateParamsPaymentMethodOptionsAuBecsDebit as PaymentIntentCreateParamsPaymentMethodOptionsAuBecsDebit,
        PaymentIntentCreateParamsPaymentMethodOptionsBacsDebit as PaymentIntentCreateParamsPaymentMethodOptionsBacsDebit,
        PaymentIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsBancontact as PaymentIntentCreateParamsPaymentMethodOptionsBancontact,
        PaymentIntentCreateParamsPaymentMethodOptionsBillie as PaymentIntentCreateParamsPaymentMethodOptionsBillie,
        PaymentIntentCreateParamsPaymentMethodOptionsBlik as PaymentIntentCreateParamsPaymentMethodOptionsBlik,
        PaymentIntentCreateParamsPaymentMethodOptionsBoleto as PaymentIntentCreateParamsPaymentMethodOptionsBoleto,
        PaymentIntentCreateParamsPaymentMethodOptionsCard as PaymentIntentCreateParamsPaymentMethodOptionsCard,
        PaymentIntentCreateParamsPaymentMethodOptionsCardInstallments as PaymentIntentCreateParamsPaymentMethodOptionsCardInstallments,
        PaymentIntentCreateParamsPaymentMethodOptionsCardInstallmentsPlan as PaymentIntentCreateParamsPaymentMethodOptionsCardInstallmentsPlan,
        PaymentIntentCreateParamsPaymentMethodOptionsCardMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsCardMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsCardPresent as PaymentIntentCreateParamsPaymentMethodOptionsCardPresent,
        PaymentIntentCreateParamsPaymentMethodOptionsCardPresentRouting as PaymentIntentCreateParamsPaymentMethodOptionsCardPresentRouting,
        PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetails as PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetails,
        PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetailsAddress as PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetailsAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecure as PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecure,
        PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        PaymentIntentCreateParamsPaymentMethodOptionsCashapp as PaymentIntentCreateParamsPaymentMethodOptionsCashapp,
        PaymentIntentCreateParamsPaymentMethodOptionsCrypto as PaymentIntentCreateParamsPaymentMethodOptionsCrypto,
        PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalance as PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalance,
        PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        PaymentIntentCreateParamsPaymentMethodOptionsEps as PaymentIntentCreateParamsPaymentMethodOptionsEps,
        PaymentIntentCreateParamsPaymentMethodOptionsFpx as PaymentIntentCreateParamsPaymentMethodOptionsFpx,
        PaymentIntentCreateParamsPaymentMethodOptionsGiropay as PaymentIntentCreateParamsPaymentMethodOptionsGiropay,
        PaymentIntentCreateParamsPaymentMethodOptionsGopay as PaymentIntentCreateParamsPaymentMethodOptionsGopay,
        PaymentIntentCreateParamsPaymentMethodOptionsGrabpay as PaymentIntentCreateParamsPaymentMethodOptionsGrabpay,
        PaymentIntentCreateParamsPaymentMethodOptionsIdBankTransfer as PaymentIntentCreateParamsPaymentMethodOptionsIdBankTransfer,
        PaymentIntentCreateParamsPaymentMethodOptionsIdeal as PaymentIntentCreateParamsPaymentMethodOptionsIdeal,
        PaymentIntentCreateParamsPaymentMethodOptionsInteracPresent as PaymentIntentCreateParamsPaymentMethodOptionsInteracPresent,
        PaymentIntentCreateParamsPaymentMethodOptionsKakaoPay as PaymentIntentCreateParamsPaymentMethodOptionsKakaoPay,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarna as PaymentIntentCreateParamsPaymentMethodOptionsKlarna,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscription as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscription,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        PaymentIntentCreateParamsPaymentMethodOptionsKonbini as PaymentIntentCreateParamsPaymentMethodOptionsKonbini,
        PaymentIntentCreateParamsPaymentMethodOptionsKrCard as PaymentIntentCreateParamsPaymentMethodOptionsKrCard,
        PaymentIntentCreateParamsPaymentMethodOptionsLink as PaymentIntentCreateParamsPaymentMethodOptionsLink,
        PaymentIntentCreateParamsPaymentMethodOptionsMbWay as PaymentIntentCreateParamsPaymentMethodOptionsMbWay,
        PaymentIntentCreateParamsPaymentMethodOptionsMobilepay as PaymentIntentCreateParamsPaymentMethodOptionsMobilepay,
        PaymentIntentCreateParamsPaymentMethodOptionsMultibanco as PaymentIntentCreateParamsPaymentMethodOptionsMultibanco,
        PaymentIntentCreateParamsPaymentMethodOptionsNaverPay as PaymentIntentCreateParamsPaymentMethodOptionsNaverPay,
        PaymentIntentCreateParamsPaymentMethodOptionsNzBankAccount as PaymentIntentCreateParamsPaymentMethodOptionsNzBankAccount,
        PaymentIntentCreateParamsPaymentMethodOptionsOxxo as PaymentIntentCreateParamsPaymentMethodOptionsOxxo,
        PaymentIntentCreateParamsPaymentMethodOptionsP24 as PaymentIntentCreateParamsPaymentMethodOptionsP24,
        PaymentIntentCreateParamsPaymentMethodOptionsPayByBank as PaymentIntentCreateParamsPaymentMethodOptionsPayByBank,
        PaymentIntentCreateParamsPaymentMethodOptionsPayco as PaymentIntentCreateParamsPaymentMethodOptionsPayco,
        PaymentIntentCreateParamsPaymentMethodOptionsPaynow as PaymentIntentCreateParamsPaymentMethodOptionsPaynow,
        PaymentIntentCreateParamsPaymentMethodOptionsPaypal as PaymentIntentCreateParamsPaymentMethodOptionsPaypal,
        PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItem as PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItem,
        PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItemTax as PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItemTax,
        PaymentIntentCreateParamsPaymentMethodOptionsPaypay as PaymentIntentCreateParamsPaymentMethodOptionsPaypay,
        PaymentIntentCreateParamsPaymentMethodOptionsPayto as PaymentIntentCreateParamsPaymentMethodOptionsPayto,
        PaymentIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsPix as PaymentIntentCreateParamsPaymentMethodOptionsPix,
        PaymentIntentCreateParamsPaymentMethodOptionsPixMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsPixMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsPromptpay as PaymentIntentCreateParamsPaymentMethodOptionsPromptpay,
        PaymentIntentCreateParamsPaymentMethodOptionsQris as PaymentIntentCreateParamsPaymentMethodOptionsQris,
        PaymentIntentCreateParamsPaymentMethodOptionsRechnung as PaymentIntentCreateParamsPaymentMethodOptionsRechnung,
        PaymentIntentCreateParamsPaymentMethodOptionsRevolutPay as PaymentIntentCreateParamsPaymentMethodOptionsRevolutPay,
        PaymentIntentCreateParamsPaymentMethodOptionsSamsungPay as PaymentIntentCreateParamsPaymentMethodOptionsSamsungPay,
        PaymentIntentCreateParamsPaymentMethodOptionsSatispay as PaymentIntentCreateParamsPaymentMethodOptionsSatispay,
        PaymentIntentCreateParamsPaymentMethodOptionsSepaDebit as PaymentIntentCreateParamsPaymentMethodOptionsSepaDebit,
        PaymentIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsShopeepay as PaymentIntentCreateParamsPaymentMethodOptionsShopeepay,
        PaymentIntentCreateParamsPaymentMethodOptionsSofort as PaymentIntentCreateParamsPaymentMethodOptionsSofort,
        PaymentIntentCreateParamsPaymentMethodOptionsStripeBalance as PaymentIntentCreateParamsPaymentMethodOptionsStripeBalance,
        PaymentIntentCreateParamsPaymentMethodOptionsSwish as PaymentIntentCreateParamsPaymentMethodOptionsSwish,
        PaymentIntentCreateParamsPaymentMethodOptionsTwint as PaymentIntentCreateParamsPaymentMethodOptionsTwint,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccount as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccount,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks as PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks,
        PaymentIntentCreateParamsPaymentMethodOptionsWechatPay as PaymentIntentCreateParamsPaymentMethodOptionsWechatPay,
        PaymentIntentCreateParamsPaymentMethodOptionsZip as PaymentIntentCreateParamsPaymentMethodOptionsZip,
        PaymentIntentCreateParamsRadarOptions as PaymentIntentCreateParamsRadarOptions,
        PaymentIntentCreateParamsShipping as PaymentIntentCreateParamsShipping,
        PaymentIntentCreateParamsShippingAddress as PaymentIntentCreateParamsShippingAddress,
        PaymentIntentCreateParamsTransferData as PaymentIntentCreateParamsTransferData,
    )
    from stripe.params._payment_intent_decrement_authorization_params import (
        PaymentIntentDecrementAuthorizationParams as PaymentIntentDecrementAuthorizationParams,
        PaymentIntentDecrementAuthorizationParamsHooks as PaymentIntentDecrementAuthorizationParamsHooks,
        PaymentIntentDecrementAuthorizationParamsHooksInputs as PaymentIntentDecrementAuthorizationParamsHooksInputs,
        PaymentIntentDecrementAuthorizationParamsHooksInputsTax as PaymentIntentDecrementAuthorizationParamsHooksInputsTax,
        PaymentIntentDecrementAuthorizationParamsTransferData as PaymentIntentDecrementAuthorizationParamsTransferData,
    )
    from stripe.params._payment_intent_increment_authorization_params import (
        PaymentIntentIncrementAuthorizationParams as PaymentIntentIncrementAuthorizationParams,
        PaymentIntentIncrementAuthorizationParamsAmountDetails as PaymentIntentIncrementAuthorizationParamsAmountDetails,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItem as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItem,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemTax as PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemTax,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsShipping as PaymentIntentIncrementAuthorizationParamsAmountDetailsShipping,
        PaymentIntentIncrementAuthorizationParamsAmountDetailsTax as PaymentIntentIncrementAuthorizationParamsAmountDetailsTax,
        PaymentIntentIncrementAuthorizationParamsHooks as PaymentIntentIncrementAuthorizationParamsHooks,
        PaymentIntentIncrementAuthorizationParamsHooksInputs as PaymentIntentIncrementAuthorizationParamsHooksInputs,
        PaymentIntentIncrementAuthorizationParamsHooksInputsTax as PaymentIntentIncrementAuthorizationParamsHooksInputsTax,
        PaymentIntentIncrementAuthorizationParamsPaymentDetails as PaymentIntentIncrementAuthorizationParamsPaymentDetails,
        PaymentIntentIncrementAuthorizationParamsPaymentMethodOptions as PaymentIntentIncrementAuthorizationParamsPaymentMethodOptions,
        PaymentIntentIncrementAuthorizationParamsPaymentMethodOptionsCard as PaymentIntentIncrementAuthorizationParamsPaymentMethodOptionsCard,
        PaymentIntentIncrementAuthorizationParamsTransferData as PaymentIntentIncrementAuthorizationParamsTransferData,
    )
    from stripe.params._payment_intent_list_amount_details_line_items_params import (
        PaymentIntentListAmountDetailsLineItemsParams as PaymentIntentListAmountDetailsLineItemsParams,
    )
    from stripe.params._payment_intent_list_params import (
        PaymentIntentListParams as PaymentIntentListParams,
        PaymentIntentListParamsCreated as PaymentIntentListParamsCreated,
    )
    from stripe.params._payment_intent_modify_params import (
        PaymentIntentModifyParams as PaymentIntentModifyParams,
        PaymentIntentModifyParamsAllocatedFunds as PaymentIntentModifyParamsAllocatedFunds,
        PaymentIntentModifyParamsAmountDetails as PaymentIntentModifyParamsAmountDetails,
        PaymentIntentModifyParamsAmountDetailsLineItem as PaymentIntentModifyParamsAmountDetailsLineItem,
        PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentModifyParamsAmountDetailsLineItemTax as PaymentIntentModifyParamsAmountDetailsLineItemTax,
        PaymentIntentModifyParamsAmountDetailsShipping as PaymentIntentModifyParamsAmountDetailsShipping,
        PaymentIntentModifyParamsAmountDetailsTax as PaymentIntentModifyParamsAmountDetailsTax,
        PaymentIntentModifyParamsHooks as PaymentIntentModifyParamsHooks,
        PaymentIntentModifyParamsHooksInputs as PaymentIntentModifyParamsHooksInputs,
        PaymentIntentModifyParamsHooksInputsTax as PaymentIntentModifyParamsHooksInputsTax,
        PaymentIntentModifyParamsMandateData as PaymentIntentModifyParamsMandateData,
        PaymentIntentModifyParamsMandateDataCustomerAcceptance as PaymentIntentModifyParamsMandateDataCustomerAcceptance,
        PaymentIntentModifyParamsMandateDataCustomerAcceptanceOnline as PaymentIntentModifyParamsMandateDataCustomerAcceptanceOnline,
        PaymentIntentModifyParamsPaymentDetails as PaymentIntentModifyParamsPaymentDetails,
        PaymentIntentModifyParamsPaymentDetailsBenefit as PaymentIntentModifyParamsPaymentDetailsBenefit,
        PaymentIntentModifyParamsPaymentDetailsBenefitFrMealVoucher as PaymentIntentModifyParamsPaymentDetailsBenefitFrMealVoucher,
        PaymentIntentModifyParamsPaymentDetailsCarRental as PaymentIntentModifyParamsPaymentDetailsCarRental,
        PaymentIntentModifyParamsPaymentDetailsCarRentalAffiliate as PaymentIntentModifyParamsPaymentDetailsCarRentalAffiliate,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatum as PaymentIntentModifyParamsPaymentDetailsCarRentalDatum,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumAffiliate as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumAffiliate,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDistance as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDistance,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriver as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriver,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOff as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOff,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOffAddress as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOffAddress,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumInsurance as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumInsurance,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickup as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickup,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickupAddress as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickupAddress,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotal as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotal,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTax as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTax,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDatumVehicle as PaymentIntentModifyParamsPaymentDetailsCarRentalDatumVehicle,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDelivery as PaymentIntentModifyParamsPaymentDetailsCarRentalDelivery,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDeliveryRecipient as PaymentIntentModifyParamsPaymentDetailsCarRentalDeliveryRecipient,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDistance as PaymentIntentModifyParamsPaymentDetailsCarRentalDistance,
        PaymentIntentModifyParamsPaymentDetailsCarRentalDriver as PaymentIntentModifyParamsPaymentDetailsCarRentalDriver,
        PaymentIntentModifyParamsPaymentDetailsCarRentalPickupAddress as PaymentIntentModifyParamsPaymentDetailsCarRentalPickupAddress,
        PaymentIntentModifyParamsPaymentDetailsCarRentalReturnAddress as PaymentIntentModifyParamsPaymentDetailsCarRentalReturnAddress,
        PaymentIntentModifyParamsPaymentDetailsEventDetails as PaymentIntentModifyParamsPaymentDetailsEventDetails,
        PaymentIntentModifyParamsPaymentDetailsEventDetailsAddress as PaymentIntentModifyParamsPaymentDetailsEventDetailsAddress,
        PaymentIntentModifyParamsPaymentDetailsEventDetailsAffiliate as PaymentIntentModifyParamsPaymentDetailsEventDetailsAffiliate,
        PaymentIntentModifyParamsPaymentDetailsEventDetailsDelivery as PaymentIntentModifyParamsPaymentDetailsEventDetailsDelivery,
        PaymentIntentModifyParamsPaymentDetailsEventDetailsDeliveryRecipient as PaymentIntentModifyParamsPaymentDetailsEventDetailsDeliveryRecipient,
        PaymentIntentModifyParamsPaymentDetailsFlight as PaymentIntentModifyParamsPaymentDetailsFlight,
        PaymentIntentModifyParamsPaymentDetailsFlightAffiliate as PaymentIntentModifyParamsPaymentDetailsFlightAffiliate,
        PaymentIntentModifyParamsPaymentDetailsFlightDatum as PaymentIntentModifyParamsPaymentDetailsFlightDatum,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumAffiliate as PaymentIntentModifyParamsPaymentDetailsFlightDatumAffiliate,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumInsurance as PaymentIntentModifyParamsPaymentDetailsFlightDatumInsurance,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumPassenger as PaymentIntentModifyParamsPaymentDetailsFlightDatumPassenger,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumSegment as PaymentIntentModifyParamsPaymentDetailsFlightDatumSegment,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentArrival as PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentArrival,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentDeparture as PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentDeparture,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumTotal as PaymentIntentModifyParamsPaymentDetailsFlightDatumTotal,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalDiscounts as PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalDiscounts,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalExtraCharge as PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalExtraCharge,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTax as PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTax,
        PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTaxTax as PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTaxTax,
        PaymentIntentModifyParamsPaymentDetailsFlightDelivery as PaymentIntentModifyParamsPaymentDetailsFlightDelivery,
        PaymentIntentModifyParamsPaymentDetailsFlightDeliveryRecipient as PaymentIntentModifyParamsPaymentDetailsFlightDeliveryRecipient,
        PaymentIntentModifyParamsPaymentDetailsFlightPassenger as PaymentIntentModifyParamsPaymentDetailsFlightPassenger,
        PaymentIntentModifyParamsPaymentDetailsFlightSegment as PaymentIntentModifyParamsPaymentDetailsFlightSegment,
        PaymentIntentModifyParamsPaymentDetailsLodging as PaymentIntentModifyParamsPaymentDetailsLodging,
        PaymentIntentModifyParamsPaymentDetailsLodgingAddress as PaymentIntentModifyParamsPaymentDetailsLodgingAddress,
        PaymentIntentModifyParamsPaymentDetailsLodgingAffiliate as PaymentIntentModifyParamsPaymentDetailsLodgingAffiliate,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatum as PaymentIntentModifyParamsPaymentDetailsLodgingDatum,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumAccommodation as PaymentIntentModifyParamsPaymentDetailsLodgingDatumAccommodation,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumAffiliate as PaymentIntentModifyParamsPaymentDetailsLodgingDatumAffiliate,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumGuest as PaymentIntentModifyParamsPaymentDetailsLodgingDatumGuest,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumHost as PaymentIntentModifyParamsPaymentDetailsLodgingDatumHost,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumHostAddress as PaymentIntentModifyParamsPaymentDetailsLodgingDatumHostAddress,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumInsurance as PaymentIntentModifyParamsPaymentDetailsLodgingDatumInsurance,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotal as PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotal,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalDiscounts as PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalDiscounts,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge as PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTax as PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTax,
        PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTaxTax as PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTaxTax,
        PaymentIntentModifyParamsPaymentDetailsLodgingDelivery as PaymentIntentModifyParamsPaymentDetailsLodgingDelivery,
        PaymentIntentModifyParamsPaymentDetailsLodgingDeliveryRecipient as PaymentIntentModifyParamsPaymentDetailsLodgingDeliveryRecipient,
        PaymentIntentModifyParamsPaymentDetailsLodgingPassenger as PaymentIntentModifyParamsPaymentDetailsLodgingPassenger,
        PaymentIntentModifyParamsPaymentDetailsSubscription as PaymentIntentModifyParamsPaymentDetailsSubscription,
        PaymentIntentModifyParamsPaymentDetailsSubscriptionAffiliate as PaymentIntentModifyParamsPaymentDetailsSubscriptionAffiliate,
        PaymentIntentModifyParamsPaymentDetailsSubscriptionBillingInterval as PaymentIntentModifyParamsPaymentDetailsSubscriptionBillingInterval,
        PaymentIntentModifyParamsPaymentMethodData as PaymentIntentModifyParamsPaymentMethodData,
        PaymentIntentModifyParamsPaymentMethodDataAcssDebit as PaymentIntentModifyParamsPaymentMethodDataAcssDebit,
        PaymentIntentModifyParamsPaymentMethodDataAffirm as PaymentIntentModifyParamsPaymentMethodDataAffirm,
        PaymentIntentModifyParamsPaymentMethodDataAfterpayClearpay as PaymentIntentModifyParamsPaymentMethodDataAfterpayClearpay,
        PaymentIntentModifyParamsPaymentMethodDataAlipay as PaymentIntentModifyParamsPaymentMethodDataAlipay,
        PaymentIntentModifyParamsPaymentMethodDataAlma as PaymentIntentModifyParamsPaymentMethodDataAlma,
        PaymentIntentModifyParamsPaymentMethodDataAmazonPay as PaymentIntentModifyParamsPaymentMethodDataAmazonPay,
        PaymentIntentModifyParamsPaymentMethodDataAuBecsDebit as PaymentIntentModifyParamsPaymentMethodDataAuBecsDebit,
        PaymentIntentModifyParamsPaymentMethodDataBacsDebit as PaymentIntentModifyParamsPaymentMethodDataBacsDebit,
        PaymentIntentModifyParamsPaymentMethodDataBancontact as PaymentIntentModifyParamsPaymentMethodDataBancontact,
        PaymentIntentModifyParamsPaymentMethodDataBillie as PaymentIntentModifyParamsPaymentMethodDataBillie,
        PaymentIntentModifyParamsPaymentMethodDataBillingDetails as PaymentIntentModifyParamsPaymentMethodDataBillingDetails,
        PaymentIntentModifyParamsPaymentMethodDataBillingDetailsAddress as PaymentIntentModifyParamsPaymentMethodDataBillingDetailsAddress,
        PaymentIntentModifyParamsPaymentMethodDataBlik as PaymentIntentModifyParamsPaymentMethodDataBlik,
        PaymentIntentModifyParamsPaymentMethodDataBoleto as PaymentIntentModifyParamsPaymentMethodDataBoleto,
        PaymentIntentModifyParamsPaymentMethodDataCashapp as PaymentIntentModifyParamsPaymentMethodDataCashapp,
        PaymentIntentModifyParamsPaymentMethodDataCrypto as PaymentIntentModifyParamsPaymentMethodDataCrypto,
        PaymentIntentModifyParamsPaymentMethodDataCustomerBalance as PaymentIntentModifyParamsPaymentMethodDataCustomerBalance,
        PaymentIntentModifyParamsPaymentMethodDataEps as PaymentIntentModifyParamsPaymentMethodDataEps,
        PaymentIntentModifyParamsPaymentMethodDataFpx as PaymentIntentModifyParamsPaymentMethodDataFpx,
        PaymentIntentModifyParamsPaymentMethodDataGiropay as PaymentIntentModifyParamsPaymentMethodDataGiropay,
        PaymentIntentModifyParamsPaymentMethodDataGopay as PaymentIntentModifyParamsPaymentMethodDataGopay,
        PaymentIntentModifyParamsPaymentMethodDataGrabpay as PaymentIntentModifyParamsPaymentMethodDataGrabpay,
        PaymentIntentModifyParamsPaymentMethodDataIdBankTransfer as PaymentIntentModifyParamsPaymentMethodDataIdBankTransfer,
        PaymentIntentModifyParamsPaymentMethodDataIdeal as PaymentIntentModifyParamsPaymentMethodDataIdeal,
        PaymentIntentModifyParamsPaymentMethodDataInteracPresent as PaymentIntentModifyParamsPaymentMethodDataInteracPresent,
        PaymentIntentModifyParamsPaymentMethodDataKakaoPay as PaymentIntentModifyParamsPaymentMethodDataKakaoPay,
        PaymentIntentModifyParamsPaymentMethodDataKlarna as PaymentIntentModifyParamsPaymentMethodDataKlarna,
        PaymentIntentModifyParamsPaymentMethodDataKlarnaDob as PaymentIntentModifyParamsPaymentMethodDataKlarnaDob,
        PaymentIntentModifyParamsPaymentMethodDataKonbini as PaymentIntentModifyParamsPaymentMethodDataKonbini,
        PaymentIntentModifyParamsPaymentMethodDataKrCard as PaymentIntentModifyParamsPaymentMethodDataKrCard,
        PaymentIntentModifyParamsPaymentMethodDataLink as PaymentIntentModifyParamsPaymentMethodDataLink,
        PaymentIntentModifyParamsPaymentMethodDataMbWay as PaymentIntentModifyParamsPaymentMethodDataMbWay,
        PaymentIntentModifyParamsPaymentMethodDataMobilepay as PaymentIntentModifyParamsPaymentMethodDataMobilepay,
        PaymentIntentModifyParamsPaymentMethodDataMultibanco as PaymentIntentModifyParamsPaymentMethodDataMultibanco,
        PaymentIntentModifyParamsPaymentMethodDataNaverPay as PaymentIntentModifyParamsPaymentMethodDataNaverPay,
        PaymentIntentModifyParamsPaymentMethodDataNzBankAccount as PaymentIntentModifyParamsPaymentMethodDataNzBankAccount,
        PaymentIntentModifyParamsPaymentMethodDataOxxo as PaymentIntentModifyParamsPaymentMethodDataOxxo,
        PaymentIntentModifyParamsPaymentMethodDataP24 as PaymentIntentModifyParamsPaymentMethodDataP24,
        PaymentIntentModifyParamsPaymentMethodDataPayByBank as PaymentIntentModifyParamsPaymentMethodDataPayByBank,
        PaymentIntentModifyParamsPaymentMethodDataPayco as PaymentIntentModifyParamsPaymentMethodDataPayco,
        PaymentIntentModifyParamsPaymentMethodDataPaynow as PaymentIntentModifyParamsPaymentMethodDataPaynow,
        PaymentIntentModifyParamsPaymentMethodDataPaypal as PaymentIntentModifyParamsPaymentMethodDataPaypal,
        PaymentIntentModifyParamsPaymentMethodDataPaypay as PaymentIntentModifyParamsPaymentMethodDataPaypay,
        PaymentIntentModifyParamsPaymentMethodDataPayto as PaymentIntentModifyParamsPaymentMethodDataPayto,
        PaymentIntentModifyParamsPaymentMethodDataPix as PaymentIntentModifyParamsPaymentMethodDataPix,
        PaymentIntentModifyParamsPaymentMethodDataPromptpay as PaymentIntentModifyParamsPaymentMethodDataPromptpay,
        PaymentIntentModifyParamsPaymentMethodDataQris as PaymentIntentModifyParamsPaymentMethodDataQris,
        PaymentIntentModifyParamsPaymentMethodDataRadarOptions as PaymentIntentModifyParamsPaymentMethodDataRadarOptions,
        PaymentIntentModifyParamsPaymentMethodDataRechnung as PaymentIntentModifyParamsPaymentMethodDataRechnung,
        PaymentIntentModifyParamsPaymentMethodDataRechnungDob as PaymentIntentModifyParamsPaymentMethodDataRechnungDob,
        PaymentIntentModifyParamsPaymentMethodDataRevolutPay as PaymentIntentModifyParamsPaymentMethodDataRevolutPay,
        PaymentIntentModifyParamsPaymentMethodDataSamsungPay as PaymentIntentModifyParamsPaymentMethodDataSamsungPay,
        PaymentIntentModifyParamsPaymentMethodDataSatispay as PaymentIntentModifyParamsPaymentMethodDataSatispay,
        PaymentIntentModifyParamsPaymentMethodDataSepaDebit as PaymentIntentModifyParamsPaymentMethodDataSepaDebit,
        PaymentIntentModifyParamsPaymentMethodDataShopeepay as PaymentIntentModifyParamsPaymentMethodDataShopeepay,
        PaymentIntentModifyParamsPaymentMethodDataSofort as PaymentIntentModifyParamsPaymentMethodDataSofort,
        PaymentIntentModifyParamsPaymentMethodDataStripeBalance as PaymentIntentModifyParamsPaymentMethodDataStripeBalance,
        PaymentIntentModifyParamsPaymentMethodDataSwish as PaymentIntentModifyParamsPaymentMethodDataSwish,
        PaymentIntentModifyParamsPaymentMethodDataTwint as PaymentIntentModifyParamsPaymentMethodDataTwint,
        PaymentIntentModifyParamsPaymentMethodDataUsBankAccount as PaymentIntentModifyParamsPaymentMethodDataUsBankAccount,
        PaymentIntentModifyParamsPaymentMethodDataWechatPay as PaymentIntentModifyParamsPaymentMethodDataWechatPay,
        PaymentIntentModifyParamsPaymentMethodDataZip as PaymentIntentModifyParamsPaymentMethodDataZip,
        PaymentIntentModifyParamsPaymentMethodOptions as PaymentIntentModifyParamsPaymentMethodOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsAcssDebit as PaymentIntentModifyParamsPaymentMethodOptionsAcssDebit,
        PaymentIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsAffirm as PaymentIntentModifyParamsPaymentMethodOptionsAffirm,
        PaymentIntentModifyParamsPaymentMethodOptionsAfterpayClearpay as PaymentIntentModifyParamsPaymentMethodOptionsAfterpayClearpay,
        PaymentIntentModifyParamsPaymentMethodOptionsAlipay as PaymentIntentModifyParamsPaymentMethodOptionsAlipay,
        PaymentIntentModifyParamsPaymentMethodOptionsAlma as PaymentIntentModifyParamsPaymentMethodOptionsAlma,
        PaymentIntentModifyParamsPaymentMethodOptionsAmazonPay as PaymentIntentModifyParamsPaymentMethodOptionsAmazonPay,
        PaymentIntentModifyParamsPaymentMethodOptionsAuBecsDebit as PaymentIntentModifyParamsPaymentMethodOptionsAuBecsDebit,
        PaymentIntentModifyParamsPaymentMethodOptionsBacsDebit as PaymentIntentModifyParamsPaymentMethodOptionsBacsDebit,
        PaymentIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsBancontact as PaymentIntentModifyParamsPaymentMethodOptionsBancontact,
        PaymentIntentModifyParamsPaymentMethodOptionsBillie as PaymentIntentModifyParamsPaymentMethodOptionsBillie,
        PaymentIntentModifyParamsPaymentMethodOptionsBlik as PaymentIntentModifyParamsPaymentMethodOptionsBlik,
        PaymentIntentModifyParamsPaymentMethodOptionsBoleto as PaymentIntentModifyParamsPaymentMethodOptionsBoleto,
        PaymentIntentModifyParamsPaymentMethodOptionsCard as PaymentIntentModifyParamsPaymentMethodOptionsCard,
        PaymentIntentModifyParamsPaymentMethodOptionsCardInstallments as PaymentIntentModifyParamsPaymentMethodOptionsCardInstallments,
        PaymentIntentModifyParamsPaymentMethodOptionsCardInstallmentsPlan as PaymentIntentModifyParamsPaymentMethodOptionsCardInstallmentsPlan,
        PaymentIntentModifyParamsPaymentMethodOptionsCardMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsCardMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsCardPresent as PaymentIntentModifyParamsPaymentMethodOptionsCardPresent,
        PaymentIntentModifyParamsPaymentMethodOptionsCardPresentRouting as PaymentIntentModifyParamsPaymentMethodOptionsCardPresentRouting,
        PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetails as PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetails,
        PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetailsAddress as PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetailsAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecure as PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecure,
        PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        PaymentIntentModifyParamsPaymentMethodOptionsCashapp as PaymentIntentModifyParamsPaymentMethodOptionsCashapp,
        PaymentIntentModifyParamsPaymentMethodOptionsCrypto as PaymentIntentModifyParamsPaymentMethodOptionsCrypto,
        PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalance as PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalance,
        PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransfer as PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        PaymentIntentModifyParamsPaymentMethodOptionsEps as PaymentIntentModifyParamsPaymentMethodOptionsEps,
        PaymentIntentModifyParamsPaymentMethodOptionsFpx as PaymentIntentModifyParamsPaymentMethodOptionsFpx,
        PaymentIntentModifyParamsPaymentMethodOptionsGiropay as PaymentIntentModifyParamsPaymentMethodOptionsGiropay,
        PaymentIntentModifyParamsPaymentMethodOptionsGopay as PaymentIntentModifyParamsPaymentMethodOptionsGopay,
        PaymentIntentModifyParamsPaymentMethodOptionsGrabpay as PaymentIntentModifyParamsPaymentMethodOptionsGrabpay,
        PaymentIntentModifyParamsPaymentMethodOptionsIdBankTransfer as PaymentIntentModifyParamsPaymentMethodOptionsIdBankTransfer,
        PaymentIntentModifyParamsPaymentMethodOptionsIdeal as PaymentIntentModifyParamsPaymentMethodOptionsIdeal,
        PaymentIntentModifyParamsPaymentMethodOptionsInteracPresent as PaymentIntentModifyParamsPaymentMethodOptionsInteracPresent,
        PaymentIntentModifyParamsPaymentMethodOptionsKakaoPay as PaymentIntentModifyParamsPaymentMethodOptionsKakaoPay,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarna as PaymentIntentModifyParamsPaymentMethodOptionsKlarna,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscription as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscription,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        PaymentIntentModifyParamsPaymentMethodOptionsKonbini as PaymentIntentModifyParamsPaymentMethodOptionsKonbini,
        PaymentIntentModifyParamsPaymentMethodOptionsKrCard as PaymentIntentModifyParamsPaymentMethodOptionsKrCard,
        PaymentIntentModifyParamsPaymentMethodOptionsLink as PaymentIntentModifyParamsPaymentMethodOptionsLink,
        PaymentIntentModifyParamsPaymentMethodOptionsMbWay as PaymentIntentModifyParamsPaymentMethodOptionsMbWay,
        PaymentIntentModifyParamsPaymentMethodOptionsMobilepay as PaymentIntentModifyParamsPaymentMethodOptionsMobilepay,
        PaymentIntentModifyParamsPaymentMethodOptionsMultibanco as PaymentIntentModifyParamsPaymentMethodOptionsMultibanco,
        PaymentIntentModifyParamsPaymentMethodOptionsNaverPay as PaymentIntentModifyParamsPaymentMethodOptionsNaverPay,
        PaymentIntentModifyParamsPaymentMethodOptionsNzBankAccount as PaymentIntentModifyParamsPaymentMethodOptionsNzBankAccount,
        PaymentIntentModifyParamsPaymentMethodOptionsOxxo as PaymentIntentModifyParamsPaymentMethodOptionsOxxo,
        PaymentIntentModifyParamsPaymentMethodOptionsP24 as PaymentIntentModifyParamsPaymentMethodOptionsP24,
        PaymentIntentModifyParamsPaymentMethodOptionsPayByBank as PaymentIntentModifyParamsPaymentMethodOptionsPayByBank,
        PaymentIntentModifyParamsPaymentMethodOptionsPayco as PaymentIntentModifyParamsPaymentMethodOptionsPayco,
        PaymentIntentModifyParamsPaymentMethodOptionsPaynow as PaymentIntentModifyParamsPaymentMethodOptionsPaynow,
        PaymentIntentModifyParamsPaymentMethodOptionsPaypal as PaymentIntentModifyParamsPaymentMethodOptionsPaypal,
        PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItem as PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItem,
        PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItemTax as PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItemTax,
        PaymentIntentModifyParamsPaymentMethodOptionsPaypay as PaymentIntentModifyParamsPaymentMethodOptionsPaypay,
        PaymentIntentModifyParamsPaymentMethodOptionsPayto as PaymentIntentModifyParamsPaymentMethodOptionsPayto,
        PaymentIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsPix as PaymentIntentModifyParamsPaymentMethodOptionsPix,
        PaymentIntentModifyParamsPaymentMethodOptionsPixMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsPixMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsPromptpay as PaymentIntentModifyParamsPaymentMethodOptionsPromptpay,
        PaymentIntentModifyParamsPaymentMethodOptionsQris as PaymentIntentModifyParamsPaymentMethodOptionsQris,
        PaymentIntentModifyParamsPaymentMethodOptionsRechnung as PaymentIntentModifyParamsPaymentMethodOptionsRechnung,
        PaymentIntentModifyParamsPaymentMethodOptionsRevolutPay as PaymentIntentModifyParamsPaymentMethodOptionsRevolutPay,
        PaymentIntentModifyParamsPaymentMethodOptionsSamsungPay as PaymentIntentModifyParamsPaymentMethodOptionsSamsungPay,
        PaymentIntentModifyParamsPaymentMethodOptionsSatispay as PaymentIntentModifyParamsPaymentMethodOptionsSatispay,
        PaymentIntentModifyParamsPaymentMethodOptionsSepaDebit as PaymentIntentModifyParamsPaymentMethodOptionsSepaDebit,
        PaymentIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsShopeepay as PaymentIntentModifyParamsPaymentMethodOptionsShopeepay,
        PaymentIntentModifyParamsPaymentMethodOptionsSofort as PaymentIntentModifyParamsPaymentMethodOptionsSofort,
        PaymentIntentModifyParamsPaymentMethodOptionsStripeBalance as PaymentIntentModifyParamsPaymentMethodOptionsStripeBalance,
        PaymentIntentModifyParamsPaymentMethodOptionsSwish as PaymentIntentModifyParamsPaymentMethodOptionsSwish,
        PaymentIntentModifyParamsPaymentMethodOptionsTwint as PaymentIntentModifyParamsPaymentMethodOptionsTwint,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccount as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccount,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks as PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks,
        PaymentIntentModifyParamsPaymentMethodOptionsWechatPay as PaymentIntentModifyParamsPaymentMethodOptionsWechatPay,
        PaymentIntentModifyParamsPaymentMethodOptionsZip as PaymentIntentModifyParamsPaymentMethodOptionsZip,
        PaymentIntentModifyParamsShipping as PaymentIntentModifyParamsShipping,
        PaymentIntentModifyParamsShippingAddress as PaymentIntentModifyParamsShippingAddress,
        PaymentIntentModifyParamsTransferData as PaymentIntentModifyParamsTransferData,
    )
    from stripe.params._payment_intent_retrieve_params import (
        PaymentIntentRetrieveParams as PaymentIntentRetrieveParams,
    )
    from stripe.params._payment_intent_search_params import (
        PaymentIntentSearchParams as PaymentIntentSearchParams,
    )
    from stripe.params._payment_intent_trigger_action_params import (
        PaymentIntentTriggerActionParams as PaymentIntentTriggerActionParams,
        PaymentIntentTriggerActionParamsScanQrCode as PaymentIntentTriggerActionParamsScanQrCode,
    )
    from stripe.params._payment_intent_update_params import (
        PaymentIntentUpdateParams as PaymentIntentUpdateParams,
        PaymentIntentUpdateParamsAllocatedFunds as PaymentIntentUpdateParamsAllocatedFunds,
        PaymentIntentUpdateParamsAmountDetails as PaymentIntentUpdateParamsAmountDetails,
        PaymentIntentUpdateParamsAmountDetailsLineItem as PaymentIntentUpdateParamsAmountDetailsLineItem,
        PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptions as PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptions,
        PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCard as PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCard,
        PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent as PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent,
        PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna as PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna,
        PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal as PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal,
        PaymentIntentUpdateParamsAmountDetailsLineItemTax as PaymentIntentUpdateParamsAmountDetailsLineItemTax,
        PaymentIntentUpdateParamsAmountDetailsShipping as PaymentIntentUpdateParamsAmountDetailsShipping,
        PaymentIntentUpdateParamsAmountDetailsTax as PaymentIntentUpdateParamsAmountDetailsTax,
        PaymentIntentUpdateParamsHooks as PaymentIntentUpdateParamsHooks,
        PaymentIntentUpdateParamsHooksInputs as PaymentIntentUpdateParamsHooksInputs,
        PaymentIntentUpdateParamsHooksInputsTax as PaymentIntentUpdateParamsHooksInputsTax,
        PaymentIntentUpdateParamsMandateData as PaymentIntentUpdateParamsMandateData,
        PaymentIntentUpdateParamsMandateDataCustomerAcceptance as PaymentIntentUpdateParamsMandateDataCustomerAcceptance,
        PaymentIntentUpdateParamsMandateDataCustomerAcceptanceOnline as PaymentIntentUpdateParamsMandateDataCustomerAcceptanceOnline,
        PaymentIntentUpdateParamsPaymentDetails as PaymentIntentUpdateParamsPaymentDetails,
        PaymentIntentUpdateParamsPaymentDetailsBenefit as PaymentIntentUpdateParamsPaymentDetailsBenefit,
        PaymentIntentUpdateParamsPaymentDetailsBenefitFrMealVoucher as PaymentIntentUpdateParamsPaymentDetailsBenefitFrMealVoucher,
        PaymentIntentUpdateParamsPaymentDetailsCarRental as PaymentIntentUpdateParamsPaymentDetailsCarRental,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalAffiliate as PaymentIntentUpdateParamsPaymentDetailsCarRentalAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatum as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatum,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumAffiliate as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDistance as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDistance,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriver as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriver,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOff as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOff,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumInsurance as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumInsurance,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickup as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickup,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickupAddress as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickupAddress,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotal as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotal,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTax as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTax,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumVehicle as PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumVehicle,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDelivery as PaymentIntentUpdateParamsPaymentDetailsCarRentalDelivery,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDeliveryRecipient as PaymentIntentUpdateParamsPaymentDetailsCarRentalDeliveryRecipient,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDistance as PaymentIntentUpdateParamsPaymentDetailsCarRentalDistance,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalDriver as PaymentIntentUpdateParamsPaymentDetailsCarRentalDriver,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalPickupAddress as PaymentIntentUpdateParamsPaymentDetailsCarRentalPickupAddress,
        PaymentIntentUpdateParamsPaymentDetailsCarRentalReturnAddress as PaymentIntentUpdateParamsPaymentDetailsCarRentalReturnAddress,
        PaymentIntentUpdateParamsPaymentDetailsEventDetails as PaymentIntentUpdateParamsPaymentDetailsEventDetails,
        PaymentIntentUpdateParamsPaymentDetailsEventDetailsAddress as PaymentIntentUpdateParamsPaymentDetailsEventDetailsAddress,
        PaymentIntentUpdateParamsPaymentDetailsEventDetailsAffiliate as PaymentIntentUpdateParamsPaymentDetailsEventDetailsAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsEventDetailsDelivery as PaymentIntentUpdateParamsPaymentDetailsEventDetailsDelivery,
        PaymentIntentUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient as PaymentIntentUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient,
        PaymentIntentUpdateParamsPaymentDetailsFlight as PaymentIntentUpdateParamsPaymentDetailsFlight,
        PaymentIntentUpdateParamsPaymentDetailsFlightAffiliate as PaymentIntentUpdateParamsPaymentDetailsFlightAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatum as PaymentIntentUpdateParamsPaymentDetailsFlightDatum,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumAffiliate as PaymentIntentUpdateParamsPaymentDetailsFlightDatumAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumInsurance as PaymentIntentUpdateParamsPaymentDetailsFlightDatumInsurance,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumPassenger as PaymentIntentUpdateParamsPaymentDetailsFlightDatumPassenger,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegment as PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegment,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentArrival as PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentArrival,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentDeparture as PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentDeparture,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotal as PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotal,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalDiscounts as PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalDiscounts,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge as PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTax as PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTax,
        PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTaxTax as PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTaxTax,
        PaymentIntentUpdateParamsPaymentDetailsFlightDelivery as PaymentIntentUpdateParamsPaymentDetailsFlightDelivery,
        PaymentIntentUpdateParamsPaymentDetailsFlightDeliveryRecipient as PaymentIntentUpdateParamsPaymentDetailsFlightDeliveryRecipient,
        PaymentIntentUpdateParamsPaymentDetailsFlightPassenger as PaymentIntentUpdateParamsPaymentDetailsFlightPassenger,
        PaymentIntentUpdateParamsPaymentDetailsFlightSegment as PaymentIntentUpdateParamsPaymentDetailsFlightSegment,
        PaymentIntentUpdateParamsPaymentDetailsLodging as PaymentIntentUpdateParamsPaymentDetailsLodging,
        PaymentIntentUpdateParamsPaymentDetailsLodgingAddress as PaymentIntentUpdateParamsPaymentDetailsLodgingAddress,
        PaymentIntentUpdateParamsPaymentDetailsLodgingAffiliate as PaymentIntentUpdateParamsPaymentDetailsLodgingAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatum as PaymentIntentUpdateParamsPaymentDetailsLodgingDatum,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAccommodation as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAccommodation,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAffiliate as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumGuest as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumGuest,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHost as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHost,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHostAddress as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHostAddress,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumInsurance as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumInsurance,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotal as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotal,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTax as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTax,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax as PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDelivery as PaymentIntentUpdateParamsPaymentDetailsLodgingDelivery,
        PaymentIntentUpdateParamsPaymentDetailsLodgingDeliveryRecipient as PaymentIntentUpdateParamsPaymentDetailsLodgingDeliveryRecipient,
        PaymentIntentUpdateParamsPaymentDetailsLodgingPassenger as PaymentIntentUpdateParamsPaymentDetailsLodgingPassenger,
        PaymentIntentUpdateParamsPaymentDetailsSubscription as PaymentIntentUpdateParamsPaymentDetailsSubscription,
        PaymentIntentUpdateParamsPaymentDetailsSubscriptionAffiliate as PaymentIntentUpdateParamsPaymentDetailsSubscriptionAffiliate,
        PaymentIntentUpdateParamsPaymentDetailsSubscriptionBillingInterval as PaymentIntentUpdateParamsPaymentDetailsSubscriptionBillingInterval,
        PaymentIntentUpdateParamsPaymentMethodData as PaymentIntentUpdateParamsPaymentMethodData,
        PaymentIntentUpdateParamsPaymentMethodDataAcssDebit as PaymentIntentUpdateParamsPaymentMethodDataAcssDebit,
        PaymentIntentUpdateParamsPaymentMethodDataAffirm as PaymentIntentUpdateParamsPaymentMethodDataAffirm,
        PaymentIntentUpdateParamsPaymentMethodDataAfterpayClearpay as PaymentIntentUpdateParamsPaymentMethodDataAfterpayClearpay,
        PaymentIntentUpdateParamsPaymentMethodDataAlipay as PaymentIntentUpdateParamsPaymentMethodDataAlipay,
        PaymentIntentUpdateParamsPaymentMethodDataAlma as PaymentIntentUpdateParamsPaymentMethodDataAlma,
        PaymentIntentUpdateParamsPaymentMethodDataAmazonPay as PaymentIntentUpdateParamsPaymentMethodDataAmazonPay,
        PaymentIntentUpdateParamsPaymentMethodDataAuBecsDebit as PaymentIntentUpdateParamsPaymentMethodDataAuBecsDebit,
        PaymentIntentUpdateParamsPaymentMethodDataBacsDebit as PaymentIntentUpdateParamsPaymentMethodDataBacsDebit,
        PaymentIntentUpdateParamsPaymentMethodDataBancontact as PaymentIntentUpdateParamsPaymentMethodDataBancontact,
        PaymentIntentUpdateParamsPaymentMethodDataBillie as PaymentIntentUpdateParamsPaymentMethodDataBillie,
        PaymentIntentUpdateParamsPaymentMethodDataBillingDetails as PaymentIntentUpdateParamsPaymentMethodDataBillingDetails,
        PaymentIntentUpdateParamsPaymentMethodDataBillingDetailsAddress as PaymentIntentUpdateParamsPaymentMethodDataBillingDetailsAddress,
        PaymentIntentUpdateParamsPaymentMethodDataBlik as PaymentIntentUpdateParamsPaymentMethodDataBlik,
        PaymentIntentUpdateParamsPaymentMethodDataBoleto as PaymentIntentUpdateParamsPaymentMethodDataBoleto,
        PaymentIntentUpdateParamsPaymentMethodDataCashapp as PaymentIntentUpdateParamsPaymentMethodDataCashapp,
        PaymentIntentUpdateParamsPaymentMethodDataCrypto as PaymentIntentUpdateParamsPaymentMethodDataCrypto,
        PaymentIntentUpdateParamsPaymentMethodDataCustomerBalance as PaymentIntentUpdateParamsPaymentMethodDataCustomerBalance,
        PaymentIntentUpdateParamsPaymentMethodDataEps as PaymentIntentUpdateParamsPaymentMethodDataEps,
        PaymentIntentUpdateParamsPaymentMethodDataFpx as PaymentIntentUpdateParamsPaymentMethodDataFpx,
        PaymentIntentUpdateParamsPaymentMethodDataGiropay as PaymentIntentUpdateParamsPaymentMethodDataGiropay,
        PaymentIntentUpdateParamsPaymentMethodDataGopay as PaymentIntentUpdateParamsPaymentMethodDataGopay,
        PaymentIntentUpdateParamsPaymentMethodDataGrabpay as PaymentIntentUpdateParamsPaymentMethodDataGrabpay,
        PaymentIntentUpdateParamsPaymentMethodDataIdBankTransfer as PaymentIntentUpdateParamsPaymentMethodDataIdBankTransfer,
        PaymentIntentUpdateParamsPaymentMethodDataIdeal as PaymentIntentUpdateParamsPaymentMethodDataIdeal,
        PaymentIntentUpdateParamsPaymentMethodDataInteracPresent as PaymentIntentUpdateParamsPaymentMethodDataInteracPresent,
        PaymentIntentUpdateParamsPaymentMethodDataKakaoPay as PaymentIntentUpdateParamsPaymentMethodDataKakaoPay,
        PaymentIntentUpdateParamsPaymentMethodDataKlarna as PaymentIntentUpdateParamsPaymentMethodDataKlarna,
        PaymentIntentUpdateParamsPaymentMethodDataKlarnaDob as PaymentIntentUpdateParamsPaymentMethodDataKlarnaDob,
        PaymentIntentUpdateParamsPaymentMethodDataKonbini as PaymentIntentUpdateParamsPaymentMethodDataKonbini,
        PaymentIntentUpdateParamsPaymentMethodDataKrCard as PaymentIntentUpdateParamsPaymentMethodDataKrCard,
        PaymentIntentUpdateParamsPaymentMethodDataLink as PaymentIntentUpdateParamsPaymentMethodDataLink,
        PaymentIntentUpdateParamsPaymentMethodDataMbWay as PaymentIntentUpdateParamsPaymentMethodDataMbWay,
        PaymentIntentUpdateParamsPaymentMethodDataMobilepay as PaymentIntentUpdateParamsPaymentMethodDataMobilepay,
        PaymentIntentUpdateParamsPaymentMethodDataMultibanco as PaymentIntentUpdateParamsPaymentMethodDataMultibanco,
        PaymentIntentUpdateParamsPaymentMethodDataNaverPay as PaymentIntentUpdateParamsPaymentMethodDataNaverPay,
        PaymentIntentUpdateParamsPaymentMethodDataNzBankAccount as PaymentIntentUpdateParamsPaymentMethodDataNzBankAccount,
        PaymentIntentUpdateParamsPaymentMethodDataOxxo as PaymentIntentUpdateParamsPaymentMethodDataOxxo,
        PaymentIntentUpdateParamsPaymentMethodDataP24 as PaymentIntentUpdateParamsPaymentMethodDataP24,
        PaymentIntentUpdateParamsPaymentMethodDataPayByBank as PaymentIntentUpdateParamsPaymentMethodDataPayByBank,
        PaymentIntentUpdateParamsPaymentMethodDataPayco as PaymentIntentUpdateParamsPaymentMethodDataPayco,
        PaymentIntentUpdateParamsPaymentMethodDataPaynow as PaymentIntentUpdateParamsPaymentMethodDataPaynow,
        PaymentIntentUpdateParamsPaymentMethodDataPaypal as PaymentIntentUpdateParamsPaymentMethodDataPaypal,
        PaymentIntentUpdateParamsPaymentMethodDataPaypay as PaymentIntentUpdateParamsPaymentMethodDataPaypay,
        PaymentIntentUpdateParamsPaymentMethodDataPayto as PaymentIntentUpdateParamsPaymentMethodDataPayto,
        PaymentIntentUpdateParamsPaymentMethodDataPix as PaymentIntentUpdateParamsPaymentMethodDataPix,
        PaymentIntentUpdateParamsPaymentMethodDataPromptpay as PaymentIntentUpdateParamsPaymentMethodDataPromptpay,
        PaymentIntentUpdateParamsPaymentMethodDataQris as PaymentIntentUpdateParamsPaymentMethodDataQris,
        PaymentIntentUpdateParamsPaymentMethodDataRadarOptions as PaymentIntentUpdateParamsPaymentMethodDataRadarOptions,
        PaymentIntentUpdateParamsPaymentMethodDataRechnung as PaymentIntentUpdateParamsPaymentMethodDataRechnung,
        PaymentIntentUpdateParamsPaymentMethodDataRechnungDob as PaymentIntentUpdateParamsPaymentMethodDataRechnungDob,
        PaymentIntentUpdateParamsPaymentMethodDataRevolutPay as PaymentIntentUpdateParamsPaymentMethodDataRevolutPay,
        PaymentIntentUpdateParamsPaymentMethodDataSamsungPay as PaymentIntentUpdateParamsPaymentMethodDataSamsungPay,
        PaymentIntentUpdateParamsPaymentMethodDataSatispay as PaymentIntentUpdateParamsPaymentMethodDataSatispay,
        PaymentIntentUpdateParamsPaymentMethodDataSepaDebit as PaymentIntentUpdateParamsPaymentMethodDataSepaDebit,
        PaymentIntentUpdateParamsPaymentMethodDataShopeepay as PaymentIntentUpdateParamsPaymentMethodDataShopeepay,
        PaymentIntentUpdateParamsPaymentMethodDataSofort as PaymentIntentUpdateParamsPaymentMethodDataSofort,
        PaymentIntentUpdateParamsPaymentMethodDataStripeBalance as PaymentIntentUpdateParamsPaymentMethodDataStripeBalance,
        PaymentIntentUpdateParamsPaymentMethodDataSwish as PaymentIntentUpdateParamsPaymentMethodDataSwish,
        PaymentIntentUpdateParamsPaymentMethodDataTwint as PaymentIntentUpdateParamsPaymentMethodDataTwint,
        PaymentIntentUpdateParamsPaymentMethodDataUsBankAccount as PaymentIntentUpdateParamsPaymentMethodDataUsBankAccount,
        PaymentIntentUpdateParamsPaymentMethodDataWechatPay as PaymentIntentUpdateParamsPaymentMethodDataWechatPay,
        PaymentIntentUpdateParamsPaymentMethodDataZip as PaymentIntentUpdateParamsPaymentMethodDataZip,
        PaymentIntentUpdateParamsPaymentMethodOptions as PaymentIntentUpdateParamsPaymentMethodOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebit as PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebit,
        PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsAffirm as PaymentIntentUpdateParamsPaymentMethodOptionsAffirm,
        PaymentIntentUpdateParamsPaymentMethodOptionsAfterpayClearpay as PaymentIntentUpdateParamsPaymentMethodOptionsAfterpayClearpay,
        PaymentIntentUpdateParamsPaymentMethodOptionsAlipay as PaymentIntentUpdateParamsPaymentMethodOptionsAlipay,
        PaymentIntentUpdateParamsPaymentMethodOptionsAlma as PaymentIntentUpdateParamsPaymentMethodOptionsAlma,
        PaymentIntentUpdateParamsPaymentMethodOptionsAmazonPay as PaymentIntentUpdateParamsPaymentMethodOptionsAmazonPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsAuBecsDebit as PaymentIntentUpdateParamsPaymentMethodOptionsAuBecsDebit,
        PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebit as PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebit,
        PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsBancontact as PaymentIntentUpdateParamsPaymentMethodOptionsBancontact,
        PaymentIntentUpdateParamsPaymentMethodOptionsBillie as PaymentIntentUpdateParamsPaymentMethodOptionsBillie,
        PaymentIntentUpdateParamsPaymentMethodOptionsBlik as PaymentIntentUpdateParamsPaymentMethodOptionsBlik,
        PaymentIntentUpdateParamsPaymentMethodOptionsBoleto as PaymentIntentUpdateParamsPaymentMethodOptionsBoleto,
        PaymentIntentUpdateParamsPaymentMethodOptionsCard as PaymentIntentUpdateParamsPaymentMethodOptionsCard,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallments as PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallments,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallmentsPlan as PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallmentsPlan,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsCardMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardPresent as PaymentIntentUpdateParamsPaymentMethodOptionsCardPresent,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardPresentRouting as PaymentIntentUpdateParamsPaymentMethodOptionsCardPresentRouting,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetails as PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetails,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetailsAddress as PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetailsAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure as PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        PaymentIntentUpdateParamsPaymentMethodOptionsCashapp as PaymentIntentUpdateParamsPaymentMethodOptionsCashapp,
        PaymentIntentUpdateParamsPaymentMethodOptionsCrypto as PaymentIntentUpdateParamsPaymentMethodOptionsCrypto,
        PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalance as PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalance,
        PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        PaymentIntentUpdateParamsPaymentMethodOptionsEps as PaymentIntentUpdateParamsPaymentMethodOptionsEps,
        PaymentIntentUpdateParamsPaymentMethodOptionsFpx as PaymentIntentUpdateParamsPaymentMethodOptionsFpx,
        PaymentIntentUpdateParamsPaymentMethodOptionsGiropay as PaymentIntentUpdateParamsPaymentMethodOptionsGiropay,
        PaymentIntentUpdateParamsPaymentMethodOptionsGopay as PaymentIntentUpdateParamsPaymentMethodOptionsGopay,
        PaymentIntentUpdateParamsPaymentMethodOptionsGrabpay as PaymentIntentUpdateParamsPaymentMethodOptionsGrabpay,
        PaymentIntentUpdateParamsPaymentMethodOptionsIdBankTransfer as PaymentIntentUpdateParamsPaymentMethodOptionsIdBankTransfer,
        PaymentIntentUpdateParamsPaymentMethodOptionsIdeal as PaymentIntentUpdateParamsPaymentMethodOptionsIdeal,
        PaymentIntentUpdateParamsPaymentMethodOptionsInteracPresent as PaymentIntentUpdateParamsPaymentMethodOptionsInteracPresent,
        PaymentIntentUpdateParamsPaymentMethodOptionsKakaoPay as PaymentIntentUpdateParamsPaymentMethodOptionsKakaoPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarna as PaymentIntentUpdateParamsPaymentMethodOptionsKlarna,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger,
        PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher as PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher,
        PaymentIntentUpdateParamsPaymentMethodOptionsKonbini as PaymentIntentUpdateParamsPaymentMethodOptionsKonbini,
        PaymentIntentUpdateParamsPaymentMethodOptionsKrCard as PaymentIntentUpdateParamsPaymentMethodOptionsKrCard,
        PaymentIntentUpdateParamsPaymentMethodOptionsLink as PaymentIntentUpdateParamsPaymentMethodOptionsLink,
        PaymentIntentUpdateParamsPaymentMethodOptionsMbWay as PaymentIntentUpdateParamsPaymentMethodOptionsMbWay,
        PaymentIntentUpdateParamsPaymentMethodOptionsMobilepay as PaymentIntentUpdateParamsPaymentMethodOptionsMobilepay,
        PaymentIntentUpdateParamsPaymentMethodOptionsMultibanco as PaymentIntentUpdateParamsPaymentMethodOptionsMultibanco,
        PaymentIntentUpdateParamsPaymentMethodOptionsNaverPay as PaymentIntentUpdateParamsPaymentMethodOptionsNaverPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsNzBankAccount as PaymentIntentUpdateParamsPaymentMethodOptionsNzBankAccount,
        PaymentIntentUpdateParamsPaymentMethodOptionsOxxo as PaymentIntentUpdateParamsPaymentMethodOptionsOxxo,
        PaymentIntentUpdateParamsPaymentMethodOptionsP24 as PaymentIntentUpdateParamsPaymentMethodOptionsP24,
        PaymentIntentUpdateParamsPaymentMethodOptionsPayByBank as PaymentIntentUpdateParamsPaymentMethodOptionsPayByBank,
        PaymentIntentUpdateParamsPaymentMethodOptionsPayco as PaymentIntentUpdateParamsPaymentMethodOptionsPayco,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaynow as PaymentIntentUpdateParamsPaymentMethodOptionsPaynow,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaypal as PaymentIntentUpdateParamsPaymentMethodOptionsPaypal,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItem as PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItem,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItemTax as PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItemTax,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaypay as PaymentIntentUpdateParamsPaymentMethodOptionsPaypay,
        PaymentIntentUpdateParamsPaymentMethodOptionsPayto as PaymentIntentUpdateParamsPaymentMethodOptionsPayto,
        PaymentIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsPix as PaymentIntentUpdateParamsPaymentMethodOptionsPix,
        PaymentIntentUpdateParamsPaymentMethodOptionsPixMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsPixMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsPromptpay as PaymentIntentUpdateParamsPaymentMethodOptionsPromptpay,
        PaymentIntentUpdateParamsPaymentMethodOptionsQris as PaymentIntentUpdateParamsPaymentMethodOptionsQris,
        PaymentIntentUpdateParamsPaymentMethodOptionsRechnung as PaymentIntentUpdateParamsPaymentMethodOptionsRechnung,
        PaymentIntentUpdateParamsPaymentMethodOptionsRevolutPay as PaymentIntentUpdateParamsPaymentMethodOptionsRevolutPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsSamsungPay as PaymentIntentUpdateParamsPaymentMethodOptionsSamsungPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsSatispay as PaymentIntentUpdateParamsPaymentMethodOptionsSatispay,
        PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebit as PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebit,
        PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsShopeepay as PaymentIntentUpdateParamsPaymentMethodOptionsShopeepay,
        PaymentIntentUpdateParamsPaymentMethodOptionsSofort as PaymentIntentUpdateParamsPaymentMethodOptionsSofort,
        PaymentIntentUpdateParamsPaymentMethodOptionsStripeBalance as PaymentIntentUpdateParamsPaymentMethodOptionsStripeBalance,
        PaymentIntentUpdateParamsPaymentMethodOptionsSwish as PaymentIntentUpdateParamsPaymentMethodOptionsSwish,
        PaymentIntentUpdateParamsPaymentMethodOptionsTwint as PaymentIntentUpdateParamsPaymentMethodOptionsTwint,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccount as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccount,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks as PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks,
        PaymentIntentUpdateParamsPaymentMethodOptionsWechatPay as PaymentIntentUpdateParamsPaymentMethodOptionsWechatPay,
        PaymentIntentUpdateParamsPaymentMethodOptionsZip as PaymentIntentUpdateParamsPaymentMethodOptionsZip,
        PaymentIntentUpdateParamsShipping as PaymentIntentUpdateParamsShipping,
        PaymentIntentUpdateParamsShippingAddress as PaymentIntentUpdateParamsShippingAddress,
        PaymentIntentUpdateParamsTransferData as PaymentIntentUpdateParamsTransferData,
    )
    from stripe.params._payment_intent_verify_microdeposits_params import (
        PaymentIntentVerifyMicrodepositsParams as PaymentIntentVerifyMicrodepositsParams,
    )
    from stripe.params._payment_link_create_params import (
        PaymentLinkCreateParams as PaymentLinkCreateParams,
        PaymentLinkCreateParamsAfterCompletion as PaymentLinkCreateParamsAfterCompletion,
        PaymentLinkCreateParamsAfterCompletionHostedConfirmation as PaymentLinkCreateParamsAfterCompletionHostedConfirmation,
        PaymentLinkCreateParamsAfterCompletionRedirect as PaymentLinkCreateParamsAfterCompletionRedirect,
        PaymentLinkCreateParamsAutomaticTax as PaymentLinkCreateParamsAutomaticTax,
        PaymentLinkCreateParamsAutomaticTaxLiability as PaymentLinkCreateParamsAutomaticTaxLiability,
        PaymentLinkCreateParamsConsentCollection as PaymentLinkCreateParamsConsentCollection,
        PaymentLinkCreateParamsConsentCollectionPaymentMethodReuseAgreement as PaymentLinkCreateParamsConsentCollectionPaymentMethodReuseAgreement,
        PaymentLinkCreateParamsCustomField as PaymentLinkCreateParamsCustomField,
        PaymentLinkCreateParamsCustomFieldDropdown as PaymentLinkCreateParamsCustomFieldDropdown,
        PaymentLinkCreateParamsCustomFieldDropdownOption as PaymentLinkCreateParamsCustomFieldDropdownOption,
        PaymentLinkCreateParamsCustomFieldLabel as PaymentLinkCreateParamsCustomFieldLabel,
        PaymentLinkCreateParamsCustomFieldNumeric as PaymentLinkCreateParamsCustomFieldNumeric,
        PaymentLinkCreateParamsCustomFieldText as PaymentLinkCreateParamsCustomFieldText,
        PaymentLinkCreateParamsCustomText as PaymentLinkCreateParamsCustomText,
        PaymentLinkCreateParamsCustomTextAfterSubmit as PaymentLinkCreateParamsCustomTextAfterSubmit,
        PaymentLinkCreateParamsCustomTextShippingAddress as PaymentLinkCreateParamsCustomTextShippingAddress,
        PaymentLinkCreateParamsCustomTextSubmit as PaymentLinkCreateParamsCustomTextSubmit,
        PaymentLinkCreateParamsCustomTextTermsOfServiceAcceptance as PaymentLinkCreateParamsCustomTextTermsOfServiceAcceptance,
        PaymentLinkCreateParamsInvoiceCreation as PaymentLinkCreateParamsInvoiceCreation,
        PaymentLinkCreateParamsInvoiceCreationInvoiceData as PaymentLinkCreateParamsInvoiceCreationInvoiceData,
        PaymentLinkCreateParamsInvoiceCreationInvoiceDataCustomField as PaymentLinkCreateParamsInvoiceCreationInvoiceDataCustomField,
        PaymentLinkCreateParamsInvoiceCreationInvoiceDataIssuer as PaymentLinkCreateParamsInvoiceCreationInvoiceDataIssuer,
        PaymentLinkCreateParamsInvoiceCreationInvoiceDataRenderingOptions as PaymentLinkCreateParamsInvoiceCreationInvoiceDataRenderingOptions,
        PaymentLinkCreateParamsLineItem as PaymentLinkCreateParamsLineItem,
        PaymentLinkCreateParamsLineItemAdjustableQuantity as PaymentLinkCreateParamsLineItemAdjustableQuantity,
        PaymentLinkCreateParamsLineItemPriceData as PaymentLinkCreateParamsLineItemPriceData,
        PaymentLinkCreateParamsLineItemPriceDataProductData as PaymentLinkCreateParamsLineItemPriceDataProductData,
        PaymentLinkCreateParamsLineItemPriceDataRecurring as PaymentLinkCreateParamsLineItemPriceDataRecurring,
        PaymentLinkCreateParamsNameCollection as PaymentLinkCreateParamsNameCollection,
        PaymentLinkCreateParamsNameCollectionBusiness as PaymentLinkCreateParamsNameCollectionBusiness,
        PaymentLinkCreateParamsNameCollectionIndividual as PaymentLinkCreateParamsNameCollectionIndividual,
        PaymentLinkCreateParamsOptionalItem as PaymentLinkCreateParamsOptionalItem,
        PaymentLinkCreateParamsOptionalItemAdjustableQuantity as PaymentLinkCreateParamsOptionalItemAdjustableQuantity,
        PaymentLinkCreateParamsPaymentIntentData as PaymentLinkCreateParamsPaymentIntentData,
        PaymentLinkCreateParamsPhoneNumberCollection as PaymentLinkCreateParamsPhoneNumberCollection,
        PaymentLinkCreateParamsRestrictions as PaymentLinkCreateParamsRestrictions,
        PaymentLinkCreateParamsRestrictionsCompletedSessions as PaymentLinkCreateParamsRestrictionsCompletedSessions,
        PaymentLinkCreateParamsShippingAddressCollection as PaymentLinkCreateParamsShippingAddressCollection,
        PaymentLinkCreateParamsShippingOption as PaymentLinkCreateParamsShippingOption,
        PaymentLinkCreateParamsSubscriptionData as PaymentLinkCreateParamsSubscriptionData,
        PaymentLinkCreateParamsSubscriptionDataInvoiceSettings as PaymentLinkCreateParamsSubscriptionDataInvoiceSettings,
        PaymentLinkCreateParamsSubscriptionDataInvoiceSettingsIssuer as PaymentLinkCreateParamsSubscriptionDataInvoiceSettingsIssuer,
        PaymentLinkCreateParamsSubscriptionDataTrialSettings as PaymentLinkCreateParamsSubscriptionDataTrialSettings,
        PaymentLinkCreateParamsSubscriptionDataTrialSettingsEndBehavior as PaymentLinkCreateParamsSubscriptionDataTrialSettingsEndBehavior,
        PaymentLinkCreateParamsTaxIdCollection as PaymentLinkCreateParamsTaxIdCollection,
        PaymentLinkCreateParamsTransferData as PaymentLinkCreateParamsTransferData,
    )
    from stripe.params._payment_link_line_item_list_params import (
        PaymentLinkLineItemListParams as PaymentLinkLineItemListParams,
    )
    from stripe.params._payment_link_list_line_items_params import (
        PaymentLinkListLineItemsParams as PaymentLinkListLineItemsParams,
    )
    from stripe.params._payment_link_list_params import (
        PaymentLinkListParams as PaymentLinkListParams,
    )
    from stripe.params._payment_link_modify_params import (
        PaymentLinkModifyParams as PaymentLinkModifyParams,
        PaymentLinkModifyParamsAfterCompletion as PaymentLinkModifyParamsAfterCompletion,
        PaymentLinkModifyParamsAfterCompletionHostedConfirmation as PaymentLinkModifyParamsAfterCompletionHostedConfirmation,
        PaymentLinkModifyParamsAfterCompletionRedirect as PaymentLinkModifyParamsAfterCompletionRedirect,
        PaymentLinkModifyParamsAutomaticTax as PaymentLinkModifyParamsAutomaticTax,
        PaymentLinkModifyParamsAutomaticTaxLiability as PaymentLinkModifyParamsAutomaticTaxLiability,
        PaymentLinkModifyParamsCustomField as PaymentLinkModifyParamsCustomField,
        PaymentLinkModifyParamsCustomFieldDropdown as PaymentLinkModifyParamsCustomFieldDropdown,
        PaymentLinkModifyParamsCustomFieldDropdownOption as PaymentLinkModifyParamsCustomFieldDropdownOption,
        PaymentLinkModifyParamsCustomFieldLabel as PaymentLinkModifyParamsCustomFieldLabel,
        PaymentLinkModifyParamsCustomFieldNumeric as PaymentLinkModifyParamsCustomFieldNumeric,
        PaymentLinkModifyParamsCustomFieldText as PaymentLinkModifyParamsCustomFieldText,
        PaymentLinkModifyParamsCustomText as PaymentLinkModifyParamsCustomText,
        PaymentLinkModifyParamsCustomTextAfterSubmit as PaymentLinkModifyParamsCustomTextAfterSubmit,
        PaymentLinkModifyParamsCustomTextShippingAddress as PaymentLinkModifyParamsCustomTextShippingAddress,
        PaymentLinkModifyParamsCustomTextSubmit as PaymentLinkModifyParamsCustomTextSubmit,
        PaymentLinkModifyParamsCustomTextTermsOfServiceAcceptance as PaymentLinkModifyParamsCustomTextTermsOfServiceAcceptance,
        PaymentLinkModifyParamsInvoiceCreation as PaymentLinkModifyParamsInvoiceCreation,
        PaymentLinkModifyParamsInvoiceCreationInvoiceData as PaymentLinkModifyParamsInvoiceCreationInvoiceData,
        PaymentLinkModifyParamsInvoiceCreationInvoiceDataCustomField as PaymentLinkModifyParamsInvoiceCreationInvoiceDataCustomField,
        PaymentLinkModifyParamsInvoiceCreationInvoiceDataIssuer as PaymentLinkModifyParamsInvoiceCreationInvoiceDataIssuer,
        PaymentLinkModifyParamsInvoiceCreationInvoiceDataRenderingOptions as PaymentLinkModifyParamsInvoiceCreationInvoiceDataRenderingOptions,
        PaymentLinkModifyParamsLineItem as PaymentLinkModifyParamsLineItem,
        PaymentLinkModifyParamsLineItemAdjustableQuantity as PaymentLinkModifyParamsLineItemAdjustableQuantity,
        PaymentLinkModifyParamsNameCollection as PaymentLinkModifyParamsNameCollection,
        PaymentLinkModifyParamsNameCollectionBusiness as PaymentLinkModifyParamsNameCollectionBusiness,
        PaymentLinkModifyParamsNameCollectionIndividual as PaymentLinkModifyParamsNameCollectionIndividual,
        PaymentLinkModifyParamsPaymentIntentData as PaymentLinkModifyParamsPaymentIntentData,
        PaymentLinkModifyParamsPhoneNumberCollection as PaymentLinkModifyParamsPhoneNumberCollection,
        PaymentLinkModifyParamsRestrictions as PaymentLinkModifyParamsRestrictions,
        PaymentLinkModifyParamsRestrictionsCompletedSessions as PaymentLinkModifyParamsRestrictionsCompletedSessions,
        PaymentLinkModifyParamsShippingAddressCollection as PaymentLinkModifyParamsShippingAddressCollection,
        PaymentLinkModifyParamsSubscriptionData as PaymentLinkModifyParamsSubscriptionData,
        PaymentLinkModifyParamsSubscriptionDataInvoiceSettings as PaymentLinkModifyParamsSubscriptionDataInvoiceSettings,
        PaymentLinkModifyParamsSubscriptionDataInvoiceSettingsIssuer as PaymentLinkModifyParamsSubscriptionDataInvoiceSettingsIssuer,
        PaymentLinkModifyParamsSubscriptionDataTrialSettings as PaymentLinkModifyParamsSubscriptionDataTrialSettings,
        PaymentLinkModifyParamsSubscriptionDataTrialSettingsEndBehavior as PaymentLinkModifyParamsSubscriptionDataTrialSettingsEndBehavior,
        PaymentLinkModifyParamsTaxIdCollection as PaymentLinkModifyParamsTaxIdCollection,
    )
    from stripe.params._payment_link_retrieve_params import (
        PaymentLinkRetrieveParams as PaymentLinkRetrieveParams,
    )
    from stripe.params._payment_link_update_params import (
        PaymentLinkUpdateParams as PaymentLinkUpdateParams,
        PaymentLinkUpdateParamsAfterCompletion as PaymentLinkUpdateParamsAfterCompletion,
        PaymentLinkUpdateParamsAfterCompletionHostedConfirmation as PaymentLinkUpdateParamsAfterCompletionHostedConfirmation,
        PaymentLinkUpdateParamsAfterCompletionRedirect as PaymentLinkUpdateParamsAfterCompletionRedirect,
        PaymentLinkUpdateParamsAutomaticTax as PaymentLinkUpdateParamsAutomaticTax,
        PaymentLinkUpdateParamsAutomaticTaxLiability as PaymentLinkUpdateParamsAutomaticTaxLiability,
        PaymentLinkUpdateParamsCustomField as PaymentLinkUpdateParamsCustomField,
        PaymentLinkUpdateParamsCustomFieldDropdown as PaymentLinkUpdateParamsCustomFieldDropdown,
        PaymentLinkUpdateParamsCustomFieldDropdownOption as PaymentLinkUpdateParamsCustomFieldDropdownOption,
        PaymentLinkUpdateParamsCustomFieldLabel as PaymentLinkUpdateParamsCustomFieldLabel,
        PaymentLinkUpdateParamsCustomFieldNumeric as PaymentLinkUpdateParamsCustomFieldNumeric,
        PaymentLinkUpdateParamsCustomFieldText as PaymentLinkUpdateParamsCustomFieldText,
        PaymentLinkUpdateParamsCustomText as PaymentLinkUpdateParamsCustomText,
        PaymentLinkUpdateParamsCustomTextAfterSubmit as PaymentLinkUpdateParamsCustomTextAfterSubmit,
        PaymentLinkUpdateParamsCustomTextShippingAddress as PaymentLinkUpdateParamsCustomTextShippingAddress,
        PaymentLinkUpdateParamsCustomTextSubmit as PaymentLinkUpdateParamsCustomTextSubmit,
        PaymentLinkUpdateParamsCustomTextTermsOfServiceAcceptance as PaymentLinkUpdateParamsCustomTextTermsOfServiceAcceptance,
        PaymentLinkUpdateParamsInvoiceCreation as PaymentLinkUpdateParamsInvoiceCreation,
        PaymentLinkUpdateParamsInvoiceCreationInvoiceData as PaymentLinkUpdateParamsInvoiceCreationInvoiceData,
        PaymentLinkUpdateParamsInvoiceCreationInvoiceDataCustomField as PaymentLinkUpdateParamsInvoiceCreationInvoiceDataCustomField,
        PaymentLinkUpdateParamsInvoiceCreationInvoiceDataIssuer as PaymentLinkUpdateParamsInvoiceCreationInvoiceDataIssuer,
        PaymentLinkUpdateParamsInvoiceCreationInvoiceDataRenderingOptions as PaymentLinkUpdateParamsInvoiceCreationInvoiceDataRenderingOptions,
        PaymentLinkUpdateParamsLineItem as PaymentLinkUpdateParamsLineItem,
        PaymentLinkUpdateParamsLineItemAdjustableQuantity as PaymentLinkUpdateParamsLineItemAdjustableQuantity,
        PaymentLinkUpdateParamsNameCollection as PaymentLinkUpdateParamsNameCollection,
        PaymentLinkUpdateParamsNameCollectionBusiness as PaymentLinkUpdateParamsNameCollectionBusiness,
        PaymentLinkUpdateParamsNameCollectionIndividual as PaymentLinkUpdateParamsNameCollectionIndividual,
        PaymentLinkUpdateParamsPaymentIntentData as PaymentLinkUpdateParamsPaymentIntentData,
        PaymentLinkUpdateParamsPhoneNumberCollection as PaymentLinkUpdateParamsPhoneNumberCollection,
        PaymentLinkUpdateParamsRestrictions as PaymentLinkUpdateParamsRestrictions,
        PaymentLinkUpdateParamsRestrictionsCompletedSessions as PaymentLinkUpdateParamsRestrictionsCompletedSessions,
        PaymentLinkUpdateParamsShippingAddressCollection as PaymentLinkUpdateParamsShippingAddressCollection,
        PaymentLinkUpdateParamsSubscriptionData as PaymentLinkUpdateParamsSubscriptionData,
        PaymentLinkUpdateParamsSubscriptionDataInvoiceSettings as PaymentLinkUpdateParamsSubscriptionDataInvoiceSettings,
        PaymentLinkUpdateParamsSubscriptionDataInvoiceSettingsIssuer as PaymentLinkUpdateParamsSubscriptionDataInvoiceSettingsIssuer,
        PaymentLinkUpdateParamsSubscriptionDataTrialSettings as PaymentLinkUpdateParamsSubscriptionDataTrialSettings,
        PaymentLinkUpdateParamsSubscriptionDataTrialSettingsEndBehavior as PaymentLinkUpdateParamsSubscriptionDataTrialSettingsEndBehavior,
        PaymentLinkUpdateParamsTaxIdCollection as PaymentLinkUpdateParamsTaxIdCollection,
    )
    from stripe.params._payment_method_attach_params import (
        PaymentMethodAttachParams as PaymentMethodAttachParams,
    )
    from stripe.params._payment_method_check_balance_params import (
        PaymentMethodCheckBalanceParams as PaymentMethodCheckBalanceParams,
    )
    from stripe.params._payment_method_configuration_create_params import (
        PaymentMethodConfigurationCreateParams as PaymentMethodConfigurationCreateParams,
        PaymentMethodConfigurationCreateParamsAcssDebit as PaymentMethodConfigurationCreateParamsAcssDebit,
        PaymentMethodConfigurationCreateParamsAcssDebitDisplayPreference as PaymentMethodConfigurationCreateParamsAcssDebitDisplayPreference,
        PaymentMethodConfigurationCreateParamsAffirm as PaymentMethodConfigurationCreateParamsAffirm,
        PaymentMethodConfigurationCreateParamsAffirmDisplayPreference as PaymentMethodConfigurationCreateParamsAffirmDisplayPreference,
        PaymentMethodConfigurationCreateParamsAfterpayClearpay as PaymentMethodConfigurationCreateParamsAfterpayClearpay,
        PaymentMethodConfigurationCreateParamsAfterpayClearpayDisplayPreference as PaymentMethodConfigurationCreateParamsAfterpayClearpayDisplayPreference,
        PaymentMethodConfigurationCreateParamsAlipay as PaymentMethodConfigurationCreateParamsAlipay,
        PaymentMethodConfigurationCreateParamsAlipayDisplayPreference as PaymentMethodConfigurationCreateParamsAlipayDisplayPreference,
        PaymentMethodConfigurationCreateParamsAlma as PaymentMethodConfigurationCreateParamsAlma,
        PaymentMethodConfigurationCreateParamsAlmaDisplayPreference as PaymentMethodConfigurationCreateParamsAlmaDisplayPreference,
        PaymentMethodConfigurationCreateParamsAmazonPay as PaymentMethodConfigurationCreateParamsAmazonPay,
        PaymentMethodConfigurationCreateParamsAmazonPayDisplayPreference as PaymentMethodConfigurationCreateParamsAmazonPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsApplePay as PaymentMethodConfigurationCreateParamsApplePay,
        PaymentMethodConfigurationCreateParamsApplePayDisplayPreference as PaymentMethodConfigurationCreateParamsApplePayDisplayPreference,
        PaymentMethodConfigurationCreateParamsApplePayLater as PaymentMethodConfigurationCreateParamsApplePayLater,
        PaymentMethodConfigurationCreateParamsApplePayLaterDisplayPreference as PaymentMethodConfigurationCreateParamsApplePayLaterDisplayPreference,
        PaymentMethodConfigurationCreateParamsAuBecsDebit as PaymentMethodConfigurationCreateParamsAuBecsDebit,
        PaymentMethodConfigurationCreateParamsAuBecsDebitDisplayPreference as PaymentMethodConfigurationCreateParamsAuBecsDebitDisplayPreference,
        PaymentMethodConfigurationCreateParamsBacsDebit as PaymentMethodConfigurationCreateParamsBacsDebit,
        PaymentMethodConfigurationCreateParamsBacsDebitDisplayPreference as PaymentMethodConfigurationCreateParamsBacsDebitDisplayPreference,
        PaymentMethodConfigurationCreateParamsBancontact as PaymentMethodConfigurationCreateParamsBancontact,
        PaymentMethodConfigurationCreateParamsBancontactDisplayPreference as PaymentMethodConfigurationCreateParamsBancontactDisplayPreference,
        PaymentMethodConfigurationCreateParamsBillie as PaymentMethodConfigurationCreateParamsBillie,
        PaymentMethodConfigurationCreateParamsBillieDisplayPreference as PaymentMethodConfigurationCreateParamsBillieDisplayPreference,
        PaymentMethodConfigurationCreateParamsBlik as PaymentMethodConfigurationCreateParamsBlik,
        PaymentMethodConfigurationCreateParamsBlikDisplayPreference as PaymentMethodConfigurationCreateParamsBlikDisplayPreference,
        PaymentMethodConfigurationCreateParamsBoleto as PaymentMethodConfigurationCreateParamsBoleto,
        PaymentMethodConfigurationCreateParamsBoletoDisplayPreference as PaymentMethodConfigurationCreateParamsBoletoDisplayPreference,
        PaymentMethodConfigurationCreateParamsCard as PaymentMethodConfigurationCreateParamsCard,
        PaymentMethodConfigurationCreateParamsCardDisplayPreference as PaymentMethodConfigurationCreateParamsCardDisplayPreference,
        PaymentMethodConfigurationCreateParamsCartesBancaires as PaymentMethodConfigurationCreateParamsCartesBancaires,
        PaymentMethodConfigurationCreateParamsCartesBancairesDisplayPreference as PaymentMethodConfigurationCreateParamsCartesBancairesDisplayPreference,
        PaymentMethodConfigurationCreateParamsCashapp as PaymentMethodConfigurationCreateParamsCashapp,
        PaymentMethodConfigurationCreateParamsCashappDisplayPreference as PaymentMethodConfigurationCreateParamsCashappDisplayPreference,
        PaymentMethodConfigurationCreateParamsCrypto as PaymentMethodConfigurationCreateParamsCrypto,
        PaymentMethodConfigurationCreateParamsCryptoDisplayPreference as PaymentMethodConfigurationCreateParamsCryptoDisplayPreference,
        PaymentMethodConfigurationCreateParamsCustomerBalance as PaymentMethodConfigurationCreateParamsCustomerBalance,
        PaymentMethodConfigurationCreateParamsCustomerBalanceDisplayPreference as PaymentMethodConfigurationCreateParamsCustomerBalanceDisplayPreference,
        PaymentMethodConfigurationCreateParamsEps as PaymentMethodConfigurationCreateParamsEps,
        PaymentMethodConfigurationCreateParamsEpsDisplayPreference as PaymentMethodConfigurationCreateParamsEpsDisplayPreference,
        PaymentMethodConfigurationCreateParamsFpx as PaymentMethodConfigurationCreateParamsFpx,
        PaymentMethodConfigurationCreateParamsFpxDisplayPreference as PaymentMethodConfigurationCreateParamsFpxDisplayPreference,
        PaymentMethodConfigurationCreateParamsFrMealVoucherConecs as PaymentMethodConfigurationCreateParamsFrMealVoucherConecs,
        PaymentMethodConfigurationCreateParamsFrMealVoucherConecsDisplayPreference as PaymentMethodConfigurationCreateParamsFrMealVoucherConecsDisplayPreference,
        PaymentMethodConfigurationCreateParamsGiropay as PaymentMethodConfigurationCreateParamsGiropay,
        PaymentMethodConfigurationCreateParamsGiropayDisplayPreference as PaymentMethodConfigurationCreateParamsGiropayDisplayPreference,
        PaymentMethodConfigurationCreateParamsGooglePay as PaymentMethodConfigurationCreateParamsGooglePay,
        PaymentMethodConfigurationCreateParamsGooglePayDisplayPreference as PaymentMethodConfigurationCreateParamsGooglePayDisplayPreference,
        PaymentMethodConfigurationCreateParamsGopay as PaymentMethodConfigurationCreateParamsGopay,
        PaymentMethodConfigurationCreateParamsGopayDisplayPreference as PaymentMethodConfigurationCreateParamsGopayDisplayPreference,
        PaymentMethodConfigurationCreateParamsGrabpay as PaymentMethodConfigurationCreateParamsGrabpay,
        PaymentMethodConfigurationCreateParamsGrabpayDisplayPreference as PaymentMethodConfigurationCreateParamsGrabpayDisplayPreference,
        PaymentMethodConfigurationCreateParamsIdBankTransfer as PaymentMethodConfigurationCreateParamsIdBankTransfer,
        PaymentMethodConfigurationCreateParamsIdBankTransferDisplayPreference as PaymentMethodConfigurationCreateParamsIdBankTransferDisplayPreference,
        PaymentMethodConfigurationCreateParamsIdeal as PaymentMethodConfigurationCreateParamsIdeal,
        PaymentMethodConfigurationCreateParamsIdealDisplayPreference as PaymentMethodConfigurationCreateParamsIdealDisplayPreference,
        PaymentMethodConfigurationCreateParamsJcb as PaymentMethodConfigurationCreateParamsJcb,
        PaymentMethodConfigurationCreateParamsJcbDisplayPreference as PaymentMethodConfigurationCreateParamsJcbDisplayPreference,
        PaymentMethodConfigurationCreateParamsKakaoPay as PaymentMethodConfigurationCreateParamsKakaoPay,
        PaymentMethodConfigurationCreateParamsKakaoPayDisplayPreference as PaymentMethodConfigurationCreateParamsKakaoPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsKlarna as PaymentMethodConfigurationCreateParamsKlarna,
        PaymentMethodConfigurationCreateParamsKlarnaDisplayPreference as PaymentMethodConfigurationCreateParamsKlarnaDisplayPreference,
        PaymentMethodConfigurationCreateParamsKonbini as PaymentMethodConfigurationCreateParamsKonbini,
        PaymentMethodConfigurationCreateParamsKonbiniDisplayPreference as PaymentMethodConfigurationCreateParamsKonbiniDisplayPreference,
        PaymentMethodConfigurationCreateParamsKrCard as PaymentMethodConfigurationCreateParamsKrCard,
        PaymentMethodConfigurationCreateParamsKrCardDisplayPreference as PaymentMethodConfigurationCreateParamsKrCardDisplayPreference,
        PaymentMethodConfigurationCreateParamsLink as PaymentMethodConfigurationCreateParamsLink,
        PaymentMethodConfigurationCreateParamsLinkDisplayPreference as PaymentMethodConfigurationCreateParamsLinkDisplayPreference,
        PaymentMethodConfigurationCreateParamsMbWay as PaymentMethodConfigurationCreateParamsMbWay,
        PaymentMethodConfigurationCreateParamsMbWayDisplayPreference as PaymentMethodConfigurationCreateParamsMbWayDisplayPreference,
        PaymentMethodConfigurationCreateParamsMobilepay as PaymentMethodConfigurationCreateParamsMobilepay,
        PaymentMethodConfigurationCreateParamsMobilepayDisplayPreference as PaymentMethodConfigurationCreateParamsMobilepayDisplayPreference,
        PaymentMethodConfigurationCreateParamsMultibanco as PaymentMethodConfigurationCreateParamsMultibanco,
        PaymentMethodConfigurationCreateParamsMultibancoDisplayPreference as PaymentMethodConfigurationCreateParamsMultibancoDisplayPreference,
        PaymentMethodConfigurationCreateParamsNaverPay as PaymentMethodConfigurationCreateParamsNaverPay,
        PaymentMethodConfigurationCreateParamsNaverPayDisplayPreference as PaymentMethodConfigurationCreateParamsNaverPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsNzBankAccount as PaymentMethodConfigurationCreateParamsNzBankAccount,
        PaymentMethodConfigurationCreateParamsNzBankAccountDisplayPreference as PaymentMethodConfigurationCreateParamsNzBankAccountDisplayPreference,
        PaymentMethodConfigurationCreateParamsOxxo as PaymentMethodConfigurationCreateParamsOxxo,
        PaymentMethodConfigurationCreateParamsOxxoDisplayPreference as PaymentMethodConfigurationCreateParamsOxxoDisplayPreference,
        PaymentMethodConfigurationCreateParamsP24 as PaymentMethodConfigurationCreateParamsP24,
        PaymentMethodConfigurationCreateParamsP24DisplayPreference as PaymentMethodConfigurationCreateParamsP24DisplayPreference,
        PaymentMethodConfigurationCreateParamsPayByBank as PaymentMethodConfigurationCreateParamsPayByBank,
        PaymentMethodConfigurationCreateParamsPayByBankDisplayPreference as PaymentMethodConfigurationCreateParamsPayByBankDisplayPreference,
        PaymentMethodConfigurationCreateParamsPayco as PaymentMethodConfigurationCreateParamsPayco,
        PaymentMethodConfigurationCreateParamsPaycoDisplayPreference as PaymentMethodConfigurationCreateParamsPaycoDisplayPreference,
        PaymentMethodConfigurationCreateParamsPaynow as PaymentMethodConfigurationCreateParamsPaynow,
        PaymentMethodConfigurationCreateParamsPaynowDisplayPreference as PaymentMethodConfigurationCreateParamsPaynowDisplayPreference,
        PaymentMethodConfigurationCreateParamsPaypal as PaymentMethodConfigurationCreateParamsPaypal,
        PaymentMethodConfigurationCreateParamsPaypalDisplayPreference as PaymentMethodConfigurationCreateParamsPaypalDisplayPreference,
        PaymentMethodConfigurationCreateParamsPaypay as PaymentMethodConfigurationCreateParamsPaypay,
        PaymentMethodConfigurationCreateParamsPaypayDisplayPreference as PaymentMethodConfigurationCreateParamsPaypayDisplayPreference,
        PaymentMethodConfigurationCreateParamsPayto as PaymentMethodConfigurationCreateParamsPayto,
        PaymentMethodConfigurationCreateParamsPaytoDisplayPreference as PaymentMethodConfigurationCreateParamsPaytoDisplayPreference,
        PaymentMethodConfigurationCreateParamsPix as PaymentMethodConfigurationCreateParamsPix,
        PaymentMethodConfigurationCreateParamsPixDisplayPreference as PaymentMethodConfigurationCreateParamsPixDisplayPreference,
        PaymentMethodConfigurationCreateParamsPromptpay as PaymentMethodConfigurationCreateParamsPromptpay,
        PaymentMethodConfigurationCreateParamsPromptpayDisplayPreference as PaymentMethodConfigurationCreateParamsPromptpayDisplayPreference,
        PaymentMethodConfigurationCreateParamsQris as PaymentMethodConfigurationCreateParamsQris,
        PaymentMethodConfigurationCreateParamsQrisDisplayPreference as PaymentMethodConfigurationCreateParamsQrisDisplayPreference,
        PaymentMethodConfigurationCreateParamsRevolutPay as PaymentMethodConfigurationCreateParamsRevolutPay,
        PaymentMethodConfigurationCreateParamsRevolutPayDisplayPreference as PaymentMethodConfigurationCreateParamsRevolutPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsSamsungPay as PaymentMethodConfigurationCreateParamsSamsungPay,
        PaymentMethodConfigurationCreateParamsSamsungPayDisplayPreference as PaymentMethodConfigurationCreateParamsSamsungPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsSatispay as PaymentMethodConfigurationCreateParamsSatispay,
        PaymentMethodConfigurationCreateParamsSatispayDisplayPreference as PaymentMethodConfigurationCreateParamsSatispayDisplayPreference,
        PaymentMethodConfigurationCreateParamsSepaDebit as PaymentMethodConfigurationCreateParamsSepaDebit,
        PaymentMethodConfigurationCreateParamsSepaDebitDisplayPreference as PaymentMethodConfigurationCreateParamsSepaDebitDisplayPreference,
        PaymentMethodConfigurationCreateParamsShopeepay as PaymentMethodConfigurationCreateParamsShopeepay,
        PaymentMethodConfigurationCreateParamsShopeepayDisplayPreference as PaymentMethodConfigurationCreateParamsShopeepayDisplayPreference,
        PaymentMethodConfigurationCreateParamsSofort as PaymentMethodConfigurationCreateParamsSofort,
        PaymentMethodConfigurationCreateParamsSofortDisplayPreference as PaymentMethodConfigurationCreateParamsSofortDisplayPreference,
        PaymentMethodConfigurationCreateParamsSwish as PaymentMethodConfigurationCreateParamsSwish,
        PaymentMethodConfigurationCreateParamsSwishDisplayPreference as PaymentMethodConfigurationCreateParamsSwishDisplayPreference,
        PaymentMethodConfigurationCreateParamsTwint as PaymentMethodConfigurationCreateParamsTwint,
        PaymentMethodConfigurationCreateParamsTwintDisplayPreference as PaymentMethodConfigurationCreateParamsTwintDisplayPreference,
        PaymentMethodConfigurationCreateParamsUsBankAccount as PaymentMethodConfigurationCreateParamsUsBankAccount,
        PaymentMethodConfigurationCreateParamsUsBankAccountDisplayPreference as PaymentMethodConfigurationCreateParamsUsBankAccountDisplayPreference,
        PaymentMethodConfigurationCreateParamsWechatPay as PaymentMethodConfigurationCreateParamsWechatPay,
        PaymentMethodConfigurationCreateParamsWechatPayDisplayPreference as PaymentMethodConfigurationCreateParamsWechatPayDisplayPreference,
        PaymentMethodConfigurationCreateParamsZip as PaymentMethodConfigurationCreateParamsZip,
        PaymentMethodConfigurationCreateParamsZipDisplayPreference as PaymentMethodConfigurationCreateParamsZipDisplayPreference,
    )
    from stripe.params._payment_method_configuration_list_params import (
        PaymentMethodConfigurationListParams as PaymentMethodConfigurationListParams,
    )
    from stripe.params._payment_method_configuration_modify_params import (
        PaymentMethodConfigurationModifyParams as PaymentMethodConfigurationModifyParams,
        PaymentMethodConfigurationModifyParamsAcssDebit as PaymentMethodConfigurationModifyParamsAcssDebit,
        PaymentMethodConfigurationModifyParamsAcssDebitDisplayPreference as PaymentMethodConfigurationModifyParamsAcssDebitDisplayPreference,
        PaymentMethodConfigurationModifyParamsAffirm as PaymentMethodConfigurationModifyParamsAffirm,
        PaymentMethodConfigurationModifyParamsAffirmDisplayPreference as PaymentMethodConfigurationModifyParamsAffirmDisplayPreference,
        PaymentMethodConfigurationModifyParamsAfterpayClearpay as PaymentMethodConfigurationModifyParamsAfterpayClearpay,
        PaymentMethodConfigurationModifyParamsAfterpayClearpayDisplayPreference as PaymentMethodConfigurationModifyParamsAfterpayClearpayDisplayPreference,
        PaymentMethodConfigurationModifyParamsAlipay as PaymentMethodConfigurationModifyParamsAlipay,
        PaymentMethodConfigurationModifyParamsAlipayDisplayPreference as PaymentMethodConfigurationModifyParamsAlipayDisplayPreference,
        PaymentMethodConfigurationModifyParamsAlma as PaymentMethodConfigurationModifyParamsAlma,
        PaymentMethodConfigurationModifyParamsAlmaDisplayPreference as PaymentMethodConfigurationModifyParamsAlmaDisplayPreference,
        PaymentMethodConfigurationModifyParamsAmazonPay as PaymentMethodConfigurationModifyParamsAmazonPay,
        PaymentMethodConfigurationModifyParamsAmazonPayDisplayPreference as PaymentMethodConfigurationModifyParamsAmazonPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsApplePay as PaymentMethodConfigurationModifyParamsApplePay,
        PaymentMethodConfigurationModifyParamsApplePayDisplayPreference as PaymentMethodConfigurationModifyParamsApplePayDisplayPreference,
        PaymentMethodConfigurationModifyParamsApplePayLater as PaymentMethodConfigurationModifyParamsApplePayLater,
        PaymentMethodConfigurationModifyParamsApplePayLaterDisplayPreference as PaymentMethodConfigurationModifyParamsApplePayLaterDisplayPreference,
        PaymentMethodConfigurationModifyParamsAuBecsDebit as PaymentMethodConfigurationModifyParamsAuBecsDebit,
        PaymentMethodConfigurationModifyParamsAuBecsDebitDisplayPreference as PaymentMethodConfigurationModifyParamsAuBecsDebitDisplayPreference,
        PaymentMethodConfigurationModifyParamsBacsDebit as PaymentMethodConfigurationModifyParamsBacsDebit,
        PaymentMethodConfigurationModifyParamsBacsDebitDisplayPreference as PaymentMethodConfigurationModifyParamsBacsDebitDisplayPreference,
        PaymentMethodConfigurationModifyParamsBancontact as PaymentMethodConfigurationModifyParamsBancontact,
        PaymentMethodConfigurationModifyParamsBancontactDisplayPreference as PaymentMethodConfigurationModifyParamsBancontactDisplayPreference,
        PaymentMethodConfigurationModifyParamsBillie as PaymentMethodConfigurationModifyParamsBillie,
        PaymentMethodConfigurationModifyParamsBillieDisplayPreference as PaymentMethodConfigurationModifyParamsBillieDisplayPreference,
        PaymentMethodConfigurationModifyParamsBlik as PaymentMethodConfigurationModifyParamsBlik,
        PaymentMethodConfigurationModifyParamsBlikDisplayPreference as PaymentMethodConfigurationModifyParamsBlikDisplayPreference,
        PaymentMethodConfigurationModifyParamsBoleto as PaymentMethodConfigurationModifyParamsBoleto,
        PaymentMethodConfigurationModifyParamsBoletoDisplayPreference as PaymentMethodConfigurationModifyParamsBoletoDisplayPreference,
        PaymentMethodConfigurationModifyParamsCard as PaymentMethodConfigurationModifyParamsCard,
        PaymentMethodConfigurationModifyParamsCardDisplayPreference as PaymentMethodConfigurationModifyParamsCardDisplayPreference,
        PaymentMethodConfigurationModifyParamsCartesBancaires as PaymentMethodConfigurationModifyParamsCartesBancaires,
        PaymentMethodConfigurationModifyParamsCartesBancairesDisplayPreference as PaymentMethodConfigurationModifyParamsCartesBancairesDisplayPreference,
        PaymentMethodConfigurationModifyParamsCashapp as PaymentMethodConfigurationModifyParamsCashapp,
        PaymentMethodConfigurationModifyParamsCashappDisplayPreference as PaymentMethodConfigurationModifyParamsCashappDisplayPreference,
        PaymentMethodConfigurationModifyParamsCrypto as PaymentMethodConfigurationModifyParamsCrypto,
        PaymentMethodConfigurationModifyParamsCryptoDisplayPreference as PaymentMethodConfigurationModifyParamsCryptoDisplayPreference,
        PaymentMethodConfigurationModifyParamsCustomerBalance as PaymentMethodConfigurationModifyParamsCustomerBalance,
        PaymentMethodConfigurationModifyParamsCustomerBalanceDisplayPreference as PaymentMethodConfigurationModifyParamsCustomerBalanceDisplayPreference,
        PaymentMethodConfigurationModifyParamsEps as PaymentMethodConfigurationModifyParamsEps,
        PaymentMethodConfigurationModifyParamsEpsDisplayPreference as PaymentMethodConfigurationModifyParamsEpsDisplayPreference,
        PaymentMethodConfigurationModifyParamsFpx as PaymentMethodConfigurationModifyParamsFpx,
        PaymentMethodConfigurationModifyParamsFpxDisplayPreference as PaymentMethodConfigurationModifyParamsFpxDisplayPreference,
        PaymentMethodConfigurationModifyParamsFrMealVoucherConecs as PaymentMethodConfigurationModifyParamsFrMealVoucherConecs,
        PaymentMethodConfigurationModifyParamsFrMealVoucherConecsDisplayPreference as PaymentMethodConfigurationModifyParamsFrMealVoucherConecsDisplayPreference,
        PaymentMethodConfigurationModifyParamsGiropay as PaymentMethodConfigurationModifyParamsGiropay,
        PaymentMethodConfigurationModifyParamsGiropayDisplayPreference as PaymentMethodConfigurationModifyParamsGiropayDisplayPreference,
        PaymentMethodConfigurationModifyParamsGooglePay as PaymentMethodConfigurationModifyParamsGooglePay,
        PaymentMethodConfigurationModifyParamsGooglePayDisplayPreference as PaymentMethodConfigurationModifyParamsGooglePayDisplayPreference,
        PaymentMethodConfigurationModifyParamsGopay as PaymentMethodConfigurationModifyParamsGopay,
        PaymentMethodConfigurationModifyParamsGopayDisplayPreference as PaymentMethodConfigurationModifyParamsGopayDisplayPreference,
        PaymentMethodConfigurationModifyParamsGrabpay as PaymentMethodConfigurationModifyParamsGrabpay,
        PaymentMethodConfigurationModifyParamsGrabpayDisplayPreference as PaymentMethodConfigurationModifyParamsGrabpayDisplayPreference,
        PaymentMethodConfigurationModifyParamsIdBankTransfer as PaymentMethodConfigurationModifyParamsIdBankTransfer,
        PaymentMethodConfigurationModifyParamsIdBankTransferDisplayPreference as PaymentMethodConfigurationModifyParamsIdBankTransferDisplayPreference,
        PaymentMethodConfigurationModifyParamsIdeal as PaymentMethodConfigurationModifyParamsIdeal,
        PaymentMethodConfigurationModifyParamsIdealDisplayPreference as PaymentMethodConfigurationModifyParamsIdealDisplayPreference,
        PaymentMethodConfigurationModifyParamsJcb as PaymentMethodConfigurationModifyParamsJcb,
        PaymentMethodConfigurationModifyParamsJcbDisplayPreference as PaymentMethodConfigurationModifyParamsJcbDisplayPreference,
        PaymentMethodConfigurationModifyParamsKakaoPay as PaymentMethodConfigurationModifyParamsKakaoPay,
        PaymentMethodConfigurationModifyParamsKakaoPayDisplayPreference as PaymentMethodConfigurationModifyParamsKakaoPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsKlarna as PaymentMethodConfigurationModifyParamsKlarna,
        PaymentMethodConfigurationModifyParamsKlarnaDisplayPreference as PaymentMethodConfigurationModifyParamsKlarnaDisplayPreference,
        PaymentMethodConfigurationModifyParamsKonbini as PaymentMethodConfigurationModifyParamsKonbini,
        PaymentMethodConfigurationModifyParamsKonbiniDisplayPreference as PaymentMethodConfigurationModifyParamsKonbiniDisplayPreference,
        PaymentMethodConfigurationModifyParamsKrCard as PaymentMethodConfigurationModifyParamsKrCard,
        PaymentMethodConfigurationModifyParamsKrCardDisplayPreference as PaymentMethodConfigurationModifyParamsKrCardDisplayPreference,
        PaymentMethodConfigurationModifyParamsLink as PaymentMethodConfigurationModifyParamsLink,
        PaymentMethodConfigurationModifyParamsLinkDisplayPreference as PaymentMethodConfigurationModifyParamsLinkDisplayPreference,
        PaymentMethodConfigurationModifyParamsMbWay as PaymentMethodConfigurationModifyParamsMbWay,
        PaymentMethodConfigurationModifyParamsMbWayDisplayPreference as PaymentMethodConfigurationModifyParamsMbWayDisplayPreference,
        PaymentMethodConfigurationModifyParamsMobilepay as PaymentMethodConfigurationModifyParamsMobilepay,
        PaymentMethodConfigurationModifyParamsMobilepayDisplayPreference as PaymentMethodConfigurationModifyParamsMobilepayDisplayPreference,
        PaymentMethodConfigurationModifyParamsMultibanco as PaymentMethodConfigurationModifyParamsMultibanco,
        PaymentMethodConfigurationModifyParamsMultibancoDisplayPreference as PaymentMethodConfigurationModifyParamsMultibancoDisplayPreference,
        PaymentMethodConfigurationModifyParamsNaverPay as PaymentMethodConfigurationModifyParamsNaverPay,
        PaymentMethodConfigurationModifyParamsNaverPayDisplayPreference as PaymentMethodConfigurationModifyParamsNaverPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsNzBankAccount as PaymentMethodConfigurationModifyParamsNzBankAccount,
        PaymentMethodConfigurationModifyParamsNzBankAccountDisplayPreference as PaymentMethodConfigurationModifyParamsNzBankAccountDisplayPreference,
        PaymentMethodConfigurationModifyParamsOxxo as PaymentMethodConfigurationModifyParamsOxxo,
        PaymentMethodConfigurationModifyParamsOxxoDisplayPreference as PaymentMethodConfigurationModifyParamsOxxoDisplayPreference,
        PaymentMethodConfigurationModifyParamsP24 as PaymentMethodConfigurationModifyParamsP24,
        PaymentMethodConfigurationModifyParamsP24DisplayPreference as PaymentMethodConfigurationModifyParamsP24DisplayPreference,
        PaymentMethodConfigurationModifyParamsPayByBank as PaymentMethodConfigurationModifyParamsPayByBank,
        PaymentMethodConfigurationModifyParamsPayByBankDisplayPreference as PaymentMethodConfigurationModifyParamsPayByBankDisplayPreference,
        PaymentMethodConfigurationModifyParamsPayco as PaymentMethodConfigurationModifyParamsPayco,
        PaymentMethodConfigurationModifyParamsPaycoDisplayPreference as PaymentMethodConfigurationModifyParamsPaycoDisplayPreference,
        PaymentMethodConfigurationModifyParamsPaynow as PaymentMethodConfigurationModifyParamsPaynow,
        PaymentMethodConfigurationModifyParamsPaynowDisplayPreference as PaymentMethodConfigurationModifyParamsPaynowDisplayPreference,
        PaymentMethodConfigurationModifyParamsPaypal as PaymentMethodConfigurationModifyParamsPaypal,
        PaymentMethodConfigurationModifyParamsPaypalDisplayPreference as PaymentMethodConfigurationModifyParamsPaypalDisplayPreference,
        PaymentMethodConfigurationModifyParamsPaypay as PaymentMethodConfigurationModifyParamsPaypay,
        PaymentMethodConfigurationModifyParamsPaypayDisplayPreference as PaymentMethodConfigurationModifyParamsPaypayDisplayPreference,
        PaymentMethodConfigurationModifyParamsPayto as PaymentMethodConfigurationModifyParamsPayto,
        PaymentMethodConfigurationModifyParamsPaytoDisplayPreference as PaymentMethodConfigurationModifyParamsPaytoDisplayPreference,
        PaymentMethodConfigurationModifyParamsPix as PaymentMethodConfigurationModifyParamsPix,
        PaymentMethodConfigurationModifyParamsPixDisplayPreference as PaymentMethodConfigurationModifyParamsPixDisplayPreference,
        PaymentMethodConfigurationModifyParamsPromptpay as PaymentMethodConfigurationModifyParamsPromptpay,
        PaymentMethodConfigurationModifyParamsPromptpayDisplayPreference as PaymentMethodConfigurationModifyParamsPromptpayDisplayPreference,
        PaymentMethodConfigurationModifyParamsQris as PaymentMethodConfigurationModifyParamsQris,
        PaymentMethodConfigurationModifyParamsQrisDisplayPreference as PaymentMethodConfigurationModifyParamsQrisDisplayPreference,
        PaymentMethodConfigurationModifyParamsRevolutPay as PaymentMethodConfigurationModifyParamsRevolutPay,
        PaymentMethodConfigurationModifyParamsRevolutPayDisplayPreference as PaymentMethodConfigurationModifyParamsRevolutPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsSamsungPay as PaymentMethodConfigurationModifyParamsSamsungPay,
        PaymentMethodConfigurationModifyParamsSamsungPayDisplayPreference as PaymentMethodConfigurationModifyParamsSamsungPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsSatispay as PaymentMethodConfigurationModifyParamsSatispay,
        PaymentMethodConfigurationModifyParamsSatispayDisplayPreference as PaymentMethodConfigurationModifyParamsSatispayDisplayPreference,
        PaymentMethodConfigurationModifyParamsSepaDebit as PaymentMethodConfigurationModifyParamsSepaDebit,
        PaymentMethodConfigurationModifyParamsSepaDebitDisplayPreference as PaymentMethodConfigurationModifyParamsSepaDebitDisplayPreference,
        PaymentMethodConfigurationModifyParamsShopeepay as PaymentMethodConfigurationModifyParamsShopeepay,
        PaymentMethodConfigurationModifyParamsShopeepayDisplayPreference as PaymentMethodConfigurationModifyParamsShopeepayDisplayPreference,
        PaymentMethodConfigurationModifyParamsSofort as PaymentMethodConfigurationModifyParamsSofort,
        PaymentMethodConfigurationModifyParamsSofortDisplayPreference as PaymentMethodConfigurationModifyParamsSofortDisplayPreference,
        PaymentMethodConfigurationModifyParamsSwish as PaymentMethodConfigurationModifyParamsSwish,
        PaymentMethodConfigurationModifyParamsSwishDisplayPreference as PaymentMethodConfigurationModifyParamsSwishDisplayPreference,
        PaymentMethodConfigurationModifyParamsTwint as PaymentMethodConfigurationModifyParamsTwint,
        PaymentMethodConfigurationModifyParamsTwintDisplayPreference as PaymentMethodConfigurationModifyParamsTwintDisplayPreference,
        PaymentMethodConfigurationModifyParamsUsBankAccount as PaymentMethodConfigurationModifyParamsUsBankAccount,
        PaymentMethodConfigurationModifyParamsUsBankAccountDisplayPreference as PaymentMethodConfigurationModifyParamsUsBankAccountDisplayPreference,
        PaymentMethodConfigurationModifyParamsWechatPay as PaymentMethodConfigurationModifyParamsWechatPay,
        PaymentMethodConfigurationModifyParamsWechatPayDisplayPreference as PaymentMethodConfigurationModifyParamsWechatPayDisplayPreference,
        PaymentMethodConfigurationModifyParamsZip as PaymentMethodConfigurationModifyParamsZip,
        PaymentMethodConfigurationModifyParamsZipDisplayPreference as PaymentMethodConfigurationModifyParamsZipDisplayPreference,
    )
    from stripe.params._payment_method_configuration_retrieve_params import (
        PaymentMethodConfigurationRetrieveParams as PaymentMethodConfigurationRetrieveParams,
    )
    from stripe.params._payment_method_configuration_update_params import (
        PaymentMethodConfigurationUpdateParams as PaymentMethodConfigurationUpdateParams,
        PaymentMethodConfigurationUpdateParamsAcssDebit as PaymentMethodConfigurationUpdateParamsAcssDebit,
        PaymentMethodConfigurationUpdateParamsAcssDebitDisplayPreference as PaymentMethodConfigurationUpdateParamsAcssDebitDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAffirm as PaymentMethodConfigurationUpdateParamsAffirm,
        PaymentMethodConfigurationUpdateParamsAffirmDisplayPreference as PaymentMethodConfigurationUpdateParamsAffirmDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAfterpayClearpay as PaymentMethodConfigurationUpdateParamsAfterpayClearpay,
        PaymentMethodConfigurationUpdateParamsAfterpayClearpayDisplayPreference as PaymentMethodConfigurationUpdateParamsAfterpayClearpayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAlipay as PaymentMethodConfigurationUpdateParamsAlipay,
        PaymentMethodConfigurationUpdateParamsAlipayDisplayPreference as PaymentMethodConfigurationUpdateParamsAlipayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAlma as PaymentMethodConfigurationUpdateParamsAlma,
        PaymentMethodConfigurationUpdateParamsAlmaDisplayPreference as PaymentMethodConfigurationUpdateParamsAlmaDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAmazonPay as PaymentMethodConfigurationUpdateParamsAmazonPay,
        PaymentMethodConfigurationUpdateParamsAmazonPayDisplayPreference as PaymentMethodConfigurationUpdateParamsAmazonPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsApplePay as PaymentMethodConfigurationUpdateParamsApplePay,
        PaymentMethodConfigurationUpdateParamsApplePayDisplayPreference as PaymentMethodConfigurationUpdateParamsApplePayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsApplePayLater as PaymentMethodConfigurationUpdateParamsApplePayLater,
        PaymentMethodConfigurationUpdateParamsApplePayLaterDisplayPreference as PaymentMethodConfigurationUpdateParamsApplePayLaterDisplayPreference,
        PaymentMethodConfigurationUpdateParamsAuBecsDebit as PaymentMethodConfigurationUpdateParamsAuBecsDebit,
        PaymentMethodConfigurationUpdateParamsAuBecsDebitDisplayPreference as PaymentMethodConfigurationUpdateParamsAuBecsDebitDisplayPreference,
        PaymentMethodConfigurationUpdateParamsBacsDebit as PaymentMethodConfigurationUpdateParamsBacsDebit,
        PaymentMethodConfigurationUpdateParamsBacsDebitDisplayPreference as PaymentMethodConfigurationUpdateParamsBacsDebitDisplayPreference,
        PaymentMethodConfigurationUpdateParamsBancontact as PaymentMethodConfigurationUpdateParamsBancontact,
        PaymentMethodConfigurationUpdateParamsBancontactDisplayPreference as PaymentMethodConfigurationUpdateParamsBancontactDisplayPreference,
        PaymentMethodConfigurationUpdateParamsBillie as PaymentMethodConfigurationUpdateParamsBillie,
        PaymentMethodConfigurationUpdateParamsBillieDisplayPreference as PaymentMethodConfigurationUpdateParamsBillieDisplayPreference,
        PaymentMethodConfigurationUpdateParamsBlik as PaymentMethodConfigurationUpdateParamsBlik,
        PaymentMethodConfigurationUpdateParamsBlikDisplayPreference as PaymentMethodConfigurationUpdateParamsBlikDisplayPreference,
        PaymentMethodConfigurationUpdateParamsBoleto as PaymentMethodConfigurationUpdateParamsBoleto,
        PaymentMethodConfigurationUpdateParamsBoletoDisplayPreference as PaymentMethodConfigurationUpdateParamsBoletoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsCard as PaymentMethodConfigurationUpdateParamsCard,
        PaymentMethodConfigurationUpdateParamsCardDisplayPreference as PaymentMethodConfigurationUpdateParamsCardDisplayPreference,
        PaymentMethodConfigurationUpdateParamsCartesBancaires as PaymentMethodConfigurationUpdateParamsCartesBancaires,
        PaymentMethodConfigurationUpdateParamsCartesBancairesDisplayPreference as PaymentMethodConfigurationUpdateParamsCartesBancairesDisplayPreference,
        PaymentMethodConfigurationUpdateParamsCashapp as PaymentMethodConfigurationUpdateParamsCashapp,
        PaymentMethodConfigurationUpdateParamsCashappDisplayPreference as PaymentMethodConfigurationUpdateParamsCashappDisplayPreference,
        PaymentMethodConfigurationUpdateParamsCrypto as PaymentMethodConfigurationUpdateParamsCrypto,
        PaymentMethodConfigurationUpdateParamsCryptoDisplayPreference as PaymentMethodConfigurationUpdateParamsCryptoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsCustomerBalance as PaymentMethodConfigurationUpdateParamsCustomerBalance,
        PaymentMethodConfigurationUpdateParamsCustomerBalanceDisplayPreference as PaymentMethodConfigurationUpdateParamsCustomerBalanceDisplayPreference,
        PaymentMethodConfigurationUpdateParamsEps as PaymentMethodConfigurationUpdateParamsEps,
        PaymentMethodConfigurationUpdateParamsEpsDisplayPreference as PaymentMethodConfigurationUpdateParamsEpsDisplayPreference,
        PaymentMethodConfigurationUpdateParamsFpx as PaymentMethodConfigurationUpdateParamsFpx,
        PaymentMethodConfigurationUpdateParamsFpxDisplayPreference as PaymentMethodConfigurationUpdateParamsFpxDisplayPreference,
        PaymentMethodConfigurationUpdateParamsFrMealVoucherConecs as PaymentMethodConfigurationUpdateParamsFrMealVoucherConecs,
        PaymentMethodConfigurationUpdateParamsFrMealVoucherConecsDisplayPreference as PaymentMethodConfigurationUpdateParamsFrMealVoucherConecsDisplayPreference,
        PaymentMethodConfigurationUpdateParamsGiropay as PaymentMethodConfigurationUpdateParamsGiropay,
        PaymentMethodConfigurationUpdateParamsGiropayDisplayPreference as PaymentMethodConfigurationUpdateParamsGiropayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsGooglePay as PaymentMethodConfigurationUpdateParamsGooglePay,
        PaymentMethodConfigurationUpdateParamsGooglePayDisplayPreference as PaymentMethodConfigurationUpdateParamsGooglePayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsGopay as PaymentMethodConfigurationUpdateParamsGopay,
        PaymentMethodConfigurationUpdateParamsGopayDisplayPreference as PaymentMethodConfigurationUpdateParamsGopayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsGrabpay as PaymentMethodConfigurationUpdateParamsGrabpay,
        PaymentMethodConfigurationUpdateParamsGrabpayDisplayPreference as PaymentMethodConfigurationUpdateParamsGrabpayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsIdBankTransfer as PaymentMethodConfigurationUpdateParamsIdBankTransfer,
        PaymentMethodConfigurationUpdateParamsIdBankTransferDisplayPreference as PaymentMethodConfigurationUpdateParamsIdBankTransferDisplayPreference,
        PaymentMethodConfigurationUpdateParamsIdeal as PaymentMethodConfigurationUpdateParamsIdeal,
        PaymentMethodConfigurationUpdateParamsIdealDisplayPreference as PaymentMethodConfigurationUpdateParamsIdealDisplayPreference,
        PaymentMethodConfigurationUpdateParamsJcb as PaymentMethodConfigurationUpdateParamsJcb,
        PaymentMethodConfigurationUpdateParamsJcbDisplayPreference as PaymentMethodConfigurationUpdateParamsJcbDisplayPreference,
        PaymentMethodConfigurationUpdateParamsKakaoPay as PaymentMethodConfigurationUpdateParamsKakaoPay,
        PaymentMethodConfigurationUpdateParamsKakaoPayDisplayPreference as PaymentMethodConfigurationUpdateParamsKakaoPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsKlarna as PaymentMethodConfigurationUpdateParamsKlarna,
        PaymentMethodConfigurationUpdateParamsKlarnaDisplayPreference as PaymentMethodConfigurationUpdateParamsKlarnaDisplayPreference,
        PaymentMethodConfigurationUpdateParamsKonbini as PaymentMethodConfigurationUpdateParamsKonbini,
        PaymentMethodConfigurationUpdateParamsKonbiniDisplayPreference as PaymentMethodConfigurationUpdateParamsKonbiniDisplayPreference,
        PaymentMethodConfigurationUpdateParamsKrCard as PaymentMethodConfigurationUpdateParamsKrCard,
        PaymentMethodConfigurationUpdateParamsKrCardDisplayPreference as PaymentMethodConfigurationUpdateParamsKrCardDisplayPreference,
        PaymentMethodConfigurationUpdateParamsLink as PaymentMethodConfigurationUpdateParamsLink,
        PaymentMethodConfigurationUpdateParamsLinkDisplayPreference as PaymentMethodConfigurationUpdateParamsLinkDisplayPreference,
        PaymentMethodConfigurationUpdateParamsMbWay as PaymentMethodConfigurationUpdateParamsMbWay,
        PaymentMethodConfigurationUpdateParamsMbWayDisplayPreference as PaymentMethodConfigurationUpdateParamsMbWayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsMobilepay as PaymentMethodConfigurationUpdateParamsMobilepay,
        PaymentMethodConfigurationUpdateParamsMobilepayDisplayPreference as PaymentMethodConfigurationUpdateParamsMobilepayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsMultibanco as PaymentMethodConfigurationUpdateParamsMultibanco,
        PaymentMethodConfigurationUpdateParamsMultibancoDisplayPreference as PaymentMethodConfigurationUpdateParamsMultibancoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsNaverPay as PaymentMethodConfigurationUpdateParamsNaverPay,
        PaymentMethodConfigurationUpdateParamsNaverPayDisplayPreference as PaymentMethodConfigurationUpdateParamsNaverPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsNzBankAccount as PaymentMethodConfigurationUpdateParamsNzBankAccount,
        PaymentMethodConfigurationUpdateParamsNzBankAccountDisplayPreference as PaymentMethodConfigurationUpdateParamsNzBankAccountDisplayPreference,
        PaymentMethodConfigurationUpdateParamsOxxo as PaymentMethodConfigurationUpdateParamsOxxo,
        PaymentMethodConfigurationUpdateParamsOxxoDisplayPreference as PaymentMethodConfigurationUpdateParamsOxxoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsP24 as PaymentMethodConfigurationUpdateParamsP24,
        PaymentMethodConfigurationUpdateParamsP24DisplayPreference as PaymentMethodConfigurationUpdateParamsP24DisplayPreference,
        PaymentMethodConfigurationUpdateParamsPayByBank as PaymentMethodConfigurationUpdateParamsPayByBank,
        PaymentMethodConfigurationUpdateParamsPayByBankDisplayPreference as PaymentMethodConfigurationUpdateParamsPayByBankDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPayco as PaymentMethodConfigurationUpdateParamsPayco,
        PaymentMethodConfigurationUpdateParamsPaycoDisplayPreference as PaymentMethodConfigurationUpdateParamsPaycoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPaynow as PaymentMethodConfigurationUpdateParamsPaynow,
        PaymentMethodConfigurationUpdateParamsPaynowDisplayPreference as PaymentMethodConfigurationUpdateParamsPaynowDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPaypal as PaymentMethodConfigurationUpdateParamsPaypal,
        PaymentMethodConfigurationUpdateParamsPaypalDisplayPreference as PaymentMethodConfigurationUpdateParamsPaypalDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPaypay as PaymentMethodConfigurationUpdateParamsPaypay,
        PaymentMethodConfigurationUpdateParamsPaypayDisplayPreference as PaymentMethodConfigurationUpdateParamsPaypayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPayto as PaymentMethodConfigurationUpdateParamsPayto,
        PaymentMethodConfigurationUpdateParamsPaytoDisplayPreference as PaymentMethodConfigurationUpdateParamsPaytoDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPix as PaymentMethodConfigurationUpdateParamsPix,
        PaymentMethodConfigurationUpdateParamsPixDisplayPreference as PaymentMethodConfigurationUpdateParamsPixDisplayPreference,
        PaymentMethodConfigurationUpdateParamsPromptpay as PaymentMethodConfigurationUpdateParamsPromptpay,
        PaymentMethodConfigurationUpdateParamsPromptpayDisplayPreference as PaymentMethodConfigurationUpdateParamsPromptpayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsQris as PaymentMethodConfigurationUpdateParamsQris,
        PaymentMethodConfigurationUpdateParamsQrisDisplayPreference as PaymentMethodConfigurationUpdateParamsQrisDisplayPreference,
        PaymentMethodConfigurationUpdateParamsRevolutPay as PaymentMethodConfigurationUpdateParamsRevolutPay,
        PaymentMethodConfigurationUpdateParamsRevolutPayDisplayPreference as PaymentMethodConfigurationUpdateParamsRevolutPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsSamsungPay as PaymentMethodConfigurationUpdateParamsSamsungPay,
        PaymentMethodConfigurationUpdateParamsSamsungPayDisplayPreference as PaymentMethodConfigurationUpdateParamsSamsungPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsSatispay as PaymentMethodConfigurationUpdateParamsSatispay,
        PaymentMethodConfigurationUpdateParamsSatispayDisplayPreference as PaymentMethodConfigurationUpdateParamsSatispayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsSepaDebit as PaymentMethodConfigurationUpdateParamsSepaDebit,
        PaymentMethodConfigurationUpdateParamsSepaDebitDisplayPreference as PaymentMethodConfigurationUpdateParamsSepaDebitDisplayPreference,
        PaymentMethodConfigurationUpdateParamsShopeepay as PaymentMethodConfigurationUpdateParamsShopeepay,
        PaymentMethodConfigurationUpdateParamsShopeepayDisplayPreference as PaymentMethodConfigurationUpdateParamsShopeepayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsSofort as PaymentMethodConfigurationUpdateParamsSofort,
        PaymentMethodConfigurationUpdateParamsSofortDisplayPreference as PaymentMethodConfigurationUpdateParamsSofortDisplayPreference,
        PaymentMethodConfigurationUpdateParamsSwish as PaymentMethodConfigurationUpdateParamsSwish,
        PaymentMethodConfigurationUpdateParamsSwishDisplayPreference as PaymentMethodConfigurationUpdateParamsSwishDisplayPreference,
        PaymentMethodConfigurationUpdateParamsTwint as PaymentMethodConfigurationUpdateParamsTwint,
        PaymentMethodConfigurationUpdateParamsTwintDisplayPreference as PaymentMethodConfigurationUpdateParamsTwintDisplayPreference,
        PaymentMethodConfigurationUpdateParamsUsBankAccount as PaymentMethodConfigurationUpdateParamsUsBankAccount,
        PaymentMethodConfigurationUpdateParamsUsBankAccountDisplayPreference as PaymentMethodConfigurationUpdateParamsUsBankAccountDisplayPreference,
        PaymentMethodConfigurationUpdateParamsWechatPay as PaymentMethodConfigurationUpdateParamsWechatPay,
        PaymentMethodConfigurationUpdateParamsWechatPayDisplayPreference as PaymentMethodConfigurationUpdateParamsWechatPayDisplayPreference,
        PaymentMethodConfigurationUpdateParamsZip as PaymentMethodConfigurationUpdateParamsZip,
        PaymentMethodConfigurationUpdateParamsZipDisplayPreference as PaymentMethodConfigurationUpdateParamsZipDisplayPreference,
    )
    from stripe.params._payment_method_create_params import (
        PaymentMethodCreateParams as PaymentMethodCreateParams,
        PaymentMethodCreateParamsAcssDebit as PaymentMethodCreateParamsAcssDebit,
        PaymentMethodCreateParamsAffirm as PaymentMethodCreateParamsAffirm,
        PaymentMethodCreateParamsAfterpayClearpay as PaymentMethodCreateParamsAfterpayClearpay,
        PaymentMethodCreateParamsAlipay as PaymentMethodCreateParamsAlipay,
        PaymentMethodCreateParamsAlma as PaymentMethodCreateParamsAlma,
        PaymentMethodCreateParamsAmazonPay as PaymentMethodCreateParamsAmazonPay,
        PaymentMethodCreateParamsAuBecsDebit as PaymentMethodCreateParamsAuBecsDebit,
        PaymentMethodCreateParamsBacsDebit as PaymentMethodCreateParamsBacsDebit,
        PaymentMethodCreateParamsBancontact as PaymentMethodCreateParamsBancontact,
        PaymentMethodCreateParamsBillie as PaymentMethodCreateParamsBillie,
        PaymentMethodCreateParamsBillingDetails as PaymentMethodCreateParamsBillingDetails,
        PaymentMethodCreateParamsBillingDetailsAddress as PaymentMethodCreateParamsBillingDetailsAddress,
        PaymentMethodCreateParamsBlik as PaymentMethodCreateParamsBlik,
        PaymentMethodCreateParamsBoleto as PaymentMethodCreateParamsBoleto,
        PaymentMethodCreateParamsCard as PaymentMethodCreateParamsCard,
        PaymentMethodCreateParamsCardNetworks as PaymentMethodCreateParamsCardNetworks,
        PaymentMethodCreateParamsCashapp as PaymentMethodCreateParamsCashapp,
        PaymentMethodCreateParamsCrypto as PaymentMethodCreateParamsCrypto,
        PaymentMethodCreateParamsCustom as PaymentMethodCreateParamsCustom,
        PaymentMethodCreateParamsCustomerBalance as PaymentMethodCreateParamsCustomerBalance,
        PaymentMethodCreateParamsEps as PaymentMethodCreateParamsEps,
        PaymentMethodCreateParamsFpx as PaymentMethodCreateParamsFpx,
        PaymentMethodCreateParamsGiropay as PaymentMethodCreateParamsGiropay,
        PaymentMethodCreateParamsGopay as PaymentMethodCreateParamsGopay,
        PaymentMethodCreateParamsGrabpay as PaymentMethodCreateParamsGrabpay,
        PaymentMethodCreateParamsIdBankTransfer as PaymentMethodCreateParamsIdBankTransfer,
        PaymentMethodCreateParamsIdeal as PaymentMethodCreateParamsIdeal,
        PaymentMethodCreateParamsInteracPresent as PaymentMethodCreateParamsInteracPresent,
        PaymentMethodCreateParamsKakaoPay as PaymentMethodCreateParamsKakaoPay,
        PaymentMethodCreateParamsKlarna as PaymentMethodCreateParamsKlarna,
        PaymentMethodCreateParamsKlarnaDob as PaymentMethodCreateParamsKlarnaDob,
        PaymentMethodCreateParamsKonbini as PaymentMethodCreateParamsKonbini,
        PaymentMethodCreateParamsKrCard as PaymentMethodCreateParamsKrCard,
        PaymentMethodCreateParamsLink as PaymentMethodCreateParamsLink,
        PaymentMethodCreateParamsMbWay as PaymentMethodCreateParamsMbWay,
        PaymentMethodCreateParamsMobilepay as PaymentMethodCreateParamsMobilepay,
        PaymentMethodCreateParamsMultibanco as PaymentMethodCreateParamsMultibanco,
        PaymentMethodCreateParamsNaverPay as PaymentMethodCreateParamsNaverPay,
        PaymentMethodCreateParamsNzBankAccount as PaymentMethodCreateParamsNzBankAccount,
        PaymentMethodCreateParamsOxxo as PaymentMethodCreateParamsOxxo,
        PaymentMethodCreateParamsP24 as PaymentMethodCreateParamsP24,
        PaymentMethodCreateParamsPayByBank as PaymentMethodCreateParamsPayByBank,
        PaymentMethodCreateParamsPayco as PaymentMethodCreateParamsPayco,
        PaymentMethodCreateParamsPaynow as PaymentMethodCreateParamsPaynow,
        PaymentMethodCreateParamsPaypal as PaymentMethodCreateParamsPaypal,
        PaymentMethodCreateParamsPaypay as PaymentMethodCreateParamsPaypay,
        PaymentMethodCreateParamsPayto as PaymentMethodCreateParamsPayto,
        PaymentMethodCreateParamsPix as PaymentMethodCreateParamsPix,
        PaymentMethodCreateParamsPromptpay as PaymentMethodCreateParamsPromptpay,
        PaymentMethodCreateParamsQris as PaymentMethodCreateParamsQris,
        PaymentMethodCreateParamsRadarOptions as PaymentMethodCreateParamsRadarOptions,
        PaymentMethodCreateParamsRechnung as PaymentMethodCreateParamsRechnung,
        PaymentMethodCreateParamsRechnungDob as PaymentMethodCreateParamsRechnungDob,
        PaymentMethodCreateParamsRevolutPay as PaymentMethodCreateParamsRevolutPay,
        PaymentMethodCreateParamsSamsungPay as PaymentMethodCreateParamsSamsungPay,
        PaymentMethodCreateParamsSatispay as PaymentMethodCreateParamsSatispay,
        PaymentMethodCreateParamsSepaDebit as PaymentMethodCreateParamsSepaDebit,
        PaymentMethodCreateParamsShopeepay as PaymentMethodCreateParamsShopeepay,
        PaymentMethodCreateParamsSofort as PaymentMethodCreateParamsSofort,
        PaymentMethodCreateParamsStripeBalance as PaymentMethodCreateParamsStripeBalance,
        PaymentMethodCreateParamsSwish as PaymentMethodCreateParamsSwish,
        PaymentMethodCreateParamsTwint as PaymentMethodCreateParamsTwint,
        PaymentMethodCreateParamsUsBankAccount as PaymentMethodCreateParamsUsBankAccount,
        PaymentMethodCreateParamsWechatPay as PaymentMethodCreateParamsWechatPay,
        PaymentMethodCreateParamsZip as PaymentMethodCreateParamsZip,
    )
    from stripe.params._payment_method_detach_params import (
        PaymentMethodDetachParams as PaymentMethodDetachParams,
    )
    from stripe.params._payment_method_domain_create_params import (
        PaymentMethodDomainCreateParams as PaymentMethodDomainCreateParams,
    )
    from stripe.params._payment_method_domain_list_params import (
        PaymentMethodDomainListParams as PaymentMethodDomainListParams,
    )
    from stripe.params._payment_method_domain_modify_params import (
        PaymentMethodDomainModifyParams as PaymentMethodDomainModifyParams,
    )
    from stripe.params._payment_method_domain_retrieve_params import (
        PaymentMethodDomainRetrieveParams as PaymentMethodDomainRetrieveParams,
    )
    from stripe.params._payment_method_domain_update_params import (
        PaymentMethodDomainUpdateParams as PaymentMethodDomainUpdateParams,
    )
    from stripe.params._payment_method_domain_validate_params import (
        PaymentMethodDomainValidateParams as PaymentMethodDomainValidateParams,
    )
    from stripe.params._payment_method_list_params import (
        PaymentMethodListParams as PaymentMethodListParams,
    )
    from stripe.params._payment_method_modify_params import (
        PaymentMethodModifyParams as PaymentMethodModifyParams,
        PaymentMethodModifyParamsBillingDetails as PaymentMethodModifyParamsBillingDetails,
        PaymentMethodModifyParamsBillingDetailsAddress as PaymentMethodModifyParamsBillingDetailsAddress,
        PaymentMethodModifyParamsCard as PaymentMethodModifyParamsCard,
        PaymentMethodModifyParamsCardNetworks as PaymentMethodModifyParamsCardNetworks,
        PaymentMethodModifyParamsPayto as PaymentMethodModifyParamsPayto,
        PaymentMethodModifyParamsUsBankAccount as PaymentMethodModifyParamsUsBankAccount,
    )
    from stripe.params._payment_method_retrieve_params import (
        PaymentMethodRetrieveParams as PaymentMethodRetrieveParams,
    )
    from stripe.params._payment_method_update_params import (
        PaymentMethodUpdateParams as PaymentMethodUpdateParams,
        PaymentMethodUpdateParamsBillingDetails as PaymentMethodUpdateParamsBillingDetails,
        PaymentMethodUpdateParamsBillingDetailsAddress as PaymentMethodUpdateParamsBillingDetailsAddress,
        PaymentMethodUpdateParamsCard as PaymentMethodUpdateParamsCard,
        PaymentMethodUpdateParamsCardNetworks as PaymentMethodUpdateParamsCardNetworks,
        PaymentMethodUpdateParamsPayto as PaymentMethodUpdateParamsPayto,
        PaymentMethodUpdateParamsUsBankAccount as PaymentMethodUpdateParamsUsBankAccount,
    )
    from stripe.params._payment_record_report_payment_attempt_canceled_params import (
        PaymentRecordReportPaymentAttemptCanceledParams as PaymentRecordReportPaymentAttemptCanceledParams,
    )
    from stripe.params._payment_record_report_payment_attempt_failed_params import (
        PaymentRecordReportPaymentAttemptFailedParams as PaymentRecordReportPaymentAttemptFailedParams,
    )
    from stripe.params._payment_record_report_payment_attempt_guaranteed_params import (
        PaymentRecordReportPaymentAttemptGuaranteedParams as PaymentRecordReportPaymentAttemptGuaranteedParams,
    )
    from stripe.params._payment_record_report_payment_attempt_informational_params import (
        PaymentRecordReportPaymentAttemptInformationalParams as PaymentRecordReportPaymentAttemptInformationalParams,
        PaymentRecordReportPaymentAttemptInformationalParamsCustomerDetails as PaymentRecordReportPaymentAttemptInformationalParamsCustomerDetails,
        PaymentRecordReportPaymentAttemptInformationalParamsShippingDetails as PaymentRecordReportPaymentAttemptInformationalParamsShippingDetails,
        PaymentRecordReportPaymentAttemptInformationalParamsShippingDetailsAddress as PaymentRecordReportPaymentAttemptInformationalParamsShippingDetailsAddress,
    )
    from stripe.params._payment_record_report_payment_attempt_params import (
        PaymentRecordReportPaymentAttemptParams as PaymentRecordReportPaymentAttemptParams,
        PaymentRecordReportPaymentAttemptParamsFailed as PaymentRecordReportPaymentAttemptParamsFailed,
        PaymentRecordReportPaymentAttemptParamsGuaranteed as PaymentRecordReportPaymentAttemptParamsGuaranteed,
        PaymentRecordReportPaymentAttemptParamsPaymentMethodDetails as PaymentRecordReportPaymentAttemptParamsPaymentMethodDetails,
        PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetails as PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetails,
        PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetailsAddress as PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetailsAddress,
        PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsCustom as PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsCustom,
        PaymentRecordReportPaymentAttemptParamsShippingDetails as PaymentRecordReportPaymentAttemptParamsShippingDetails,
        PaymentRecordReportPaymentAttemptParamsShippingDetailsAddress as PaymentRecordReportPaymentAttemptParamsShippingDetailsAddress,
    )
    from stripe.params._payment_record_report_payment_params import (
        PaymentRecordReportPaymentParams as PaymentRecordReportPaymentParams,
        PaymentRecordReportPaymentParamsAmountRequested as PaymentRecordReportPaymentParamsAmountRequested,
        PaymentRecordReportPaymentParamsCustomerDetails as PaymentRecordReportPaymentParamsCustomerDetails,
        PaymentRecordReportPaymentParamsFailed as PaymentRecordReportPaymentParamsFailed,
        PaymentRecordReportPaymentParamsGuaranteed as PaymentRecordReportPaymentParamsGuaranteed,
        PaymentRecordReportPaymentParamsPaymentMethodDetails as PaymentRecordReportPaymentParamsPaymentMethodDetails,
        PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetails as PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetails,
        PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetailsAddress as PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetailsAddress,
        PaymentRecordReportPaymentParamsPaymentMethodDetailsCustom as PaymentRecordReportPaymentParamsPaymentMethodDetailsCustom,
        PaymentRecordReportPaymentParamsProcessorDetails as PaymentRecordReportPaymentParamsProcessorDetails,
        PaymentRecordReportPaymentParamsProcessorDetailsCustom as PaymentRecordReportPaymentParamsProcessorDetailsCustom,
        PaymentRecordReportPaymentParamsShippingDetails as PaymentRecordReportPaymentParamsShippingDetails,
        PaymentRecordReportPaymentParamsShippingDetailsAddress as PaymentRecordReportPaymentParamsShippingDetailsAddress,
    )
    from stripe.params._payment_record_report_refund_params import (
        PaymentRecordReportRefundParams as PaymentRecordReportRefundParams,
        PaymentRecordReportRefundParamsAmount as PaymentRecordReportRefundParamsAmount,
        PaymentRecordReportRefundParamsProcessorDetails as PaymentRecordReportRefundParamsProcessorDetails,
        PaymentRecordReportRefundParamsProcessorDetailsCustom as PaymentRecordReportRefundParamsProcessorDetailsCustom,
        PaymentRecordReportRefundParamsRefunded as PaymentRecordReportRefundParamsRefunded,
    )
    from stripe.params._payment_record_retrieve_params import (
        PaymentRecordRetrieveParams as PaymentRecordRetrieveParams,
    )
    from stripe.params._payout_cancel_params import (
        PayoutCancelParams as PayoutCancelParams,
    )
    from stripe.params._payout_create_params import (
        PayoutCreateParams as PayoutCreateParams,
    )
    from stripe.params._payout_list_params import (
        PayoutListParams as PayoutListParams,
        PayoutListParamsArrivalDate as PayoutListParamsArrivalDate,
        PayoutListParamsCreated as PayoutListParamsCreated,
    )
    from stripe.params._payout_modify_params import (
        PayoutModifyParams as PayoutModifyParams,
    )
    from stripe.params._payout_retrieve_params import (
        PayoutRetrieveParams as PayoutRetrieveParams,
    )
    from stripe.params._payout_reverse_params import (
        PayoutReverseParams as PayoutReverseParams,
    )
    from stripe.params._payout_update_params import (
        PayoutUpdateParams as PayoutUpdateParams,
    )
    from stripe.params._plan_create_params import (
        PlanCreateParams as PlanCreateParams,
        PlanCreateParamsProduct as PlanCreateParamsProduct,
        PlanCreateParamsTier as PlanCreateParamsTier,
        PlanCreateParamsTransformUsage as PlanCreateParamsTransformUsage,
    )
    from stripe.params._plan_delete_params import (
        PlanDeleteParams as PlanDeleteParams,
    )
    from stripe.params._plan_list_params import (
        PlanListParams as PlanListParams,
        PlanListParamsCreated as PlanListParamsCreated,
    )
    from stripe.params._plan_modify_params import (
        PlanModifyParams as PlanModifyParams,
    )
    from stripe.params._plan_retrieve_params import (
        PlanRetrieveParams as PlanRetrieveParams,
    )
    from stripe.params._plan_update_params import (
        PlanUpdateParams as PlanUpdateParams,
    )
    from stripe.params._price_create_params import (
        PriceCreateParams as PriceCreateParams,
        PriceCreateParamsCurrencyOptions as PriceCreateParamsCurrencyOptions,
        PriceCreateParamsCurrencyOptionsCustomUnitAmount as PriceCreateParamsCurrencyOptionsCustomUnitAmount,
        PriceCreateParamsCurrencyOptionsTier as PriceCreateParamsCurrencyOptionsTier,
        PriceCreateParamsCustomUnitAmount as PriceCreateParamsCustomUnitAmount,
        PriceCreateParamsProductData as PriceCreateParamsProductData,
        PriceCreateParamsRecurring as PriceCreateParamsRecurring,
        PriceCreateParamsTier as PriceCreateParamsTier,
        PriceCreateParamsTransformQuantity as PriceCreateParamsTransformQuantity,
    )
    from stripe.params._price_list_params import (
        PriceListParams as PriceListParams,
        PriceListParamsCreated as PriceListParamsCreated,
        PriceListParamsRecurring as PriceListParamsRecurring,
    )
    from stripe.params._price_modify_params import (
        PriceModifyParams as PriceModifyParams,
        PriceModifyParamsCurrencyOptions as PriceModifyParamsCurrencyOptions,
        PriceModifyParamsCurrencyOptionsCustomUnitAmount as PriceModifyParamsCurrencyOptionsCustomUnitAmount,
        PriceModifyParamsCurrencyOptionsTier as PriceModifyParamsCurrencyOptionsTier,
        PriceModifyParamsMigrateTo as PriceModifyParamsMigrateTo,
    )
    from stripe.params._price_retrieve_params import (
        PriceRetrieveParams as PriceRetrieveParams,
    )
    from stripe.params._price_search_params import (
        PriceSearchParams as PriceSearchParams,
    )
    from stripe.params._price_update_params import (
        PriceUpdateParams as PriceUpdateParams,
        PriceUpdateParamsCurrencyOptions as PriceUpdateParamsCurrencyOptions,
        PriceUpdateParamsCurrencyOptionsCustomUnitAmount as PriceUpdateParamsCurrencyOptionsCustomUnitAmount,
        PriceUpdateParamsCurrencyOptionsTier as PriceUpdateParamsCurrencyOptionsTier,
        PriceUpdateParamsMigrateTo as PriceUpdateParamsMigrateTo,
    )
    from stripe.params._product_create_feature_params import (
        ProductCreateFeatureParams as ProductCreateFeatureParams,
    )
    from stripe.params._product_create_params import (
        ProductCreateParams as ProductCreateParams,
        ProductCreateParamsDefaultPriceData as ProductCreateParamsDefaultPriceData,
        ProductCreateParamsDefaultPriceDataCurrencyOptions as ProductCreateParamsDefaultPriceDataCurrencyOptions,
        ProductCreateParamsDefaultPriceDataCurrencyOptionsCustomUnitAmount as ProductCreateParamsDefaultPriceDataCurrencyOptionsCustomUnitAmount,
        ProductCreateParamsDefaultPriceDataCurrencyOptionsTier as ProductCreateParamsDefaultPriceDataCurrencyOptionsTier,
        ProductCreateParamsDefaultPriceDataCustomUnitAmount as ProductCreateParamsDefaultPriceDataCustomUnitAmount,
        ProductCreateParamsDefaultPriceDataRecurring as ProductCreateParamsDefaultPriceDataRecurring,
        ProductCreateParamsMarketingFeature as ProductCreateParamsMarketingFeature,
        ProductCreateParamsPackageDimensions as ProductCreateParamsPackageDimensions,
    )
    from stripe.params._product_delete_feature_params import (
        ProductDeleteFeatureParams as ProductDeleteFeatureParams,
    )
    from stripe.params._product_delete_params import (
        ProductDeleteParams as ProductDeleteParams,
    )
    from stripe.params._product_feature_create_params import (
        ProductFeatureCreateParams as ProductFeatureCreateParams,
    )
    from stripe.params._product_feature_delete_params import (
        ProductFeatureDeleteParams as ProductFeatureDeleteParams,
    )
    from stripe.params._product_feature_list_params import (
        ProductFeatureListParams as ProductFeatureListParams,
    )
    from stripe.params._product_feature_retrieve_params import (
        ProductFeatureRetrieveParams as ProductFeatureRetrieveParams,
    )
    from stripe.params._product_list_features_params import (
        ProductListFeaturesParams as ProductListFeaturesParams,
    )
    from stripe.params._product_list_params import (
        ProductListParams as ProductListParams,
        ProductListParamsCreated as ProductListParamsCreated,
    )
    from stripe.params._product_modify_params import (
        ProductModifyParams as ProductModifyParams,
        ProductModifyParamsMarketingFeature as ProductModifyParamsMarketingFeature,
        ProductModifyParamsPackageDimensions as ProductModifyParamsPackageDimensions,
    )
    from stripe.params._product_retrieve_feature_params import (
        ProductRetrieveFeatureParams as ProductRetrieveFeatureParams,
    )
    from stripe.params._product_retrieve_params import (
        ProductRetrieveParams as ProductRetrieveParams,
    )
    from stripe.params._product_search_params import (
        ProductSearchParams as ProductSearchParams,
    )
    from stripe.params._product_update_params import (
        ProductUpdateParams as ProductUpdateParams,
        ProductUpdateParamsMarketingFeature as ProductUpdateParamsMarketingFeature,
        ProductUpdateParamsPackageDimensions as ProductUpdateParamsPackageDimensions,
    )
    from stripe.params._promotion_code_create_params import (
        PromotionCodeCreateParams as PromotionCodeCreateParams,
        PromotionCodeCreateParamsPromotion as PromotionCodeCreateParamsPromotion,
        PromotionCodeCreateParamsRestrictions as PromotionCodeCreateParamsRestrictions,
        PromotionCodeCreateParamsRestrictionsCurrencyOptions as PromotionCodeCreateParamsRestrictionsCurrencyOptions,
    )
    from stripe.params._promotion_code_list_params import (
        PromotionCodeListParams as PromotionCodeListParams,
        PromotionCodeListParamsCreated as PromotionCodeListParamsCreated,
    )
    from stripe.params._promotion_code_modify_params import (
        PromotionCodeModifyParams as PromotionCodeModifyParams,
        PromotionCodeModifyParamsRestrictions as PromotionCodeModifyParamsRestrictions,
        PromotionCodeModifyParamsRestrictionsCurrencyOptions as PromotionCodeModifyParamsRestrictionsCurrencyOptions,
    )
    from stripe.params._promotion_code_retrieve_params import (
        PromotionCodeRetrieveParams as PromotionCodeRetrieveParams,
    )
    from stripe.params._promotion_code_update_params import (
        PromotionCodeUpdateParams as PromotionCodeUpdateParams,
        PromotionCodeUpdateParamsRestrictions as PromotionCodeUpdateParamsRestrictions,
        PromotionCodeUpdateParamsRestrictionsCurrencyOptions as PromotionCodeUpdateParamsRestrictionsCurrencyOptions,
    )
    from stripe.params._quote_accept_params import (
        QuoteAcceptParams as QuoteAcceptParams,
    )
    from stripe.params._quote_cancel_params import (
        QuoteCancelParams as QuoteCancelParams,
    )
    from stripe.params._quote_computed_upfront_line_items_list_params import (
        QuoteComputedUpfrontLineItemsListParams as QuoteComputedUpfrontLineItemsListParams,
    )
    from stripe.params._quote_create_params import (
        QuoteCreateParams as QuoteCreateParams,
        QuoteCreateParamsAutomaticTax as QuoteCreateParamsAutomaticTax,
        QuoteCreateParamsAutomaticTaxLiability as QuoteCreateParamsAutomaticTaxLiability,
        QuoteCreateParamsDiscount as QuoteCreateParamsDiscount,
        QuoteCreateParamsDiscountDiscountEnd as QuoteCreateParamsDiscountDiscountEnd,
        QuoteCreateParamsDiscountDiscountEndDuration as QuoteCreateParamsDiscountDiscountEndDuration,
        QuoteCreateParamsFromQuote as QuoteCreateParamsFromQuote,
        QuoteCreateParamsInvoiceSettings as QuoteCreateParamsInvoiceSettings,
        QuoteCreateParamsInvoiceSettingsIssuer as QuoteCreateParamsInvoiceSettingsIssuer,
        QuoteCreateParamsLine as QuoteCreateParamsLine,
        QuoteCreateParamsLineAction as QuoteCreateParamsLineAction,
        QuoteCreateParamsLineActionAddDiscount as QuoteCreateParamsLineActionAddDiscount,
        QuoteCreateParamsLineActionAddDiscountDiscountEnd as QuoteCreateParamsLineActionAddDiscountDiscountEnd,
        QuoteCreateParamsLineActionAddItem as QuoteCreateParamsLineActionAddItem,
        QuoteCreateParamsLineActionAddItemDiscount as QuoteCreateParamsLineActionAddItemDiscount,
        QuoteCreateParamsLineActionAddItemDiscountDiscountEnd as QuoteCreateParamsLineActionAddItemDiscountDiscountEnd,
        QuoteCreateParamsLineActionAddItemDiscountDiscountEndDuration as QuoteCreateParamsLineActionAddItemDiscountDiscountEndDuration,
        QuoteCreateParamsLineActionAddItemTrial as QuoteCreateParamsLineActionAddItemTrial,
        QuoteCreateParamsLineActionRemoveDiscount as QuoteCreateParamsLineActionRemoveDiscount,
        QuoteCreateParamsLineActionRemoveItem as QuoteCreateParamsLineActionRemoveItem,
        QuoteCreateParamsLineActionSetDiscount as QuoteCreateParamsLineActionSetDiscount,
        QuoteCreateParamsLineActionSetItem as QuoteCreateParamsLineActionSetItem,
        QuoteCreateParamsLineActionSetItemDiscount as QuoteCreateParamsLineActionSetItemDiscount,
        QuoteCreateParamsLineActionSetItemDiscountDiscountEnd as QuoteCreateParamsLineActionSetItemDiscountDiscountEnd,
        QuoteCreateParamsLineActionSetItemDiscountDiscountEndDuration as QuoteCreateParamsLineActionSetItemDiscountDiscountEndDuration,
        QuoteCreateParamsLineActionSetItemTrial as QuoteCreateParamsLineActionSetItemTrial,
        QuoteCreateParamsLineAppliesTo as QuoteCreateParamsLineAppliesTo,
        QuoteCreateParamsLineCancelSubscriptionSchedule as QuoteCreateParamsLineCancelSubscriptionSchedule,
        QuoteCreateParamsLineEndsAt as QuoteCreateParamsLineEndsAt,
        QuoteCreateParamsLineEndsAtDiscountEnd as QuoteCreateParamsLineEndsAtDiscountEnd,
        QuoteCreateParamsLineEndsAtDuration as QuoteCreateParamsLineEndsAtDuration,
        QuoteCreateParamsLineItem as QuoteCreateParamsLineItem,
        QuoteCreateParamsLineItemDiscount as QuoteCreateParamsLineItemDiscount,
        QuoteCreateParamsLineItemDiscountDiscountEnd as QuoteCreateParamsLineItemDiscountDiscountEnd,
        QuoteCreateParamsLineItemDiscountDiscountEndDuration as QuoteCreateParamsLineItemDiscountDiscountEndDuration,
        QuoteCreateParamsLineItemPriceData as QuoteCreateParamsLineItemPriceData,
        QuoteCreateParamsLineItemPriceDataRecurring as QuoteCreateParamsLineItemPriceDataRecurring,
        QuoteCreateParamsLineSetPauseCollection as QuoteCreateParamsLineSetPauseCollection,
        QuoteCreateParamsLineSetPauseCollectionSet as QuoteCreateParamsLineSetPauseCollectionSet,
        QuoteCreateParamsLineStartsAt as QuoteCreateParamsLineStartsAt,
        QuoteCreateParamsLineStartsAtDiscountEnd as QuoteCreateParamsLineStartsAtDiscountEnd,
        QuoteCreateParamsLineStartsAtLineEndsAt as QuoteCreateParamsLineStartsAtLineEndsAt,
        QuoteCreateParamsLineTrialSettings as QuoteCreateParamsLineTrialSettings,
        QuoteCreateParamsLineTrialSettingsEndBehavior as QuoteCreateParamsLineTrialSettingsEndBehavior,
        QuoteCreateParamsSubscriptionData as QuoteCreateParamsSubscriptionData,
        QuoteCreateParamsSubscriptionDataBillOnAcceptance as QuoteCreateParamsSubscriptionDataBillOnAcceptance,
        QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFrom as QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFrom,
        QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt as QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt,
        QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntil as QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntil,
        QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration as QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration,
        QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt as QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt,
        QuoteCreateParamsSubscriptionDataBillingMode as QuoteCreateParamsSubscriptionDataBillingMode,
        QuoteCreateParamsSubscriptionDataBillingModeFlexible as QuoteCreateParamsSubscriptionDataBillingModeFlexible,
        QuoteCreateParamsSubscriptionDataBillingSchedule as QuoteCreateParamsSubscriptionDataBillingSchedule,
        QuoteCreateParamsSubscriptionDataBillingScheduleAppliesTo as QuoteCreateParamsSubscriptionDataBillingScheduleAppliesTo,
        QuoteCreateParamsSubscriptionDataBillingScheduleBillFrom as QuoteCreateParamsSubscriptionDataBillingScheduleBillFrom,
        QuoteCreateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt as QuoteCreateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt,
        QuoteCreateParamsSubscriptionDataBillingScheduleBillUntil as QuoteCreateParamsSubscriptionDataBillingScheduleBillUntil,
        QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilDuration as QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilDuration,
        QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt as QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt,
        QuoteCreateParamsSubscriptionDataOverride as QuoteCreateParamsSubscriptionDataOverride,
        QuoteCreateParamsSubscriptionDataOverrideAppliesTo as QuoteCreateParamsSubscriptionDataOverrideAppliesTo,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptance as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptance,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration,
        QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt as QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt,
        QuoteCreateParamsSubscriptionDataOverrideBillingSchedule as QuoteCreateParamsSubscriptionDataOverrideBillingSchedule,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleAppliesTo as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleAppliesTo,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFrom as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFrom,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntil as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntil,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration,
        QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt as QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt,
        QuoteCreateParamsSubscriptionDataPrebilling as QuoteCreateParamsSubscriptionDataPrebilling,
        QuoteCreateParamsTransferData as QuoteCreateParamsTransferData,
    )
    from stripe.params._quote_finalize_quote_params import (
        QuoteFinalizeQuoteParams as QuoteFinalizeQuoteParams,
    )
    from stripe.params._quote_line_item_list_params import (
        QuoteLineItemListParams as QuoteLineItemListParams,
    )
    from stripe.params._quote_line_list_params import (
        QuoteLineListParams as QuoteLineListParams,
    )
    from stripe.params._quote_list_computed_upfront_line_items_params import (
        QuoteListComputedUpfrontLineItemsParams as QuoteListComputedUpfrontLineItemsParams,
    )
    from stripe.params._quote_list_line_items_params import (
        QuoteListLineItemsParams as QuoteListLineItemsParams,
    )
    from stripe.params._quote_list_lines_params import (
        QuoteListLinesParams as QuoteListLinesParams,
    )
    from stripe.params._quote_list_params import (
        QuoteListParams as QuoteListParams,
    )
    from stripe.params._quote_list_preview_invoice_lines_params import (
        QuoteListPreviewInvoiceLinesParams as QuoteListPreviewInvoiceLinesParams,
    )
    from stripe.params._quote_list_preview_invoices_params import (
        QuoteListPreviewInvoicesParams as QuoteListPreviewInvoicesParams,
    )
    from stripe.params._quote_list_preview_subscription_schedules_params import (
        QuoteListPreviewSubscriptionSchedulesParams as QuoteListPreviewSubscriptionSchedulesParams,
    )
    from stripe.params._quote_mark_draft_params import (
        QuoteMarkDraftParams as QuoteMarkDraftParams,
    )
    from stripe.params._quote_mark_stale_params import (
        QuoteMarkStaleParams as QuoteMarkStaleParams,
    )
    from stripe.params._quote_modify_params import (
        QuoteModifyParams as QuoteModifyParams,
        QuoteModifyParamsAutomaticTax as QuoteModifyParamsAutomaticTax,
        QuoteModifyParamsAutomaticTaxLiability as QuoteModifyParamsAutomaticTaxLiability,
        QuoteModifyParamsDiscount as QuoteModifyParamsDiscount,
        QuoteModifyParamsDiscountDiscountEnd as QuoteModifyParamsDiscountDiscountEnd,
        QuoteModifyParamsDiscountDiscountEndDuration as QuoteModifyParamsDiscountDiscountEndDuration,
        QuoteModifyParamsInvoiceSettings as QuoteModifyParamsInvoiceSettings,
        QuoteModifyParamsInvoiceSettingsIssuer as QuoteModifyParamsInvoiceSettingsIssuer,
        QuoteModifyParamsLine as QuoteModifyParamsLine,
        QuoteModifyParamsLineAction as QuoteModifyParamsLineAction,
        QuoteModifyParamsLineActionAddDiscount as QuoteModifyParamsLineActionAddDiscount,
        QuoteModifyParamsLineActionAddDiscountDiscountEnd as QuoteModifyParamsLineActionAddDiscountDiscountEnd,
        QuoteModifyParamsLineActionAddItem as QuoteModifyParamsLineActionAddItem,
        QuoteModifyParamsLineActionAddItemDiscount as QuoteModifyParamsLineActionAddItemDiscount,
        QuoteModifyParamsLineActionAddItemDiscountDiscountEnd as QuoteModifyParamsLineActionAddItemDiscountDiscountEnd,
        QuoteModifyParamsLineActionAddItemDiscountDiscountEndDuration as QuoteModifyParamsLineActionAddItemDiscountDiscountEndDuration,
        QuoteModifyParamsLineActionAddItemTrial as QuoteModifyParamsLineActionAddItemTrial,
        QuoteModifyParamsLineActionRemoveDiscount as QuoteModifyParamsLineActionRemoveDiscount,
        QuoteModifyParamsLineActionRemoveItem as QuoteModifyParamsLineActionRemoveItem,
        QuoteModifyParamsLineActionSetDiscount as QuoteModifyParamsLineActionSetDiscount,
        QuoteModifyParamsLineActionSetItem as QuoteModifyParamsLineActionSetItem,
        QuoteModifyParamsLineActionSetItemDiscount as QuoteModifyParamsLineActionSetItemDiscount,
        QuoteModifyParamsLineActionSetItemDiscountDiscountEnd as QuoteModifyParamsLineActionSetItemDiscountDiscountEnd,
        QuoteModifyParamsLineActionSetItemDiscountDiscountEndDuration as QuoteModifyParamsLineActionSetItemDiscountDiscountEndDuration,
        QuoteModifyParamsLineActionSetItemTrial as QuoteModifyParamsLineActionSetItemTrial,
        QuoteModifyParamsLineAppliesTo as QuoteModifyParamsLineAppliesTo,
        QuoteModifyParamsLineCancelSubscriptionSchedule as QuoteModifyParamsLineCancelSubscriptionSchedule,
        QuoteModifyParamsLineEndsAt as QuoteModifyParamsLineEndsAt,
        QuoteModifyParamsLineEndsAtDiscountEnd as QuoteModifyParamsLineEndsAtDiscountEnd,
        QuoteModifyParamsLineEndsAtDuration as QuoteModifyParamsLineEndsAtDuration,
        QuoteModifyParamsLineItem as QuoteModifyParamsLineItem,
        QuoteModifyParamsLineItemDiscount as QuoteModifyParamsLineItemDiscount,
        QuoteModifyParamsLineItemDiscountDiscountEnd as QuoteModifyParamsLineItemDiscountDiscountEnd,
        QuoteModifyParamsLineItemDiscountDiscountEndDuration as QuoteModifyParamsLineItemDiscountDiscountEndDuration,
        QuoteModifyParamsLineItemPriceData as QuoteModifyParamsLineItemPriceData,
        QuoteModifyParamsLineItemPriceDataRecurring as QuoteModifyParamsLineItemPriceDataRecurring,
        QuoteModifyParamsLineSetPauseCollection as QuoteModifyParamsLineSetPauseCollection,
        QuoteModifyParamsLineSetPauseCollectionSet as QuoteModifyParamsLineSetPauseCollectionSet,
        QuoteModifyParamsLineStartsAt as QuoteModifyParamsLineStartsAt,
        QuoteModifyParamsLineStartsAtDiscountEnd as QuoteModifyParamsLineStartsAtDiscountEnd,
        QuoteModifyParamsLineStartsAtLineEndsAt as QuoteModifyParamsLineStartsAtLineEndsAt,
        QuoteModifyParamsLineTrialSettings as QuoteModifyParamsLineTrialSettings,
        QuoteModifyParamsLineTrialSettingsEndBehavior as QuoteModifyParamsLineTrialSettingsEndBehavior,
        QuoteModifyParamsSubscriptionData as QuoteModifyParamsSubscriptionData,
        QuoteModifyParamsSubscriptionDataBillOnAcceptance as QuoteModifyParamsSubscriptionDataBillOnAcceptance,
        QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFrom as QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFrom,
        QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt as QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt,
        QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntil as QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntil,
        QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilDuration as QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilDuration,
        QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt as QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt,
        QuoteModifyParamsSubscriptionDataBillingSchedule as QuoteModifyParamsSubscriptionDataBillingSchedule,
        QuoteModifyParamsSubscriptionDataBillingScheduleAppliesTo as QuoteModifyParamsSubscriptionDataBillingScheduleAppliesTo,
        QuoteModifyParamsSubscriptionDataBillingScheduleBillFrom as QuoteModifyParamsSubscriptionDataBillingScheduleBillFrom,
        QuoteModifyParamsSubscriptionDataBillingScheduleBillFromLineStartsAt as QuoteModifyParamsSubscriptionDataBillingScheduleBillFromLineStartsAt,
        QuoteModifyParamsSubscriptionDataBillingScheduleBillUntil as QuoteModifyParamsSubscriptionDataBillingScheduleBillUntil,
        QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilDuration as QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilDuration,
        QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt as QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt,
        QuoteModifyParamsSubscriptionDataOverride as QuoteModifyParamsSubscriptionDataOverride,
        QuoteModifyParamsSubscriptionDataOverrideAppliesTo as QuoteModifyParamsSubscriptionDataOverrideAppliesTo,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptance as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptance,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration,
        QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt as QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt,
        QuoteModifyParamsSubscriptionDataOverrideBillingSchedule as QuoteModifyParamsSubscriptionDataOverrideBillingSchedule,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleAppliesTo as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleAppliesTo,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFrom as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFrom,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntil as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntil,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration,
        QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt as QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt,
        QuoteModifyParamsSubscriptionDataPrebilling as QuoteModifyParamsSubscriptionDataPrebilling,
        QuoteModifyParamsTransferData as QuoteModifyParamsTransferData,
    )
    from stripe.params._quote_pdf_params import (
        QuotePdfParams as QuotePdfParams,
    )
    from stripe.params._quote_preview_invoice_list_params import (
        QuotePreviewInvoiceListParams as QuotePreviewInvoiceListParams,
    )
    from stripe.params._quote_preview_subscription_schedule_list_params import (
        QuotePreviewSubscriptionScheduleListParams as QuotePreviewSubscriptionScheduleListParams,
    )
    from stripe.params._quote_reestimate_params import (
        QuoteReestimateParams as QuoteReestimateParams,
    )
    from stripe.params._quote_retrieve_params import (
        QuoteRetrieveParams as QuoteRetrieveParams,
    )
    from stripe.params._quote_update_params import (
        QuoteUpdateParams as QuoteUpdateParams,
        QuoteUpdateParamsAutomaticTax as QuoteUpdateParamsAutomaticTax,
        QuoteUpdateParamsAutomaticTaxLiability as QuoteUpdateParamsAutomaticTaxLiability,
        QuoteUpdateParamsDiscount as QuoteUpdateParamsDiscount,
        QuoteUpdateParamsDiscountDiscountEnd as QuoteUpdateParamsDiscountDiscountEnd,
        QuoteUpdateParamsDiscountDiscountEndDuration as QuoteUpdateParamsDiscountDiscountEndDuration,
        QuoteUpdateParamsInvoiceSettings as QuoteUpdateParamsInvoiceSettings,
        QuoteUpdateParamsInvoiceSettingsIssuer as QuoteUpdateParamsInvoiceSettingsIssuer,
        QuoteUpdateParamsLine as QuoteUpdateParamsLine,
        QuoteUpdateParamsLineAction as QuoteUpdateParamsLineAction,
        QuoteUpdateParamsLineActionAddDiscount as QuoteUpdateParamsLineActionAddDiscount,
        QuoteUpdateParamsLineActionAddDiscountDiscountEnd as QuoteUpdateParamsLineActionAddDiscountDiscountEnd,
        QuoteUpdateParamsLineActionAddItem as QuoteUpdateParamsLineActionAddItem,
        QuoteUpdateParamsLineActionAddItemDiscount as QuoteUpdateParamsLineActionAddItemDiscount,
        QuoteUpdateParamsLineActionAddItemDiscountDiscountEnd as QuoteUpdateParamsLineActionAddItemDiscountDiscountEnd,
        QuoteUpdateParamsLineActionAddItemDiscountDiscountEndDuration as QuoteUpdateParamsLineActionAddItemDiscountDiscountEndDuration,
        QuoteUpdateParamsLineActionAddItemTrial as QuoteUpdateParamsLineActionAddItemTrial,
        QuoteUpdateParamsLineActionRemoveDiscount as QuoteUpdateParamsLineActionRemoveDiscount,
        QuoteUpdateParamsLineActionRemoveItem as QuoteUpdateParamsLineActionRemoveItem,
        QuoteUpdateParamsLineActionSetDiscount as QuoteUpdateParamsLineActionSetDiscount,
        QuoteUpdateParamsLineActionSetItem as QuoteUpdateParamsLineActionSetItem,
        QuoteUpdateParamsLineActionSetItemDiscount as QuoteUpdateParamsLineActionSetItemDiscount,
        QuoteUpdateParamsLineActionSetItemDiscountDiscountEnd as QuoteUpdateParamsLineActionSetItemDiscountDiscountEnd,
        QuoteUpdateParamsLineActionSetItemDiscountDiscountEndDuration as QuoteUpdateParamsLineActionSetItemDiscountDiscountEndDuration,
        QuoteUpdateParamsLineActionSetItemTrial as QuoteUpdateParamsLineActionSetItemTrial,
        QuoteUpdateParamsLineAppliesTo as QuoteUpdateParamsLineAppliesTo,
        QuoteUpdateParamsLineCancelSubscriptionSchedule as QuoteUpdateParamsLineCancelSubscriptionSchedule,
        QuoteUpdateParamsLineEndsAt as QuoteUpdateParamsLineEndsAt,
        QuoteUpdateParamsLineEndsAtDiscountEnd as QuoteUpdateParamsLineEndsAtDiscountEnd,
        QuoteUpdateParamsLineEndsAtDuration as QuoteUpdateParamsLineEndsAtDuration,
        QuoteUpdateParamsLineItem as QuoteUpdateParamsLineItem,
        QuoteUpdateParamsLineItemDiscount as QuoteUpdateParamsLineItemDiscount,
        QuoteUpdateParamsLineItemDiscountDiscountEnd as QuoteUpdateParamsLineItemDiscountDiscountEnd,
        QuoteUpdateParamsLineItemDiscountDiscountEndDuration as QuoteUpdateParamsLineItemDiscountDiscountEndDuration,
        QuoteUpdateParamsLineItemPriceData as QuoteUpdateParamsLineItemPriceData,
        QuoteUpdateParamsLineItemPriceDataRecurring as QuoteUpdateParamsLineItemPriceDataRecurring,
        QuoteUpdateParamsLineSetPauseCollection as QuoteUpdateParamsLineSetPauseCollection,
        QuoteUpdateParamsLineSetPauseCollectionSet as QuoteUpdateParamsLineSetPauseCollectionSet,
        QuoteUpdateParamsLineStartsAt as QuoteUpdateParamsLineStartsAt,
        QuoteUpdateParamsLineStartsAtDiscountEnd as QuoteUpdateParamsLineStartsAtDiscountEnd,
        QuoteUpdateParamsLineStartsAtLineEndsAt as QuoteUpdateParamsLineStartsAtLineEndsAt,
        QuoteUpdateParamsLineTrialSettings as QuoteUpdateParamsLineTrialSettings,
        QuoteUpdateParamsLineTrialSettingsEndBehavior as QuoteUpdateParamsLineTrialSettingsEndBehavior,
        QuoteUpdateParamsSubscriptionData as QuoteUpdateParamsSubscriptionData,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptance as QuoteUpdateParamsSubscriptionDataBillOnAcceptance,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFrom as QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFrom,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt as QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntil as QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntil,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration as QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration,
        QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt as QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt,
        QuoteUpdateParamsSubscriptionDataBillingSchedule as QuoteUpdateParamsSubscriptionDataBillingSchedule,
        QuoteUpdateParamsSubscriptionDataBillingScheduleAppliesTo as QuoteUpdateParamsSubscriptionDataBillingScheduleAppliesTo,
        QuoteUpdateParamsSubscriptionDataBillingScheduleBillFrom as QuoteUpdateParamsSubscriptionDataBillingScheduleBillFrom,
        QuoteUpdateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt as QuoteUpdateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt,
        QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntil as QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntil,
        QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilDuration as QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilDuration,
        QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt as QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt,
        QuoteUpdateParamsSubscriptionDataOverride as QuoteUpdateParamsSubscriptionDataOverride,
        QuoteUpdateParamsSubscriptionDataOverrideAppliesTo as QuoteUpdateParamsSubscriptionDataOverrideAppliesTo,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptance as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptance,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration,
        QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt as QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt,
        QuoteUpdateParamsSubscriptionDataOverrideBillingSchedule as QuoteUpdateParamsSubscriptionDataOverrideBillingSchedule,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleAppliesTo as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleAppliesTo,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFrom as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFrom,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntil as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntil,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration,
        QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt as QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt,
        QuoteUpdateParamsSubscriptionDataPrebilling as QuoteUpdateParamsSubscriptionDataPrebilling,
        QuoteUpdateParamsTransferData as QuoteUpdateParamsTransferData,
    )
    from stripe.params._refund_cancel_params import (
        RefundCancelParams as RefundCancelParams,
    )
    from stripe.params._refund_create_params import (
        RefundCreateParams as RefundCreateParams,
    )
    from stripe.params._refund_expire_params import (
        RefundExpireParams as RefundExpireParams,
    )
    from stripe.params._refund_list_params import (
        RefundListParams as RefundListParams,
        RefundListParamsCreated as RefundListParamsCreated,
    )
    from stripe.params._refund_modify_params import (
        RefundModifyParams as RefundModifyParams,
    )
    from stripe.params._refund_retrieve_params import (
        RefundRetrieveParams as RefundRetrieveParams,
    )
    from stripe.params._refund_update_params import (
        RefundUpdateParams as RefundUpdateParams,
    )
    from stripe.params._review_approve_params import (
        ReviewApproveParams as ReviewApproveParams,
    )
    from stripe.params._review_list_params import (
        ReviewListParams as ReviewListParams,
        ReviewListParamsCreated as ReviewListParamsCreated,
    )
    from stripe.params._review_retrieve_params import (
        ReviewRetrieveParams as ReviewRetrieveParams,
    )
    from stripe.params._setup_attempt_list_params import (
        SetupAttemptListParams as SetupAttemptListParams,
        SetupAttemptListParamsCreated as SetupAttemptListParamsCreated,
    )
    from stripe.params._setup_intent_cancel_params import (
        SetupIntentCancelParams as SetupIntentCancelParams,
    )
    from stripe.params._setup_intent_confirm_params import (
        SetupIntentConfirmParams as SetupIntentConfirmParams,
        SetupIntentConfirmParamsMandateData as SetupIntentConfirmParamsMandateData,
        SetupIntentConfirmParamsMandateDataCustomerAcceptance as SetupIntentConfirmParamsMandateDataCustomerAcceptance,
        SetupIntentConfirmParamsMandateDataCustomerAcceptanceOffline as SetupIntentConfirmParamsMandateDataCustomerAcceptanceOffline,
        SetupIntentConfirmParamsMandateDataCustomerAcceptanceOnline as SetupIntentConfirmParamsMandateDataCustomerAcceptanceOnline,
        SetupIntentConfirmParamsPaymentMethodData as SetupIntentConfirmParamsPaymentMethodData,
        SetupIntentConfirmParamsPaymentMethodDataAcssDebit as SetupIntentConfirmParamsPaymentMethodDataAcssDebit,
        SetupIntentConfirmParamsPaymentMethodDataAffirm as SetupIntentConfirmParamsPaymentMethodDataAffirm,
        SetupIntentConfirmParamsPaymentMethodDataAfterpayClearpay as SetupIntentConfirmParamsPaymentMethodDataAfterpayClearpay,
        SetupIntentConfirmParamsPaymentMethodDataAlipay as SetupIntentConfirmParamsPaymentMethodDataAlipay,
        SetupIntentConfirmParamsPaymentMethodDataAlma as SetupIntentConfirmParamsPaymentMethodDataAlma,
        SetupIntentConfirmParamsPaymentMethodDataAmazonPay as SetupIntentConfirmParamsPaymentMethodDataAmazonPay,
        SetupIntentConfirmParamsPaymentMethodDataAuBecsDebit as SetupIntentConfirmParamsPaymentMethodDataAuBecsDebit,
        SetupIntentConfirmParamsPaymentMethodDataBacsDebit as SetupIntentConfirmParamsPaymentMethodDataBacsDebit,
        SetupIntentConfirmParamsPaymentMethodDataBancontact as SetupIntentConfirmParamsPaymentMethodDataBancontact,
        SetupIntentConfirmParamsPaymentMethodDataBillie as SetupIntentConfirmParamsPaymentMethodDataBillie,
        SetupIntentConfirmParamsPaymentMethodDataBillingDetails as SetupIntentConfirmParamsPaymentMethodDataBillingDetails,
        SetupIntentConfirmParamsPaymentMethodDataBillingDetailsAddress as SetupIntentConfirmParamsPaymentMethodDataBillingDetailsAddress,
        SetupIntentConfirmParamsPaymentMethodDataBlik as SetupIntentConfirmParamsPaymentMethodDataBlik,
        SetupIntentConfirmParamsPaymentMethodDataBoleto as SetupIntentConfirmParamsPaymentMethodDataBoleto,
        SetupIntentConfirmParamsPaymentMethodDataCashapp as SetupIntentConfirmParamsPaymentMethodDataCashapp,
        SetupIntentConfirmParamsPaymentMethodDataCrypto as SetupIntentConfirmParamsPaymentMethodDataCrypto,
        SetupIntentConfirmParamsPaymentMethodDataCustomerBalance as SetupIntentConfirmParamsPaymentMethodDataCustomerBalance,
        SetupIntentConfirmParamsPaymentMethodDataEps as SetupIntentConfirmParamsPaymentMethodDataEps,
        SetupIntentConfirmParamsPaymentMethodDataFpx as SetupIntentConfirmParamsPaymentMethodDataFpx,
        SetupIntentConfirmParamsPaymentMethodDataGiropay as SetupIntentConfirmParamsPaymentMethodDataGiropay,
        SetupIntentConfirmParamsPaymentMethodDataGopay as SetupIntentConfirmParamsPaymentMethodDataGopay,
        SetupIntentConfirmParamsPaymentMethodDataGrabpay as SetupIntentConfirmParamsPaymentMethodDataGrabpay,
        SetupIntentConfirmParamsPaymentMethodDataIdBankTransfer as SetupIntentConfirmParamsPaymentMethodDataIdBankTransfer,
        SetupIntentConfirmParamsPaymentMethodDataIdeal as SetupIntentConfirmParamsPaymentMethodDataIdeal,
        SetupIntentConfirmParamsPaymentMethodDataInteracPresent as SetupIntentConfirmParamsPaymentMethodDataInteracPresent,
        SetupIntentConfirmParamsPaymentMethodDataKakaoPay as SetupIntentConfirmParamsPaymentMethodDataKakaoPay,
        SetupIntentConfirmParamsPaymentMethodDataKlarna as SetupIntentConfirmParamsPaymentMethodDataKlarna,
        SetupIntentConfirmParamsPaymentMethodDataKlarnaDob as SetupIntentConfirmParamsPaymentMethodDataKlarnaDob,
        SetupIntentConfirmParamsPaymentMethodDataKonbini as SetupIntentConfirmParamsPaymentMethodDataKonbini,
        SetupIntentConfirmParamsPaymentMethodDataKrCard as SetupIntentConfirmParamsPaymentMethodDataKrCard,
        SetupIntentConfirmParamsPaymentMethodDataLink as SetupIntentConfirmParamsPaymentMethodDataLink,
        SetupIntentConfirmParamsPaymentMethodDataMbWay as SetupIntentConfirmParamsPaymentMethodDataMbWay,
        SetupIntentConfirmParamsPaymentMethodDataMobilepay as SetupIntentConfirmParamsPaymentMethodDataMobilepay,
        SetupIntentConfirmParamsPaymentMethodDataMultibanco as SetupIntentConfirmParamsPaymentMethodDataMultibanco,
        SetupIntentConfirmParamsPaymentMethodDataNaverPay as SetupIntentConfirmParamsPaymentMethodDataNaverPay,
        SetupIntentConfirmParamsPaymentMethodDataNzBankAccount as SetupIntentConfirmParamsPaymentMethodDataNzBankAccount,
        SetupIntentConfirmParamsPaymentMethodDataOxxo as SetupIntentConfirmParamsPaymentMethodDataOxxo,
        SetupIntentConfirmParamsPaymentMethodDataP24 as SetupIntentConfirmParamsPaymentMethodDataP24,
        SetupIntentConfirmParamsPaymentMethodDataPayByBank as SetupIntentConfirmParamsPaymentMethodDataPayByBank,
        SetupIntentConfirmParamsPaymentMethodDataPayco as SetupIntentConfirmParamsPaymentMethodDataPayco,
        SetupIntentConfirmParamsPaymentMethodDataPaynow as SetupIntentConfirmParamsPaymentMethodDataPaynow,
        SetupIntentConfirmParamsPaymentMethodDataPaypal as SetupIntentConfirmParamsPaymentMethodDataPaypal,
        SetupIntentConfirmParamsPaymentMethodDataPaypay as SetupIntentConfirmParamsPaymentMethodDataPaypay,
        SetupIntentConfirmParamsPaymentMethodDataPayto as SetupIntentConfirmParamsPaymentMethodDataPayto,
        SetupIntentConfirmParamsPaymentMethodDataPix as SetupIntentConfirmParamsPaymentMethodDataPix,
        SetupIntentConfirmParamsPaymentMethodDataPromptpay as SetupIntentConfirmParamsPaymentMethodDataPromptpay,
        SetupIntentConfirmParamsPaymentMethodDataQris as SetupIntentConfirmParamsPaymentMethodDataQris,
        SetupIntentConfirmParamsPaymentMethodDataRadarOptions as SetupIntentConfirmParamsPaymentMethodDataRadarOptions,
        SetupIntentConfirmParamsPaymentMethodDataRechnung as SetupIntentConfirmParamsPaymentMethodDataRechnung,
        SetupIntentConfirmParamsPaymentMethodDataRechnungDob as SetupIntentConfirmParamsPaymentMethodDataRechnungDob,
        SetupIntentConfirmParamsPaymentMethodDataRevolutPay as SetupIntentConfirmParamsPaymentMethodDataRevolutPay,
        SetupIntentConfirmParamsPaymentMethodDataSamsungPay as SetupIntentConfirmParamsPaymentMethodDataSamsungPay,
        SetupIntentConfirmParamsPaymentMethodDataSatispay as SetupIntentConfirmParamsPaymentMethodDataSatispay,
        SetupIntentConfirmParamsPaymentMethodDataSepaDebit as SetupIntentConfirmParamsPaymentMethodDataSepaDebit,
        SetupIntentConfirmParamsPaymentMethodDataShopeepay as SetupIntentConfirmParamsPaymentMethodDataShopeepay,
        SetupIntentConfirmParamsPaymentMethodDataSofort as SetupIntentConfirmParamsPaymentMethodDataSofort,
        SetupIntentConfirmParamsPaymentMethodDataStripeBalance as SetupIntentConfirmParamsPaymentMethodDataStripeBalance,
        SetupIntentConfirmParamsPaymentMethodDataSwish as SetupIntentConfirmParamsPaymentMethodDataSwish,
        SetupIntentConfirmParamsPaymentMethodDataTwint as SetupIntentConfirmParamsPaymentMethodDataTwint,
        SetupIntentConfirmParamsPaymentMethodDataUsBankAccount as SetupIntentConfirmParamsPaymentMethodDataUsBankAccount,
        SetupIntentConfirmParamsPaymentMethodDataWechatPay as SetupIntentConfirmParamsPaymentMethodDataWechatPay,
        SetupIntentConfirmParamsPaymentMethodDataZip as SetupIntentConfirmParamsPaymentMethodDataZip,
        SetupIntentConfirmParamsPaymentMethodOptions as SetupIntentConfirmParamsPaymentMethodOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsAcssDebit as SetupIntentConfirmParamsPaymentMethodOptionsAcssDebit,
        SetupIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsAmazonPay as SetupIntentConfirmParamsPaymentMethodOptionsAmazonPay,
        SetupIntentConfirmParamsPaymentMethodOptionsBacsDebit as SetupIntentConfirmParamsPaymentMethodOptionsBacsDebit,
        SetupIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsCard as SetupIntentConfirmParamsPaymentMethodOptionsCard,
        SetupIntentConfirmParamsPaymentMethodOptionsCardMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsCardMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsCardPresent as SetupIntentConfirmParamsPaymentMethodOptionsCardPresent,
        SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure as SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure,
        SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        SetupIntentConfirmParamsPaymentMethodOptionsKlarna as SetupIntentConfirmParamsPaymentMethodOptionsKlarna,
        SetupIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand as SetupIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand,
        SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription as SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription,
        SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SetupIntentConfirmParamsPaymentMethodOptionsLink as SetupIntentConfirmParamsPaymentMethodOptionsLink,
        SetupIntentConfirmParamsPaymentMethodOptionsPaypal as SetupIntentConfirmParamsPaymentMethodOptionsPaypal,
        SetupIntentConfirmParamsPaymentMethodOptionsPayto as SetupIntentConfirmParamsPaymentMethodOptionsPayto,
        SetupIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsPix as SetupIntentConfirmParamsPaymentMethodOptionsPix,
        SetupIntentConfirmParamsPaymentMethodOptionsPixMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsPixMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsSepaDebit as SetupIntentConfirmParamsPaymentMethodOptionsSepaDebit,
        SetupIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccount as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccount,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks as SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks,
        SetupIntentConfirmParamsSetupDetails as SetupIntentConfirmParamsSetupDetails,
        SetupIntentConfirmParamsSetupDetailsBenefit as SetupIntentConfirmParamsSetupDetailsBenefit,
        SetupIntentConfirmParamsSetupDetailsBenefitFrMealVoucher as SetupIntentConfirmParamsSetupDetailsBenefitFrMealVoucher,
    )
    from stripe.params._setup_intent_create_params import (
        SetupIntentCreateParams as SetupIntentCreateParams,
        SetupIntentCreateParamsAutomaticPaymentMethods as SetupIntentCreateParamsAutomaticPaymentMethods,
        SetupIntentCreateParamsMandateData as SetupIntentCreateParamsMandateData,
        SetupIntentCreateParamsMandateDataCustomerAcceptance as SetupIntentCreateParamsMandateDataCustomerAcceptance,
        SetupIntentCreateParamsMandateDataCustomerAcceptanceOffline as SetupIntentCreateParamsMandateDataCustomerAcceptanceOffline,
        SetupIntentCreateParamsMandateDataCustomerAcceptanceOnline as SetupIntentCreateParamsMandateDataCustomerAcceptanceOnline,
        SetupIntentCreateParamsPaymentMethodData as SetupIntentCreateParamsPaymentMethodData,
        SetupIntentCreateParamsPaymentMethodDataAcssDebit as SetupIntentCreateParamsPaymentMethodDataAcssDebit,
        SetupIntentCreateParamsPaymentMethodDataAffirm as SetupIntentCreateParamsPaymentMethodDataAffirm,
        SetupIntentCreateParamsPaymentMethodDataAfterpayClearpay as SetupIntentCreateParamsPaymentMethodDataAfterpayClearpay,
        SetupIntentCreateParamsPaymentMethodDataAlipay as SetupIntentCreateParamsPaymentMethodDataAlipay,
        SetupIntentCreateParamsPaymentMethodDataAlma as SetupIntentCreateParamsPaymentMethodDataAlma,
        SetupIntentCreateParamsPaymentMethodDataAmazonPay as SetupIntentCreateParamsPaymentMethodDataAmazonPay,
        SetupIntentCreateParamsPaymentMethodDataAuBecsDebit as SetupIntentCreateParamsPaymentMethodDataAuBecsDebit,
        SetupIntentCreateParamsPaymentMethodDataBacsDebit as SetupIntentCreateParamsPaymentMethodDataBacsDebit,
        SetupIntentCreateParamsPaymentMethodDataBancontact as SetupIntentCreateParamsPaymentMethodDataBancontact,
        SetupIntentCreateParamsPaymentMethodDataBillie as SetupIntentCreateParamsPaymentMethodDataBillie,
        SetupIntentCreateParamsPaymentMethodDataBillingDetails as SetupIntentCreateParamsPaymentMethodDataBillingDetails,
        SetupIntentCreateParamsPaymentMethodDataBillingDetailsAddress as SetupIntentCreateParamsPaymentMethodDataBillingDetailsAddress,
        SetupIntentCreateParamsPaymentMethodDataBlik as SetupIntentCreateParamsPaymentMethodDataBlik,
        SetupIntentCreateParamsPaymentMethodDataBoleto as SetupIntentCreateParamsPaymentMethodDataBoleto,
        SetupIntentCreateParamsPaymentMethodDataCashapp as SetupIntentCreateParamsPaymentMethodDataCashapp,
        SetupIntentCreateParamsPaymentMethodDataCrypto as SetupIntentCreateParamsPaymentMethodDataCrypto,
        SetupIntentCreateParamsPaymentMethodDataCustomerBalance as SetupIntentCreateParamsPaymentMethodDataCustomerBalance,
        SetupIntentCreateParamsPaymentMethodDataEps as SetupIntentCreateParamsPaymentMethodDataEps,
        SetupIntentCreateParamsPaymentMethodDataFpx as SetupIntentCreateParamsPaymentMethodDataFpx,
        SetupIntentCreateParamsPaymentMethodDataGiropay as SetupIntentCreateParamsPaymentMethodDataGiropay,
        SetupIntentCreateParamsPaymentMethodDataGopay as SetupIntentCreateParamsPaymentMethodDataGopay,
        SetupIntentCreateParamsPaymentMethodDataGrabpay as SetupIntentCreateParamsPaymentMethodDataGrabpay,
        SetupIntentCreateParamsPaymentMethodDataIdBankTransfer as SetupIntentCreateParamsPaymentMethodDataIdBankTransfer,
        SetupIntentCreateParamsPaymentMethodDataIdeal as SetupIntentCreateParamsPaymentMethodDataIdeal,
        SetupIntentCreateParamsPaymentMethodDataInteracPresent as SetupIntentCreateParamsPaymentMethodDataInteracPresent,
        SetupIntentCreateParamsPaymentMethodDataKakaoPay as SetupIntentCreateParamsPaymentMethodDataKakaoPay,
        SetupIntentCreateParamsPaymentMethodDataKlarna as SetupIntentCreateParamsPaymentMethodDataKlarna,
        SetupIntentCreateParamsPaymentMethodDataKlarnaDob as SetupIntentCreateParamsPaymentMethodDataKlarnaDob,
        SetupIntentCreateParamsPaymentMethodDataKonbini as SetupIntentCreateParamsPaymentMethodDataKonbini,
        SetupIntentCreateParamsPaymentMethodDataKrCard as SetupIntentCreateParamsPaymentMethodDataKrCard,
        SetupIntentCreateParamsPaymentMethodDataLink as SetupIntentCreateParamsPaymentMethodDataLink,
        SetupIntentCreateParamsPaymentMethodDataMbWay as SetupIntentCreateParamsPaymentMethodDataMbWay,
        SetupIntentCreateParamsPaymentMethodDataMobilepay as SetupIntentCreateParamsPaymentMethodDataMobilepay,
        SetupIntentCreateParamsPaymentMethodDataMultibanco as SetupIntentCreateParamsPaymentMethodDataMultibanco,
        SetupIntentCreateParamsPaymentMethodDataNaverPay as SetupIntentCreateParamsPaymentMethodDataNaverPay,
        SetupIntentCreateParamsPaymentMethodDataNzBankAccount as SetupIntentCreateParamsPaymentMethodDataNzBankAccount,
        SetupIntentCreateParamsPaymentMethodDataOxxo as SetupIntentCreateParamsPaymentMethodDataOxxo,
        SetupIntentCreateParamsPaymentMethodDataP24 as SetupIntentCreateParamsPaymentMethodDataP24,
        SetupIntentCreateParamsPaymentMethodDataPayByBank as SetupIntentCreateParamsPaymentMethodDataPayByBank,
        SetupIntentCreateParamsPaymentMethodDataPayco as SetupIntentCreateParamsPaymentMethodDataPayco,
        SetupIntentCreateParamsPaymentMethodDataPaynow as SetupIntentCreateParamsPaymentMethodDataPaynow,
        SetupIntentCreateParamsPaymentMethodDataPaypal as SetupIntentCreateParamsPaymentMethodDataPaypal,
        SetupIntentCreateParamsPaymentMethodDataPaypay as SetupIntentCreateParamsPaymentMethodDataPaypay,
        SetupIntentCreateParamsPaymentMethodDataPayto as SetupIntentCreateParamsPaymentMethodDataPayto,
        SetupIntentCreateParamsPaymentMethodDataPix as SetupIntentCreateParamsPaymentMethodDataPix,
        SetupIntentCreateParamsPaymentMethodDataPromptpay as SetupIntentCreateParamsPaymentMethodDataPromptpay,
        SetupIntentCreateParamsPaymentMethodDataQris as SetupIntentCreateParamsPaymentMethodDataQris,
        SetupIntentCreateParamsPaymentMethodDataRadarOptions as SetupIntentCreateParamsPaymentMethodDataRadarOptions,
        SetupIntentCreateParamsPaymentMethodDataRechnung as SetupIntentCreateParamsPaymentMethodDataRechnung,
        SetupIntentCreateParamsPaymentMethodDataRechnungDob as SetupIntentCreateParamsPaymentMethodDataRechnungDob,
        SetupIntentCreateParamsPaymentMethodDataRevolutPay as SetupIntentCreateParamsPaymentMethodDataRevolutPay,
        SetupIntentCreateParamsPaymentMethodDataSamsungPay as SetupIntentCreateParamsPaymentMethodDataSamsungPay,
        SetupIntentCreateParamsPaymentMethodDataSatispay as SetupIntentCreateParamsPaymentMethodDataSatispay,
        SetupIntentCreateParamsPaymentMethodDataSepaDebit as SetupIntentCreateParamsPaymentMethodDataSepaDebit,
        SetupIntentCreateParamsPaymentMethodDataShopeepay as SetupIntentCreateParamsPaymentMethodDataShopeepay,
        SetupIntentCreateParamsPaymentMethodDataSofort as SetupIntentCreateParamsPaymentMethodDataSofort,
        SetupIntentCreateParamsPaymentMethodDataStripeBalance as SetupIntentCreateParamsPaymentMethodDataStripeBalance,
        SetupIntentCreateParamsPaymentMethodDataSwish as SetupIntentCreateParamsPaymentMethodDataSwish,
        SetupIntentCreateParamsPaymentMethodDataTwint as SetupIntentCreateParamsPaymentMethodDataTwint,
        SetupIntentCreateParamsPaymentMethodDataUsBankAccount as SetupIntentCreateParamsPaymentMethodDataUsBankAccount,
        SetupIntentCreateParamsPaymentMethodDataWechatPay as SetupIntentCreateParamsPaymentMethodDataWechatPay,
        SetupIntentCreateParamsPaymentMethodDataZip as SetupIntentCreateParamsPaymentMethodDataZip,
        SetupIntentCreateParamsPaymentMethodOptions as SetupIntentCreateParamsPaymentMethodOptions,
        SetupIntentCreateParamsPaymentMethodOptionsAcssDebit as SetupIntentCreateParamsPaymentMethodOptionsAcssDebit,
        SetupIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsAmazonPay as SetupIntentCreateParamsPaymentMethodOptionsAmazonPay,
        SetupIntentCreateParamsPaymentMethodOptionsBacsDebit as SetupIntentCreateParamsPaymentMethodOptionsBacsDebit,
        SetupIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsCard as SetupIntentCreateParamsPaymentMethodOptionsCard,
        SetupIntentCreateParamsPaymentMethodOptionsCardMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsCardMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsCardPresent as SetupIntentCreateParamsPaymentMethodOptionsCardPresent,
        SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecure as SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecure,
        SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        SetupIntentCreateParamsPaymentMethodOptionsKlarna as SetupIntentCreateParamsPaymentMethodOptionsKlarna,
        SetupIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand as SetupIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand,
        SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscription as SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscription,
        SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SetupIntentCreateParamsPaymentMethodOptionsLink as SetupIntentCreateParamsPaymentMethodOptionsLink,
        SetupIntentCreateParamsPaymentMethodOptionsPaypal as SetupIntentCreateParamsPaymentMethodOptionsPaypal,
        SetupIntentCreateParamsPaymentMethodOptionsPayto as SetupIntentCreateParamsPaymentMethodOptionsPayto,
        SetupIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsPix as SetupIntentCreateParamsPaymentMethodOptionsPix,
        SetupIntentCreateParamsPaymentMethodOptionsPixMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsPixMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsSepaDebit as SetupIntentCreateParamsPaymentMethodOptionsSepaDebit,
        SetupIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccount as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccount,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks as SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks,
        SetupIntentCreateParamsSetupDetails as SetupIntentCreateParamsSetupDetails,
        SetupIntentCreateParamsSetupDetailsBenefit as SetupIntentCreateParamsSetupDetailsBenefit,
        SetupIntentCreateParamsSetupDetailsBenefitFrMealVoucher as SetupIntentCreateParamsSetupDetailsBenefitFrMealVoucher,
        SetupIntentCreateParamsSingleUse as SetupIntentCreateParamsSingleUse,
    )
    from stripe.params._setup_intent_list_params import (
        SetupIntentListParams as SetupIntentListParams,
        SetupIntentListParamsCreated as SetupIntentListParamsCreated,
    )
    from stripe.params._setup_intent_modify_params import (
        SetupIntentModifyParams as SetupIntentModifyParams,
        SetupIntentModifyParamsPaymentMethodData as SetupIntentModifyParamsPaymentMethodData,
        SetupIntentModifyParamsPaymentMethodDataAcssDebit as SetupIntentModifyParamsPaymentMethodDataAcssDebit,
        SetupIntentModifyParamsPaymentMethodDataAffirm as SetupIntentModifyParamsPaymentMethodDataAffirm,
        SetupIntentModifyParamsPaymentMethodDataAfterpayClearpay as SetupIntentModifyParamsPaymentMethodDataAfterpayClearpay,
        SetupIntentModifyParamsPaymentMethodDataAlipay as SetupIntentModifyParamsPaymentMethodDataAlipay,
        SetupIntentModifyParamsPaymentMethodDataAlma as SetupIntentModifyParamsPaymentMethodDataAlma,
        SetupIntentModifyParamsPaymentMethodDataAmazonPay as SetupIntentModifyParamsPaymentMethodDataAmazonPay,
        SetupIntentModifyParamsPaymentMethodDataAuBecsDebit as SetupIntentModifyParamsPaymentMethodDataAuBecsDebit,
        SetupIntentModifyParamsPaymentMethodDataBacsDebit as SetupIntentModifyParamsPaymentMethodDataBacsDebit,
        SetupIntentModifyParamsPaymentMethodDataBancontact as SetupIntentModifyParamsPaymentMethodDataBancontact,
        SetupIntentModifyParamsPaymentMethodDataBillie as SetupIntentModifyParamsPaymentMethodDataBillie,
        SetupIntentModifyParamsPaymentMethodDataBillingDetails as SetupIntentModifyParamsPaymentMethodDataBillingDetails,
        SetupIntentModifyParamsPaymentMethodDataBillingDetailsAddress as SetupIntentModifyParamsPaymentMethodDataBillingDetailsAddress,
        SetupIntentModifyParamsPaymentMethodDataBlik as SetupIntentModifyParamsPaymentMethodDataBlik,
        SetupIntentModifyParamsPaymentMethodDataBoleto as SetupIntentModifyParamsPaymentMethodDataBoleto,
        SetupIntentModifyParamsPaymentMethodDataCashapp as SetupIntentModifyParamsPaymentMethodDataCashapp,
        SetupIntentModifyParamsPaymentMethodDataCrypto as SetupIntentModifyParamsPaymentMethodDataCrypto,
        SetupIntentModifyParamsPaymentMethodDataCustomerBalance as SetupIntentModifyParamsPaymentMethodDataCustomerBalance,
        SetupIntentModifyParamsPaymentMethodDataEps as SetupIntentModifyParamsPaymentMethodDataEps,
        SetupIntentModifyParamsPaymentMethodDataFpx as SetupIntentModifyParamsPaymentMethodDataFpx,
        SetupIntentModifyParamsPaymentMethodDataGiropay as SetupIntentModifyParamsPaymentMethodDataGiropay,
        SetupIntentModifyParamsPaymentMethodDataGopay as SetupIntentModifyParamsPaymentMethodDataGopay,
        SetupIntentModifyParamsPaymentMethodDataGrabpay as SetupIntentModifyParamsPaymentMethodDataGrabpay,
        SetupIntentModifyParamsPaymentMethodDataIdBankTransfer as SetupIntentModifyParamsPaymentMethodDataIdBankTransfer,
        SetupIntentModifyParamsPaymentMethodDataIdeal as SetupIntentModifyParamsPaymentMethodDataIdeal,
        SetupIntentModifyParamsPaymentMethodDataInteracPresent as SetupIntentModifyParamsPaymentMethodDataInteracPresent,
        SetupIntentModifyParamsPaymentMethodDataKakaoPay as SetupIntentModifyParamsPaymentMethodDataKakaoPay,
        SetupIntentModifyParamsPaymentMethodDataKlarna as SetupIntentModifyParamsPaymentMethodDataKlarna,
        SetupIntentModifyParamsPaymentMethodDataKlarnaDob as SetupIntentModifyParamsPaymentMethodDataKlarnaDob,
        SetupIntentModifyParamsPaymentMethodDataKonbini as SetupIntentModifyParamsPaymentMethodDataKonbini,
        SetupIntentModifyParamsPaymentMethodDataKrCard as SetupIntentModifyParamsPaymentMethodDataKrCard,
        SetupIntentModifyParamsPaymentMethodDataLink as SetupIntentModifyParamsPaymentMethodDataLink,
        SetupIntentModifyParamsPaymentMethodDataMbWay as SetupIntentModifyParamsPaymentMethodDataMbWay,
        SetupIntentModifyParamsPaymentMethodDataMobilepay as SetupIntentModifyParamsPaymentMethodDataMobilepay,
        SetupIntentModifyParamsPaymentMethodDataMultibanco as SetupIntentModifyParamsPaymentMethodDataMultibanco,
        SetupIntentModifyParamsPaymentMethodDataNaverPay as SetupIntentModifyParamsPaymentMethodDataNaverPay,
        SetupIntentModifyParamsPaymentMethodDataNzBankAccount as SetupIntentModifyParamsPaymentMethodDataNzBankAccount,
        SetupIntentModifyParamsPaymentMethodDataOxxo as SetupIntentModifyParamsPaymentMethodDataOxxo,
        SetupIntentModifyParamsPaymentMethodDataP24 as SetupIntentModifyParamsPaymentMethodDataP24,
        SetupIntentModifyParamsPaymentMethodDataPayByBank as SetupIntentModifyParamsPaymentMethodDataPayByBank,
        SetupIntentModifyParamsPaymentMethodDataPayco as SetupIntentModifyParamsPaymentMethodDataPayco,
        SetupIntentModifyParamsPaymentMethodDataPaynow as SetupIntentModifyParamsPaymentMethodDataPaynow,
        SetupIntentModifyParamsPaymentMethodDataPaypal as SetupIntentModifyParamsPaymentMethodDataPaypal,
        SetupIntentModifyParamsPaymentMethodDataPaypay as SetupIntentModifyParamsPaymentMethodDataPaypay,
        SetupIntentModifyParamsPaymentMethodDataPayto as SetupIntentModifyParamsPaymentMethodDataPayto,
        SetupIntentModifyParamsPaymentMethodDataPix as SetupIntentModifyParamsPaymentMethodDataPix,
        SetupIntentModifyParamsPaymentMethodDataPromptpay as SetupIntentModifyParamsPaymentMethodDataPromptpay,
        SetupIntentModifyParamsPaymentMethodDataQris as SetupIntentModifyParamsPaymentMethodDataQris,
        SetupIntentModifyParamsPaymentMethodDataRadarOptions as SetupIntentModifyParamsPaymentMethodDataRadarOptions,
        SetupIntentModifyParamsPaymentMethodDataRechnung as SetupIntentModifyParamsPaymentMethodDataRechnung,
        SetupIntentModifyParamsPaymentMethodDataRechnungDob as SetupIntentModifyParamsPaymentMethodDataRechnungDob,
        SetupIntentModifyParamsPaymentMethodDataRevolutPay as SetupIntentModifyParamsPaymentMethodDataRevolutPay,
        SetupIntentModifyParamsPaymentMethodDataSamsungPay as SetupIntentModifyParamsPaymentMethodDataSamsungPay,
        SetupIntentModifyParamsPaymentMethodDataSatispay as SetupIntentModifyParamsPaymentMethodDataSatispay,
        SetupIntentModifyParamsPaymentMethodDataSepaDebit as SetupIntentModifyParamsPaymentMethodDataSepaDebit,
        SetupIntentModifyParamsPaymentMethodDataShopeepay as SetupIntentModifyParamsPaymentMethodDataShopeepay,
        SetupIntentModifyParamsPaymentMethodDataSofort as SetupIntentModifyParamsPaymentMethodDataSofort,
        SetupIntentModifyParamsPaymentMethodDataStripeBalance as SetupIntentModifyParamsPaymentMethodDataStripeBalance,
        SetupIntentModifyParamsPaymentMethodDataSwish as SetupIntentModifyParamsPaymentMethodDataSwish,
        SetupIntentModifyParamsPaymentMethodDataTwint as SetupIntentModifyParamsPaymentMethodDataTwint,
        SetupIntentModifyParamsPaymentMethodDataUsBankAccount as SetupIntentModifyParamsPaymentMethodDataUsBankAccount,
        SetupIntentModifyParamsPaymentMethodDataWechatPay as SetupIntentModifyParamsPaymentMethodDataWechatPay,
        SetupIntentModifyParamsPaymentMethodDataZip as SetupIntentModifyParamsPaymentMethodDataZip,
        SetupIntentModifyParamsPaymentMethodOptions as SetupIntentModifyParamsPaymentMethodOptions,
        SetupIntentModifyParamsPaymentMethodOptionsAcssDebit as SetupIntentModifyParamsPaymentMethodOptionsAcssDebit,
        SetupIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsAmazonPay as SetupIntentModifyParamsPaymentMethodOptionsAmazonPay,
        SetupIntentModifyParamsPaymentMethodOptionsBacsDebit as SetupIntentModifyParamsPaymentMethodOptionsBacsDebit,
        SetupIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsCard as SetupIntentModifyParamsPaymentMethodOptionsCard,
        SetupIntentModifyParamsPaymentMethodOptionsCardMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsCardMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsCardPresent as SetupIntentModifyParamsPaymentMethodOptionsCardPresent,
        SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecure as SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecure,
        SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        SetupIntentModifyParamsPaymentMethodOptionsKlarna as SetupIntentModifyParamsPaymentMethodOptionsKlarna,
        SetupIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand as SetupIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand,
        SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscription as SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscription,
        SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SetupIntentModifyParamsPaymentMethodOptionsLink as SetupIntentModifyParamsPaymentMethodOptionsLink,
        SetupIntentModifyParamsPaymentMethodOptionsPaypal as SetupIntentModifyParamsPaymentMethodOptionsPaypal,
        SetupIntentModifyParamsPaymentMethodOptionsPayto as SetupIntentModifyParamsPaymentMethodOptionsPayto,
        SetupIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsPix as SetupIntentModifyParamsPaymentMethodOptionsPix,
        SetupIntentModifyParamsPaymentMethodOptionsPixMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsPixMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsSepaDebit as SetupIntentModifyParamsPaymentMethodOptionsSepaDebit,
        SetupIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccount as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccount,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks as SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks,
        SetupIntentModifyParamsSetupDetails as SetupIntentModifyParamsSetupDetails,
        SetupIntentModifyParamsSetupDetailsBenefit as SetupIntentModifyParamsSetupDetailsBenefit,
        SetupIntentModifyParamsSetupDetailsBenefitFrMealVoucher as SetupIntentModifyParamsSetupDetailsBenefitFrMealVoucher,
    )
    from stripe.params._setup_intent_retrieve_params import (
        SetupIntentRetrieveParams as SetupIntentRetrieveParams,
    )
    from stripe.params._setup_intent_update_params import (
        SetupIntentUpdateParams as SetupIntentUpdateParams,
        SetupIntentUpdateParamsPaymentMethodData as SetupIntentUpdateParamsPaymentMethodData,
        SetupIntentUpdateParamsPaymentMethodDataAcssDebit as SetupIntentUpdateParamsPaymentMethodDataAcssDebit,
        SetupIntentUpdateParamsPaymentMethodDataAffirm as SetupIntentUpdateParamsPaymentMethodDataAffirm,
        SetupIntentUpdateParamsPaymentMethodDataAfterpayClearpay as SetupIntentUpdateParamsPaymentMethodDataAfterpayClearpay,
        SetupIntentUpdateParamsPaymentMethodDataAlipay as SetupIntentUpdateParamsPaymentMethodDataAlipay,
        SetupIntentUpdateParamsPaymentMethodDataAlma as SetupIntentUpdateParamsPaymentMethodDataAlma,
        SetupIntentUpdateParamsPaymentMethodDataAmazonPay as SetupIntentUpdateParamsPaymentMethodDataAmazonPay,
        SetupIntentUpdateParamsPaymentMethodDataAuBecsDebit as SetupIntentUpdateParamsPaymentMethodDataAuBecsDebit,
        SetupIntentUpdateParamsPaymentMethodDataBacsDebit as SetupIntentUpdateParamsPaymentMethodDataBacsDebit,
        SetupIntentUpdateParamsPaymentMethodDataBancontact as SetupIntentUpdateParamsPaymentMethodDataBancontact,
        SetupIntentUpdateParamsPaymentMethodDataBillie as SetupIntentUpdateParamsPaymentMethodDataBillie,
        SetupIntentUpdateParamsPaymentMethodDataBillingDetails as SetupIntentUpdateParamsPaymentMethodDataBillingDetails,
        SetupIntentUpdateParamsPaymentMethodDataBillingDetailsAddress as SetupIntentUpdateParamsPaymentMethodDataBillingDetailsAddress,
        SetupIntentUpdateParamsPaymentMethodDataBlik as SetupIntentUpdateParamsPaymentMethodDataBlik,
        SetupIntentUpdateParamsPaymentMethodDataBoleto as SetupIntentUpdateParamsPaymentMethodDataBoleto,
        SetupIntentUpdateParamsPaymentMethodDataCashapp as SetupIntentUpdateParamsPaymentMethodDataCashapp,
        SetupIntentUpdateParamsPaymentMethodDataCrypto as SetupIntentUpdateParamsPaymentMethodDataCrypto,
        SetupIntentUpdateParamsPaymentMethodDataCustomerBalance as SetupIntentUpdateParamsPaymentMethodDataCustomerBalance,
        SetupIntentUpdateParamsPaymentMethodDataEps as SetupIntentUpdateParamsPaymentMethodDataEps,
        SetupIntentUpdateParamsPaymentMethodDataFpx as SetupIntentUpdateParamsPaymentMethodDataFpx,
        SetupIntentUpdateParamsPaymentMethodDataGiropay as SetupIntentUpdateParamsPaymentMethodDataGiropay,
        SetupIntentUpdateParamsPaymentMethodDataGopay as SetupIntentUpdateParamsPaymentMethodDataGopay,
        SetupIntentUpdateParamsPaymentMethodDataGrabpay as SetupIntentUpdateParamsPaymentMethodDataGrabpay,
        SetupIntentUpdateParamsPaymentMethodDataIdBankTransfer as SetupIntentUpdateParamsPaymentMethodDataIdBankTransfer,
        SetupIntentUpdateParamsPaymentMethodDataIdeal as SetupIntentUpdateParamsPaymentMethodDataIdeal,
        SetupIntentUpdateParamsPaymentMethodDataInteracPresent as SetupIntentUpdateParamsPaymentMethodDataInteracPresent,
        SetupIntentUpdateParamsPaymentMethodDataKakaoPay as SetupIntentUpdateParamsPaymentMethodDataKakaoPay,
        SetupIntentUpdateParamsPaymentMethodDataKlarna as SetupIntentUpdateParamsPaymentMethodDataKlarna,
        SetupIntentUpdateParamsPaymentMethodDataKlarnaDob as SetupIntentUpdateParamsPaymentMethodDataKlarnaDob,
        SetupIntentUpdateParamsPaymentMethodDataKonbini as SetupIntentUpdateParamsPaymentMethodDataKonbini,
        SetupIntentUpdateParamsPaymentMethodDataKrCard as SetupIntentUpdateParamsPaymentMethodDataKrCard,
        SetupIntentUpdateParamsPaymentMethodDataLink as SetupIntentUpdateParamsPaymentMethodDataLink,
        SetupIntentUpdateParamsPaymentMethodDataMbWay as SetupIntentUpdateParamsPaymentMethodDataMbWay,
        SetupIntentUpdateParamsPaymentMethodDataMobilepay as SetupIntentUpdateParamsPaymentMethodDataMobilepay,
        SetupIntentUpdateParamsPaymentMethodDataMultibanco as SetupIntentUpdateParamsPaymentMethodDataMultibanco,
        SetupIntentUpdateParamsPaymentMethodDataNaverPay as SetupIntentUpdateParamsPaymentMethodDataNaverPay,
        SetupIntentUpdateParamsPaymentMethodDataNzBankAccount as SetupIntentUpdateParamsPaymentMethodDataNzBankAccount,
        SetupIntentUpdateParamsPaymentMethodDataOxxo as SetupIntentUpdateParamsPaymentMethodDataOxxo,
        SetupIntentUpdateParamsPaymentMethodDataP24 as SetupIntentUpdateParamsPaymentMethodDataP24,
        SetupIntentUpdateParamsPaymentMethodDataPayByBank as SetupIntentUpdateParamsPaymentMethodDataPayByBank,
        SetupIntentUpdateParamsPaymentMethodDataPayco as SetupIntentUpdateParamsPaymentMethodDataPayco,
        SetupIntentUpdateParamsPaymentMethodDataPaynow as SetupIntentUpdateParamsPaymentMethodDataPaynow,
        SetupIntentUpdateParamsPaymentMethodDataPaypal as SetupIntentUpdateParamsPaymentMethodDataPaypal,
        SetupIntentUpdateParamsPaymentMethodDataPaypay as SetupIntentUpdateParamsPaymentMethodDataPaypay,
        SetupIntentUpdateParamsPaymentMethodDataPayto as SetupIntentUpdateParamsPaymentMethodDataPayto,
        SetupIntentUpdateParamsPaymentMethodDataPix as SetupIntentUpdateParamsPaymentMethodDataPix,
        SetupIntentUpdateParamsPaymentMethodDataPromptpay as SetupIntentUpdateParamsPaymentMethodDataPromptpay,
        SetupIntentUpdateParamsPaymentMethodDataQris as SetupIntentUpdateParamsPaymentMethodDataQris,
        SetupIntentUpdateParamsPaymentMethodDataRadarOptions as SetupIntentUpdateParamsPaymentMethodDataRadarOptions,
        SetupIntentUpdateParamsPaymentMethodDataRechnung as SetupIntentUpdateParamsPaymentMethodDataRechnung,
        SetupIntentUpdateParamsPaymentMethodDataRechnungDob as SetupIntentUpdateParamsPaymentMethodDataRechnungDob,
        SetupIntentUpdateParamsPaymentMethodDataRevolutPay as SetupIntentUpdateParamsPaymentMethodDataRevolutPay,
        SetupIntentUpdateParamsPaymentMethodDataSamsungPay as SetupIntentUpdateParamsPaymentMethodDataSamsungPay,
        SetupIntentUpdateParamsPaymentMethodDataSatispay as SetupIntentUpdateParamsPaymentMethodDataSatispay,
        SetupIntentUpdateParamsPaymentMethodDataSepaDebit as SetupIntentUpdateParamsPaymentMethodDataSepaDebit,
        SetupIntentUpdateParamsPaymentMethodDataShopeepay as SetupIntentUpdateParamsPaymentMethodDataShopeepay,
        SetupIntentUpdateParamsPaymentMethodDataSofort as SetupIntentUpdateParamsPaymentMethodDataSofort,
        SetupIntentUpdateParamsPaymentMethodDataStripeBalance as SetupIntentUpdateParamsPaymentMethodDataStripeBalance,
        SetupIntentUpdateParamsPaymentMethodDataSwish as SetupIntentUpdateParamsPaymentMethodDataSwish,
        SetupIntentUpdateParamsPaymentMethodDataTwint as SetupIntentUpdateParamsPaymentMethodDataTwint,
        SetupIntentUpdateParamsPaymentMethodDataUsBankAccount as SetupIntentUpdateParamsPaymentMethodDataUsBankAccount,
        SetupIntentUpdateParamsPaymentMethodDataWechatPay as SetupIntentUpdateParamsPaymentMethodDataWechatPay,
        SetupIntentUpdateParamsPaymentMethodDataZip as SetupIntentUpdateParamsPaymentMethodDataZip,
        SetupIntentUpdateParamsPaymentMethodOptions as SetupIntentUpdateParamsPaymentMethodOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsAcssDebit as SetupIntentUpdateParamsPaymentMethodOptionsAcssDebit,
        SetupIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsAmazonPay as SetupIntentUpdateParamsPaymentMethodOptionsAmazonPay,
        SetupIntentUpdateParamsPaymentMethodOptionsBacsDebit as SetupIntentUpdateParamsPaymentMethodOptionsBacsDebit,
        SetupIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsCard as SetupIntentUpdateParamsPaymentMethodOptionsCard,
        SetupIntentUpdateParamsPaymentMethodOptionsCardMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsCardMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsCardPresent as SetupIntentUpdateParamsPaymentMethodOptionsCardPresent,
        SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure as SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure,
        SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions as SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires as SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires,
        SetupIntentUpdateParamsPaymentMethodOptionsKlarna as SetupIntentUpdateParamsPaymentMethodOptionsKlarna,
        SetupIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand as SetupIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand,
        SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription as SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription,
        SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SetupIntentUpdateParamsPaymentMethodOptionsLink as SetupIntentUpdateParamsPaymentMethodOptionsLink,
        SetupIntentUpdateParamsPaymentMethodOptionsPaypal as SetupIntentUpdateParamsPaymentMethodOptionsPaypal,
        SetupIntentUpdateParamsPaymentMethodOptionsPayto as SetupIntentUpdateParamsPaymentMethodOptionsPayto,
        SetupIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsPix as SetupIntentUpdateParamsPaymentMethodOptionsPix,
        SetupIntentUpdateParamsPaymentMethodOptionsPixMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsPixMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsSepaDebit as SetupIntentUpdateParamsPaymentMethodOptionsSepaDebit,
        SetupIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccount as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccount,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions,
        SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks as SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks,
        SetupIntentUpdateParamsSetupDetails as SetupIntentUpdateParamsSetupDetails,
        SetupIntentUpdateParamsSetupDetailsBenefit as SetupIntentUpdateParamsSetupDetailsBenefit,
        SetupIntentUpdateParamsSetupDetailsBenefitFrMealVoucher as SetupIntentUpdateParamsSetupDetailsBenefitFrMealVoucher,
    )
    from stripe.params._setup_intent_verify_microdeposits_params import (
        SetupIntentVerifyMicrodepositsParams as SetupIntentVerifyMicrodepositsParams,
    )
    from stripe.params._shipping_rate_create_params import (
        ShippingRateCreateParams as ShippingRateCreateParams,
        ShippingRateCreateParamsDeliveryEstimate as ShippingRateCreateParamsDeliveryEstimate,
        ShippingRateCreateParamsDeliveryEstimateMaximum as ShippingRateCreateParamsDeliveryEstimateMaximum,
        ShippingRateCreateParamsDeliveryEstimateMinimum as ShippingRateCreateParamsDeliveryEstimateMinimum,
        ShippingRateCreateParamsFixedAmount as ShippingRateCreateParamsFixedAmount,
        ShippingRateCreateParamsFixedAmountCurrencyOptions as ShippingRateCreateParamsFixedAmountCurrencyOptions,
    )
    from stripe.params._shipping_rate_list_params import (
        ShippingRateListParams as ShippingRateListParams,
        ShippingRateListParamsCreated as ShippingRateListParamsCreated,
    )
    from stripe.params._shipping_rate_modify_params import (
        ShippingRateModifyParams as ShippingRateModifyParams,
        ShippingRateModifyParamsFixedAmount as ShippingRateModifyParamsFixedAmount,
        ShippingRateModifyParamsFixedAmountCurrencyOptions as ShippingRateModifyParamsFixedAmountCurrencyOptions,
    )
    from stripe.params._shipping_rate_retrieve_params import (
        ShippingRateRetrieveParams as ShippingRateRetrieveParams,
    )
    from stripe.params._shipping_rate_update_params import (
        ShippingRateUpdateParams as ShippingRateUpdateParams,
        ShippingRateUpdateParamsFixedAmount as ShippingRateUpdateParamsFixedAmount,
        ShippingRateUpdateParamsFixedAmountCurrencyOptions as ShippingRateUpdateParamsFixedAmountCurrencyOptions,
    )
    from stripe.params._source_create_params import (
        SourceCreateParams as SourceCreateParams,
        SourceCreateParamsMandate as SourceCreateParamsMandate,
        SourceCreateParamsMandateAcceptance as SourceCreateParamsMandateAcceptance,
        SourceCreateParamsMandateAcceptanceOffline as SourceCreateParamsMandateAcceptanceOffline,
        SourceCreateParamsMandateAcceptanceOnline as SourceCreateParamsMandateAcceptanceOnline,
        SourceCreateParamsOwner as SourceCreateParamsOwner,
        SourceCreateParamsOwnerAddress as SourceCreateParamsOwnerAddress,
        SourceCreateParamsReceiver as SourceCreateParamsReceiver,
        SourceCreateParamsRedirect as SourceCreateParamsRedirect,
        SourceCreateParamsSourceOrder as SourceCreateParamsSourceOrder,
        SourceCreateParamsSourceOrderItem as SourceCreateParamsSourceOrderItem,
        SourceCreateParamsSourceOrderShipping as SourceCreateParamsSourceOrderShipping,
        SourceCreateParamsSourceOrderShippingAddress as SourceCreateParamsSourceOrderShippingAddress,
    )
    from stripe.params._source_detach_params import (
        SourceDetachParams as SourceDetachParams,
    )
    from stripe.params._source_list_source_transactions_params import (
        SourceListSourceTransactionsParams as SourceListSourceTransactionsParams,
    )
    from stripe.params._source_modify_params import (
        SourceModifyParams as SourceModifyParams,
        SourceModifyParamsMandate as SourceModifyParamsMandate,
        SourceModifyParamsMandateAcceptance as SourceModifyParamsMandateAcceptance,
        SourceModifyParamsMandateAcceptanceOffline as SourceModifyParamsMandateAcceptanceOffline,
        SourceModifyParamsMandateAcceptanceOnline as SourceModifyParamsMandateAcceptanceOnline,
        SourceModifyParamsOwner as SourceModifyParamsOwner,
        SourceModifyParamsOwnerAddress as SourceModifyParamsOwnerAddress,
        SourceModifyParamsSourceOrder as SourceModifyParamsSourceOrder,
        SourceModifyParamsSourceOrderItem as SourceModifyParamsSourceOrderItem,
        SourceModifyParamsSourceOrderShipping as SourceModifyParamsSourceOrderShipping,
        SourceModifyParamsSourceOrderShippingAddress as SourceModifyParamsSourceOrderShippingAddress,
    )
    from stripe.params._source_retrieve_params import (
        SourceRetrieveParams as SourceRetrieveParams,
    )
    from stripe.params._source_transaction_list_params import (
        SourceTransactionListParams as SourceTransactionListParams,
    )
    from stripe.params._source_update_params import (
        SourceUpdateParams as SourceUpdateParams,
        SourceUpdateParamsMandate as SourceUpdateParamsMandate,
        SourceUpdateParamsMandateAcceptance as SourceUpdateParamsMandateAcceptance,
        SourceUpdateParamsMandateAcceptanceOffline as SourceUpdateParamsMandateAcceptanceOffline,
        SourceUpdateParamsMandateAcceptanceOnline as SourceUpdateParamsMandateAcceptanceOnline,
        SourceUpdateParamsOwner as SourceUpdateParamsOwner,
        SourceUpdateParamsOwnerAddress as SourceUpdateParamsOwnerAddress,
        SourceUpdateParamsSourceOrder as SourceUpdateParamsSourceOrder,
        SourceUpdateParamsSourceOrderItem as SourceUpdateParamsSourceOrderItem,
        SourceUpdateParamsSourceOrderShipping as SourceUpdateParamsSourceOrderShipping,
        SourceUpdateParamsSourceOrderShippingAddress as SourceUpdateParamsSourceOrderShippingAddress,
    )
    from stripe.params._source_verify_params import (
        SourceVerifyParams as SourceVerifyParams,
    )
    from stripe.params._subscription_attach_cadence_params import (
        SubscriptionAttachCadenceParams as SubscriptionAttachCadenceParams,
    )
    from stripe.params._subscription_cancel_params import (
        SubscriptionCancelParams as SubscriptionCancelParams,
        SubscriptionCancelParamsCancellationDetails as SubscriptionCancelParamsCancellationDetails,
    )
    from stripe.params._subscription_create_params import (
        SubscriptionCreateParams as SubscriptionCreateParams,
        SubscriptionCreateParamsAddInvoiceItem as SubscriptionCreateParamsAddInvoiceItem,
        SubscriptionCreateParamsAddInvoiceItemDiscount as SubscriptionCreateParamsAddInvoiceItemDiscount,
        SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEnd as SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEnd,
        SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEndDuration as SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionCreateParamsAddInvoiceItemPeriod as SubscriptionCreateParamsAddInvoiceItemPeriod,
        SubscriptionCreateParamsAddInvoiceItemPeriodEnd as SubscriptionCreateParamsAddInvoiceItemPeriodEnd,
        SubscriptionCreateParamsAddInvoiceItemPeriodStart as SubscriptionCreateParamsAddInvoiceItemPeriodStart,
        SubscriptionCreateParamsAddInvoiceItemPriceData as SubscriptionCreateParamsAddInvoiceItemPriceData,
        SubscriptionCreateParamsAutomaticTax as SubscriptionCreateParamsAutomaticTax,
        SubscriptionCreateParamsAutomaticTaxLiability as SubscriptionCreateParamsAutomaticTaxLiability,
        SubscriptionCreateParamsBillingCycleAnchorConfig as SubscriptionCreateParamsBillingCycleAnchorConfig,
        SubscriptionCreateParamsBillingMode as SubscriptionCreateParamsBillingMode,
        SubscriptionCreateParamsBillingModeFlexible as SubscriptionCreateParamsBillingModeFlexible,
        SubscriptionCreateParamsBillingSchedule as SubscriptionCreateParamsBillingSchedule,
        SubscriptionCreateParamsBillingScheduleAppliesTo as SubscriptionCreateParamsBillingScheduleAppliesTo,
        SubscriptionCreateParamsBillingScheduleBillUntil as SubscriptionCreateParamsBillingScheduleBillUntil,
        SubscriptionCreateParamsBillingScheduleBillUntilDuration as SubscriptionCreateParamsBillingScheduleBillUntilDuration,
        SubscriptionCreateParamsBillingThresholds as SubscriptionCreateParamsBillingThresholds,
        SubscriptionCreateParamsDiscount as SubscriptionCreateParamsDiscount,
        SubscriptionCreateParamsDiscountDiscountEnd as SubscriptionCreateParamsDiscountDiscountEnd,
        SubscriptionCreateParamsDiscountDiscountEndDuration as SubscriptionCreateParamsDiscountDiscountEndDuration,
        SubscriptionCreateParamsInvoiceSettings as SubscriptionCreateParamsInvoiceSettings,
        SubscriptionCreateParamsInvoiceSettingsIssuer as SubscriptionCreateParamsInvoiceSettingsIssuer,
        SubscriptionCreateParamsItem as SubscriptionCreateParamsItem,
        SubscriptionCreateParamsItemBillingThresholds as SubscriptionCreateParamsItemBillingThresholds,
        SubscriptionCreateParamsItemDiscount as SubscriptionCreateParamsItemDiscount,
        SubscriptionCreateParamsItemDiscountDiscountEnd as SubscriptionCreateParamsItemDiscountDiscountEnd,
        SubscriptionCreateParamsItemDiscountDiscountEndDuration as SubscriptionCreateParamsItemDiscountDiscountEndDuration,
        SubscriptionCreateParamsItemPriceData as SubscriptionCreateParamsItemPriceData,
        SubscriptionCreateParamsItemPriceDataRecurring as SubscriptionCreateParamsItemPriceDataRecurring,
        SubscriptionCreateParamsItemTrial as SubscriptionCreateParamsItemTrial,
        SubscriptionCreateParamsPaymentSettings as SubscriptionCreateParamsPaymentSettings,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptions as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptions,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsBancontact as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCard as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCard,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsKonbini as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsKonbini,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPix as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPix,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpi as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpi,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SubscriptionCreateParamsPendingInvoiceItemInterval as SubscriptionCreateParamsPendingInvoiceItemInterval,
        SubscriptionCreateParamsPrebilling as SubscriptionCreateParamsPrebilling,
        SubscriptionCreateParamsTransferData as SubscriptionCreateParamsTransferData,
        SubscriptionCreateParamsTrialSettings as SubscriptionCreateParamsTrialSettings,
        SubscriptionCreateParamsTrialSettingsEndBehavior as SubscriptionCreateParamsTrialSettingsEndBehavior,
    )
    from stripe.params._subscription_delete_discount_params import (
        SubscriptionDeleteDiscountParams as SubscriptionDeleteDiscountParams,
    )
    from stripe.params._subscription_item_create_params import (
        SubscriptionItemCreateParams as SubscriptionItemCreateParams,
        SubscriptionItemCreateParamsBillingThresholds as SubscriptionItemCreateParamsBillingThresholds,
        SubscriptionItemCreateParamsDiscount as SubscriptionItemCreateParamsDiscount,
        SubscriptionItemCreateParamsDiscountDiscountEnd as SubscriptionItemCreateParamsDiscountDiscountEnd,
        SubscriptionItemCreateParamsDiscountDiscountEndDuration as SubscriptionItemCreateParamsDiscountDiscountEndDuration,
        SubscriptionItemCreateParamsPriceData as SubscriptionItemCreateParamsPriceData,
        SubscriptionItemCreateParamsPriceDataRecurring as SubscriptionItemCreateParamsPriceDataRecurring,
        SubscriptionItemCreateParamsTrial as SubscriptionItemCreateParamsTrial,
    )
    from stripe.params._subscription_item_delete_params import (
        SubscriptionItemDeleteParams as SubscriptionItemDeleteParams,
    )
    from stripe.params._subscription_item_list_params import (
        SubscriptionItemListParams as SubscriptionItemListParams,
    )
    from stripe.params._subscription_item_modify_params import (
        SubscriptionItemModifyParams as SubscriptionItemModifyParams,
        SubscriptionItemModifyParamsBillingThresholds as SubscriptionItemModifyParamsBillingThresholds,
        SubscriptionItemModifyParamsDiscount as SubscriptionItemModifyParamsDiscount,
        SubscriptionItemModifyParamsDiscountDiscountEnd as SubscriptionItemModifyParamsDiscountDiscountEnd,
        SubscriptionItemModifyParamsDiscountDiscountEndDuration as SubscriptionItemModifyParamsDiscountDiscountEndDuration,
        SubscriptionItemModifyParamsPriceData as SubscriptionItemModifyParamsPriceData,
        SubscriptionItemModifyParamsPriceDataRecurring as SubscriptionItemModifyParamsPriceDataRecurring,
    )
    from stripe.params._subscription_item_retrieve_params import (
        SubscriptionItemRetrieveParams as SubscriptionItemRetrieveParams,
    )
    from stripe.params._subscription_item_update_params import (
        SubscriptionItemUpdateParams as SubscriptionItemUpdateParams,
        SubscriptionItemUpdateParamsBillingThresholds as SubscriptionItemUpdateParamsBillingThresholds,
        SubscriptionItemUpdateParamsDiscount as SubscriptionItemUpdateParamsDiscount,
        SubscriptionItemUpdateParamsDiscountDiscountEnd as SubscriptionItemUpdateParamsDiscountDiscountEnd,
        SubscriptionItemUpdateParamsDiscountDiscountEndDuration as SubscriptionItemUpdateParamsDiscountDiscountEndDuration,
        SubscriptionItemUpdateParamsPriceData as SubscriptionItemUpdateParamsPriceData,
        SubscriptionItemUpdateParamsPriceDataRecurring as SubscriptionItemUpdateParamsPriceDataRecurring,
    )
    from stripe.params._subscription_list_params import (
        SubscriptionListParams as SubscriptionListParams,
        SubscriptionListParamsAutomaticTax as SubscriptionListParamsAutomaticTax,
        SubscriptionListParamsCreated as SubscriptionListParamsCreated,
        SubscriptionListParamsCurrentPeriodEnd as SubscriptionListParamsCurrentPeriodEnd,
        SubscriptionListParamsCurrentPeriodStart as SubscriptionListParamsCurrentPeriodStart,
    )
    from stripe.params._subscription_migrate_params import (
        SubscriptionMigrateParams as SubscriptionMigrateParams,
        SubscriptionMigrateParamsBillingMode as SubscriptionMigrateParamsBillingMode,
        SubscriptionMigrateParamsBillingModeFlexible as SubscriptionMigrateParamsBillingModeFlexible,
    )
    from stripe.params._subscription_modify_params import (
        SubscriptionModifyParams as SubscriptionModifyParams,
        SubscriptionModifyParamsAddInvoiceItem as SubscriptionModifyParamsAddInvoiceItem,
        SubscriptionModifyParamsAddInvoiceItemDiscount as SubscriptionModifyParamsAddInvoiceItemDiscount,
        SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEnd as SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEnd,
        SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEndDuration as SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionModifyParamsAddInvoiceItemPeriod as SubscriptionModifyParamsAddInvoiceItemPeriod,
        SubscriptionModifyParamsAddInvoiceItemPeriodEnd as SubscriptionModifyParamsAddInvoiceItemPeriodEnd,
        SubscriptionModifyParamsAddInvoiceItemPeriodStart as SubscriptionModifyParamsAddInvoiceItemPeriodStart,
        SubscriptionModifyParamsAddInvoiceItemPriceData as SubscriptionModifyParamsAddInvoiceItemPriceData,
        SubscriptionModifyParamsAutomaticTax as SubscriptionModifyParamsAutomaticTax,
        SubscriptionModifyParamsAutomaticTaxLiability as SubscriptionModifyParamsAutomaticTaxLiability,
        SubscriptionModifyParamsBillingSchedule as SubscriptionModifyParamsBillingSchedule,
        SubscriptionModifyParamsBillingScheduleAppliesTo as SubscriptionModifyParamsBillingScheduleAppliesTo,
        SubscriptionModifyParamsBillingScheduleBillUntil as SubscriptionModifyParamsBillingScheduleBillUntil,
        SubscriptionModifyParamsBillingScheduleBillUntilDuration as SubscriptionModifyParamsBillingScheduleBillUntilDuration,
        SubscriptionModifyParamsBillingThresholds as SubscriptionModifyParamsBillingThresholds,
        SubscriptionModifyParamsCancellationDetails as SubscriptionModifyParamsCancellationDetails,
        SubscriptionModifyParamsDiscount as SubscriptionModifyParamsDiscount,
        SubscriptionModifyParamsDiscountDiscountEnd as SubscriptionModifyParamsDiscountDiscountEnd,
        SubscriptionModifyParamsDiscountDiscountEndDuration as SubscriptionModifyParamsDiscountDiscountEndDuration,
        SubscriptionModifyParamsInvoiceSettings as SubscriptionModifyParamsInvoiceSettings,
        SubscriptionModifyParamsInvoiceSettingsIssuer as SubscriptionModifyParamsInvoiceSettingsIssuer,
        SubscriptionModifyParamsItem as SubscriptionModifyParamsItem,
        SubscriptionModifyParamsItemBillingThresholds as SubscriptionModifyParamsItemBillingThresholds,
        SubscriptionModifyParamsItemDiscount as SubscriptionModifyParamsItemDiscount,
        SubscriptionModifyParamsItemDiscountDiscountEnd as SubscriptionModifyParamsItemDiscountDiscountEnd,
        SubscriptionModifyParamsItemDiscountDiscountEndDuration as SubscriptionModifyParamsItemDiscountDiscountEndDuration,
        SubscriptionModifyParamsItemPriceData as SubscriptionModifyParamsItemPriceData,
        SubscriptionModifyParamsItemPriceDataRecurring as SubscriptionModifyParamsItemPriceDataRecurring,
        SubscriptionModifyParamsPauseCollection as SubscriptionModifyParamsPauseCollection,
        SubscriptionModifyParamsPaymentSettings as SubscriptionModifyParamsPaymentSettings,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptions as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptions,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsBancontact as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsBancontact,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCard as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCard,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsKonbini as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsKonbini,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPix as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPix,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpi as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpi,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SubscriptionModifyParamsPendingInvoiceItemInterval as SubscriptionModifyParamsPendingInvoiceItemInterval,
        SubscriptionModifyParamsPrebilling as SubscriptionModifyParamsPrebilling,
        SubscriptionModifyParamsTransferData as SubscriptionModifyParamsTransferData,
        SubscriptionModifyParamsTrialSettings as SubscriptionModifyParamsTrialSettings,
        SubscriptionModifyParamsTrialSettingsEndBehavior as SubscriptionModifyParamsTrialSettingsEndBehavior,
    )
    from stripe.params._subscription_resume_params import (
        SubscriptionResumeParams as SubscriptionResumeParams,
    )
    from stripe.params._subscription_retrieve_params import (
        SubscriptionRetrieveParams as SubscriptionRetrieveParams,
    )
    from stripe.params._subscription_schedule_amend_params import (
        SubscriptionScheduleAmendParams as SubscriptionScheduleAmendParams,
        SubscriptionScheduleAmendParamsAmendment as SubscriptionScheduleAmendParamsAmendment,
        SubscriptionScheduleAmendParamsAmendmentAmendmentEnd as SubscriptionScheduleAmendParamsAmendmentAmendmentEnd,
        SubscriptionScheduleAmendParamsAmendmentAmendmentEndDiscountEnd as SubscriptionScheduleAmendParamsAmendmentAmendmentEndDiscountEnd,
        SubscriptionScheduleAmendParamsAmendmentAmendmentEndDuration as SubscriptionScheduleAmendParamsAmendmentAmendmentEndDuration,
        SubscriptionScheduleAmendParamsAmendmentAmendmentStart as SubscriptionScheduleAmendParamsAmendmentAmendmentStart,
        SubscriptionScheduleAmendParamsAmendmentAmendmentStartAmendmentEnd as SubscriptionScheduleAmendParamsAmendmentAmendmentStartAmendmentEnd,
        SubscriptionScheduleAmendParamsAmendmentAmendmentStartDiscountEnd as SubscriptionScheduleAmendParamsAmendmentAmendmentStartDiscountEnd,
        SubscriptionScheduleAmendParamsAmendmentBillingSchedulesAction as SubscriptionScheduleAmendParamsAmendmentBillingSchedulesAction,
        SubscriptionScheduleAmendParamsAmendmentBillingSchedulesActionAppliesTo as SubscriptionScheduleAmendParamsAmendmentBillingSchedulesActionAppliesTo,
        SubscriptionScheduleAmendParamsAmendmentDiscountAction as SubscriptionScheduleAmendParamsAmendmentDiscountAction,
        SubscriptionScheduleAmendParamsAmendmentDiscountActionAdd as SubscriptionScheduleAmendParamsAmendmentDiscountActionAdd,
        SubscriptionScheduleAmendParamsAmendmentDiscountActionAddDiscountEnd as SubscriptionScheduleAmendParamsAmendmentDiscountActionAddDiscountEnd,
        SubscriptionScheduleAmendParamsAmendmentDiscountActionRemove as SubscriptionScheduleAmendParamsAmendmentDiscountActionRemove,
        SubscriptionScheduleAmendParamsAmendmentDiscountActionSet as SubscriptionScheduleAmendParamsAmendmentDiscountActionSet,
        SubscriptionScheduleAmendParamsAmendmentItemAction as SubscriptionScheduleAmendParamsAmendmentItemAction,
        SubscriptionScheduleAmendParamsAmendmentItemActionAdd as SubscriptionScheduleAmendParamsAmendmentItemActionAdd,
        SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscount as SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscount,
        SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEnd as SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEnd,
        SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEndDuration as SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEndDuration,
        SubscriptionScheduleAmendParamsAmendmentItemActionAddTrial as SubscriptionScheduleAmendParamsAmendmentItemActionAddTrial,
        SubscriptionScheduleAmendParamsAmendmentItemActionRemove as SubscriptionScheduleAmendParamsAmendmentItemActionRemove,
        SubscriptionScheduleAmendParamsAmendmentItemActionSet as SubscriptionScheduleAmendParamsAmendmentItemActionSet,
        SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscount as SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscount,
        SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEnd as SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEnd,
        SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEndDuration as SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEndDuration,
        SubscriptionScheduleAmendParamsAmendmentItemActionSetTrial as SubscriptionScheduleAmendParamsAmendmentItemActionSetTrial,
        SubscriptionScheduleAmendParamsAmendmentMetadataAction as SubscriptionScheduleAmendParamsAmendmentMetadataAction,
        SubscriptionScheduleAmendParamsAmendmentSetPauseCollection as SubscriptionScheduleAmendParamsAmendmentSetPauseCollection,
        SubscriptionScheduleAmendParamsAmendmentSetPauseCollectionSet as SubscriptionScheduleAmendParamsAmendmentSetPauseCollectionSet,
        SubscriptionScheduleAmendParamsAmendmentTrialSettings as SubscriptionScheduleAmendParamsAmendmentTrialSettings,
        SubscriptionScheduleAmendParamsAmendmentTrialSettingsEndBehavior as SubscriptionScheduleAmendParamsAmendmentTrialSettingsEndBehavior,
        SubscriptionScheduleAmendParamsPrebilling as SubscriptionScheduleAmendParamsPrebilling,
        SubscriptionScheduleAmendParamsPrebillingBillFrom as SubscriptionScheduleAmendParamsPrebillingBillFrom,
        SubscriptionScheduleAmendParamsPrebillingBillFromAmendmentStart as SubscriptionScheduleAmendParamsPrebillingBillFromAmendmentStart,
        SubscriptionScheduleAmendParamsPrebillingBillUntil as SubscriptionScheduleAmendParamsPrebillingBillUntil,
        SubscriptionScheduleAmendParamsPrebillingBillUntilAmendmentEnd as SubscriptionScheduleAmendParamsPrebillingBillUntilAmendmentEnd,
        SubscriptionScheduleAmendParamsPrebillingBillUntilDuration as SubscriptionScheduleAmendParamsPrebillingBillUntilDuration,
        SubscriptionScheduleAmendParamsScheduleSettings as SubscriptionScheduleAmendParamsScheduleSettings,
    )
    from stripe.params._subscription_schedule_cancel_params import (
        SubscriptionScheduleCancelParams as SubscriptionScheduleCancelParams,
    )
    from stripe.params._subscription_schedule_create_params import (
        SubscriptionScheduleCreateParams as SubscriptionScheduleCreateParams,
        SubscriptionScheduleCreateParamsBillingMode as SubscriptionScheduleCreateParamsBillingMode,
        SubscriptionScheduleCreateParamsBillingModeFlexible as SubscriptionScheduleCreateParamsBillingModeFlexible,
        SubscriptionScheduleCreateParamsBillingSchedule as SubscriptionScheduleCreateParamsBillingSchedule,
        SubscriptionScheduleCreateParamsBillingScheduleAppliesTo as SubscriptionScheduleCreateParamsBillingScheduleAppliesTo,
        SubscriptionScheduleCreateParamsBillingScheduleBillUntil as SubscriptionScheduleCreateParamsBillingScheduleBillUntil,
        SubscriptionScheduleCreateParamsBillingScheduleBillUntilDuration as SubscriptionScheduleCreateParamsBillingScheduleBillUntilDuration,
        SubscriptionScheduleCreateParamsDefaultSettings as SubscriptionScheduleCreateParamsDefaultSettings,
        SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTax as SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTax,
        SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTaxLiability as SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTaxLiability,
        SubscriptionScheduleCreateParamsDefaultSettingsBillingThresholds as SubscriptionScheduleCreateParamsDefaultSettingsBillingThresholds,
        SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettings as SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettings,
        SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettingsIssuer as SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettingsIssuer,
        SubscriptionScheduleCreateParamsDefaultSettingsTransferData as SubscriptionScheduleCreateParamsDefaultSettingsTransferData,
        SubscriptionScheduleCreateParamsPhase as SubscriptionScheduleCreateParamsPhase,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItem as SubscriptionScheduleCreateParamsPhaseAddInvoiceItem,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscount as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscount,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEnd as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEnd,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriod as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriod,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodEnd as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodEnd,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodStart as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodStart,
        SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPriceData as SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPriceData,
        SubscriptionScheduleCreateParamsPhaseAutomaticTax as SubscriptionScheduleCreateParamsPhaseAutomaticTax,
        SubscriptionScheduleCreateParamsPhaseAutomaticTaxLiability as SubscriptionScheduleCreateParamsPhaseAutomaticTaxLiability,
        SubscriptionScheduleCreateParamsPhaseBillingThresholds as SubscriptionScheduleCreateParamsPhaseBillingThresholds,
        SubscriptionScheduleCreateParamsPhaseDiscount as SubscriptionScheduleCreateParamsPhaseDiscount,
        SubscriptionScheduleCreateParamsPhaseDiscountDiscountEnd as SubscriptionScheduleCreateParamsPhaseDiscountDiscountEnd,
        SubscriptionScheduleCreateParamsPhaseDiscountDiscountEndDuration as SubscriptionScheduleCreateParamsPhaseDiscountDiscountEndDuration,
        SubscriptionScheduleCreateParamsPhaseDuration as SubscriptionScheduleCreateParamsPhaseDuration,
        SubscriptionScheduleCreateParamsPhaseInvoiceSettings as SubscriptionScheduleCreateParamsPhaseInvoiceSettings,
        SubscriptionScheduleCreateParamsPhaseInvoiceSettingsIssuer as SubscriptionScheduleCreateParamsPhaseInvoiceSettingsIssuer,
        SubscriptionScheduleCreateParamsPhaseItem as SubscriptionScheduleCreateParamsPhaseItem,
        SubscriptionScheduleCreateParamsPhaseItemBillingThresholds as SubscriptionScheduleCreateParamsPhaseItemBillingThresholds,
        SubscriptionScheduleCreateParamsPhaseItemDiscount as SubscriptionScheduleCreateParamsPhaseItemDiscount,
        SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEnd as SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEnd,
        SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEndDuration as SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEndDuration,
        SubscriptionScheduleCreateParamsPhaseItemPriceData as SubscriptionScheduleCreateParamsPhaseItemPriceData,
        SubscriptionScheduleCreateParamsPhaseItemPriceDataRecurring as SubscriptionScheduleCreateParamsPhaseItemPriceDataRecurring,
        SubscriptionScheduleCreateParamsPhaseItemTrial as SubscriptionScheduleCreateParamsPhaseItemTrial,
        SubscriptionScheduleCreateParamsPhasePauseCollection as SubscriptionScheduleCreateParamsPhasePauseCollection,
        SubscriptionScheduleCreateParamsPhaseTransferData as SubscriptionScheduleCreateParamsPhaseTransferData,
        SubscriptionScheduleCreateParamsPhaseTrialSettings as SubscriptionScheduleCreateParamsPhaseTrialSettings,
        SubscriptionScheduleCreateParamsPhaseTrialSettingsEndBehavior as SubscriptionScheduleCreateParamsPhaseTrialSettingsEndBehavior,
        SubscriptionScheduleCreateParamsPrebilling as SubscriptionScheduleCreateParamsPrebilling,
    )
    from stripe.params._subscription_schedule_list_params import (
        SubscriptionScheduleListParams as SubscriptionScheduleListParams,
        SubscriptionScheduleListParamsCanceledAt as SubscriptionScheduleListParamsCanceledAt,
        SubscriptionScheduleListParamsCompletedAt as SubscriptionScheduleListParamsCompletedAt,
        SubscriptionScheduleListParamsCreated as SubscriptionScheduleListParamsCreated,
        SubscriptionScheduleListParamsReleasedAt as SubscriptionScheduleListParamsReleasedAt,
    )
    from stripe.params._subscription_schedule_modify_params import (
        SubscriptionScheduleModifyParams as SubscriptionScheduleModifyParams,
        SubscriptionScheduleModifyParamsBillingSchedule as SubscriptionScheduleModifyParamsBillingSchedule,
        SubscriptionScheduleModifyParamsBillingScheduleAppliesTo as SubscriptionScheduleModifyParamsBillingScheduleAppliesTo,
        SubscriptionScheduleModifyParamsBillingScheduleBillUntil as SubscriptionScheduleModifyParamsBillingScheduleBillUntil,
        SubscriptionScheduleModifyParamsBillingScheduleBillUntilDuration as SubscriptionScheduleModifyParamsBillingScheduleBillUntilDuration,
        SubscriptionScheduleModifyParamsDefaultSettings as SubscriptionScheduleModifyParamsDefaultSettings,
        SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTax as SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTax,
        SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTaxLiability as SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTaxLiability,
        SubscriptionScheduleModifyParamsDefaultSettingsBillingThresholds as SubscriptionScheduleModifyParamsDefaultSettingsBillingThresholds,
        SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettings as SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettings,
        SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettingsIssuer as SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettingsIssuer,
        SubscriptionScheduleModifyParamsDefaultSettingsTransferData as SubscriptionScheduleModifyParamsDefaultSettingsTransferData,
        SubscriptionScheduleModifyParamsPhase as SubscriptionScheduleModifyParamsPhase,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItem as SubscriptionScheduleModifyParamsPhaseAddInvoiceItem,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscount as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscount,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEnd as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEnd,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEndDuration as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriod as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriod,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodEnd as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodEnd,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodStart as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodStart,
        SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPriceData as SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPriceData,
        SubscriptionScheduleModifyParamsPhaseAutomaticTax as SubscriptionScheduleModifyParamsPhaseAutomaticTax,
        SubscriptionScheduleModifyParamsPhaseAutomaticTaxLiability as SubscriptionScheduleModifyParamsPhaseAutomaticTaxLiability,
        SubscriptionScheduleModifyParamsPhaseBillingThresholds as SubscriptionScheduleModifyParamsPhaseBillingThresholds,
        SubscriptionScheduleModifyParamsPhaseDiscount as SubscriptionScheduleModifyParamsPhaseDiscount,
        SubscriptionScheduleModifyParamsPhaseDiscountDiscountEnd as SubscriptionScheduleModifyParamsPhaseDiscountDiscountEnd,
        SubscriptionScheduleModifyParamsPhaseDiscountDiscountEndDuration as SubscriptionScheduleModifyParamsPhaseDiscountDiscountEndDuration,
        SubscriptionScheduleModifyParamsPhaseDuration as SubscriptionScheduleModifyParamsPhaseDuration,
        SubscriptionScheduleModifyParamsPhaseInvoiceSettings as SubscriptionScheduleModifyParamsPhaseInvoiceSettings,
        SubscriptionScheduleModifyParamsPhaseInvoiceSettingsIssuer as SubscriptionScheduleModifyParamsPhaseInvoiceSettingsIssuer,
        SubscriptionScheduleModifyParamsPhaseItem as SubscriptionScheduleModifyParamsPhaseItem,
        SubscriptionScheduleModifyParamsPhaseItemBillingThresholds as SubscriptionScheduleModifyParamsPhaseItemBillingThresholds,
        SubscriptionScheduleModifyParamsPhaseItemDiscount as SubscriptionScheduleModifyParamsPhaseItemDiscount,
        SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEnd as SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEnd,
        SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEndDuration as SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEndDuration,
        SubscriptionScheduleModifyParamsPhaseItemPriceData as SubscriptionScheduleModifyParamsPhaseItemPriceData,
        SubscriptionScheduleModifyParamsPhaseItemPriceDataRecurring as SubscriptionScheduleModifyParamsPhaseItemPriceDataRecurring,
        SubscriptionScheduleModifyParamsPhaseItemTrial as SubscriptionScheduleModifyParamsPhaseItemTrial,
        SubscriptionScheduleModifyParamsPhasePauseCollection as SubscriptionScheduleModifyParamsPhasePauseCollection,
        SubscriptionScheduleModifyParamsPhaseTransferData as SubscriptionScheduleModifyParamsPhaseTransferData,
        SubscriptionScheduleModifyParamsPhaseTrialSettings as SubscriptionScheduleModifyParamsPhaseTrialSettings,
        SubscriptionScheduleModifyParamsPhaseTrialSettingsEndBehavior as SubscriptionScheduleModifyParamsPhaseTrialSettingsEndBehavior,
        SubscriptionScheduleModifyParamsPrebilling as SubscriptionScheduleModifyParamsPrebilling,
    )
    from stripe.params._subscription_schedule_release_params import (
        SubscriptionScheduleReleaseParams as SubscriptionScheduleReleaseParams,
    )
    from stripe.params._subscription_schedule_retrieve_params import (
        SubscriptionScheduleRetrieveParams as SubscriptionScheduleRetrieveParams,
    )
    from stripe.params._subscription_schedule_update_params import (
        SubscriptionScheduleUpdateParams as SubscriptionScheduleUpdateParams,
        SubscriptionScheduleUpdateParamsBillingSchedule as SubscriptionScheduleUpdateParamsBillingSchedule,
        SubscriptionScheduleUpdateParamsBillingScheduleAppliesTo as SubscriptionScheduleUpdateParamsBillingScheduleAppliesTo,
        SubscriptionScheduleUpdateParamsBillingScheduleBillUntil as SubscriptionScheduleUpdateParamsBillingScheduleBillUntil,
        SubscriptionScheduleUpdateParamsBillingScheduleBillUntilDuration as SubscriptionScheduleUpdateParamsBillingScheduleBillUntilDuration,
        SubscriptionScheduleUpdateParamsDefaultSettings as SubscriptionScheduleUpdateParamsDefaultSettings,
        SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTax as SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTax,
        SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTaxLiability as SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTaxLiability,
        SubscriptionScheduleUpdateParamsDefaultSettingsBillingThresholds as SubscriptionScheduleUpdateParamsDefaultSettingsBillingThresholds,
        SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettings as SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettings,
        SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettingsIssuer as SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettingsIssuer,
        SubscriptionScheduleUpdateParamsDefaultSettingsTransferData as SubscriptionScheduleUpdateParamsDefaultSettingsTransferData,
        SubscriptionScheduleUpdateParamsPhase as SubscriptionScheduleUpdateParamsPhase,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItem as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItem,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscount as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscount,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEnd as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEnd,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriod as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriod,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodEnd as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodEnd,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodStart as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodStart,
        SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPriceData as SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPriceData,
        SubscriptionScheduleUpdateParamsPhaseAutomaticTax as SubscriptionScheduleUpdateParamsPhaseAutomaticTax,
        SubscriptionScheduleUpdateParamsPhaseAutomaticTaxLiability as SubscriptionScheduleUpdateParamsPhaseAutomaticTaxLiability,
        SubscriptionScheduleUpdateParamsPhaseBillingThresholds as SubscriptionScheduleUpdateParamsPhaseBillingThresholds,
        SubscriptionScheduleUpdateParamsPhaseDiscount as SubscriptionScheduleUpdateParamsPhaseDiscount,
        SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEnd as SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEnd,
        SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEndDuration as SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEndDuration,
        SubscriptionScheduleUpdateParamsPhaseDuration as SubscriptionScheduleUpdateParamsPhaseDuration,
        SubscriptionScheduleUpdateParamsPhaseInvoiceSettings as SubscriptionScheduleUpdateParamsPhaseInvoiceSettings,
        SubscriptionScheduleUpdateParamsPhaseInvoiceSettingsIssuer as SubscriptionScheduleUpdateParamsPhaseInvoiceSettingsIssuer,
        SubscriptionScheduleUpdateParamsPhaseItem as SubscriptionScheduleUpdateParamsPhaseItem,
        SubscriptionScheduleUpdateParamsPhaseItemBillingThresholds as SubscriptionScheduleUpdateParamsPhaseItemBillingThresholds,
        SubscriptionScheduleUpdateParamsPhaseItemDiscount as SubscriptionScheduleUpdateParamsPhaseItemDiscount,
        SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEnd as SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEnd,
        SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEndDuration as SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEndDuration,
        SubscriptionScheduleUpdateParamsPhaseItemPriceData as SubscriptionScheduleUpdateParamsPhaseItemPriceData,
        SubscriptionScheduleUpdateParamsPhaseItemPriceDataRecurring as SubscriptionScheduleUpdateParamsPhaseItemPriceDataRecurring,
        SubscriptionScheduleUpdateParamsPhaseItemTrial as SubscriptionScheduleUpdateParamsPhaseItemTrial,
        SubscriptionScheduleUpdateParamsPhasePauseCollection as SubscriptionScheduleUpdateParamsPhasePauseCollection,
        SubscriptionScheduleUpdateParamsPhaseTransferData as SubscriptionScheduleUpdateParamsPhaseTransferData,
        SubscriptionScheduleUpdateParamsPhaseTrialSettings as SubscriptionScheduleUpdateParamsPhaseTrialSettings,
        SubscriptionScheduleUpdateParamsPhaseTrialSettingsEndBehavior as SubscriptionScheduleUpdateParamsPhaseTrialSettingsEndBehavior,
        SubscriptionScheduleUpdateParamsPrebilling as SubscriptionScheduleUpdateParamsPrebilling,
    )
    from stripe.params._subscription_search_params import (
        SubscriptionSearchParams as SubscriptionSearchParams,
    )
    from stripe.params._subscription_update_params import (
        SubscriptionUpdateParams as SubscriptionUpdateParams,
        SubscriptionUpdateParamsAddInvoiceItem as SubscriptionUpdateParamsAddInvoiceItem,
        SubscriptionUpdateParamsAddInvoiceItemDiscount as SubscriptionUpdateParamsAddInvoiceItemDiscount,
        SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEnd as SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEnd,
        SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEndDuration as SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEndDuration,
        SubscriptionUpdateParamsAddInvoiceItemPeriod as SubscriptionUpdateParamsAddInvoiceItemPeriod,
        SubscriptionUpdateParamsAddInvoiceItemPeriodEnd as SubscriptionUpdateParamsAddInvoiceItemPeriodEnd,
        SubscriptionUpdateParamsAddInvoiceItemPeriodStart as SubscriptionUpdateParamsAddInvoiceItemPeriodStart,
        SubscriptionUpdateParamsAddInvoiceItemPriceData as SubscriptionUpdateParamsAddInvoiceItemPriceData,
        SubscriptionUpdateParamsAutomaticTax as SubscriptionUpdateParamsAutomaticTax,
        SubscriptionUpdateParamsAutomaticTaxLiability as SubscriptionUpdateParamsAutomaticTaxLiability,
        SubscriptionUpdateParamsBillingSchedule as SubscriptionUpdateParamsBillingSchedule,
        SubscriptionUpdateParamsBillingScheduleAppliesTo as SubscriptionUpdateParamsBillingScheduleAppliesTo,
        SubscriptionUpdateParamsBillingScheduleBillUntil as SubscriptionUpdateParamsBillingScheduleBillUntil,
        SubscriptionUpdateParamsBillingScheduleBillUntilDuration as SubscriptionUpdateParamsBillingScheduleBillUntilDuration,
        SubscriptionUpdateParamsBillingThresholds as SubscriptionUpdateParamsBillingThresholds,
        SubscriptionUpdateParamsCancellationDetails as SubscriptionUpdateParamsCancellationDetails,
        SubscriptionUpdateParamsDiscount as SubscriptionUpdateParamsDiscount,
        SubscriptionUpdateParamsDiscountDiscountEnd as SubscriptionUpdateParamsDiscountDiscountEnd,
        SubscriptionUpdateParamsDiscountDiscountEndDuration as SubscriptionUpdateParamsDiscountDiscountEndDuration,
        SubscriptionUpdateParamsInvoiceSettings as SubscriptionUpdateParamsInvoiceSettings,
        SubscriptionUpdateParamsInvoiceSettingsIssuer as SubscriptionUpdateParamsInvoiceSettingsIssuer,
        SubscriptionUpdateParamsItem as SubscriptionUpdateParamsItem,
        SubscriptionUpdateParamsItemBillingThresholds as SubscriptionUpdateParamsItemBillingThresholds,
        SubscriptionUpdateParamsItemDiscount as SubscriptionUpdateParamsItemDiscount,
        SubscriptionUpdateParamsItemDiscountDiscountEnd as SubscriptionUpdateParamsItemDiscountDiscountEnd,
        SubscriptionUpdateParamsItemDiscountDiscountEndDuration as SubscriptionUpdateParamsItemDiscountDiscountEndDuration,
        SubscriptionUpdateParamsItemPriceData as SubscriptionUpdateParamsItemPriceData,
        SubscriptionUpdateParamsItemPriceDataRecurring as SubscriptionUpdateParamsItemPriceDataRecurring,
        SubscriptionUpdateParamsPauseCollection as SubscriptionUpdateParamsPauseCollection,
        SubscriptionUpdateParamsPaymentSettings as SubscriptionUpdateParamsPaymentSettings,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptions as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptions,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCard as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCard,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPix as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPix,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpi as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpi,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters as SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters,
        SubscriptionUpdateParamsPendingInvoiceItemInterval as SubscriptionUpdateParamsPendingInvoiceItemInterval,
        SubscriptionUpdateParamsPrebilling as SubscriptionUpdateParamsPrebilling,
        SubscriptionUpdateParamsTransferData as SubscriptionUpdateParamsTransferData,
        SubscriptionUpdateParamsTrialSettings as SubscriptionUpdateParamsTrialSettings,
        SubscriptionUpdateParamsTrialSettingsEndBehavior as SubscriptionUpdateParamsTrialSettingsEndBehavior,
    )
    from stripe.params._tax_code_list_params import (
        TaxCodeListParams as TaxCodeListParams,
    )
    from stripe.params._tax_code_retrieve_params import (
        TaxCodeRetrieveParams as TaxCodeRetrieveParams,
    )
    from stripe.params._tax_id_create_params import (
        TaxIdCreateParams as TaxIdCreateParams,
        TaxIdCreateParamsOwner as TaxIdCreateParamsOwner,
    )
    from stripe.params._tax_id_delete_params import (
        TaxIdDeleteParams as TaxIdDeleteParams,
    )
    from stripe.params._tax_id_list_params import (
        TaxIdListParams as TaxIdListParams,
        TaxIdListParamsOwner as TaxIdListParamsOwner,
    )
    from stripe.params._tax_id_retrieve_params import (
        TaxIdRetrieveParams as TaxIdRetrieveParams,
    )
    from stripe.params._tax_rate_create_params import (
        TaxRateCreateParams as TaxRateCreateParams,
    )
    from stripe.params._tax_rate_list_params import (
        TaxRateListParams as TaxRateListParams,
        TaxRateListParamsCreated as TaxRateListParamsCreated,
    )
    from stripe.params._tax_rate_modify_params import (
        TaxRateModifyParams as TaxRateModifyParams,
    )
    from stripe.params._tax_rate_retrieve_params import (
        TaxRateRetrieveParams as TaxRateRetrieveParams,
    )
    from stripe.params._tax_rate_update_params import (
        TaxRateUpdateParams as TaxRateUpdateParams,
    )
    from stripe.params._token_create_params import (
        TokenCreateParams as TokenCreateParams,
        TokenCreateParamsAccount as TokenCreateParamsAccount,
        TokenCreateParamsAccountCompany as TokenCreateParamsAccountCompany,
        TokenCreateParamsAccountCompanyAddress as TokenCreateParamsAccountCompanyAddress,
        TokenCreateParamsAccountCompanyAddressKana as TokenCreateParamsAccountCompanyAddressKana,
        TokenCreateParamsAccountCompanyAddressKanji as TokenCreateParamsAccountCompanyAddressKanji,
        TokenCreateParamsAccountCompanyDirectorshipDeclaration as TokenCreateParamsAccountCompanyDirectorshipDeclaration,
        TokenCreateParamsAccountCompanyOwnershipDeclaration as TokenCreateParamsAccountCompanyOwnershipDeclaration,
        TokenCreateParamsAccountCompanyRegistrationDate as TokenCreateParamsAccountCompanyRegistrationDate,
        TokenCreateParamsAccountCompanyRepresentativeDeclaration as TokenCreateParamsAccountCompanyRepresentativeDeclaration,
        TokenCreateParamsAccountCompanyVerification as TokenCreateParamsAccountCompanyVerification,
        TokenCreateParamsAccountCompanyVerificationDocument as TokenCreateParamsAccountCompanyVerificationDocument,
        TokenCreateParamsAccountIndividual as TokenCreateParamsAccountIndividual,
        TokenCreateParamsAccountIndividualAddress as TokenCreateParamsAccountIndividualAddress,
        TokenCreateParamsAccountIndividualAddressKana as TokenCreateParamsAccountIndividualAddressKana,
        TokenCreateParamsAccountIndividualAddressKanji as TokenCreateParamsAccountIndividualAddressKanji,
        TokenCreateParamsAccountIndividualDob as TokenCreateParamsAccountIndividualDob,
        TokenCreateParamsAccountIndividualRegisteredAddress as TokenCreateParamsAccountIndividualRegisteredAddress,
        TokenCreateParamsAccountIndividualRelationship as TokenCreateParamsAccountIndividualRelationship,
        TokenCreateParamsAccountIndividualSelfReportedIncome as TokenCreateParamsAccountIndividualSelfReportedIncome,
        TokenCreateParamsAccountIndividualSelfReportedMonthlyHousingPayment as TokenCreateParamsAccountIndividualSelfReportedMonthlyHousingPayment,
        TokenCreateParamsAccountIndividualVerification as TokenCreateParamsAccountIndividualVerification,
        TokenCreateParamsAccountIndividualVerificationAdditionalDocument as TokenCreateParamsAccountIndividualVerificationAdditionalDocument,
        TokenCreateParamsAccountIndividualVerificationDocument as TokenCreateParamsAccountIndividualVerificationDocument,
        TokenCreateParamsBankAccount as TokenCreateParamsBankAccount,
        TokenCreateParamsCard as TokenCreateParamsCard,
        TokenCreateParamsCardNetworks as TokenCreateParamsCardNetworks,
        TokenCreateParamsCvcUpdate as TokenCreateParamsCvcUpdate,
        TokenCreateParamsPerson as TokenCreateParamsPerson,
        TokenCreateParamsPersonAdditionalTosAcceptances as TokenCreateParamsPersonAdditionalTosAcceptances,
        TokenCreateParamsPersonAdditionalTosAcceptancesAccount as TokenCreateParamsPersonAdditionalTosAcceptancesAccount,
        TokenCreateParamsPersonAddress as TokenCreateParamsPersonAddress,
        TokenCreateParamsPersonAddressKana as TokenCreateParamsPersonAddressKana,
        TokenCreateParamsPersonAddressKanji as TokenCreateParamsPersonAddressKanji,
        TokenCreateParamsPersonDob as TokenCreateParamsPersonDob,
        TokenCreateParamsPersonDocuments as TokenCreateParamsPersonDocuments,
        TokenCreateParamsPersonDocumentsCompanyAuthorization as TokenCreateParamsPersonDocumentsCompanyAuthorization,
        TokenCreateParamsPersonDocumentsPassport as TokenCreateParamsPersonDocumentsPassport,
        TokenCreateParamsPersonDocumentsVisa as TokenCreateParamsPersonDocumentsVisa,
        TokenCreateParamsPersonRegisteredAddress as TokenCreateParamsPersonRegisteredAddress,
        TokenCreateParamsPersonRelationship as TokenCreateParamsPersonRelationship,
        TokenCreateParamsPersonSelfReportedIncome as TokenCreateParamsPersonSelfReportedIncome,
        TokenCreateParamsPersonSelfReportedMonthlyHousingPayment as TokenCreateParamsPersonSelfReportedMonthlyHousingPayment,
        TokenCreateParamsPersonUsCfpbData as TokenCreateParamsPersonUsCfpbData,
        TokenCreateParamsPersonUsCfpbDataEthnicityDetails as TokenCreateParamsPersonUsCfpbDataEthnicityDetails,
        TokenCreateParamsPersonUsCfpbDataRaceDetails as TokenCreateParamsPersonUsCfpbDataRaceDetails,
        TokenCreateParamsPersonVerification as TokenCreateParamsPersonVerification,
        TokenCreateParamsPersonVerificationAdditionalDocument as TokenCreateParamsPersonVerificationAdditionalDocument,
        TokenCreateParamsPersonVerificationDocument as TokenCreateParamsPersonVerificationDocument,
        TokenCreateParamsPii as TokenCreateParamsPii,
    )
    from stripe.params._token_retrieve_params import (
        TokenRetrieveParams as TokenRetrieveParams,
    )
    from stripe.params._topup_cancel_params import (
        TopupCancelParams as TopupCancelParams,
    )
    from stripe.params._topup_create_params import (
        TopupCreateParams as TopupCreateParams,
    )
    from stripe.params._topup_list_params import (
        TopupListParams as TopupListParams,
        TopupListParamsAmount as TopupListParamsAmount,
        TopupListParamsCreated as TopupListParamsCreated,
    )
    from stripe.params._topup_modify_params import (
        TopupModifyParams as TopupModifyParams,
    )
    from stripe.params._topup_retrieve_params import (
        TopupRetrieveParams as TopupRetrieveParams,
    )
    from stripe.params._topup_update_params import (
        TopupUpdateParams as TopupUpdateParams,
    )
    from stripe.params._transfer_create_params import (
        TransferCreateParams as TransferCreateParams,
    )
    from stripe.params._transfer_create_reversal_params import (
        TransferCreateReversalParams as TransferCreateReversalParams,
    )
    from stripe.params._transfer_list_params import (
        TransferListParams as TransferListParams,
        TransferListParamsCreated as TransferListParamsCreated,
    )
    from stripe.params._transfer_list_reversals_params import (
        TransferListReversalsParams as TransferListReversalsParams,
    )
    from stripe.params._transfer_modify_params import (
        TransferModifyParams as TransferModifyParams,
    )
    from stripe.params._transfer_modify_reversal_params import (
        TransferModifyReversalParams as TransferModifyReversalParams,
    )
    from stripe.params._transfer_retrieve_params import (
        TransferRetrieveParams as TransferRetrieveParams,
    )
    from stripe.params._transfer_retrieve_reversal_params import (
        TransferRetrieveReversalParams as TransferRetrieveReversalParams,
    )
    from stripe.params._transfer_reversal_create_params import (
        TransferReversalCreateParams as TransferReversalCreateParams,
    )
    from stripe.params._transfer_reversal_list_params import (
        TransferReversalListParams as TransferReversalListParams,
    )
    from stripe.params._transfer_reversal_retrieve_params import (
        TransferReversalRetrieveParams as TransferReversalRetrieveParams,
    )
    from stripe.params._transfer_reversal_update_params import (
        TransferReversalUpdateParams as TransferReversalUpdateParams,
    )
    from stripe.params._transfer_update_params import (
        TransferUpdateParams as TransferUpdateParams,
    )
    from stripe.params._webhook_endpoint_create_params import (
        WebhookEndpointCreateParams as WebhookEndpointCreateParams,
    )
    from stripe.params._webhook_endpoint_delete_params import (
        WebhookEndpointDeleteParams as WebhookEndpointDeleteParams,
    )
    from stripe.params._webhook_endpoint_list_params import (
        WebhookEndpointListParams as WebhookEndpointListParams,
    )
    from stripe.params._webhook_endpoint_modify_params import (
        WebhookEndpointModifyParams as WebhookEndpointModifyParams,
    )
    from stripe.params._webhook_endpoint_retrieve_params import (
        WebhookEndpointRetrieveParams as WebhookEndpointRetrieveParams,
    )
    from stripe.params._webhook_endpoint_update_params import (
        WebhookEndpointUpdateParams as WebhookEndpointUpdateParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "apps": ("stripe.params.apps", True),
    "billing": ("stripe.params.billing", True),
    "billing_portal": ("stripe.params.billing_portal", True),
    "capital": ("stripe.params.capital", True),
    "checkout": ("stripe.params.checkout", True),
    "climate": ("stripe.params.climate", True),
    "delegated_checkout": ("stripe.params.delegated_checkout", True),
    "entitlements": ("stripe.params.entitlements", True),
    "financial_connections": ("stripe.params.financial_connections", True),
    "forwarding": ("stripe.params.forwarding", True),
    "identity": ("stripe.params.identity", True),
    "issuing": ("stripe.params.issuing", True),
    "privacy": ("stripe.params.privacy", True),
    "radar": ("stripe.params.radar", True),
    "reporting": ("stripe.params.reporting", True),
    "sigma": ("stripe.params.sigma", True),
    "tax": ("stripe.params.tax", True),
    "terminal": ("stripe.params.terminal", True),
    "test_helpers": ("stripe.params.test_helpers", True),
    "treasury": ("stripe.params.treasury", True),
    "AccountCapabilityListParams": (
        "stripe.params._account_capability_list_params",
        False,
    ),
    "AccountCapabilityRetrieveParams": (
        "stripe.params._account_capability_retrieve_params",
        False,
    ),
    "AccountCapabilityUpdateParams": (
        "stripe.params._account_capability_update_params",
        False,
    ),
    "AccountCreateExternalAccountParams": (
        "stripe.params._account_create_external_account_params",
        False,
    ),
    "AccountCreateExternalAccountParamsBankAccount": (
        "stripe.params._account_create_external_account_params",
        False,
    ),
    "AccountCreateExternalAccountParamsCard": (
        "stripe.params._account_create_external_account_params",
        False,
    ),
    "AccountCreateExternalAccountParamsCardToken": (
        "stripe.params._account_create_external_account_params",
        False,
    ),
    "AccountCreateLoginLinkParams": (
        "stripe.params._account_create_login_link_params",
        False,
    ),
    "AccountCreateParams": ("stripe.params._account_create_params", False),
    "AccountCreateParamsBankAccount": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsBusinessProfile": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsBusinessProfileAnnualRevenue": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsBusinessProfileMonthlyEstimatedRevenue": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsBusinessProfileSupportAddress": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilities": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAcssDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAffirmPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAfterpayClearpayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAlmaPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAmazonPayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAuBecsDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesAutomaticIndirectTax": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBacsDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBancontactPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBilliePayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBlikPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesBoletoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesCardIssuing": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesCardPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesCartesBancairesPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesCashappPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesCryptoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesEpsPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesFpxPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesGbBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesGiropayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesGopayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesGrabpayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesIdBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesIdBankTransferPaymentsBca": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesIdealPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesIndiaInternationalPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesJcbPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesJpBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesKakaoPayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesKlarnaPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesKonbiniPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesKrCardPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesLegacyPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesLinkPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesMbWayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesMobilepayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesMultibancoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesMxBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesNaverPayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesNzBankAccountBecsDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesOxxoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesP24Payments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPayByBankPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPaycoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPaynowPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPaypalPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPaypayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPaytoPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPixPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesPromptpayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesQrisPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesRechnungPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesRevolutPayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSamsungPayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSatispayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSepaBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSepaDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesShopeepayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSofortPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesStripeBalancePayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesSwishPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTaxReportingUs1099K": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTaxReportingUs1099Misc": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTransfers": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTreasury": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTreasuryEvolve": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTreasuryFifthThird": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTreasuryGoldmanSachs": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesTwintPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesUsBankAccountAchPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesUsBankTransferPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCapabilitiesZipPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCard": ("stripe.params._account_create_params", False),
    "AccountCreateParamsCardToken": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompany": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyAddress": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyAddressKana": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyAddressKanji": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyDirectorshipDeclaration": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyOwnershipDeclaration": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyRegistrationDate": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyRepresentativeDeclaration": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyVerification": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsCompanyVerificationDocument": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsController": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsControllerApplication": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsControllerDashboard": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsControllerFees": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsControllerLosses": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsControllerStripeDashboard": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocuments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsBankAccountOwnershipVerification": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsCompanyLicense": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsCompanyMinisterialDecree": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsCompanyRegistrationVerification": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsCompanyTaxIdVerification": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsProofOfAddress": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsProofOfRegistration": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsGroups": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividual": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualAddress": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualAddressKana": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualAddressKanji": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualDob": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualRegisteredAddress": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualRelationship": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualSelfReportedIncome": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualVerification": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualVerificationAdditionalDocument": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsIndividualVerificationDocument": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsRiskControls": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsRiskControlsCharges": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsRiskControlsPayouts": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettings": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsBacsDebitPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsBankBcaOnboarding": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsBranding": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsCapital": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsCardIssuing": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsCardIssuingTosAcceptance": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsCardPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsCardPaymentsDeclineOn": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsInvoices": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsPayouts": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsPayoutsSchedule": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsPaypayPayments": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsTaxForms": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsTreasury": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsSettingsTreasuryTosAcceptance": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreateParamsTosAcceptance": (
        "stripe.params._account_create_params",
        False,
    ),
    "AccountCreatePersonParams": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsAdditionalTosAcceptances": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsAdditionalTosAcceptancesAccount": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsAddress": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsAddressKana": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsAddressKanji": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsDob": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsDocuments": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsDocumentsCompanyAuthorization": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsDocumentsPassport": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsDocumentsVisa": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsRegisteredAddress": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsRelationship": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsSelfReportedIncome": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsUsCfpbData": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsUsCfpbDataEthnicityDetails": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsUsCfpbDataRaceDetails": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsVerification": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsVerificationAdditionalDocument": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountCreatePersonParamsVerificationDocument": (
        "stripe.params._account_create_person_params",
        False,
    ),
    "AccountDeleteExternalAccountParams": (
        "stripe.params._account_delete_external_account_params",
        False,
    ),
    "AccountDeleteParams": ("stripe.params._account_delete_params", False),
    "AccountDeletePersonParams": (
        "stripe.params._account_delete_person_params",
        False,
    ),
    "AccountExternalAccountCreateParams": (
        "stripe.params._account_external_account_create_params",
        False,
    ),
    "AccountExternalAccountCreateParamsBankAccount": (
        "stripe.params._account_external_account_create_params",
        False,
    ),
    "AccountExternalAccountCreateParamsCard": (
        "stripe.params._account_external_account_create_params",
        False,
    ),
    "AccountExternalAccountCreateParamsCardToken": (
        "stripe.params._account_external_account_create_params",
        False,
    ),
    "AccountExternalAccountDeleteParams": (
        "stripe.params._account_external_account_delete_params",
        False,
    ),
    "AccountExternalAccountListParams": (
        "stripe.params._account_external_account_list_params",
        False,
    ),
    "AccountExternalAccountRetrieveParams": (
        "stripe.params._account_external_account_retrieve_params",
        False,
    ),
    "AccountExternalAccountUpdateParams": (
        "stripe.params._account_external_account_update_params",
        False,
    ),
    "AccountExternalAccountUpdateParamsDocuments": (
        "stripe.params._account_external_account_update_params",
        False,
    ),
    "AccountExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification": (
        "stripe.params._account_external_account_update_params",
        False,
    ),
    "AccountLinkCreateParams": (
        "stripe.params._account_link_create_params",
        False,
    ),
    "AccountLinkCreateParamsCollectionOptions": (
        "stripe.params._account_link_create_params",
        False,
    ),
    "AccountListCapabilitiesParams": (
        "stripe.params._account_list_capabilities_params",
        False,
    ),
    "AccountListExternalAccountsParams": (
        "stripe.params._account_list_external_accounts_params",
        False,
    ),
    "AccountListParams": ("stripe.params._account_list_params", False),
    "AccountListParamsCreated": ("stripe.params._account_list_params", False),
    "AccountListPersonsParams": (
        "stripe.params._account_list_persons_params",
        False,
    ),
    "AccountListPersonsParamsRelationship": (
        "stripe.params._account_list_persons_params",
        False,
    ),
    "AccountLoginLinkCreateParams": (
        "stripe.params._account_login_link_create_params",
        False,
    ),
    "AccountModifyCapabilityParams": (
        "stripe.params._account_modify_capability_params",
        False,
    ),
    "AccountModifyExternalAccountParams": (
        "stripe.params._account_modify_external_account_params",
        False,
    ),
    "AccountModifyExternalAccountParamsDocuments": (
        "stripe.params._account_modify_external_account_params",
        False,
    ),
    "AccountModifyExternalAccountParamsDocumentsBankAccountOwnershipVerification": (
        "stripe.params._account_modify_external_account_params",
        False,
    ),
    "AccountModifyPersonParams": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsAdditionalTosAcceptances": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsAdditionalTosAcceptancesAccount": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsAddress": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsAddressKana": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsAddressKanji": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsDob": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsDocuments": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsDocumentsCompanyAuthorization": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsDocumentsPassport": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsDocumentsVisa": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsRegisteredAddress": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsRelationship": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsSelfReportedIncome": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsUsCfpbData": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsUsCfpbDataEthnicityDetails": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsUsCfpbDataRaceDetails": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsVerification": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsVerificationAdditionalDocument": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountModifyPersonParamsVerificationDocument": (
        "stripe.params._account_modify_person_params",
        False,
    ),
    "AccountNoticeListParams": (
        "stripe.params._account_notice_list_params",
        False,
    ),
    "AccountNoticeModifyParams": (
        "stripe.params._account_notice_modify_params",
        False,
    ),
    "AccountNoticeModifyParamsEmail": (
        "stripe.params._account_notice_modify_params",
        False,
    ),
    "AccountNoticeRetrieveParams": (
        "stripe.params._account_notice_retrieve_params",
        False,
    ),
    "AccountNoticeUpdateParams": (
        "stripe.params._account_notice_update_params",
        False,
    ),
    "AccountNoticeUpdateParamsEmail": (
        "stripe.params._account_notice_update_params",
        False,
    ),
    "AccountPersonCreateParams": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsAdditionalTosAcceptances": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsAdditionalTosAcceptancesAccount": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsAddress": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsAddressKana": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsAddressKanji": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsDob": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsDocuments": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsDocumentsCompanyAuthorization": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsDocumentsPassport": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsDocumentsVisa": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsRegisteredAddress": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsRelationship": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsSelfReportedIncome": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsUsCfpbData": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsUsCfpbDataEthnicityDetails": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsUsCfpbDataRaceDetails": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsVerification": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsVerificationAdditionalDocument": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonCreateParamsVerificationDocument": (
        "stripe.params._account_person_create_params",
        False,
    ),
    "AccountPersonDeleteParams": (
        "stripe.params._account_person_delete_params",
        False,
    ),
    "AccountPersonListParams": (
        "stripe.params._account_person_list_params",
        False,
    ),
    "AccountPersonListParamsRelationship": (
        "stripe.params._account_person_list_params",
        False,
    ),
    "AccountPersonRetrieveParams": (
        "stripe.params._account_person_retrieve_params",
        False,
    ),
    "AccountPersonUpdateParams": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsAdditionalTosAcceptances": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsAdditionalTosAcceptancesAccount": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsAddress": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsAddressKana": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsAddressKanji": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsDob": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsDocuments": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsDocumentsCompanyAuthorization": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsDocumentsPassport": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsDocumentsVisa": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsRegisteredAddress": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsRelationship": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsSelfReportedIncome": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsUsCfpbData": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsUsCfpbDataEthnicityDetails": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsUsCfpbDataRaceDetails": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsVerification": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsVerificationAdditionalDocument": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonUpdateParamsVerificationDocument": (
        "stripe.params._account_person_update_params",
        False,
    ),
    "AccountPersonsParams": ("stripe.params._account_persons_params", False),
    "AccountPersonsParamsRelationship": (
        "stripe.params._account_persons_params",
        False,
    ),
    "AccountRejectParams": ("stripe.params._account_reject_params", False),
    "AccountRetrieveCapabilityParams": (
        "stripe.params._account_retrieve_capability_params",
        False,
    ),
    "AccountRetrieveCurrentParams": (
        "stripe.params._account_retrieve_current_params",
        False,
    ),
    "AccountRetrieveExternalAccountParams": (
        "stripe.params._account_retrieve_external_account_params",
        False,
    ),
    "AccountRetrieveParams": ("stripe.params._account_retrieve_params", False),
    "AccountRetrievePersonParams": (
        "stripe.params._account_retrieve_person_params",
        False,
    ),
    "AccountSessionCreateParams": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponents": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAccountManagement": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAccountManagementFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAccountOnboarding": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAccountOnboardingFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAppInstall": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAppInstallFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAppViewport": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsAppViewportFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsBalances": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsBalancesFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancing": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancingApplication": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancingApplicationFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancingFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancingPromotion": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalFinancingPromotionFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalOverview": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsCapitalOverviewFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsDisputesList": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsDisputesListFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsDocuments": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsDocumentsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsExportTaxTransactions": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsExportTaxTransactionsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsFinancialAccount": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsFinancialAccountFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsFinancialAccountTransactions": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsFinancialAccountTransactionsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsInstantPayoutsPromotion": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsInstantPayoutsPromotionFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsIssuingCard": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsIssuingCardFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsIssuingCardsList": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsIssuingCardsListFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsNotificationBanner": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsNotificationBannerFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentDetails": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentDetailsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentDisputes": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentDisputesFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentMethodSettings": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentMethodSettingsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayments": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPaymentsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayoutDetails": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayoutDetailsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayouts": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayoutsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayoutsList": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsPayoutsListFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsProductTaxCodeSelector": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsProductTaxCodeSelectorFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsRecipients": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsRecipientsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsReportingChart": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsReportingChartFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxRegistrations": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxRegistrationsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxSettings": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxSettingsFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxThresholdMonitoring": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountSessionCreateParamsComponentsTaxThresholdMonitoringFeatures": (
        "stripe.params._account_session_create_params",
        False,
    ),
    "AccountUpdateParams": ("stripe.params._account_update_params", False),
    "AccountUpdateParamsBankAccount": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsBusinessProfile": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsBusinessProfileAnnualRevenue": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsBusinessProfileMonthlyEstimatedRevenue": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsBusinessProfileSupportAddress": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilities": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAcssDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAffirmPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAfterpayClearpayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAlmaPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAmazonPayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAuBecsDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesAutomaticIndirectTax": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBacsDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBancontactPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBilliePayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBlikPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesBoletoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesCardIssuing": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesCardPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesCartesBancairesPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesCashappPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesCryptoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesEpsPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesFpxPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesGbBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesGiropayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesGopayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesGrabpayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesIdBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesIdBankTransferPaymentsBca": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesIdealPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesIndiaInternationalPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesJcbPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesJpBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesKakaoPayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesKlarnaPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesKonbiniPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesKrCardPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesLegacyPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesLinkPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesMbWayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesMobilepayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesMultibancoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesMxBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesNaverPayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesNzBankAccountBecsDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesOxxoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesP24Payments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPayByBankPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPaycoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPaynowPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPaypalPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPaypayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPaytoPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPixPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesPromptpayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesQrisPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesRechnungPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesRevolutPayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSamsungPayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSatispayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSepaBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSepaDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesShopeepayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSofortPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesStripeBalancePayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesSwishPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTaxReportingUs1099K": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTaxReportingUs1099Misc": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTransfers": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTreasury": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTreasuryEvolve": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTreasuryFifthThird": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTreasuryGoldmanSachs": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesTwintPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesUsBankAccountAchPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesUsBankTransferPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCapabilitiesZipPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCard": ("stripe.params._account_update_params", False),
    "AccountUpdateParamsCardToken": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompany": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyAddress": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyAddressKana": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyAddressKanji": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyDirectorshipDeclaration": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyOwnershipDeclaration": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyRegistrationDate": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyRepresentativeDeclaration": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyVerification": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsCompanyVerificationDocument": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocuments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsBankAccountOwnershipVerification": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsCompanyLicense": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsCompanyMemorandumOfAssociation": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsCompanyMinisterialDecree": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsCompanyRegistrationVerification": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsCompanyTaxIdVerification": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsProofOfAddress": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsProofOfRegistration": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsDocumentsProofOfUltimateBeneficialOwnership": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsGroups": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividual": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualAddress": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualAddressKana": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualAddressKanji": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualDob": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualRegisteredAddress": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualRelationship": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualSelfReportedIncome": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualSelfReportedMonthlyHousingPayment": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualVerification": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualVerificationAdditionalDocument": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsIndividualVerificationDocument": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsRiskControls": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsRiskControlsCharges": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsRiskControlsPayouts": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettings": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsBacsDebitPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsBankBcaOnboarding": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsBranding": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsCapital": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsCardIssuing": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsCardIssuingTosAcceptance": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsCardPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsCardPaymentsDeclineOn": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsInvoices": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsPayouts": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsPayoutsSchedule": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsPaypayPayments": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsTaxForms": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsTreasury": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsSettingsTreasuryTosAcceptance": (
        "stripe.params._account_update_params",
        False,
    ),
    "AccountUpdateParamsTosAcceptance": (
        "stripe.params._account_update_params",
        False,
    ),
    "ApplePayDomainCreateParams": (
        "stripe.params._apple_pay_domain_create_params",
        False,
    ),
    "ApplePayDomainDeleteParams": (
        "stripe.params._apple_pay_domain_delete_params",
        False,
    ),
    "ApplePayDomainListParams": (
        "stripe.params._apple_pay_domain_list_params",
        False,
    ),
    "ApplePayDomainRetrieveParams": (
        "stripe.params._apple_pay_domain_retrieve_params",
        False,
    ),
    "ApplicationFeeCreateRefundParams": (
        "stripe.params._application_fee_create_refund_params",
        False,
    ),
    "ApplicationFeeListParams": (
        "stripe.params._application_fee_list_params",
        False,
    ),
    "ApplicationFeeListParamsCreated": (
        "stripe.params._application_fee_list_params",
        False,
    ),
    "ApplicationFeeListRefundsParams": (
        "stripe.params._application_fee_list_refunds_params",
        False,
    ),
    "ApplicationFeeModifyRefundParams": (
        "stripe.params._application_fee_modify_refund_params",
        False,
    ),
    "ApplicationFeeRefundCreateParams": (
        "stripe.params._application_fee_refund_create_params",
        False,
    ),
    "ApplicationFeeRefundListParams": (
        "stripe.params._application_fee_refund_list_params",
        False,
    ),
    "ApplicationFeeRefundParams": (
        "stripe.params._application_fee_refund_params",
        False,
    ),
    "ApplicationFeeRefundRetrieveParams": (
        "stripe.params._application_fee_refund_retrieve_params",
        False,
    ),
    "ApplicationFeeRefundUpdateParams": (
        "stripe.params._application_fee_refund_update_params",
        False,
    ),
    "ApplicationFeeRetrieveParams": (
        "stripe.params._application_fee_retrieve_params",
        False,
    ),
    "ApplicationFeeRetrieveRefundParams": (
        "stripe.params._application_fee_retrieve_refund_params",
        False,
    ),
    "BalanceRetrieveParams": ("stripe.params._balance_retrieve_params", False),
    "BalanceSettingsModifyParams": (
        "stripe.params._balance_settings_modify_params",
        False,
    ),
    "BalanceSettingsModifyParamsPayments": (
        "stripe.params._balance_settings_modify_params",
        False,
    ),
    "BalanceSettingsModifyParamsPaymentsPayouts": (
        "stripe.params._balance_settings_modify_params",
        False,
    ),
    "BalanceSettingsModifyParamsPaymentsPayoutsSchedule": (
        "stripe.params._balance_settings_modify_params",
        False,
    ),
    "BalanceSettingsModifyParamsPaymentsSettlementTiming": (
        "stripe.params._balance_settings_modify_params",
        False,
    ),
    "BalanceSettingsRetrieveParams": (
        "stripe.params._balance_settings_retrieve_params",
        False,
    ),
    "BalanceSettingsUpdateParams": (
        "stripe.params._balance_settings_update_params",
        False,
    ),
    "BalanceSettingsUpdateParamsPayments": (
        "stripe.params._balance_settings_update_params",
        False,
    ),
    "BalanceSettingsUpdateParamsPaymentsPayouts": (
        "stripe.params._balance_settings_update_params",
        False,
    ),
    "BalanceSettingsUpdateParamsPaymentsPayoutsSchedule": (
        "stripe.params._balance_settings_update_params",
        False,
    ),
    "BalanceSettingsUpdateParamsPaymentsSettlementTiming": (
        "stripe.params._balance_settings_update_params",
        False,
    ),
    "BalanceTransactionListParams": (
        "stripe.params._balance_transaction_list_params",
        False,
    ),
    "BalanceTransactionListParamsCreated": (
        "stripe.params._balance_transaction_list_params",
        False,
    ),
    "BalanceTransactionRetrieveParams": (
        "stripe.params._balance_transaction_retrieve_params",
        False,
    ),
    "BalanceTransferCreateParams": (
        "stripe.params._balance_transfer_create_params",
        False,
    ),
    "BalanceTransferCreateParamsDestinationBalance": (
        "stripe.params._balance_transfer_create_params",
        False,
    ),
    "BalanceTransferCreateParamsSourceBalance": (
        "stripe.params._balance_transfer_create_params",
        False,
    ),
    "BalanceTransferCreateParamsSourceBalanceAllocatedFunds": (
        "stripe.params._balance_transfer_create_params",
        False,
    ),
    "BankAccountDeleteParams": (
        "stripe.params._bank_account_delete_params",
        False,
    ),
    "CardDeleteParams": ("stripe.params._card_delete_params", False),
    "ChargeCaptureParams": ("stripe.params._charge_capture_params", False),
    "ChargeCaptureParamsPaymentDetails": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRental": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsEventDetails": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlight": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatum": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDelivery": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightPassenger": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsFlightSegment": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodging": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatum": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsSubscription": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCaptureParamsTransferData": (
        "stripe.params._charge_capture_params",
        False,
    ),
    "ChargeCreateParams": ("stripe.params._charge_create_params", False),
    "ChargeCreateParamsDestination": (
        "stripe.params._charge_create_params",
        False,
    ),
    "ChargeCreateParamsRadarOptions": (
        "stripe.params._charge_create_params",
        False,
    ),
    "ChargeCreateParamsShipping": (
        "stripe.params._charge_create_params",
        False,
    ),
    "ChargeCreateParamsShippingAddress": (
        "stripe.params._charge_create_params",
        False,
    ),
    "ChargeCreateParamsTransferData": (
        "stripe.params._charge_create_params",
        False,
    ),
    "ChargeListParams": ("stripe.params._charge_list_params", False),
    "ChargeListParamsCreated": ("stripe.params._charge_list_params", False),
    "ChargeListRefundsParams": (
        "stripe.params._charge_list_refunds_params",
        False,
    ),
    "ChargeModifyParams": ("stripe.params._charge_modify_params", False),
    "ChargeModifyParamsFraudDetails": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetails": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRental": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsEventDetails": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlight": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatum": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDelivery": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightPassenger": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsFlightSegment": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodging": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatum": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsSubscription": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsShipping": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeModifyParamsShippingAddress": (
        "stripe.params._charge_modify_params",
        False,
    ),
    "ChargeRetrieveParams": ("stripe.params._charge_retrieve_params", False),
    "ChargeRetrieveRefundParams": (
        "stripe.params._charge_retrieve_refund_params",
        False,
    ),
    "ChargeSearchParams": ("stripe.params._charge_search_params", False),
    "ChargeUpdateParams": ("stripe.params._charge_update_params", False),
    "ChargeUpdateParamsFraudDetails": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetails": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRental": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsEventDetails": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlight": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatum": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDelivery": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightPassenger": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsFlightSegment": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodging": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatum": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsSubscription": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsShipping": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ChargeUpdateParamsShippingAddress": (
        "stripe.params._charge_update_params",
        False,
    ),
    "ConfirmationTokenCreateParams": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodData": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAcssDebit": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAffirm": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAlipay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAlma": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAmazonPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBacsDebit": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBancontact": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBillie": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBillingDetails": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBlik": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataBoleto": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataCashapp": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataCrypto": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataEps": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataFpx": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataGiropay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataGopay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataGrabpay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataIdeal": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataInteracPresent": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataKakaoPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataKlarna": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataKonbini": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataKrCard": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataLink": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataMbWay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataMobilepay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataMultibanco": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataNaverPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataOxxo": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataP24": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPayByBank": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPayco": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPaynow": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPaypal": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPaypay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPayto": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPix": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataPromptpay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataQris": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataRadarOptions": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataRechnung": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataRechnungDob": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataRevolutPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataSamsungPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataSatispay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataSepaDebit": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataShopeepay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataSofort": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataStripeBalance": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataSwish": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataTwint": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataWechatPay": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodDataZip": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodOptions": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodOptionsCard": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsShipping": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenCreateParamsShippingAddress": (
        "stripe.params._confirmation_token_create_params",
        False,
    ),
    "ConfirmationTokenRetrieveParams": (
        "stripe.params._confirmation_token_retrieve_params",
        False,
    ),
    "CountrySpecListParams": (
        "stripe.params._country_spec_list_params",
        False,
    ),
    "CountrySpecRetrieveParams": (
        "stripe.params._country_spec_retrieve_params",
        False,
    ),
    "CouponCreateParams": ("stripe.params._coupon_create_params", False),
    "CouponCreateParamsAppliesTo": (
        "stripe.params._coupon_create_params",
        False,
    ),
    "CouponCreateParamsCurrencyOptions": (
        "stripe.params._coupon_create_params",
        False,
    ),
    "CouponCreateParamsScript": ("stripe.params._coupon_create_params", False),
    "CouponDeleteParams": ("stripe.params._coupon_delete_params", False),
    "CouponListParams": ("stripe.params._coupon_list_params", False),
    "CouponListParamsCreated": ("stripe.params._coupon_list_params", False),
    "CouponModifyParams": ("stripe.params._coupon_modify_params", False),
    "CouponModifyParamsCurrencyOptions": (
        "stripe.params._coupon_modify_params",
        False,
    ),
    "CouponRetrieveParams": ("stripe.params._coupon_retrieve_params", False),
    "CouponUpdateParams": ("stripe.params._coupon_update_params", False),
    "CouponUpdateParamsCurrencyOptions": (
        "stripe.params._coupon_update_params",
        False,
    ),
    "CreditNoteCreateParams": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteCreateParamsLine": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteCreateParamsLineTaxAmount": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteCreateParamsRefund": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteCreateParamsRefundPaymentRecordRefund": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteCreateParamsShippingCost": (
        "stripe.params._credit_note_create_params",
        False,
    ),
    "CreditNoteLineItemListParams": (
        "stripe.params._credit_note_line_item_list_params",
        False,
    ),
    "CreditNoteListLinesParams": (
        "stripe.params._credit_note_list_lines_params",
        False,
    ),
    "CreditNoteListParams": ("stripe.params._credit_note_list_params", False),
    "CreditNoteListParamsCreated": (
        "stripe.params._credit_note_list_params",
        False,
    ),
    "CreditNoteModifyParams": (
        "stripe.params._credit_note_modify_params",
        False,
    ),
    "CreditNotePreviewLinesListParams": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesListParamsLine": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesListParamsLineTaxAmount": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesListParamsRefund": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesListParamsRefundPaymentRecordRefund": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesListParamsShippingCost": (
        "stripe.params._credit_note_preview_lines_list_params",
        False,
    ),
    "CreditNotePreviewLinesParams": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewLinesParamsLine": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewLinesParamsLineTaxAmount": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewLinesParamsRefund": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewLinesParamsRefundPaymentRecordRefund": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewLinesParamsShippingCost": (
        "stripe.params._credit_note_preview_lines_params",
        False,
    ),
    "CreditNotePreviewParams": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNotePreviewParamsLine": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNotePreviewParamsLineTaxAmount": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNotePreviewParamsRefund": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNotePreviewParamsRefundPaymentRecordRefund": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNotePreviewParamsShippingCost": (
        "stripe.params._credit_note_preview_params",
        False,
    ),
    "CreditNoteRetrieveParams": (
        "stripe.params._credit_note_retrieve_params",
        False,
    ),
    "CreditNoteUpdateParams": (
        "stripe.params._credit_note_update_params",
        False,
    ),
    "CreditNoteVoidCreditNoteParams": (
        "stripe.params._credit_note_void_credit_note_params",
        False,
    ),
    "CustomerBalanceTransactionCreateParams": (
        "stripe.params._customer_balance_transaction_create_params",
        False,
    ),
    "CustomerBalanceTransactionListParams": (
        "stripe.params._customer_balance_transaction_list_params",
        False,
    ),
    "CustomerBalanceTransactionListParamsCreated": (
        "stripe.params._customer_balance_transaction_list_params",
        False,
    ),
    "CustomerBalanceTransactionRetrieveParams": (
        "stripe.params._customer_balance_transaction_retrieve_params",
        False,
    ),
    "CustomerBalanceTransactionUpdateParams": (
        "stripe.params._customer_balance_transaction_update_params",
        False,
    ),
    "CustomerCashBalanceRetrieveParams": (
        "stripe.params._customer_cash_balance_retrieve_params",
        False,
    ),
    "CustomerCashBalanceTransactionListParams": (
        "stripe.params._customer_cash_balance_transaction_list_params",
        False,
    ),
    "CustomerCashBalanceTransactionRetrieveParams": (
        "stripe.params._customer_cash_balance_transaction_retrieve_params",
        False,
    ),
    "CustomerCashBalanceUpdateParams": (
        "stripe.params._customer_cash_balance_update_params",
        False,
    ),
    "CustomerCashBalanceUpdateParamsSettings": (
        "stripe.params._customer_cash_balance_update_params",
        False,
    ),
    "CustomerCreateBalanceTransactionParams": (
        "stripe.params._customer_create_balance_transaction_params",
        False,
    ),
    "CustomerCreateFundingInstructionsParams": (
        "stripe.params._customer_create_funding_instructions_params",
        False,
    ),
    "CustomerCreateFundingInstructionsParamsBankTransfer": (
        "stripe.params._customer_create_funding_instructions_params",
        False,
    ),
    "CustomerCreateFundingInstructionsParamsBankTransferEuBankTransfer": (
        "stripe.params._customer_create_funding_instructions_params",
        False,
    ),
    "CustomerCreateParams": ("stripe.params._customer_create_params", False),
    "CustomerCreateParamsAddress": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsCashBalance": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsCashBalanceSettings": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsInvoiceSettings": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsInvoiceSettingsCustomField": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsInvoiceSettingsRenderingOptions": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsShipping": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsShippingAddress": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsTax": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateParamsTaxIdDatum": (
        "stripe.params._customer_create_params",
        False,
    ),
    "CustomerCreateSourceParams": (
        "stripe.params._customer_create_source_params",
        False,
    ),
    "CustomerCreateTaxIdParams": (
        "stripe.params._customer_create_tax_id_params",
        False,
    ),
    "CustomerDeleteDiscountParams": (
        "stripe.params._customer_delete_discount_params",
        False,
    ),
    "CustomerDeleteParams": ("stripe.params._customer_delete_params", False),
    "CustomerDeleteSourceParams": (
        "stripe.params._customer_delete_source_params",
        False,
    ),
    "CustomerDeleteTaxIdParams": (
        "stripe.params._customer_delete_tax_id_params",
        False,
    ),
    "CustomerFundCashBalanceParams": (
        "stripe.params._customer_fund_cash_balance_params",
        False,
    ),
    "CustomerFundingInstructionsCreateParams": (
        "stripe.params._customer_funding_instructions_create_params",
        False,
    ),
    "CustomerFundingInstructionsCreateParamsBankTransfer": (
        "stripe.params._customer_funding_instructions_create_params",
        False,
    ),
    "CustomerFundingInstructionsCreateParamsBankTransferEuBankTransfer": (
        "stripe.params._customer_funding_instructions_create_params",
        False,
    ),
    "CustomerListBalanceTransactionsParams": (
        "stripe.params._customer_list_balance_transactions_params",
        False,
    ),
    "CustomerListBalanceTransactionsParamsCreated": (
        "stripe.params._customer_list_balance_transactions_params",
        False,
    ),
    "CustomerListCashBalanceTransactionsParams": (
        "stripe.params._customer_list_cash_balance_transactions_params",
        False,
    ),
    "CustomerListParams": ("stripe.params._customer_list_params", False),
    "CustomerListParamsCreated": (
        "stripe.params._customer_list_params",
        False,
    ),
    "CustomerListPaymentMethodsParams": (
        "stripe.params._customer_list_payment_methods_params",
        False,
    ),
    "CustomerListSourcesParams": (
        "stripe.params._customer_list_sources_params",
        False,
    ),
    "CustomerListTaxIdsParams": (
        "stripe.params._customer_list_tax_ids_params",
        False,
    ),
    "CustomerModifyBalanceTransactionParams": (
        "stripe.params._customer_modify_balance_transaction_params",
        False,
    ),
    "CustomerModifyCashBalanceParams": (
        "stripe.params._customer_modify_cash_balance_params",
        False,
    ),
    "CustomerModifyCashBalanceParamsSettings": (
        "stripe.params._customer_modify_cash_balance_params",
        False,
    ),
    "CustomerModifyParams": ("stripe.params._customer_modify_params", False),
    "CustomerModifyParamsAddress": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsCashBalance": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsCashBalanceSettings": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsInvoiceSettings": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsInvoiceSettingsCustomField": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsInvoiceSettingsRenderingOptions": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsShipping": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsShippingAddress": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifyParamsTax": (
        "stripe.params._customer_modify_params",
        False,
    ),
    "CustomerModifySourceParams": (
        "stripe.params._customer_modify_source_params",
        False,
    ),
    "CustomerModifySourceParamsOwner": (
        "stripe.params._customer_modify_source_params",
        False,
    ),
    "CustomerModifySourceParamsOwnerAddress": (
        "stripe.params._customer_modify_source_params",
        False,
    ),
    "CustomerPaymentMethodListParams": (
        "stripe.params._customer_payment_method_list_params",
        False,
    ),
    "CustomerPaymentMethodRetrieveParams": (
        "stripe.params._customer_payment_method_retrieve_params",
        False,
    ),
    "CustomerPaymentSourceCreateParams": (
        "stripe.params._customer_payment_source_create_params",
        False,
    ),
    "CustomerPaymentSourceDeleteParams": (
        "stripe.params._customer_payment_source_delete_params",
        False,
    ),
    "CustomerPaymentSourceListParams": (
        "stripe.params._customer_payment_source_list_params",
        False,
    ),
    "CustomerPaymentSourceRetrieveParams": (
        "stripe.params._customer_payment_source_retrieve_params",
        False,
    ),
    "CustomerPaymentSourceUpdateParams": (
        "stripe.params._customer_payment_source_update_params",
        False,
    ),
    "CustomerPaymentSourceUpdateParamsOwner": (
        "stripe.params._customer_payment_source_update_params",
        False,
    ),
    "CustomerPaymentSourceUpdateParamsOwnerAddress": (
        "stripe.params._customer_payment_source_update_params",
        False,
    ),
    "CustomerPaymentSourceVerifyParams": (
        "stripe.params._customer_payment_source_verify_params",
        False,
    ),
    "CustomerRetrieveBalanceTransactionParams": (
        "stripe.params._customer_retrieve_balance_transaction_params",
        False,
    ),
    "CustomerRetrieveCashBalanceParams": (
        "stripe.params._customer_retrieve_cash_balance_params",
        False,
    ),
    "CustomerRetrieveCashBalanceTransactionParams": (
        "stripe.params._customer_retrieve_cash_balance_transaction_params",
        False,
    ),
    "CustomerRetrieveParams": (
        "stripe.params._customer_retrieve_params",
        False,
    ),
    "CustomerRetrievePaymentMethodParams": (
        "stripe.params._customer_retrieve_payment_method_params",
        False,
    ),
    "CustomerRetrieveSourceParams": (
        "stripe.params._customer_retrieve_source_params",
        False,
    ),
    "CustomerRetrieveTaxIdParams": (
        "stripe.params._customer_retrieve_tax_id_params",
        False,
    ),
    "CustomerSearchParams": ("stripe.params._customer_search_params", False),
    "CustomerSessionCreateParams": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponents": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsBuyButton": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsCustomerSheet": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsCustomerSheetFeatures": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsMobilePaymentElement": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsMobilePaymentElementFeatures": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsPaymentElement": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsPaymentElementFeatures": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsPricingTable": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsTaxIdElement": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerSessionCreateParamsComponentsTaxIdElementFeatures": (
        "stripe.params._customer_session_create_params",
        False,
    ),
    "CustomerTaxIdCreateParams": (
        "stripe.params._customer_tax_id_create_params",
        False,
    ),
    "CustomerTaxIdDeleteParams": (
        "stripe.params._customer_tax_id_delete_params",
        False,
    ),
    "CustomerTaxIdListParams": (
        "stripe.params._customer_tax_id_list_params",
        False,
    ),
    "CustomerTaxIdRetrieveParams": (
        "stripe.params._customer_tax_id_retrieve_params",
        False,
    ),
    "CustomerUpdateParams": ("stripe.params._customer_update_params", False),
    "CustomerUpdateParamsAddress": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsCashBalance": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsCashBalanceSettings": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsInvoiceSettings": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsInvoiceSettingsCustomField": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsInvoiceSettingsRenderingOptions": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsShipping": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsShippingAddress": (
        "stripe.params._customer_update_params",
        False,
    ),
    "CustomerUpdateParamsTax": (
        "stripe.params._customer_update_params",
        False,
    ),
    "DisputeCloseParams": ("stripe.params._dispute_close_params", False),
    "DisputeListParams": ("stripe.params._dispute_list_params", False),
    "DisputeListParamsCreated": ("stripe.params._dispute_list_params", False),
    "DisputeModifyParams": ("stripe.params._dispute_modify_params", False),
    "DisputeModifyParamsEvidence": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidence": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeModifyParamsEvidenceEnhancedEvidenceVisaCompliance": (
        "stripe.params._dispute_modify_params",
        False,
    ),
    "DisputeRetrieveParams": ("stripe.params._dispute_retrieve_params", False),
    "DisputeUpdateParams": ("stripe.params._dispute_update_params", False),
    "DisputeUpdateParamsEvidence": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidence": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransaction": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3DisputedTransactionShippingAddress": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransaction": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompellingEvidence3PriorUndisputedTransactionShippingAddress": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "DisputeUpdateParamsEvidenceEnhancedEvidenceVisaCompliance": (
        "stripe.params._dispute_update_params",
        False,
    ),
    "EphemeralKeyCreateParams": (
        "stripe.params._ephemeral_key_create_params",
        False,
    ),
    "EphemeralKeyDeleteParams": (
        "stripe.params._ephemeral_key_delete_params",
        False,
    ),
    "EventListParams": ("stripe.params._event_list_params", False),
    "EventListParamsCreated": ("stripe.params._event_list_params", False),
    "EventRetrieveParams": ("stripe.params._event_retrieve_params", False),
    "ExchangeRateListParams": (
        "stripe.params._exchange_rate_list_params",
        False,
    ),
    "ExchangeRateRetrieveParams": (
        "stripe.params._exchange_rate_retrieve_params",
        False,
    ),
    "ExternalAccountCreateParams": (
        "stripe.params._external_account_create_params",
        False,
    ),
    "ExternalAccountCreateParamsBankAccount": (
        "stripe.params._external_account_create_params",
        False,
    ),
    "ExternalAccountCreateParamsCard": (
        "stripe.params._external_account_create_params",
        False,
    ),
    "ExternalAccountCreateParamsCardToken": (
        "stripe.params._external_account_create_params",
        False,
    ),
    "ExternalAccountDeleteParams": (
        "stripe.params._external_account_delete_params",
        False,
    ),
    "ExternalAccountListParams": (
        "stripe.params._external_account_list_params",
        False,
    ),
    "ExternalAccountRetrieveParams": (
        "stripe.params._external_account_retrieve_params",
        False,
    ),
    "ExternalAccountUpdateParams": (
        "stripe.params._external_account_update_params",
        False,
    ),
    "ExternalAccountUpdateParamsDocuments": (
        "stripe.params._external_account_update_params",
        False,
    ),
    "ExternalAccountUpdateParamsDocumentsBankAccountOwnershipVerification": (
        "stripe.params._external_account_update_params",
        False,
    ),
    "FileCreateParams": ("stripe.params._file_create_params", False),
    "FileCreateParamsFileLinkData": (
        "stripe.params._file_create_params",
        False,
    ),
    "FileLinkCreateParams": ("stripe.params._file_link_create_params", False),
    "FileLinkListParams": ("stripe.params._file_link_list_params", False),
    "FileLinkListParamsCreated": (
        "stripe.params._file_link_list_params",
        False,
    ),
    "FileLinkModifyParams": ("stripe.params._file_link_modify_params", False),
    "FileLinkRetrieveParams": (
        "stripe.params._file_link_retrieve_params",
        False,
    ),
    "FileLinkUpdateParams": ("stripe.params._file_link_update_params", False),
    "FileListParams": ("stripe.params._file_list_params", False),
    "FileListParamsCreated": ("stripe.params._file_list_params", False),
    "FileRetrieveParams": ("stripe.params._file_retrieve_params", False),
    "FxQuoteCreateParams": ("stripe.params._fx_quote_create_params", False),
    "FxQuoteCreateParamsUsage": (
        "stripe.params._fx_quote_create_params",
        False,
    ),
    "FxQuoteCreateParamsUsagePayment": (
        "stripe.params._fx_quote_create_params",
        False,
    ),
    "FxQuoteCreateParamsUsageTransfer": (
        "stripe.params._fx_quote_create_params",
        False,
    ),
    "FxQuoteListParams": ("stripe.params._fx_quote_list_params", False),
    "FxQuoteRetrieveParams": (
        "stripe.params._fx_quote_retrieve_params",
        False,
    ),
    "InvoiceAddLinesParams": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLine": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLineDiscount": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLineDiscountDiscountEnd": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLineDiscountDiscountEndDuration": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLinePeriod": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLinePriceData": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLinePriceDataProductData": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLinePricing": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLineTaxAmount": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAddLinesParamsLineTaxAmountTaxRateData": (
        "stripe.params._invoice_add_lines_params",
        False,
    ),
    "InvoiceAttachPaymentParams": (
        "stripe.params._invoice_attach_payment_params",
        False,
    ),
    "InvoiceAttachPaymentParamsPaymentRecordData": (
        "stripe.params._invoice_attach_payment_params",
        False,
    ),
    "InvoiceCreateParams": ("stripe.params._invoice_create_params", False),
    "InvoiceCreateParamsAmountsDue": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsAutomaticTax": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsAutomaticTaxLiability": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsCustomField": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsDiscount": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsDiscountDiscountEnd": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsFromInvoice": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsIssuer": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettings": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallments": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsRendering": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsRenderingPdf": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCost": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateData": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingDetails": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsShippingDetailsAddress": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreateParamsTransferData": (
        "stripe.params._invoice_create_params",
        False,
    ),
    "InvoiceCreatePreviewParams": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsAutomaticTax": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsAutomaticTaxLiability": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetails": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetailsAddress": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetailsShipping": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetailsShippingAddress": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetailsTax": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsCustomerDetailsTaxId": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItem": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItemDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItemPeriod": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsInvoiceItemPriceData": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsIssuer": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetails": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendment": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStart": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartAmendmentEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentAmendmentStartDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesAction": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentBillingSchedulesActionAppliesTo": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountAction": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAdd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionAddDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionRemove": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentDiscountActionSet": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemAction": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAdd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionAddTrial": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionRemove": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSet": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentItemActionSetTrial": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentMetadataAction": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollection": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentSetPauseCollectionSet": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettings": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsAmendmentTrialSettingsEndBehavior": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingMode": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingModeFlexible": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingSchedule": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleAppliesTo": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntil": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsBillingScheduleBillUntilDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhase": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItem": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriod": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPeriodStart": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAddInvoiceItemPriceData": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTax": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseAutomaticTaxLiability": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseBillingThresholds": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettings": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseInvoiceSettingsIssuer": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItem": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemBillingThresholds": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceData": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemPriceDataRecurring": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseItemTrial": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhasePauseCollection": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseTransferData": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettings": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPhaseTrialSettingsEndBehavior": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPrebilling": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntil": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilAmendmentEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsScheduleDetailsPrebillingBillUntilDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetails": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingMode": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingModeFlexible": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingSchedule": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleAppliesTo": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntil": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsBillingScheduleBillUntilDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItem": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemBillingThresholds": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscount": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEnd": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemDiscountDiscountEndDuration": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceData": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsItemPriceDataRecurring": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceCreatePreviewParamsSubscriptionDetailsPrebilling": (
        "stripe.params._invoice_create_preview_params",
        False,
    ),
    "InvoiceDeleteParams": ("stripe.params._invoice_delete_params", False),
    "InvoiceFinalizeInvoiceParams": (
        "stripe.params._invoice_finalize_invoice_params",
        False,
    ),
    "InvoiceItemCreateParams": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsDiscount": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsDiscountDiscountEnd": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsPeriod": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsPriceData": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemCreateParamsPricing": (
        "stripe.params._invoice_item_create_params",
        False,
    ),
    "InvoiceItemDeleteParams": (
        "stripe.params._invoice_item_delete_params",
        False,
    ),
    "InvoiceItemListParams": (
        "stripe.params._invoice_item_list_params",
        False,
    ),
    "InvoiceItemListParamsCreated": (
        "stripe.params._invoice_item_list_params",
        False,
    ),
    "InvoiceItemModifyParams": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsDiscount": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsDiscountDiscountEnd": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsPeriod": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsPriceData": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemModifyParamsPricing": (
        "stripe.params._invoice_item_modify_params",
        False,
    ),
    "InvoiceItemRetrieveParams": (
        "stripe.params._invoice_item_retrieve_params",
        False,
    ),
    "InvoiceItemUpdateParams": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsDiscount": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsDiscountDiscountEnd": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsPeriod": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsPriceData": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceItemUpdateParamsPricing": (
        "stripe.params._invoice_item_update_params",
        False,
    ),
    "InvoiceLineItemListParams": (
        "stripe.params._invoice_line_item_list_params",
        False,
    ),
    "InvoiceLineItemUpdateParams": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsDiscount": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsDiscountDiscountEnd": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsPeriod": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsPriceData": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsPriceDataProductData": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsPricing": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsTaxAmount": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceLineItemUpdateParamsTaxAmountTaxRateData": (
        "stripe.params._invoice_line_item_update_params",
        False,
    ),
    "InvoiceListLinesParams": (
        "stripe.params._invoice_list_lines_params",
        False,
    ),
    "InvoiceListParams": ("stripe.params._invoice_list_params", False),
    "InvoiceListParamsCreated": ("stripe.params._invoice_list_params", False),
    "InvoiceListParamsDueDate": ("stripe.params._invoice_list_params", False),
    "InvoiceMarkUncollectibleParams": (
        "stripe.params._invoice_mark_uncollectible_params",
        False,
    ),
    "InvoiceModifyParams": ("stripe.params._invoice_modify_params", False),
    "InvoiceModifyParamsAmountsDue": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsAutomaticTax": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsAutomaticTaxLiability": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsCustomField": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsDiscount": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsDiscountDiscountEnd": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsIssuer": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettings": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallments": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsRendering": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsRenderingPdf": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCost": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateData": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingDetails": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsShippingDetailsAddress": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoiceModifyParamsTransferData": (
        "stripe.params._invoice_modify_params",
        False,
    ),
    "InvoicePayParams": ("stripe.params._invoice_pay_params", False),
    "InvoicePaymentListParams": (
        "stripe.params._invoice_payment_list_params",
        False,
    ),
    "InvoicePaymentListParamsCreated": (
        "stripe.params._invoice_payment_list_params",
        False,
    ),
    "InvoicePaymentListParamsPayment": (
        "stripe.params._invoice_payment_list_params",
        False,
    ),
    "InvoicePaymentRetrieveParams": (
        "stripe.params._invoice_payment_retrieve_params",
        False,
    ),
    "InvoiceRemoveLinesParams": (
        "stripe.params._invoice_remove_lines_params",
        False,
    ),
    "InvoiceRemoveLinesParamsLine": (
        "stripe.params._invoice_remove_lines_params",
        False,
    ),
    "InvoiceRenderingTemplateArchiveParams": (
        "stripe.params._invoice_rendering_template_archive_params",
        False,
    ),
    "InvoiceRenderingTemplateListParams": (
        "stripe.params._invoice_rendering_template_list_params",
        False,
    ),
    "InvoiceRenderingTemplateRetrieveParams": (
        "stripe.params._invoice_rendering_template_retrieve_params",
        False,
    ),
    "InvoiceRenderingTemplateUnarchiveParams": (
        "stripe.params._invoice_rendering_template_unarchive_params",
        False,
    ),
    "InvoiceRetrieveParams": ("stripe.params._invoice_retrieve_params", False),
    "InvoiceSearchParams": ("stripe.params._invoice_search_params", False),
    "InvoiceSendInvoiceParams": (
        "stripe.params._invoice_send_invoice_params",
        False,
    ),
    "InvoiceUpdateLinesParams": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLine": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLineDiscount": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLineDiscountDiscountEnd": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLineDiscountDiscountEndDuration": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLinePeriod": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLinePriceData": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLinePriceDataProductData": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLinePricing": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLineTaxAmount": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateLinesParamsLineTaxAmountTaxRateData": (
        "stripe.params._invoice_update_lines_params",
        False,
    ),
    "InvoiceUpdateParams": ("stripe.params._invoice_update_params", False),
    "InvoiceUpdateParamsAmountsDue": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsAutomaticTax": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsAutomaticTaxLiability": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsCustomField": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsDiscount": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsDiscountDiscountEnd": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsIssuer": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettings": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallments": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsRendering": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsRenderingPdf": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCost": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateData": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingDetails": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsShippingDetailsAddress": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceUpdateParamsTransferData": (
        "stripe.params._invoice_update_params",
        False,
    ),
    "InvoiceVoidInvoiceParams": (
        "stripe.params._invoice_void_invoice_params",
        False,
    ),
    "MandateListParams": ("stripe.params._mandate_list_params", False),
    "MandateRetrieveParams": ("stripe.params._mandate_retrieve_params", False),
    "MarginCreateParams": ("stripe.params._margin_create_params", False),
    "MarginListParams": ("stripe.params._margin_list_params", False),
    "MarginModifyParams": ("stripe.params._margin_modify_params", False),
    "MarginRetrieveParams": ("stripe.params._margin_retrieve_params", False),
    "MarginUpdateParams": ("stripe.params._margin_update_params", False),
    "OrderCancelParams": ("stripe.params._order_cancel_params", False),
    "OrderCreateParams": ("stripe.params._order_create_params", False),
    "OrderCreateParamsAutomaticTax": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsBillingDetails": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsBillingDetailsAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsDiscount": ("stripe.params._order_create_params", False),
    "OrderCreateParamsLineItem": ("stripe.params._order_create_params", False),
    "OrderCreateParamsLineItemDiscount": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsLineItemPriceData": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsLineItemProductData": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsLineItemProductDataPackageDimensions": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPayment": ("stripe.params._order_create_params", False),
    "OrderCreateParamsPaymentSettings": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsAlipay": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsIdeal": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarna": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsLink": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsOxxo": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsP24": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypal": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsSofort": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsPaymentMethodOptionsWechatPay": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsPaymentSettingsTransferData": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCost": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateData": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingDetails": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsShippingDetailsAddress": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsTaxDetails": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderCreateParamsTaxDetailsTaxId": (
        "stripe.params._order_create_params",
        False,
    ),
    "OrderLineItemListParams": (
        "stripe.params._order_line_item_list_params",
        False,
    ),
    "OrderListLineItemsParams": (
        "stripe.params._order_list_line_items_params",
        False,
    ),
    "OrderListParams": ("stripe.params._order_list_params", False),
    "OrderModifyParams": ("stripe.params._order_modify_params", False),
    "OrderModifyParamsAutomaticTax": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsBillingDetails": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsBillingDetailsAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsDiscount": ("stripe.params._order_modify_params", False),
    "OrderModifyParamsLineItem": ("stripe.params._order_modify_params", False),
    "OrderModifyParamsLineItemDiscount": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsLineItemPriceData": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsLineItemProductData": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsLineItemProductDataPackageDimensions": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPayment": ("stripe.params._order_modify_params", False),
    "OrderModifyParamsPaymentSettings": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsAlipay": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsIdeal": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarna": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsLink": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsOxxo": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsP24": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypal": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsSofort": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsPaymentMethodOptionsWechatPay": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsPaymentSettingsTransferData": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCost": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateData": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingDetails": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsShippingDetailsAddress": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsTaxDetails": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderModifyParamsTaxDetailsTaxId": (
        "stripe.params._order_modify_params",
        False,
    ),
    "OrderReopenParams": ("stripe.params._order_reopen_params", False),
    "OrderRetrieveParams": ("stripe.params._order_retrieve_params", False),
    "OrderSubmitParams": ("stripe.params._order_submit_params", False),
    "OrderUpdateParams": ("stripe.params._order_update_params", False),
    "OrderUpdateParamsAutomaticTax": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsBillingDetails": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsBillingDetailsAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsDiscount": ("stripe.params._order_update_params", False),
    "OrderUpdateParamsLineItem": ("stripe.params._order_update_params", False),
    "OrderUpdateParamsLineItemDiscount": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsLineItemPriceData": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsLineItemProductData": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsLineItemProductDataPackageDimensions": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPayment": ("stripe.params._order_update_params", False),
    "OrderUpdateParamsPaymentSettings": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsAlipay": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsIdeal": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarna": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsLink": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsOxxo": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsP24": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypal": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsSofort": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsPaymentMethodOptionsWechatPay": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsPaymentSettingsTransferData": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCost": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateData": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimate": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateDataFixedAmount": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingCostShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingDetails": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsShippingDetailsAddress": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsTaxDetails": (
        "stripe.params._order_update_params",
        False,
    ),
    "OrderUpdateParamsTaxDetailsTaxId": (
        "stripe.params._order_update_params",
        False,
    ),
    "PaymentAttemptRecordListParams": (
        "stripe.params._payment_attempt_record_list_params",
        False,
    ),
    "PaymentAttemptRecordRetrieveParams": (
        "stripe.params._payment_attempt_record_retrieve_params",
        False,
    ),
    "PaymentIntentAmountDetailsLineItemListParams": (
        "stripe.params._payment_intent_amount_details_line_item_list_params",
        False,
    ),
    "PaymentIntentApplyCustomerBalanceParams": (
        "stripe.params._payment_intent_apply_customer_balance_params",
        False,
    ),
    "PaymentIntentCancelParams": (
        "stripe.params._payment_intent_cancel_params",
        False,
    ),
    "PaymentIntentCaptureParams": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetails": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsAmountDetailsTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsHooks": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsHooksInputs": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsHooksInputsTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetails": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRental": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsEventDetails": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlight": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatum": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDelivery": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightPassenger": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsFlightSegment": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodging": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatum": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsSubscription": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentCaptureParamsTransferData": (
        "stripe.params._payment_intent_capture_params",
        False,
    ),
    "PaymentIntentConfirmParams": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAllocatedFunds": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetails": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsAmountDetailsTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsHooks": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsHooksInputs": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsHooksInputsTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsMandateData": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsMandateDataCustomerAcceptance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOffline": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetails": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsBenefit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsBenefitFrMealVoucher": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRental": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsEventDetails": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlight": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatum": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDelivery": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsFlightSegment": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodging": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatum": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsSubscription": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodData": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAcssDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAffirm": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAlipay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAlma": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAmazonPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBacsDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBancontact": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBillie": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBillingDetails": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBlik": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataBoleto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataCashapp": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataCrypto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataEps": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataFpx": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataGiropay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataGopay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataGrabpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataIdeal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataInteracPresent": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataKakaoPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataKlarna": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataKonbini": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataKrCard": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataLink": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataMbWay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataMobilepay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataMultibanco": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataNaverPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataOxxo": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataP24": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPayByBank": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPayco": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPaynow": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPaypal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPaypay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPayto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPix": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataPromptpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataQris": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataRadarOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataRechnung": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataRechnungDob": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataRevolutPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataSamsungPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataSatispay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataSepaDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataShopeepay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataSofort": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataStripeBalance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataSwish": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataTwint": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataWechatPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodDataZip": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAffirm": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAlipay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAlma": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBancontact": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBillie": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBlik": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsBoleto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardPresentRouting": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetails": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardStatementDetailsAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCashapp": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCrypto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsEps": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsFpx": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsGiropay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsGopay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsGrabpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsIdeal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsInteracPresent": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKonbini": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsKrCard": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsLink": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsMbWay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsMobilepay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsMultibanco": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsNaverPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsNzBankAccount": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsOxxo": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsP24": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPayByBank": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPayco": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaynow": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaypay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPayto": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPix": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsPromptpay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsQris": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsRechnung": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSatispay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsShopeepay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSofort": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsStripeBalance": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsSwish": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsTwint": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsWechatPay": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsPaymentMethodOptionsZip": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsRadarOptions": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsShipping": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentConfirmParamsShippingAddress": (
        "stripe.params._payment_intent_confirm_params",
        False,
    ),
    "PaymentIntentCreateParams": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAllocatedFunds": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetails": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAmountDetailsTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsAutomaticPaymentMethods": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsHooks": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsHooksInputs": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsHooksInputsTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsMandateData": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsMandateDataCustomerAcceptance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsMandateDataCustomerAcceptanceOffline": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetails": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsBenefit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsBenefitFrMealVoucher": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRental": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsEventDetails": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlight": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatum": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDelivery": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsFlightSegment": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodging": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatum": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsSubscription": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodData": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAcssDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAffirm": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAlipay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAlma": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAmazonPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBacsDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBancontact": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBillie": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBillingDetails": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBlik": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataBoleto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataCashapp": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataCrypto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataEps": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataFpx": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataGiropay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataGopay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataGrabpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataIdeal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataInteracPresent": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataKakaoPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataKlarna": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataKonbini": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataKrCard": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataLink": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataMbWay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataMobilepay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataMultibanco": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataNaverPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataOxxo": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataP24": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPayByBank": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPayco": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPaynow": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPaypal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPaypay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPayto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPix": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataPromptpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataQris": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataRadarOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataRechnung": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataRechnungDob": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataRevolutPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataSamsungPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataSatispay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataSepaDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataShopeepay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataSofort": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataStripeBalance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataSwish": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataTwint": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataWechatPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodDataZip": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAffirm": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAlipay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAlma": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBancontact": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBillie": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBlik": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsBoleto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardPresentRouting": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetails": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardStatementDetailsAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCashapp": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCrypto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsEps": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsFpx": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsGiropay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsGopay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsGrabpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsIdeal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsInteracPresent": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKonbini": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsKrCard": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsLink": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsMbWay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsMobilepay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsMultibanco": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsNaverPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsNzBankAccount": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsOxxo": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsP24": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPayByBank": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPayco": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaynow": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaypay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPayto": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPix": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsPromptpay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsQris": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsRechnung": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSatispay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsShopeepay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSofort": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsStripeBalance": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsSwish": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsTwint": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsWechatPay": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsPaymentMethodOptionsZip": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsRadarOptions": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsShipping": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsShippingAddress": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentCreateParamsTransferData": (
        "stripe.params._payment_intent_create_params",
        False,
    ),
    "PaymentIntentDecrementAuthorizationParams": (
        "stripe.params._payment_intent_decrement_authorization_params",
        False,
    ),
    "PaymentIntentDecrementAuthorizationParamsHooks": (
        "stripe.params._payment_intent_decrement_authorization_params",
        False,
    ),
    "PaymentIntentDecrementAuthorizationParamsHooksInputs": (
        "stripe.params._payment_intent_decrement_authorization_params",
        False,
    ),
    "PaymentIntentDecrementAuthorizationParamsHooksInputsTax": (
        "stripe.params._payment_intent_decrement_authorization_params",
        False,
    ),
    "PaymentIntentDecrementAuthorizationParamsTransferData": (
        "stripe.params._payment_intent_decrement_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParams": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetails": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsAmountDetailsTax": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsHooks": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsHooksInputs": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsHooksInputsTax": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsPaymentDetails": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsPaymentMethodOptions": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentIncrementAuthorizationParamsTransferData": (
        "stripe.params._payment_intent_increment_authorization_params",
        False,
    ),
    "PaymentIntentListAmountDetailsLineItemsParams": (
        "stripe.params._payment_intent_list_amount_details_line_items_params",
        False,
    ),
    "PaymentIntentListParams": (
        "stripe.params._payment_intent_list_params",
        False,
    ),
    "PaymentIntentListParamsCreated": (
        "stripe.params._payment_intent_list_params",
        False,
    ),
    "PaymentIntentModifyParams": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAllocatedFunds": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetails": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsAmountDetailsTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsHooks": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsHooksInputs": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsHooksInputsTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsMandateData": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsMandateDataCustomerAcceptance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetails": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsBenefit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsBenefitFrMealVoucher": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRental": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsEventDetails": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlight": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatum": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDelivery": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsFlightSegment": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodging": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatum": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsSubscription": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodData": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAcssDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAffirm": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAlipay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAlma": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAmazonPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBacsDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBancontact": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBillie": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBillingDetails": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBlik": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataBoleto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataCashapp": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataCrypto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataEps": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataFpx": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataGiropay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataGopay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataGrabpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataIdeal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataInteracPresent": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataKakaoPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataKlarna": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataKonbini": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataKrCard": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataLink": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataMbWay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataMobilepay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataMultibanco": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataNaverPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataOxxo": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataP24": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPayByBank": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPayco": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPaynow": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPaypal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPaypay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPayto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPix": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataPromptpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataQris": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataRadarOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataRechnung": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataRechnungDob": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataRevolutPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataSamsungPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataSatispay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataSepaDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataShopeepay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataSofort": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataStripeBalance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataSwish": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataTwint": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataWechatPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodDataZip": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAffirm": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAlipay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAlma": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBancontact": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBillie": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBlik": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsBoleto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardPresentRouting": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetails": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardStatementDetailsAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCashapp": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCrypto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsEps": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsFpx": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsGiropay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsGopay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsGrabpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsIdeal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsInteracPresent": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKonbini": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsKrCard": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsLink": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsMbWay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsMobilepay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsMultibanco": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsNaverPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsNzBankAccount": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsOxxo": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsP24": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPayByBank": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPayco": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaynow": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaypay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPayto": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPix": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsPromptpay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsQris": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsRechnung": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSatispay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsShopeepay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSofort": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsStripeBalance": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsSwish": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsTwint": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsWechatPay": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsPaymentMethodOptionsZip": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsShipping": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsShippingAddress": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentModifyParamsTransferData": (
        "stripe.params._payment_intent_modify_params",
        False,
    ),
    "PaymentIntentRetrieveParams": (
        "stripe.params._payment_intent_retrieve_params",
        False,
    ),
    "PaymentIntentSearchParams": (
        "stripe.params._payment_intent_search_params",
        False,
    ),
    "PaymentIntentTriggerActionParams": (
        "stripe.params._payment_intent_trigger_action_params",
        False,
    ),
    "PaymentIntentTriggerActionParamsScanQrCode": (
        "stripe.params._payment_intent_trigger_action_params",
        False,
    ),
    "PaymentIntentUpdateParams": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAllocatedFunds": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetails": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItem": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsLineItemTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsShipping": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsAmountDetailsTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsHooks": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsHooksInputs": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsHooksInputsTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsMandateData": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsMandateDataCustomerAcceptance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetails": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsBenefit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsBenefitFrMealVoucher": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRental": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatum": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDistance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriver": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDriverDateOfBirth": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOff": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumDropOffAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickup": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumPickupAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalDiscounts": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalExtraCharge": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumTotalTaxTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDatumVehicle": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDelivery": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDeliveryRecipient": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDistance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalDriver": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalPickupAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsCarRentalReturnAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsEventDetails": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsEventDetailsAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsEventDetailsAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsEventDetailsDelivery": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsEventDetailsDeliveryRecipient": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlight": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatum": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegment": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentArrival": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumSegmentDeparture": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalDiscounts": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalExtraCharge": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDatumTotalTaxTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDelivery": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightDeliveryRecipient": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsFlightSegment": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodging": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatum": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAccommodation": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumGuest": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHost": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumHostAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalDiscounts": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalExtraCharge": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDatumTotalTaxTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDelivery": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingDeliveryRecipient": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsLodgingPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsSubscription": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsSubscriptionAffiliate": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentDetailsSubscriptionBillingInterval": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodData": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAcssDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAffirm": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAlipay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAlma": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAmazonPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBacsDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBancontact": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBillie": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBillingDetails": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBlik": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataBoleto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataCashapp": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataCrypto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataEps": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataFpx": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataGiropay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataGopay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataGrabpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataIdeal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataInteracPresent": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataKakaoPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataKlarna": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataKonbini": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataKrCard": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataLink": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataMbWay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataMobilepay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataMultibanco": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataNaverPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataOxxo": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataP24": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPayByBank": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPayco": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPaynow": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPaypal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPaypay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPayto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPix": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataPromptpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataQris": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataRadarOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataRechnung": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataRechnungDob": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataRevolutPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataSamsungPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataSatispay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataSepaDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataShopeepay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataSofort": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataStripeBalance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataSwish": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataTwint": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataWechatPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodDataZip": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAffirm": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAlipay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAlma": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBancontact": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBillie": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBlik": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsBoleto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCard": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardInstallmentsPlan": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardPresentRouting": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetails": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardStatementDetailsAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCashapp": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCrypto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsEps": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsFpx": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsGiropay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsGopay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsGrabpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsIdeal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsInteracPresent": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarna": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseData": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetail": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrival": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDeparture": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataBusReservationDetailPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetail": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataEventReservationDetailInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetail": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrival": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDeparture": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataFerryReservationDetailPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSeller": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataMarketplaceSellerMarketplaceSellerAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetail": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrival": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDeparture": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataRoundTripReservationDetailPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetail": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrival": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailArrivalAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDeparture": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailDepartureAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailInsurance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataTrainReservationDetailPassenger": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKlarnaSupplementaryPurchaseDataVoucher": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKonbini": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsKrCard": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsLink": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsMbWay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsMobilepay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsMultibanco": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsNaverPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsNzBankAccount": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsOxxo": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsP24": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPayByBank": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPayco": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaynow": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaypal": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItem": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaypalLineItemTax": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaypay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPayto": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPix": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsPromptpay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsQris": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsRechnung": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSatispay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsShopeepay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSofort": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsStripeBalance": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsSwish": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsTwint": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsWechatPay": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsPaymentMethodOptionsZip": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsShipping": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsShippingAddress": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentUpdateParamsTransferData": (
        "stripe.params._payment_intent_update_params",
        False,
    ),
    "PaymentIntentVerifyMicrodepositsParams": (
        "stripe.params._payment_intent_verify_microdeposits_params",
        False,
    ),
    "PaymentLinkCreateParams": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsAfterCompletion": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsAfterCompletionHostedConfirmation": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsAfterCompletionRedirect": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsAutomaticTax": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsAutomaticTaxLiability": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsConsentCollection": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsConsentCollectionPaymentMethodReuseAgreement": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomField": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomFieldDropdown": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomFieldDropdownOption": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomFieldLabel": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomFieldNumeric": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomFieldText": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomText": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomTextAfterSubmit": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomTextShippingAddress": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomTextSubmit": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsCustomTextTermsOfServiceAcceptance": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsInvoiceCreation": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsInvoiceCreationInvoiceData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsInvoiceCreationInvoiceDataCustomField": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsInvoiceCreationInvoiceDataRenderingOptions": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsLineItem": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsLineItemAdjustableQuantity": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsLineItemPriceData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsLineItemPriceDataProductData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsLineItemPriceDataRecurring": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsNameCollection": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsNameCollectionBusiness": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsNameCollectionIndividual": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsOptionalItem": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsOptionalItemAdjustableQuantity": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsPaymentIntentData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsPhoneNumberCollection": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsRestrictions": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsRestrictionsCompletedSessions": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsShippingAddressCollection": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsShippingOption": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsSubscriptionData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsSubscriptionDataInvoiceSettings": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsSubscriptionDataTrialSettings": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsSubscriptionDataTrialSettingsEndBehavior": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsTaxIdCollection": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkCreateParamsTransferData": (
        "stripe.params._payment_link_create_params",
        False,
    ),
    "PaymentLinkLineItemListParams": (
        "stripe.params._payment_link_line_item_list_params",
        False,
    ),
    "PaymentLinkListLineItemsParams": (
        "stripe.params._payment_link_list_line_items_params",
        False,
    ),
    "PaymentLinkListParams": (
        "stripe.params._payment_link_list_params",
        False,
    ),
    "PaymentLinkModifyParams": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsAfterCompletion": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsAfterCompletionHostedConfirmation": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsAfterCompletionRedirect": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsAutomaticTax": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsAutomaticTaxLiability": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomField": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomFieldDropdown": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomFieldDropdownOption": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomFieldLabel": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomFieldNumeric": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomFieldText": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomText": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomTextAfterSubmit": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomTextShippingAddress": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomTextSubmit": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsCustomTextTermsOfServiceAcceptance": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsInvoiceCreation": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsInvoiceCreationInvoiceData": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsInvoiceCreationInvoiceDataCustomField": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsInvoiceCreationInvoiceDataRenderingOptions": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsLineItem": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsLineItemAdjustableQuantity": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsNameCollection": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsNameCollectionBusiness": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsNameCollectionIndividual": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsPaymentIntentData": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsPhoneNumberCollection": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsRestrictions": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsRestrictionsCompletedSessions": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsShippingAddressCollection": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsSubscriptionData": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsSubscriptionDataInvoiceSettings": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsSubscriptionDataTrialSettings": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsSubscriptionDataTrialSettingsEndBehavior": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkModifyParamsTaxIdCollection": (
        "stripe.params._payment_link_modify_params",
        False,
    ),
    "PaymentLinkRetrieveParams": (
        "stripe.params._payment_link_retrieve_params",
        False,
    ),
    "PaymentLinkUpdateParams": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsAfterCompletion": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsAfterCompletionHostedConfirmation": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsAfterCompletionRedirect": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsAutomaticTax": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsAutomaticTaxLiability": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomField": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomFieldDropdown": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomFieldDropdownOption": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomFieldLabel": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomFieldNumeric": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomFieldText": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomText": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomTextAfterSubmit": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomTextShippingAddress": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomTextSubmit": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsCustomTextTermsOfServiceAcceptance": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsInvoiceCreation": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsInvoiceCreationInvoiceData": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsInvoiceCreationInvoiceDataCustomField": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsInvoiceCreationInvoiceDataRenderingOptions": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsLineItem": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsLineItemAdjustableQuantity": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsNameCollection": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsNameCollectionBusiness": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsNameCollectionIndividual": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsPaymentIntentData": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsPhoneNumberCollection": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsRestrictions": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsRestrictionsCompletedSessions": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsShippingAddressCollection": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsSubscriptionData": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsSubscriptionDataInvoiceSettings": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsSubscriptionDataTrialSettings": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsSubscriptionDataTrialSettingsEndBehavior": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentLinkUpdateParamsTaxIdCollection": (
        "stripe.params._payment_link_update_params",
        False,
    ),
    "PaymentMethodAttachParams": (
        "stripe.params._payment_method_attach_params",
        False,
    ),
    "PaymentMethodCheckBalanceParams": (
        "stripe.params._payment_method_check_balance_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParams": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAcssDebit": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAcssDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAffirm": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAffirmDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAfterpayClearpay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAfterpayClearpayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAlipay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAlipayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAlma": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAlmaDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAmazonPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAmazonPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsApplePay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsApplePayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsApplePayLater": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsApplePayLaterDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAuBecsDebit": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsAuBecsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBacsDebit": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBacsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBancontact": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBancontactDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBillie": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBillieDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBlik": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBlikDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBoleto": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsBoletoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCard": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCardDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCartesBancaires": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCartesBancairesDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCashapp": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCashappDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCrypto": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCryptoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCustomerBalance": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsCustomerBalanceDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsEps": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsEpsDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsFpx": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsFpxDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsFrMealVoucherConecs": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsFrMealVoucherConecsDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGiropay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGiropayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGooglePay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGooglePayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGopay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGopayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGrabpay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsGrabpayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsIdBankTransfer": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsIdBankTransferDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsIdeal": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsIdealDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsJcb": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsJcbDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKakaoPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKakaoPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKlarna": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKlarnaDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKonbini": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKonbiniDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKrCard": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsKrCardDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsLink": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsLinkDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMbWay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMbWayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMobilepay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMobilepayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMultibanco": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsMultibancoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsNaverPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsNaverPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsNzBankAccount": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsNzBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsOxxo": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsOxxoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsP24": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsP24DisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPayByBank": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPayByBankDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPayco": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaycoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaynow": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaynowDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaypal": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaypalDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaypay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaypayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPayto": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPaytoDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPix": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPixDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPromptpay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsPromptpayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsQris": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsQrisDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsRevolutPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsRevolutPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSamsungPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSamsungPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSatispay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSatispayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSepaDebit": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSepaDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsShopeepay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsShopeepayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSofort": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSofortDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSwish": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsSwishDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsTwint": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsTwintDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsUsBankAccount": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsUsBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsWechatPay": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsWechatPayDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsZip": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationCreateParamsZipDisplayPreference": (
        "stripe.params._payment_method_configuration_create_params",
        False,
    ),
    "PaymentMethodConfigurationListParams": (
        "stripe.params._payment_method_configuration_list_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParams": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAcssDebit": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAcssDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAffirm": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAffirmDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAfterpayClearpay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAfterpayClearpayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAlipay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAlipayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAlma": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAlmaDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAmazonPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAmazonPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsApplePay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsApplePayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsApplePayLater": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsApplePayLaterDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAuBecsDebit": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsAuBecsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBacsDebit": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBacsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBancontact": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBancontactDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBillie": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBillieDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBlik": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBlikDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBoleto": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsBoletoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCard": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCardDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCartesBancaires": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCartesBancairesDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCashapp": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCashappDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCrypto": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCryptoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCustomerBalance": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsCustomerBalanceDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsEps": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsEpsDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsFpx": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsFpxDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsFrMealVoucherConecs": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsFrMealVoucherConecsDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGiropay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGiropayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGooglePay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGooglePayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGopay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGopayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGrabpay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsGrabpayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsIdBankTransfer": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsIdBankTransferDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsIdeal": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsIdealDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsJcb": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsJcbDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKakaoPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKakaoPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKlarna": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKlarnaDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKonbini": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKonbiniDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKrCard": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsKrCardDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsLink": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsLinkDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMbWay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMbWayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMobilepay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMobilepayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMultibanco": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsMultibancoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsNaverPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsNaverPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsNzBankAccount": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsNzBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsOxxo": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsOxxoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsP24": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsP24DisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPayByBank": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPayByBankDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPayco": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaycoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaynow": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaynowDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaypal": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaypalDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaypay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaypayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPayto": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPaytoDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPix": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPixDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPromptpay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsPromptpayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsQris": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsQrisDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsRevolutPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsRevolutPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSamsungPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSamsungPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSatispay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSatispayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSepaDebit": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSepaDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsShopeepay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsShopeepayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSofort": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSofortDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSwish": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsSwishDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsTwint": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsTwintDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsUsBankAccount": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsUsBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsWechatPay": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsWechatPayDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsZip": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationModifyParamsZipDisplayPreference": (
        "stripe.params._payment_method_configuration_modify_params",
        False,
    ),
    "PaymentMethodConfigurationRetrieveParams": (
        "stripe.params._payment_method_configuration_retrieve_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParams": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAcssDebit": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAcssDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAffirm": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAffirmDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAfterpayClearpay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAfterpayClearpayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAlipay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAlipayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAlma": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAlmaDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAmazonPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAmazonPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsApplePay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsApplePayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsApplePayLater": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsApplePayLaterDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAuBecsDebit": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsAuBecsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBacsDebit": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBacsDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBancontact": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBancontactDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBillie": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBillieDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBlik": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBlikDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBoleto": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsBoletoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCard": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCardDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCartesBancaires": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCartesBancairesDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCashapp": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCashappDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCrypto": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCryptoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCustomerBalance": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsCustomerBalanceDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsEps": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsEpsDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsFpx": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsFpxDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsFrMealVoucherConecs": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsFrMealVoucherConecsDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGiropay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGiropayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGooglePay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGooglePayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGopay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGopayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGrabpay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsGrabpayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsIdBankTransfer": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsIdBankTransferDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsIdeal": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsIdealDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsJcb": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsJcbDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKakaoPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKakaoPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKlarna": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKlarnaDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKonbini": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKonbiniDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKrCard": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsKrCardDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsLink": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsLinkDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMbWay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMbWayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMobilepay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMobilepayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMultibanco": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsMultibancoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsNaverPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsNaverPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsNzBankAccount": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsNzBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsOxxo": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsOxxoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsP24": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsP24DisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPayByBank": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPayByBankDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPayco": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaycoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaynow": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaynowDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaypal": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaypalDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaypay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaypayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPayto": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPaytoDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPix": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPixDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPromptpay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsPromptpayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsQris": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsQrisDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsRevolutPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsRevolutPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSamsungPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSamsungPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSatispay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSatispayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSepaDebit": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSepaDebitDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsShopeepay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsShopeepayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSofort": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSofortDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSwish": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsSwishDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsTwint": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsTwintDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsUsBankAccount": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsUsBankAccountDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsWechatPay": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsWechatPayDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsZip": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodConfigurationUpdateParamsZipDisplayPreference": (
        "stripe.params._payment_method_configuration_update_params",
        False,
    ),
    "PaymentMethodCreateParams": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAcssDebit": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAffirm": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAfterpayClearpay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAlipay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAlma": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAmazonPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsAuBecsDebit": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBacsDebit": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBancontact": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBillie": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBillingDetails": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBillingDetailsAddress": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBlik": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsBoleto": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCard": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCardNetworks": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCashapp": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCrypto": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCustom": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsCustomerBalance": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsEps": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsFpx": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsGiropay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsGopay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsGrabpay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsIdBankTransfer": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsIdeal": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsInteracPresent": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsKakaoPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsKlarna": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsKlarnaDob": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsKonbini": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsKrCard": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsLink": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsMbWay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsMobilepay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsMultibanco": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsNaverPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsNzBankAccount": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsOxxo": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsP24": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPayByBank": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPayco": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPaynow": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPaypal": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPaypay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPayto": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPix": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsPromptpay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsQris": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsRadarOptions": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsRechnung": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsRechnungDob": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsRevolutPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsSamsungPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsSatispay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsSepaDebit": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsShopeepay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsSofort": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsStripeBalance": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsSwish": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsTwint": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsUsBankAccount": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsWechatPay": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodCreateParamsZip": (
        "stripe.params._payment_method_create_params",
        False,
    ),
    "PaymentMethodDetachParams": (
        "stripe.params._payment_method_detach_params",
        False,
    ),
    "PaymentMethodDomainCreateParams": (
        "stripe.params._payment_method_domain_create_params",
        False,
    ),
    "PaymentMethodDomainListParams": (
        "stripe.params._payment_method_domain_list_params",
        False,
    ),
    "PaymentMethodDomainModifyParams": (
        "stripe.params._payment_method_domain_modify_params",
        False,
    ),
    "PaymentMethodDomainRetrieveParams": (
        "stripe.params._payment_method_domain_retrieve_params",
        False,
    ),
    "PaymentMethodDomainUpdateParams": (
        "stripe.params._payment_method_domain_update_params",
        False,
    ),
    "PaymentMethodDomainValidateParams": (
        "stripe.params._payment_method_domain_validate_params",
        False,
    ),
    "PaymentMethodListParams": (
        "stripe.params._payment_method_list_params",
        False,
    ),
    "PaymentMethodModifyParams": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsBillingDetails": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsBillingDetailsAddress": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsCard": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsCardNetworks": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsPayto": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodModifyParamsUsBankAccount": (
        "stripe.params._payment_method_modify_params",
        False,
    ),
    "PaymentMethodRetrieveParams": (
        "stripe.params._payment_method_retrieve_params",
        False,
    ),
    "PaymentMethodUpdateParams": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsBillingDetails": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsBillingDetailsAddress": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsCard": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsCardNetworks": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsPayto": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentMethodUpdateParamsUsBankAccount": (
        "stripe.params._payment_method_update_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptCanceledParams": (
        "stripe.params._payment_record_report_payment_attempt_canceled_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptFailedParams": (
        "stripe.params._payment_record_report_payment_attempt_failed_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptGuaranteedParams": (
        "stripe.params._payment_record_report_payment_attempt_guaranteed_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptInformationalParams": (
        "stripe.params._payment_record_report_payment_attempt_informational_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptInformationalParamsCustomerDetails": (
        "stripe.params._payment_record_report_payment_attempt_informational_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptInformationalParamsShippingDetails": (
        "stripe.params._payment_record_report_payment_attempt_informational_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptInformationalParamsShippingDetailsAddress": (
        "stripe.params._payment_record_report_payment_attempt_informational_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParams": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsFailed": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsGuaranteed": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsPaymentMethodDetails": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetails": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsBillingDetailsAddress": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsPaymentMethodDetailsCustom": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsShippingDetails": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentAttemptParamsShippingDetailsAddress": (
        "stripe.params._payment_record_report_payment_attempt_params",
        False,
    ),
    "PaymentRecordReportPaymentParams": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsAmountRequested": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsCustomerDetails": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsFailed": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsGuaranteed": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsPaymentMethodDetails": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetails": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsPaymentMethodDetailsBillingDetailsAddress": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsPaymentMethodDetailsCustom": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsProcessorDetails": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsProcessorDetailsCustom": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsShippingDetails": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportPaymentParamsShippingDetailsAddress": (
        "stripe.params._payment_record_report_payment_params",
        False,
    ),
    "PaymentRecordReportRefundParams": (
        "stripe.params._payment_record_report_refund_params",
        False,
    ),
    "PaymentRecordReportRefundParamsAmount": (
        "stripe.params._payment_record_report_refund_params",
        False,
    ),
    "PaymentRecordReportRefundParamsProcessorDetails": (
        "stripe.params._payment_record_report_refund_params",
        False,
    ),
    "PaymentRecordReportRefundParamsProcessorDetailsCustom": (
        "stripe.params._payment_record_report_refund_params",
        False,
    ),
    "PaymentRecordReportRefundParamsRefunded": (
        "stripe.params._payment_record_report_refund_params",
        False,
    ),
    "PaymentRecordRetrieveParams": (
        "stripe.params._payment_record_retrieve_params",
        False,
    ),
    "PayoutCancelParams": ("stripe.params._payout_cancel_params", False),
    "PayoutCreateParams": ("stripe.params._payout_create_params", False),
    "PayoutListParams": ("stripe.params._payout_list_params", False),
    "PayoutListParamsArrivalDate": (
        "stripe.params._payout_list_params",
        False,
    ),
    "PayoutListParamsCreated": ("stripe.params._payout_list_params", False),
    "PayoutModifyParams": ("stripe.params._payout_modify_params", False),
    "PayoutRetrieveParams": ("stripe.params._payout_retrieve_params", False),
    "PayoutReverseParams": ("stripe.params._payout_reverse_params", False),
    "PayoutUpdateParams": ("stripe.params._payout_update_params", False),
    "PlanCreateParams": ("stripe.params._plan_create_params", False),
    "PlanCreateParamsProduct": ("stripe.params._plan_create_params", False),
    "PlanCreateParamsTier": ("stripe.params._plan_create_params", False),
    "PlanCreateParamsTransformUsage": (
        "stripe.params._plan_create_params",
        False,
    ),
    "PlanDeleteParams": ("stripe.params._plan_delete_params", False),
    "PlanListParams": ("stripe.params._plan_list_params", False),
    "PlanListParamsCreated": ("stripe.params._plan_list_params", False),
    "PlanModifyParams": ("stripe.params._plan_modify_params", False),
    "PlanRetrieveParams": ("stripe.params._plan_retrieve_params", False),
    "PlanUpdateParams": ("stripe.params._plan_update_params", False),
    "PriceCreateParams": ("stripe.params._price_create_params", False),
    "PriceCreateParamsCurrencyOptions": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsCurrencyOptionsCustomUnitAmount": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsCurrencyOptionsTier": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsCustomUnitAmount": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsProductData": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsRecurring": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceCreateParamsTier": ("stripe.params._price_create_params", False),
    "PriceCreateParamsTransformQuantity": (
        "stripe.params._price_create_params",
        False,
    ),
    "PriceListParams": ("stripe.params._price_list_params", False),
    "PriceListParamsCreated": ("stripe.params._price_list_params", False),
    "PriceListParamsRecurring": ("stripe.params._price_list_params", False),
    "PriceModifyParams": ("stripe.params._price_modify_params", False),
    "PriceModifyParamsCurrencyOptions": (
        "stripe.params._price_modify_params",
        False,
    ),
    "PriceModifyParamsCurrencyOptionsCustomUnitAmount": (
        "stripe.params._price_modify_params",
        False,
    ),
    "PriceModifyParamsCurrencyOptionsTier": (
        "stripe.params._price_modify_params",
        False,
    ),
    "PriceModifyParamsMigrateTo": (
        "stripe.params._price_modify_params",
        False,
    ),
    "PriceRetrieveParams": ("stripe.params._price_retrieve_params", False),
    "PriceSearchParams": ("stripe.params._price_search_params", False),
    "PriceUpdateParams": ("stripe.params._price_update_params", False),
    "PriceUpdateParamsCurrencyOptions": (
        "stripe.params._price_update_params",
        False,
    ),
    "PriceUpdateParamsCurrencyOptionsCustomUnitAmount": (
        "stripe.params._price_update_params",
        False,
    ),
    "PriceUpdateParamsCurrencyOptionsTier": (
        "stripe.params._price_update_params",
        False,
    ),
    "PriceUpdateParamsMigrateTo": (
        "stripe.params._price_update_params",
        False,
    ),
    "ProductCreateFeatureParams": (
        "stripe.params._product_create_feature_params",
        False,
    ),
    "ProductCreateParams": ("stripe.params._product_create_params", False),
    "ProductCreateParamsDefaultPriceData": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsDefaultPriceDataCurrencyOptions": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsDefaultPriceDataCurrencyOptionsCustomUnitAmount": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsDefaultPriceDataCurrencyOptionsTier": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsDefaultPriceDataCustomUnitAmount": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsDefaultPriceDataRecurring": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsMarketingFeature": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductCreateParamsPackageDimensions": (
        "stripe.params._product_create_params",
        False,
    ),
    "ProductDeleteFeatureParams": (
        "stripe.params._product_delete_feature_params",
        False,
    ),
    "ProductDeleteParams": ("stripe.params._product_delete_params", False),
    "ProductFeatureCreateParams": (
        "stripe.params._product_feature_create_params",
        False,
    ),
    "ProductFeatureDeleteParams": (
        "stripe.params._product_feature_delete_params",
        False,
    ),
    "ProductFeatureListParams": (
        "stripe.params._product_feature_list_params",
        False,
    ),
    "ProductFeatureRetrieveParams": (
        "stripe.params._product_feature_retrieve_params",
        False,
    ),
    "ProductListFeaturesParams": (
        "stripe.params._product_list_features_params",
        False,
    ),
    "ProductListParams": ("stripe.params._product_list_params", False),
    "ProductListParamsCreated": ("stripe.params._product_list_params", False),
    "ProductModifyParams": ("stripe.params._product_modify_params", False),
    "ProductModifyParamsMarketingFeature": (
        "stripe.params._product_modify_params",
        False,
    ),
    "ProductModifyParamsPackageDimensions": (
        "stripe.params._product_modify_params",
        False,
    ),
    "ProductRetrieveFeatureParams": (
        "stripe.params._product_retrieve_feature_params",
        False,
    ),
    "ProductRetrieveParams": ("stripe.params._product_retrieve_params", False),
    "ProductSearchParams": ("stripe.params._product_search_params", False),
    "ProductUpdateParams": ("stripe.params._product_update_params", False),
    "ProductUpdateParamsMarketingFeature": (
        "stripe.params._product_update_params",
        False,
    ),
    "ProductUpdateParamsPackageDimensions": (
        "stripe.params._product_update_params",
        False,
    ),
    "PromotionCodeCreateParams": (
        "stripe.params._promotion_code_create_params",
        False,
    ),
    "PromotionCodeCreateParamsPromotion": (
        "stripe.params._promotion_code_create_params",
        False,
    ),
    "PromotionCodeCreateParamsRestrictions": (
        "stripe.params._promotion_code_create_params",
        False,
    ),
    "PromotionCodeCreateParamsRestrictionsCurrencyOptions": (
        "stripe.params._promotion_code_create_params",
        False,
    ),
    "PromotionCodeListParams": (
        "stripe.params._promotion_code_list_params",
        False,
    ),
    "PromotionCodeListParamsCreated": (
        "stripe.params._promotion_code_list_params",
        False,
    ),
    "PromotionCodeModifyParams": (
        "stripe.params._promotion_code_modify_params",
        False,
    ),
    "PromotionCodeModifyParamsRestrictions": (
        "stripe.params._promotion_code_modify_params",
        False,
    ),
    "PromotionCodeModifyParamsRestrictionsCurrencyOptions": (
        "stripe.params._promotion_code_modify_params",
        False,
    ),
    "PromotionCodeRetrieveParams": (
        "stripe.params._promotion_code_retrieve_params",
        False,
    ),
    "PromotionCodeUpdateParams": (
        "stripe.params._promotion_code_update_params",
        False,
    ),
    "PromotionCodeUpdateParamsRestrictions": (
        "stripe.params._promotion_code_update_params",
        False,
    ),
    "PromotionCodeUpdateParamsRestrictionsCurrencyOptions": (
        "stripe.params._promotion_code_update_params",
        False,
    ),
    "QuoteAcceptParams": ("stripe.params._quote_accept_params", False),
    "QuoteCancelParams": ("stripe.params._quote_cancel_params", False),
    "QuoteComputedUpfrontLineItemsListParams": (
        "stripe.params._quote_computed_upfront_line_items_list_params",
        False,
    ),
    "QuoteCreateParams": ("stripe.params._quote_create_params", False),
    "QuoteCreateParamsAutomaticTax": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsAutomaticTaxLiability": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsDiscount": ("stripe.params._quote_create_params", False),
    "QuoteCreateParamsDiscountDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsDiscountDiscountEndDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsFromQuote": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsInvoiceSettings": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsInvoiceSettingsIssuer": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLine": ("stripe.params._quote_create_params", False),
    "QuoteCreateParamsLineAction": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddDiscountDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddItem": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddItemDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddItemDiscountDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddItemDiscountDiscountEndDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionAddItemTrial": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionRemoveDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionRemoveItem": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetItem": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetItemDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetItemDiscountDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetItemDiscountDiscountEndDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineActionSetItemTrial": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineAppliesTo": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineCancelSubscriptionSchedule": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineEndsAtDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineEndsAtDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineItem": ("stripe.params._quote_create_params", False),
    "QuoteCreateParamsLineItemDiscount": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineItemDiscountDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineItemDiscountDiscountEndDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineItemPriceData": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineItemPriceDataRecurring": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineSetPauseCollection": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineSetPauseCollectionSet": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineStartsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineStartsAtDiscountEnd": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineStartsAtLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineTrialSettings": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsLineTrialSettingsEndBehavior": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionData": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptance": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFrom": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntil": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingMode": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingModeFlexible": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingSchedule": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleAppliesTo": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleBillFrom": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleBillUntil": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverride": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideAppliesTo": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptance": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingSchedule": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleAppliesTo": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFrom": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntil": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsSubscriptionDataPrebilling": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteCreateParamsTransferData": (
        "stripe.params._quote_create_params",
        False,
    ),
    "QuoteFinalizeQuoteParams": (
        "stripe.params._quote_finalize_quote_params",
        False,
    ),
    "QuoteLineItemListParams": (
        "stripe.params._quote_line_item_list_params",
        False,
    ),
    "QuoteLineListParams": ("stripe.params._quote_line_list_params", False),
    "QuoteListComputedUpfrontLineItemsParams": (
        "stripe.params._quote_list_computed_upfront_line_items_params",
        False,
    ),
    "QuoteListLineItemsParams": (
        "stripe.params._quote_list_line_items_params",
        False,
    ),
    "QuoteListLinesParams": ("stripe.params._quote_list_lines_params", False),
    "QuoteListParams": ("stripe.params._quote_list_params", False),
    "QuoteListPreviewInvoiceLinesParams": (
        "stripe.params._quote_list_preview_invoice_lines_params",
        False,
    ),
    "QuoteListPreviewInvoicesParams": (
        "stripe.params._quote_list_preview_invoices_params",
        False,
    ),
    "QuoteListPreviewSubscriptionSchedulesParams": (
        "stripe.params._quote_list_preview_subscription_schedules_params",
        False,
    ),
    "QuoteMarkDraftParams": ("stripe.params._quote_mark_draft_params", False),
    "QuoteMarkStaleParams": ("stripe.params._quote_mark_stale_params", False),
    "QuoteModifyParams": ("stripe.params._quote_modify_params", False),
    "QuoteModifyParamsAutomaticTax": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsAutomaticTaxLiability": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsDiscount": ("stripe.params._quote_modify_params", False),
    "QuoteModifyParamsDiscountDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsDiscountDiscountEndDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsInvoiceSettings": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsInvoiceSettingsIssuer": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLine": ("stripe.params._quote_modify_params", False),
    "QuoteModifyParamsLineAction": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddDiscountDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddItem": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddItemDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddItemDiscountDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddItemDiscountDiscountEndDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionAddItemTrial": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionRemoveDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionRemoveItem": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetItem": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetItemDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetItemDiscountDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetItemDiscountDiscountEndDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineActionSetItemTrial": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineAppliesTo": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineCancelSubscriptionSchedule": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineEndsAtDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineEndsAtDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineItem": ("stripe.params._quote_modify_params", False),
    "QuoteModifyParamsLineItemDiscount": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineItemDiscountDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineItemDiscountDiscountEndDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineItemPriceData": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineItemPriceDataRecurring": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineSetPauseCollection": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineSetPauseCollectionSet": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineStartsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineStartsAtDiscountEnd": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineStartsAtLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineTrialSettings": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsLineTrialSettingsEndBehavior": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionData": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptance": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFrom": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntil": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingSchedule": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleAppliesTo": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleBillFrom": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleBillUntil": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverride": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideAppliesTo": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptance": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingSchedule": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleAppliesTo": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFrom": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntil": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsSubscriptionDataPrebilling": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuoteModifyParamsTransferData": (
        "stripe.params._quote_modify_params",
        False,
    ),
    "QuotePdfParams": ("stripe.params._quote_pdf_params", False),
    "QuotePreviewInvoiceListParams": (
        "stripe.params._quote_preview_invoice_list_params",
        False,
    ),
    "QuotePreviewSubscriptionScheduleListParams": (
        "stripe.params._quote_preview_subscription_schedule_list_params",
        False,
    ),
    "QuoteReestimateParams": ("stripe.params._quote_reestimate_params", False),
    "QuoteRetrieveParams": ("stripe.params._quote_retrieve_params", False),
    "QuoteUpdateParams": ("stripe.params._quote_update_params", False),
    "QuoteUpdateParamsAutomaticTax": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsAutomaticTaxLiability": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsDiscount": ("stripe.params._quote_update_params", False),
    "QuoteUpdateParamsDiscountDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsInvoiceSettings": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsInvoiceSettingsIssuer": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLine": ("stripe.params._quote_update_params", False),
    "QuoteUpdateParamsLineAction": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddDiscountDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddItem": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddItemDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddItemDiscountDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddItemDiscountDiscountEndDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionAddItemTrial": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionRemoveDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionRemoveItem": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetItem": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetItemDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetItemDiscountDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetItemDiscountDiscountEndDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineActionSetItemTrial": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineAppliesTo": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineCancelSubscriptionSchedule": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineEndsAtDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineEndsAtDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineItem": ("stripe.params._quote_update_params", False),
    "QuoteUpdateParamsLineItemDiscount": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineItemDiscountDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineItemDiscountDiscountEndDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineItemPriceData": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineItemPriceDataRecurring": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineSetPauseCollection": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineSetPauseCollectionSet": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineStartsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineStartsAtDiscountEnd": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineStartsAtLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineTrialSettings": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsLineTrialSettingsEndBehavior": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionData": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptance": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFrom": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntil": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingSchedule": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleAppliesTo": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleBillFrom": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntil": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverride": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideAppliesTo": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptance": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFrom": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillFromLineStartsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntil": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillOnAcceptanceBillUntilLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingSchedule": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleAppliesTo": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFrom": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillFromLineStartsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntil": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilDuration": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataOverrideBillingScheduleBillUntilLineEndsAt": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsSubscriptionDataPrebilling": (
        "stripe.params._quote_update_params",
        False,
    ),
    "QuoteUpdateParamsTransferData": (
        "stripe.params._quote_update_params",
        False,
    ),
    "RefundCancelParams": ("stripe.params._refund_cancel_params", False),
    "RefundCreateParams": ("stripe.params._refund_create_params", False),
    "RefundExpireParams": ("stripe.params._refund_expire_params", False),
    "RefundListParams": ("stripe.params._refund_list_params", False),
    "RefundListParamsCreated": ("stripe.params._refund_list_params", False),
    "RefundModifyParams": ("stripe.params._refund_modify_params", False),
    "RefundRetrieveParams": ("stripe.params._refund_retrieve_params", False),
    "RefundUpdateParams": ("stripe.params._refund_update_params", False),
    "ReviewApproveParams": ("stripe.params._review_approve_params", False),
    "ReviewListParams": ("stripe.params._review_list_params", False),
    "ReviewListParamsCreated": ("stripe.params._review_list_params", False),
    "ReviewRetrieveParams": ("stripe.params._review_retrieve_params", False),
    "SetupAttemptListParams": (
        "stripe.params._setup_attempt_list_params",
        False,
    ),
    "SetupAttemptListParamsCreated": (
        "stripe.params._setup_attempt_list_params",
        False,
    ),
    "SetupIntentCancelParams": (
        "stripe.params._setup_intent_cancel_params",
        False,
    ),
    "SetupIntentConfirmParams": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsMandateData": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsMandateDataCustomerAcceptance": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsMandateDataCustomerAcceptanceOffline": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodData": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAcssDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAffirm": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAlipay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAlma": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAmazonPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBacsDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBancontact": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBillie": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBillingDetails": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBlik": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataBoleto": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataCashapp": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataCrypto": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataEps": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataFpx": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataGiropay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataGopay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataGrabpay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataIdeal": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataInteracPresent": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataKakaoPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataKlarna": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataKonbini": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataKrCard": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataLink": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataMbWay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataMobilepay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataMultibanco": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataNaverPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataOxxo": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataP24": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPayByBank": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPayco": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPaynow": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPaypal": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPaypay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPayto": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPix": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataPromptpay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataQris": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataRadarOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataRechnung": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataRechnungDob": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataRevolutPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataSamsungPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataSatispay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataSepaDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataShopeepay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataSofort": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataStripeBalance": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataSwish": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataTwint": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataWechatPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodDataZip": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCard": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsKlarna": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsLink": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsPaypal": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsPayto": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsPix": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsSetupDetails": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsSetupDetailsBenefit": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentConfirmParamsSetupDetailsBenefitFrMealVoucher": (
        "stripe.params._setup_intent_confirm_params",
        False,
    ),
    "SetupIntentCreateParams": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsAutomaticPaymentMethods": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsMandateData": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsMandateDataCustomerAcceptance": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsMandateDataCustomerAcceptanceOffline": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsMandateDataCustomerAcceptanceOnline": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodData": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAcssDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAffirm": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAlipay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAlma": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAmazonPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBacsDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBancontact": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBillie": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBillingDetails": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBlik": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataBoleto": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataCashapp": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataCrypto": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataEps": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataFpx": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataGiropay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataGopay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataGrabpay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataIdeal": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataInteracPresent": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataKakaoPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataKlarna": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataKonbini": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataKrCard": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataLink": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataMbWay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataMobilepay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataMultibanco": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataNaverPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataOxxo": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataP24": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPayByBank": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPayco": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPaynow": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPaypal": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPaypay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPayto": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPix": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataPromptpay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataQris": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataRadarOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataRechnung": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataRechnungDob": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataRevolutPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataSamsungPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataSatispay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataSepaDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataShopeepay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataSofort": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataStripeBalance": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataSwish": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataTwint": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataWechatPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodDataZip": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCard": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsKlarna": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsLink": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsPaypal": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsPayto": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsPix": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsSetupDetails": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsSetupDetailsBenefit": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsSetupDetailsBenefitFrMealVoucher": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentCreateParamsSingleUse": (
        "stripe.params._setup_intent_create_params",
        False,
    ),
    "SetupIntentListParams": (
        "stripe.params._setup_intent_list_params",
        False,
    ),
    "SetupIntentListParamsCreated": (
        "stripe.params._setup_intent_list_params",
        False,
    ),
    "SetupIntentModifyParams": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodData": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAcssDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAffirm": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAlipay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAlma": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAmazonPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBacsDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBancontact": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBillie": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBillingDetails": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBlik": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataBoleto": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataCashapp": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataCrypto": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataEps": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataFpx": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataGiropay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataGopay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataGrabpay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataIdeal": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataInteracPresent": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataKakaoPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataKlarna": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataKonbini": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataKrCard": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataLink": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataMbWay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataMobilepay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataMultibanco": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataNaverPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataOxxo": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataP24": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPayByBank": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPayco": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPaynow": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPaypal": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPaypay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPayto": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPix": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataPromptpay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataQris": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataRadarOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataRechnung": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataRechnungDob": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataRevolutPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataSamsungPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataSatispay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataSepaDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataShopeepay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataSofort": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataStripeBalance": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataSwish": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataTwint": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataWechatPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodDataZip": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCard": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsKlarna": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsLink": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsPaypal": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsPayto": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsPix": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsSetupDetails": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsSetupDetailsBenefit": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentModifyParamsSetupDetailsBenefitFrMealVoucher": (
        "stripe.params._setup_intent_modify_params",
        False,
    ),
    "SetupIntentRetrieveParams": (
        "stripe.params._setup_intent_retrieve_params",
        False,
    ),
    "SetupIntentUpdateParams": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodData": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAcssDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAffirm": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAfterpayClearpay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAlipay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAlma": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAmazonPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataAuBecsDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBacsDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBancontact": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBillie": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBillingDetails": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBillingDetailsAddress": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBlik": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataBoleto": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataCashapp": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataCrypto": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataCustomerBalance": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataEps": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataFpx": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataGiropay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataGopay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataGrabpay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataIdBankTransfer": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataIdeal": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataInteracPresent": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataKakaoPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataKlarna": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataKlarnaDob": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataKonbini": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataKrCard": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataLink": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataMbWay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataMobilepay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataMultibanco": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataNaverPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataNzBankAccount": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataOxxo": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataP24": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPayByBank": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPayco": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPaynow": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPaypal": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPaypay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPayto": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPix": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataPromptpay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataQris": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataRadarOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataRechnung": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataRechnungDob": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataRevolutPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataSamsungPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataSatispay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataSepaDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataShopeepay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataSofort": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataStripeBalance": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataSwish": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataTwint": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataUsBankAccount": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataWechatPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodDataZip": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCard": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCardPresent": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecure": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsCardThreeDSecureNetworkOptionsCartesBancaires": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsKlarna": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsKlarnaOnDemand": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsLink": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsPaypal": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsPayto": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsPix": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountFinancialConnectionsManualEntry": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountMandateOptions": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsPaymentMethodOptionsUsBankAccountNetworks": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsSetupDetails": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsSetupDetailsBenefit": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentUpdateParamsSetupDetailsBenefitFrMealVoucher": (
        "stripe.params._setup_intent_update_params",
        False,
    ),
    "SetupIntentVerifyMicrodepositsParams": (
        "stripe.params._setup_intent_verify_microdeposits_params",
        False,
    ),
    "ShippingRateCreateParams": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateCreateParamsDeliveryEstimate": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateCreateParamsDeliveryEstimateMaximum": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateCreateParamsDeliveryEstimateMinimum": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateCreateParamsFixedAmount": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateCreateParamsFixedAmountCurrencyOptions": (
        "stripe.params._shipping_rate_create_params",
        False,
    ),
    "ShippingRateListParams": (
        "stripe.params._shipping_rate_list_params",
        False,
    ),
    "ShippingRateListParamsCreated": (
        "stripe.params._shipping_rate_list_params",
        False,
    ),
    "ShippingRateModifyParams": (
        "stripe.params._shipping_rate_modify_params",
        False,
    ),
    "ShippingRateModifyParamsFixedAmount": (
        "stripe.params._shipping_rate_modify_params",
        False,
    ),
    "ShippingRateModifyParamsFixedAmountCurrencyOptions": (
        "stripe.params._shipping_rate_modify_params",
        False,
    ),
    "ShippingRateRetrieveParams": (
        "stripe.params._shipping_rate_retrieve_params",
        False,
    ),
    "ShippingRateUpdateParams": (
        "stripe.params._shipping_rate_update_params",
        False,
    ),
    "ShippingRateUpdateParamsFixedAmount": (
        "stripe.params._shipping_rate_update_params",
        False,
    ),
    "ShippingRateUpdateParamsFixedAmountCurrencyOptions": (
        "stripe.params._shipping_rate_update_params",
        False,
    ),
    "SourceCreateParams": ("stripe.params._source_create_params", False),
    "SourceCreateParamsMandate": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsMandateAcceptance": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsMandateAcceptanceOffline": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsMandateAcceptanceOnline": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsOwner": ("stripe.params._source_create_params", False),
    "SourceCreateParamsOwnerAddress": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsReceiver": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsRedirect": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsSourceOrder": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsSourceOrderItem": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsSourceOrderShipping": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceCreateParamsSourceOrderShippingAddress": (
        "stripe.params._source_create_params",
        False,
    ),
    "SourceDetachParams": ("stripe.params._source_detach_params", False),
    "SourceListSourceTransactionsParams": (
        "stripe.params._source_list_source_transactions_params",
        False,
    ),
    "SourceModifyParams": ("stripe.params._source_modify_params", False),
    "SourceModifyParamsMandate": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsMandateAcceptance": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsMandateAcceptanceOffline": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsMandateAcceptanceOnline": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsOwner": ("stripe.params._source_modify_params", False),
    "SourceModifyParamsOwnerAddress": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsSourceOrder": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsSourceOrderItem": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsSourceOrderShipping": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceModifyParamsSourceOrderShippingAddress": (
        "stripe.params._source_modify_params",
        False,
    ),
    "SourceRetrieveParams": ("stripe.params._source_retrieve_params", False),
    "SourceTransactionListParams": (
        "stripe.params._source_transaction_list_params",
        False,
    ),
    "SourceUpdateParams": ("stripe.params._source_update_params", False),
    "SourceUpdateParamsMandate": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsMandateAcceptance": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsMandateAcceptanceOffline": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsMandateAcceptanceOnline": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsOwner": ("stripe.params._source_update_params", False),
    "SourceUpdateParamsOwnerAddress": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsSourceOrder": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsSourceOrderItem": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsSourceOrderShipping": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceUpdateParamsSourceOrderShippingAddress": (
        "stripe.params._source_update_params",
        False,
    ),
    "SourceVerifyParams": ("stripe.params._source_verify_params", False),
    "SubscriptionAttachCadenceParams": (
        "stripe.params._subscription_attach_cadence_params",
        False,
    ),
    "SubscriptionCancelParams": (
        "stripe.params._subscription_cancel_params",
        False,
    ),
    "SubscriptionCancelParamsCancellationDetails": (
        "stripe.params._subscription_cancel_params",
        False,
    ),
    "SubscriptionCreateParams": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItem": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemDiscount": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemPeriod": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAddInvoiceItemPriceData": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAutomaticTax": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsAutomaticTaxLiability": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingCycleAnchorConfig": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingMode": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingModeFlexible": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingSchedule": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsBillingThresholds": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsDiscount": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsDiscountDiscountEnd": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsInvoiceSettings": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsInvoiceSettingsIssuer": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItem": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemBillingThresholds": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemDiscount": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemDiscountDiscountEnd": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemPriceData": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemPriceDataRecurring": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsItemTrial": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettings": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPendingInvoiceItemInterval": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsPrebilling": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsTransferData": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsTrialSettings": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionCreateParamsTrialSettingsEndBehavior": (
        "stripe.params._subscription_create_params",
        False,
    ),
    "SubscriptionDeleteDiscountParams": (
        "stripe.params._subscription_delete_discount_params",
        False,
    ),
    "SubscriptionItemCreateParams": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsBillingThresholds": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsDiscount": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsDiscountDiscountEnd": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsPriceData": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsPriceDataRecurring": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemCreateParamsTrial": (
        "stripe.params._subscription_item_create_params",
        False,
    ),
    "SubscriptionItemDeleteParams": (
        "stripe.params._subscription_item_delete_params",
        False,
    ),
    "SubscriptionItemListParams": (
        "stripe.params._subscription_item_list_params",
        False,
    ),
    "SubscriptionItemModifyParams": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsBillingThresholds": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsDiscount": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsDiscountDiscountEnd": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsPriceData": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemModifyParamsPriceDataRecurring": (
        "stripe.params._subscription_item_modify_params",
        False,
    ),
    "SubscriptionItemRetrieveParams": (
        "stripe.params._subscription_item_retrieve_params",
        False,
    ),
    "SubscriptionItemUpdateParams": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsBillingThresholds": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsDiscount": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsDiscountDiscountEnd": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsPriceData": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionItemUpdateParamsPriceDataRecurring": (
        "stripe.params._subscription_item_update_params",
        False,
    ),
    "SubscriptionListParams": (
        "stripe.params._subscription_list_params",
        False,
    ),
    "SubscriptionListParamsAutomaticTax": (
        "stripe.params._subscription_list_params",
        False,
    ),
    "SubscriptionListParamsCreated": (
        "stripe.params._subscription_list_params",
        False,
    ),
    "SubscriptionListParamsCurrentPeriodEnd": (
        "stripe.params._subscription_list_params",
        False,
    ),
    "SubscriptionListParamsCurrentPeriodStart": (
        "stripe.params._subscription_list_params",
        False,
    ),
    "SubscriptionMigrateParams": (
        "stripe.params._subscription_migrate_params",
        False,
    ),
    "SubscriptionMigrateParamsBillingMode": (
        "stripe.params._subscription_migrate_params",
        False,
    ),
    "SubscriptionMigrateParamsBillingModeFlexible": (
        "stripe.params._subscription_migrate_params",
        False,
    ),
    "SubscriptionModifyParams": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItem": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemDiscount": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemPeriod": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAddInvoiceItemPriceData": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAutomaticTax": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsAutomaticTaxLiability": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsBillingSchedule": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsBillingThresholds": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsCancellationDetails": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsDiscount": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsDiscountDiscountEnd": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsInvoiceSettings": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsInvoiceSettingsIssuer": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItem": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemBillingThresholds": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemDiscount": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemDiscountDiscountEnd": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemPriceData": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsItemPriceDataRecurring": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPauseCollection": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettings": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPendingInvoiceItemInterval": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsPrebilling": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsTransferData": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsTrialSettings": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionModifyParamsTrialSettingsEndBehavior": (
        "stripe.params._subscription_modify_params",
        False,
    ),
    "SubscriptionResumeParams": (
        "stripe.params._subscription_resume_params",
        False,
    ),
    "SubscriptionRetrieveParams": (
        "stripe.params._subscription_retrieve_params",
        False,
    ),
    "SubscriptionScheduleAmendParams": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendment": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentEndDiscountEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentEndDuration": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentStart": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentStartAmendmentEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentAmendmentStartDiscountEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentBillingSchedulesAction": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentBillingSchedulesActionAppliesTo": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentDiscountAction": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentDiscountActionAdd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentDiscountActionAddDiscountEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentDiscountActionRemove": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentDiscountActionSet": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemAction": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionAdd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscount": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionAddDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionAddTrial": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionRemove": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionSet": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscount": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionSetDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentItemActionSetTrial": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentMetadataAction": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentSetPauseCollection": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentSetPauseCollectionSet": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentTrialSettings": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsAmendmentTrialSettingsEndBehavior": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebilling": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebillingBillFrom": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebillingBillFromAmendmentStart": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebillingBillUntil": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebillingBillUntilAmendmentEnd": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsPrebillingBillUntilDuration": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleAmendParamsScheduleSettings": (
        "stripe.params._subscription_schedule_amend_params",
        False,
    ),
    "SubscriptionScheduleCancelParams": (
        "stripe.params._subscription_schedule_cancel_params",
        False,
    ),
    "SubscriptionScheduleCreateParams": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingMode": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingModeFlexible": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingSchedule": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettings": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTax": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsBillingThresholds": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettings": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsDefaultSettingsTransferData": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhase": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItem": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscount": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriod": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAddInvoiceItemPriceData": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAutomaticTax": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseBillingThresholds": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseDiscount": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseDuration": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseInvoiceSettings": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItem": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemBillingThresholds": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemDiscount": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemPriceData": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemPriceDataRecurring": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseItemTrial": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhasePauseCollection": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseTransferData": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseTrialSettings": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPhaseTrialSettingsEndBehavior": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleCreateParamsPrebilling": (
        "stripe.params._subscription_schedule_create_params",
        False,
    ),
    "SubscriptionScheduleListParams": (
        "stripe.params._subscription_schedule_list_params",
        False,
    ),
    "SubscriptionScheduleListParamsCanceledAt": (
        "stripe.params._subscription_schedule_list_params",
        False,
    ),
    "SubscriptionScheduleListParamsCompletedAt": (
        "stripe.params._subscription_schedule_list_params",
        False,
    ),
    "SubscriptionScheduleListParamsCreated": (
        "stripe.params._subscription_schedule_list_params",
        False,
    ),
    "SubscriptionScheduleListParamsReleasedAt": (
        "stripe.params._subscription_schedule_list_params",
        False,
    ),
    "SubscriptionScheduleModifyParams": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsBillingSchedule": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettings": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTax": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsBillingThresholds": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettings": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsDefaultSettingsTransferData": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhase": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItem": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscount": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriod": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAddInvoiceItemPriceData": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAutomaticTax": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseBillingThresholds": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseDiscount": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseDuration": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseInvoiceSettings": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItem": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemBillingThresholds": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemDiscount": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemPriceData": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemPriceDataRecurring": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseItemTrial": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhasePauseCollection": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseTransferData": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseTrialSettings": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPhaseTrialSettingsEndBehavior": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleModifyParamsPrebilling": (
        "stripe.params._subscription_schedule_modify_params",
        False,
    ),
    "SubscriptionScheduleReleaseParams": (
        "stripe.params._subscription_schedule_release_params",
        False,
    ),
    "SubscriptionScheduleRetrieveParams": (
        "stripe.params._subscription_schedule_retrieve_params",
        False,
    ),
    "SubscriptionScheduleUpdateParams": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsBillingSchedule": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettings": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTax": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsBillingThresholds": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettings": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsDefaultSettingsTransferData": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhase": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItem": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscount": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriod": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAddInvoiceItemPriceData": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAutomaticTax": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseAutomaticTaxLiability": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseBillingThresholds": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseDiscount": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseDuration": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseInvoiceSettings": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseInvoiceSettingsIssuer": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItem": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemBillingThresholds": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemDiscount": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEnd": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemPriceData": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemPriceDataRecurring": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseItemTrial": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhasePauseCollection": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseTransferData": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseTrialSettings": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPhaseTrialSettingsEndBehavior": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionScheduleUpdateParamsPrebilling": (
        "stripe.params._subscription_schedule_update_params",
        False,
    ),
    "SubscriptionSearchParams": (
        "stripe.params._subscription_search_params",
        False,
    ),
    "SubscriptionUpdateParams": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItem": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemDiscount": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEnd": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemPeriod": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemPeriodEnd": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemPeriodStart": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAddInvoiceItemPriceData": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAutomaticTax": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsAutomaticTaxLiability": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsBillingSchedule": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsBillingScheduleAppliesTo": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsBillingScheduleBillUntil": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsBillingScheduleBillUntilDuration": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsBillingThresholds": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsCancellationDetails": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsDiscount": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsDiscountDiscountEnd": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsDiscountDiscountEndDuration": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsInvoiceSettings": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsInvoiceSettingsIssuer": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItem": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemBillingThresholds": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemDiscount": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemDiscountDiscountEnd": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemDiscountDiscountEndDuration": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemPriceData": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsItemPriceDataRecurring": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPauseCollection": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettings": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptions": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebit": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsBancontact": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCard": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCardMandateOptions": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalance": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsIdBankTransfer": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsKonbini": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPix": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsSepaDebit": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpi": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUpiMandateOptions": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccount": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPaymentSettingsPaymentMethodOptionsUsBankAccountFinancialConnectionsFilters": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPendingInvoiceItemInterval": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsPrebilling": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsTransferData": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsTrialSettings": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "SubscriptionUpdateParamsTrialSettingsEndBehavior": (
        "stripe.params._subscription_update_params",
        False,
    ),
    "TaxCodeListParams": ("stripe.params._tax_code_list_params", False),
    "TaxCodeRetrieveParams": (
        "stripe.params._tax_code_retrieve_params",
        False,
    ),
    "TaxIdCreateParams": ("stripe.params._tax_id_create_params", False),
    "TaxIdCreateParamsOwner": ("stripe.params._tax_id_create_params", False),
    "TaxIdDeleteParams": ("stripe.params._tax_id_delete_params", False),
    "TaxIdListParams": ("stripe.params._tax_id_list_params", False),
    "TaxIdListParamsOwner": ("stripe.params._tax_id_list_params", False),
    "TaxIdRetrieveParams": ("stripe.params._tax_id_retrieve_params", False),
    "TaxRateCreateParams": ("stripe.params._tax_rate_create_params", False),
    "TaxRateListParams": ("stripe.params._tax_rate_list_params", False),
    "TaxRateListParamsCreated": ("stripe.params._tax_rate_list_params", False),
    "TaxRateModifyParams": ("stripe.params._tax_rate_modify_params", False),
    "TaxRateRetrieveParams": (
        "stripe.params._tax_rate_retrieve_params",
        False,
    ),
    "TaxRateUpdateParams": ("stripe.params._tax_rate_update_params", False),
    "TokenCreateParams": ("stripe.params._token_create_params", False),
    "TokenCreateParamsAccount": ("stripe.params._token_create_params", False),
    "TokenCreateParamsAccountCompany": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyAddress": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyAddressKana": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyAddressKanji": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyDirectorshipDeclaration": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyOwnershipDeclaration": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyRegistrationDate": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyRepresentativeDeclaration": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyVerification": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountCompanyVerificationDocument": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividual": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualAddress": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualAddressKana": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualAddressKanji": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualDob": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualRegisteredAddress": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualRelationship": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualSelfReportedIncome": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualSelfReportedMonthlyHousingPayment": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualVerification": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualVerificationAdditionalDocument": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsAccountIndividualVerificationDocument": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsBankAccount": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsCard": ("stripe.params._token_create_params", False),
    "TokenCreateParamsCardNetworks": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsCvcUpdate": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPerson": ("stripe.params._token_create_params", False),
    "TokenCreateParamsPersonAdditionalTosAcceptances": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonAdditionalTosAcceptancesAccount": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonAddress": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonAddressKana": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonAddressKanji": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonDob": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonDocuments": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonDocumentsCompanyAuthorization": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonDocumentsPassport": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonDocumentsVisa": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonRegisteredAddress": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonRelationship": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonSelfReportedIncome": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonSelfReportedMonthlyHousingPayment": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonUsCfpbData": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonUsCfpbDataEthnicityDetails": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonUsCfpbDataRaceDetails": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonVerification": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonVerificationAdditionalDocument": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPersonVerificationDocument": (
        "stripe.params._token_create_params",
        False,
    ),
    "TokenCreateParamsPii": ("stripe.params._token_create_params", False),
    "TokenRetrieveParams": ("stripe.params._token_retrieve_params", False),
    "TopupCancelParams": ("stripe.params._topup_cancel_params", False),
    "TopupCreateParams": ("stripe.params._topup_create_params", False),
    "TopupListParams": ("stripe.params._topup_list_params", False),
    "TopupListParamsAmount": ("stripe.params._topup_list_params", False),
    "TopupListParamsCreated": ("stripe.params._topup_list_params", False),
    "TopupModifyParams": ("stripe.params._topup_modify_params", False),
    "TopupRetrieveParams": ("stripe.params._topup_retrieve_params", False),
    "TopupUpdateParams": ("stripe.params._topup_update_params", False),
    "TransferCreateParams": ("stripe.params._transfer_create_params", False),
    "TransferCreateReversalParams": (
        "stripe.params._transfer_create_reversal_params",
        False,
    ),
    "TransferListParams": ("stripe.params._transfer_list_params", False),
    "TransferListParamsCreated": (
        "stripe.params._transfer_list_params",
        False,
    ),
    "TransferListReversalsParams": (
        "stripe.params._transfer_list_reversals_params",
        False,
    ),
    "TransferModifyParams": ("stripe.params._transfer_modify_params", False),
    "TransferModifyReversalParams": (
        "stripe.params._transfer_modify_reversal_params",
        False,
    ),
    "TransferRetrieveParams": (
        "stripe.params._transfer_retrieve_params",
        False,
    ),
    "TransferRetrieveReversalParams": (
        "stripe.params._transfer_retrieve_reversal_params",
        False,
    ),
    "TransferReversalCreateParams": (
        "stripe.params._transfer_reversal_create_params",
        False,
    ),
    "TransferReversalListParams": (
        "stripe.params._transfer_reversal_list_params",
        False,
    ),
    "TransferReversalRetrieveParams": (
        "stripe.params._transfer_reversal_retrieve_params",
        False,
    ),
    "TransferReversalUpdateParams": (
        "stripe.params._transfer_reversal_update_params",
        False,
    ),
    "TransferUpdateParams": ("stripe.params._transfer_update_params", False),
    "WebhookEndpointCreateParams": (
        "stripe.params._webhook_endpoint_create_params",
        False,
    ),
    "WebhookEndpointDeleteParams": (
        "stripe.params._webhook_endpoint_delete_params",
        False,
    ),
    "WebhookEndpointListParams": (
        "stripe.params._webhook_endpoint_list_params",
        False,
    ),
    "WebhookEndpointModifyParams": (
        "stripe.params._webhook_endpoint_modify_params",
        False,
    ),
    "WebhookEndpointRetrieveParams": (
        "stripe.params._webhook_endpoint_retrieve_params",
        False,
    ),
    "WebhookEndpointUpdateParams": (
        "stripe.params._webhook_endpoint_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()
